(*#line 175.10 "urweb.mlton.lex"*)functor UrwebLexFn(structure Tokens : Urweb_TOKENS)(*#line 1.1 "urweb.mlton.lex.sml"*)
=
   struct
    structure UserDeclarations =
      struct
(*#line 1.1 "urweb.mlton.lex"*)(* -*- mode: sml-lex -*- *)

(* Copyright (c) 2008-2009, Adam Chlipala
 * All rights reserved.
 *
 * Redistribution and use in source and binary forms, with or without
 * modification, are permitted provided that the following conditions are met:
 *
 * - Redistributions of source code must retain the above copyright notice,
 *   this list of conditions and the following disclaimer.
 * - Redistributions in binary form must reproduce the above copyright notice,
 *   this list of conditions and the following disclaimer in the documentation
 *   and/or other materials provided with the distribution.
 * - The names of contributors may not be used to endorse or promote products
 *   derived from this software without specific prior written permission.
 *
 * THIS SOFTWARE IS PROVIDED BY THE COPYRIGHT HOLDERS AND CONTRIBUTORS "AS IS"
 * AND ANY EXPRESS OR IMPLIED WARRANTIES, INCLUDING, BUT NOT LIMITED TO, THE
 * IMPLIED WARRANTIES OF MERCHANTABILITY AND FITNESS FOR A PARTICULAR PURPOSE
 * ARE DISCLAIMED. IN NO EVENT SHALL THE COPYRIGHT OWNER OR CONTRIBUTORS BE
 * LIABLE FOR ANY DIRECT, INDIRECT, INCIDENTAL, SPECIAL, EXEMPLARY, OR
 * CONSEQUENTIAL DAMAGES (INCLUDING, BUT NOT LIMITED TO, PROCUREMENT OF
 * SUBSTITUTE GOODS OR SERVICES; LOSS OF USE, DATA, OR PROFITS; OR BUSINESS
 * INTERRUPTION) HOWEVER CAUSED AND ON ANY THEORY OF LIABILITY, WHETHER IN
 * CONTRACT, STRICT LIABILITY, OR TORT (INCLUDING NEGLIGENCE OR OTHERWISE)
 * ARISING IN ANY WAY OUT OF THE USE OF THIS SOFTWARE, EVEN IF ADVISED OF THE
 * POSSIBILITY OF SUCH DAMAGE.
 *)

(* Lexing info for Ur/Web programs *)

type pos = int
type svalue = Tokens.svalue
type ('a,'b) token = ('a,'b) Tokens.token
type lexresult = (svalue,pos) Tokens.token

val commentOut = ref (fn () => ())

local
  val commentLevel = ref 0
  val commentPos = ref 0
in
  fun reset () =
      (commentLevel := 0;
       commentPos := 0)

  fun enterComment pos =
      (if !commentLevel = 0 then
           commentPos := pos
       else
           ();
       commentLevel := !commentLevel + 1)

  fun exitComment () =
      (ignore (commentLevel := !commentLevel - 1);
       if !commentLevel = 0 then
           !commentOut ()
       else
           ())

  fun eof () =
    let
      val pos = ErrorMsg.lastLineStart ()
    in
      if !commentLevel > 0 then
          ErrorMsg.errorAt' (!commentPos, !commentPos) "Unterminated comment"
      else
          ();
      Tokens.EOF (pos, pos)
    end
end

val strEnder = ref #"\""
val str = ref ([] : char list)
val strStart = ref 0

local
    val initSig = ref false
    val offset = ref 0
in

fun initialSig () = initSig := true

fun pos yypos = yypos - !offset

fun newline yypos =
    if !initSig then
        (initSig := false;
         offset := yypos + 1)
    else
        ErrorMsg.newline (pos yypos)

end

val xmlTag = ref ([] : string list)
val xmlString = ref true
val braceLevels = ref ([] : ((unit -> unit) * int) list)

fun pushLevel s = braceLevels := (s, 1) :: (!braceLevels)

fun enterBrace () =
    case !braceLevels of
	(s, i) :: rest => braceLevels := (s, i+1) :: rest
      | _ => ()

fun exitBrace () =
    case !braceLevels of
	(s, i) :: rest =>
	if i = 1 then
	    (braceLevels := rest;
	     s ())
	else
	    braceLevels := (s, i-1) :: rest
      | _ => ()

fun initialize () = (reset ();
                     xmlTag := [];
		     xmlString := false)


structure StringMap = BinaryMapFn(struct
                                  type ord_key = string
                                  val compare = String.compare
                                  end)

val entities = foldl (fn ((key, value), entities) => StringMap.insert (entities, key, value))
                     StringMap.empty Entities.all

fun unescape loc s =
    let
        fun process (s, acc) =
            let
                val (befor, after) = Substring.splitl (fn ch => ch <> #"&") s
            in
                if Substring.size after = 0 then
                    Substring.concat (rev (s :: acc))
                else
                    let
                        val after = Substring.slice (after, 1, NONE)
                        val (befor', after') = Substring.splitl (fn ch => ch <> #";") after
                    in
                        if Substring.size after' = 0 then
                            (ErrorMsg.errorAt' loc "Missing ';' after '&'";
                             "")
                        else
                            let
                                val pre = befor
                                val code = befor'
                                val s = Substring.slice (after', 1, NONE)

                                val special =
                                    if Substring.size code > 0 andalso Substring.sub (code, 0) = #"#"
                                       andalso CharVectorSlice.all Char.isDigit (Substring.slice (code, 1, NONE)) then
                                        let
                                            val code = Substring.string (Substring.slice (code, 1, NONE))
                                        in
                                            Option.map Utf8.encode (Int.fromString code)
                                        end
                                    else
                                        Option.map Utf8.encode (StringMap.find (entities, Substring.string code))
                            in
                                case special of
                                    NONE => (ErrorMsg.errorAt' loc ("Unsupported XML character entity "
                                                                        ^ Substring.string code);
                                             "")
                                  | SOME sp => process (s, Substring.full sp :: pre :: acc)
                            end
                    end
            end
    in
        process (Substring.full s, [])
    end

(*#line 179.1 "urweb.mlton.lex.sml"*)
end (* end of user routines *)
exception LexError (* raised if illegal leaf action tried *)
structure Internal =
	struct

datatype yyfinstate = N of int
type statedata = {fin : yyfinstate list, trans: int Vector.vector}
(* transition & final state table *)
val tab = let
fun decode s k =
  let val k' = k + k
      val hi = Char.ord(String.sub(s, k'))
      val lo = Char.ord(String.sub(s, k' + 1))
  in hi * 256 + lo end
val s = [ 
 (0,256, 
"\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\
\\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\
\\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\
\\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\
\\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\
\\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\
\\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\
\\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\
\\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\
\\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\
\\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\
\\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\
\\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\
\\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\
\\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\
\\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\
\\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\
\\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\
\\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\
\\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\
\\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\
\\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\
\\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\
\\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\
\\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\
\\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\
\\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\
\\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\
\\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\
\\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\
\\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\
\\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000"
),
 (1,256, 
"\000\013\000\013\000\013\000\013\000\013\000\013\000\013\000\013\
\\000\013\001\249\001\251\000\013\001\249\001\249\000\013\000\013\
\\000\013\000\013\000\013\000\013\000\013\000\013\000\013\000\013\
\\000\013\000\013\000\013\000\013\000\013\000\013\000\013\000\013\
\\001\249\001\248\001\247\001\245\001\244\001\243\001\241\001\240\
\\001\237\001\236\001\234\001\232\001\231\001\226\001\223\001\222\
\\001\219\001\216\001\216\001\216\001\216\001\216\001\216\001\216\
\\001\216\001\216\001\211\001\210\001\199\001\195\001\191\000\013\
\\001\190\001\176\001\174\001\125\001\110\001\101\001\084\001\079\
\\001\073\001\054\001\050\001\047\001\037\001\032\001\023\001\005\
\\000\246\000\169\000\220\000\208\000\198\000\182\000\176\000\171\
\\000\169\000\169\000\169\000\168\000\013\000\167\000\166\000\160\
\\000\155\000\152\000\020\000\130\000\122\000\111\000\101\000\020\
\\000\020\000\093\000\020\000\020\000\090\000\087\000\020\000\082\
\\000\076\000\020\000\073\000\046\000\033\000\020\000\027\000\022\
\\000\020\000\020\000\020\000\019\000\016\000\015\000\014\000\013\
\\000\013\000\013\000\013\000\013\000\013\000\013\000\013\000\013\
\\000\013\000\013\000\013\000\013\000\013\000\013\000\013\000\013\
\\000\013\000\013\000\013\000\013\000\013\000\013\000\013\000\013\
\\000\013\000\013\000\013\000\013\000\013\000\013\000\013\000\013\
\\000\013\000\013\000\013\000\013\000\013\000\013\000\013\000\013\
\\000\013\000\013\000\013\000\013\000\013\000\013\000\013\000\013\
\\000\013\000\013\000\013\000\013\000\013\000\013\000\013\000\013\
\\000\013\000\013\000\013\000\013\000\013\000\013\000\013\000\013\
\\000\013\000\013\000\013\000\013\000\013\000\013\000\013\000\013\
\\000\013\000\013\000\013\000\013\000\013\000\013\000\013\000\013\
\\000\013\000\013\000\013\000\013\000\013\000\013\000\013\000\013\
\\000\013\000\013\000\013\000\013\000\013\000\013\000\013\000\013\
\\000\013\000\013\000\013\000\013\000\013\000\013\000\013\000\013\
\\000\013\000\013\000\013\000\013\000\013\000\013\000\013\000\013\
\\000\013\000\013\000\013\000\013\000\013\000\013\000\013\000\013\
\\000\013\000\013\000\013\000\013\000\013\000\013\000\013\000\013"
),
 (3,256, 
"\001\252\001\252\001\252\001\252\001\252\001\252\001\252\001\252\
\\001\252\001\252\001\251\001\252\001\252\001\252\001\252\001\252\
\\001\252\001\252\001\252\001\252\001\252\001\252\001\252\001\252\
\\001\252\001\252\001\252\001\252\001\252\001\252\001\252\001\252\
\\001\252\001\252\001\252\001\252\001\252\001\252\001\252\001\252\
\\001\255\001\252\001\253\001\252\001\252\001\252\001\252\001\252\
\\001\252\001\252\001\252\001\252\001\252\001\252\001\252\001\252\
\\001\252\001\252\001\252\001\252\001\252\001\252\001\252\001\252\
\\001\252\001\252\001\252\001\252\001\252\001\252\001\252\001\252\
\\001\252\001\252\001\252\001\252\001\252\001\252\001\252\001\252\
\\001\252\001\252\001\252\001\252\001\252\001\252\001\252\001\252\
\\001\252\001\252\001\252\001\252\001\252\001\252\001\252\001\252\
\\001\252\001\252\001\252\001\252\001\252\001\252\001\252\001\252\
\\001\252\001\252\001\252\001\252\001\252\001\252\001\252\001\252\
\\001\252\001\252\001\252\001\252\001\252\001\252\001\252\001\252\
\\001\252\001\252\001\252\001\252\001\252\001\252\001\252\001\252\
\\001\252\001\252\001\252\001\252\001\252\001\252\001\252\001\252\
\\001\252\001\252\001\252\001\252\001\252\001\252\001\252\001\252\
\\001\252\001\252\001\252\001\252\001\252\001\252\001\252\001\252\
\\001\252\001\252\001\252\001\252\001\252\001\252\001\252\001\252\
\\001\252\001\252\001\252\001\252\001\252\001\252\001\252\001\252\
\\001\252\001\252\001\252\001\252\001\252\001\252\001\252\001\252\
\\001\252\001\252\001\252\001\252\001\252\001\252\001\252\001\252\
\\001\252\001\252\001\252\001\252\001\252\001\252\001\252\001\252\
\\001\252\001\252\001\252\001\252\001\252\001\252\001\252\001\252\
\\001\252\001\252\001\252\001\252\001\252\001\252\001\252\001\252\
\\001\252\001\252\001\252\001\252\001\252\001\252\001\252\001\252\
\\001\252\001\252\001\252\001\252\001\252\001\252\001\252\001\252\
\\001\252\001\252\001\252\001\252\001\252\001\252\001\252\001\252\
\\001\252\001\252\001\252\001\252\001\252\001\252\001\252\001\252\
\\001\252\001\252\001\252\001\252\001\252\001\252\001\252\001\252\
\\001\252\001\252\001\252\001\252\001\252\001\252\001\252\001\252"
),
 (5,256, 
"\002\001\002\001\002\001\002\001\002\001\002\001\002\001\002\001\
\\002\001\002\001\002\015\002\001\002\001\002\001\002\001\002\001\
\\002\001\002\001\002\001\002\001\002\001\002\001\002\001\002\001\
\\002\001\002\001\002\001\002\001\002\001\002\001\002\001\002\001\
\\002\001\002\001\002\001\002\001\002\001\002\001\002\001\002\001\
\\002\001\002\001\002\001\002\001\002\001\002\001\002\001\002\001\
\\002\001\002\001\002\001\002\001\002\001\002\001\002\001\002\001\
\\002\001\002\001\002\001\002\001\002\001\002\001\002\001\002\001\
\\002\001\002\001\002\001\002\001\002\001\002\001\002\001\002\001\
\\002\001\002\001\002\001\002\001\002\001\002\001\002\001\002\001\
\\002\001\002\001\002\001\002\001\002\001\002\001\002\001\002\001\
\\002\001\002\001\002\001\002\001\002\002\002\001\002\001\002\001\
\\002\001\002\001\002\001\002\001\002\001\002\001\002\001\002\001\
\\002\001\002\001\002\001\002\001\002\001\002\001\002\001\002\001\
\\002\001\002\001\002\001\002\001\002\001\002\001\002\001\002\001\
\\002\001\002\001\002\001\002\001\002\001\002\001\002\001\002\001\
\\002\001\002\001\002\001\002\001\002\001\002\001\002\001\002\001\
\\002\001\002\001\002\001\002\001\002\001\002\001\002\001\002\001\
\\002\001\002\001\002\001\002\001\002\001\002\001\002\001\002\001\
\\002\001\002\001\002\001\002\001\002\001\002\001\002\001\002\001\
\\002\001\002\001\002\001\002\001\002\001\002\001\002\001\002\001\
\\002\001\002\001\002\001\002\001\002\001\002\001\002\001\002\001\
\\002\001\002\001\002\001\002\001\002\001\002\001\002\001\002\001\
\\002\001\002\001\002\001\002\001\002\001\002\001\002\001\002\001\
\\002\001\002\001\002\001\002\001\002\001\002\001\002\001\002\001\
\\002\001\002\001\002\001\002\001\002\001\002\001\002\001\002\001\
\\002\001\002\001\002\001\002\001\002\001\002\001\002\001\002\001\
\\002\001\002\001\002\001\002\001\002\001\002\001\002\001\002\001\
\\002\001\002\001\002\001\002\001\002\001\002\001\002\001\002\001\
\\002\001\002\001\002\001\002\001\002\001\002\001\002\001\002\001\
\\002\001\002\001\002\001\002\001\002\001\002\001\002\001\002\001\
\\002\001\002\001\002\001\002\001\002\001\002\001\002\001\002\001"
),
 (7,256, 
"\002\016\002\016\002\016\002\016\002\016\002\016\002\016\002\016\
\\002\016\002\016\002\015\002\016\002\016\002\016\002\016\002\016\
\\002\016\002\016\002\016\002\016\002\016\002\016\002\016\002\016\
\\002\016\002\016\002\016\002\016\002\016\002\016\002\016\002\016\
\\002\016\002\016\002\016\002\016\002\016\002\016\002\016\002\016\
\\002\016\002\016\002\016\002\016\002\016\002\016\002\016\002\016\
\\002\016\002\016\002\016\002\016\002\016\002\016\002\016\002\016\
\\002\016\002\016\002\016\002\016\002\016\002\016\002\016\002\016\
\\002\016\002\016\002\016\002\016\002\016\002\016\002\016\002\016\
\\002\016\002\016\002\016\002\016\002\016\002\016\002\016\002\016\
\\002\016\002\016\002\016\002\016\002\016\002\016\002\016\002\016\
\\002\016\002\016\002\016\002\016\002\017\002\016\002\016\002\016\
\\002\016\002\016\002\016\002\016\002\016\002\016\002\016\002\016\
\\002\016\002\016\002\016\002\016\002\016\002\016\002\016\002\016\
\\002\016\002\016\002\016\002\016\002\016\002\016\002\016\002\016\
\\002\016\002\016\002\016\002\016\002\016\002\016\002\016\002\016\
\\002\016\002\016\002\016\002\016\002\016\002\016\002\016\002\016\
\\002\016\002\016\002\016\002\016\002\016\002\016\002\016\002\016\
\\002\016\002\016\002\016\002\016\002\016\002\016\002\016\002\016\
\\002\016\002\016\002\016\002\016\002\016\002\016\002\016\002\016\
\\002\016\002\016\002\016\002\016\002\016\002\016\002\016\002\016\
\\002\016\002\016\002\016\002\016\002\016\002\016\002\016\002\016\
\\002\016\002\016\002\016\002\016\002\016\002\016\002\016\002\016\
\\002\016\002\016\002\016\002\016\002\016\002\016\002\016\002\016\
\\002\016\002\016\002\016\002\016\002\016\002\016\002\016\002\016\
\\002\016\002\016\002\016\002\016\002\016\002\016\002\016\002\016\
\\002\016\002\016\002\016\002\016\002\016\002\016\002\016\002\016\
\\002\016\002\016\002\016\002\016\002\016\002\016\002\016\002\016\
\\002\016\002\016\002\016\002\016\002\016\002\016\002\016\002\016\
\\002\016\002\016\002\016\002\016\002\016\002\016\002\016\002\016\
\\002\016\002\016\002\016\002\016\002\016\002\016\002\016\002\016\
\\002\016\002\016\002\016\002\016\002\016\002\016\002\016\002\016"
),
 (9,256, 
"\002\018\002\018\002\018\002\018\002\018\002\018\002\018\002\018\
\\002\018\002\018\002\039\002\018\002\018\002\018\002\018\002\018\
\\002\018\002\018\002\018\002\018\002\018\002\018\002\018\002\018\
\\002\018\002\018\002\018\002\018\002\018\002\018\002\018\002\018\
\\002\018\002\018\002\018\002\018\002\018\002\018\002\018\002\018\
\\002\037\002\018\002\035\002\018\002\018\002\018\002\018\002\018\
\\002\018\002\018\002\018\002\018\002\018\002\018\002\018\002\018\
\\002\018\002\018\002\018\002\018\002\022\002\018\002\018\002\018\
\\002\018\002\018\002\018\002\018\002\018\002\018\002\018\002\018\
\\002\018\002\018\002\018\002\018\002\018\002\018\002\018\002\018\
\\002\018\002\018\002\018\002\018\002\018\002\018\002\018\002\018\
\\002\018\002\018\002\018\002\018\002\018\002\018\002\018\002\018\
\\002\018\002\018\002\018\002\018\002\018\002\018\002\018\002\018\
\\002\018\002\018\002\018\002\018\002\018\002\018\002\018\002\018\
\\002\018\002\018\002\018\002\018\002\018\002\018\002\018\002\018\
\\002\018\002\018\002\018\002\021\002\018\002\018\002\018\002\018\
\\002\018\002\018\002\018\002\018\002\018\002\018\002\018\002\018\
\\002\018\002\018\002\018\002\018\002\018\002\018\002\018\002\018\
\\002\018\002\018\002\018\002\018\002\018\002\018\002\018\002\018\
\\002\018\002\018\002\018\002\018\002\018\002\018\002\018\002\018\
\\002\018\002\018\002\018\002\018\002\018\002\018\002\018\002\018\
\\002\018\002\018\002\018\002\018\002\018\002\018\002\018\002\018\
\\002\018\002\018\002\018\002\018\002\018\002\018\002\018\002\018\
\\002\018\002\018\002\018\002\018\002\018\002\018\002\018\002\018\
\\002\018\002\018\002\018\002\018\002\018\002\018\002\018\002\018\
\\002\018\002\018\002\018\002\018\002\018\002\018\002\018\002\018\
\\002\018\002\018\002\018\002\018\002\018\002\018\002\018\002\018\
\\002\018\002\018\002\018\002\018\002\018\002\018\002\018\002\018\
\\002\018\002\018\002\018\002\018\002\018\002\018\002\018\002\018\
\\002\018\002\018\002\018\002\018\002\018\002\018\002\018\002\018\
\\002\018\002\018\002\018\002\018\002\018\002\018\002\018\002\018\
\\002\018\002\018\002\018\002\018\002\018\002\018\002\018\002\018"
),
 (11,256, 
"\002\040\002\040\002\040\002\040\002\040\002\040\002\040\002\040\
\\002\040\002\054\001\251\002\040\002\054\002\054\002\040\002\040\
\\002\040\002\040\002\040\002\040\002\040\002\040\002\040\002\040\
\\002\040\002\040\002\040\002\040\002\040\002\040\002\040\002\040\
\\002\054\002\040\002\053\002\040\002\040\002\040\002\040\002\040\
\\002\051\002\040\002\050\002\040\002\040\002\040\002\040\002\049\
\\002\046\002\046\002\046\002\046\002\046\002\046\002\046\002\046\
\\002\046\002\046\002\040\002\040\002\040\002\045\002\044\002\040\
\\002\040\002\042\002\042\002\042\002\042\002\042\002\042\002\042\
\\002\042\002\042\002\042\002\042\002\042\002\042\002\042\002\042\
\\002\042\002\042\002\042\002\042\002\042\002\042\002\042\002\042\
\\002\042\002\042\002\042\002\040\002\040\002\040\002\040\002\040\
\\002\040\002\042\002\042\002\042\002\042\002\042\002\042\002\042\
\\002\042\002\042\002\042\002\042\002\042\002\042\002\042\002\042\
\\002\042\002\042\002\042\002\042\002\042\002\042\002\042\002\042\
\\002\042\002\042\002\042\002\041\002\040\002\040\002\040\002\040\
\\002\040\002\040\002\040\002\040\002\040\002\040\002\040\002\040\
\\002\040\002\040\002\040\002\040\002\040\002\040\002\040\002\040\
\\002\040\002\040\002\040\002\040\002\040\002\040\002\040\002\040\
\\002\040\002\040\002\040\002\040\002\040\002\040\002\040\002\040\
\\002\040\002\040\002\040\002\040\002\040\002\040\002\040\002\040\
\\002\040\002\040\002\040\002\040\002\040\002\040\002\040\002\040\
\\002\040\002\040\002\040\002\040\002\040\002\040\002\040\002\040\
\\002\040\002\040\002\040\002\040\002\040\002\040\002\040\002\040\
\\002\040\002\040\002\040\002\040\002\040\002\040\002\040\002\040\
\\002\040\002\040\002\040\002\040\002\040\002\040\002\040\002\040\
\\002\040\002\040\002\040\002\040\002\040\002\040\002\040\002\040\
\\002\040\002\040\002\040\002\040\002\040\002\040\002\040\002\040\
\\002\040\002\040\002\040\002\040\002\040\002\040\002\040\002\040\
\\002\040\002\040\002\040\002\040\002\040\002\040\002\040\002\040\
\\002\040\002\040\002\040\002\040\002\040\002\040\002\040\002\040\
\\002\040\002\040\002\040\002\040\002\040\002\040\002\040\002\040"
),
 (16,256, 
"\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\
\\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\
\\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\
\\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\
\\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\
\\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\
\\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\
\\000\000\000\000\000\000\000\000\000\000\000\000\000\018\000\000\
\\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\
\\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\
\\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\
\\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\
\\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\
\\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\
\\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\
\\000\000\000\000\000\000\000\000\000\017\000\000\000\000\000\000\
\\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\
\\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\
\\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\
\\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\
\\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\
\\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\
\\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\
\\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\
\\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\
\\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\
\\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\
\\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\
\\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\
\\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\
\\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\
\\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000"
),
 (20,256, 
"\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\
\\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\
\\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\
\\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\
\\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\021\
\\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\
\\000\021\000\021\000\021\000\021\000\021\000\021\000\021\000\021\
\\000\021\000\021\000\000\000\000\000\000\000\000\000\000\000\000\
\\000\000\000\021\000\021\000\021\000\021\000\021\000\021\000\021\
\\000\021\000\021\000\021\000\021\000\021\000\021\000\021\000\021\
\\000\021\000\021\000\021\000\021\000\021\000\021\000\021\000\021\
\\000\021\000\021\000\021\000\000\000\000\000\000\000\000\000\021\
\\000\000\000\021\000\021\000\021\000\021\000\021\000\021\000\021\
\\000\021\000\021\000\021\000\021\000\021\000\021\000\021\000\021\
\\000\021\000\021\000\021\000\021\000\021\000\021\000\021\000\021\
\\000\021\000\021\000\021\000\000\000\000\000\000\000\000\000\000\
\\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\
\\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\
\\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\
\\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\
\\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\
\\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\
\\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\
\\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\
\\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\
\\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\
\\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\
\\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\
\\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\
\\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\
\\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\
\\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000"
),
 (22,256, 
"\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\
\\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\
\\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\
\\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\
\\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\021\
\\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\
\\000\021\000\021\000\021\000\021\000\021\000\021\000\021\000\021\
\\000\021\000\021\000\000\000\000\000\000\000\000\000\000\000\000\
\\000\000\000\021\000\021\000\021\000\021\000\021\000\021\000\021\
\\000\021\000\021\000\021\000\021\000\021\000\021\000\021\000\021\
\\000\021\000\021\000\021\000\021\000\021\000\021\000\021\000\021\
\\000\021\000\021\000\021\000\000\000\000\000\000\000\000\000\021\
\\000\000\000\021\000\021\000\021\000\021\000\021\000\021\000\021\
\\000\023\000\021\000\021\000\021\000\021\000\021\000\021\000\021\
\\000\021\000\021\000\021\000\021\000\021\000\021\000\021\000\021\
\\000\021\000\021\000\021\000\000\000\000\000\000\000\000\000\000\
\\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\
\\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\
\\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\
\\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\
\\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\
\\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\
\\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\
\\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\
\\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\
\\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\
\\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\
\\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\
\\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\
\\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\
\\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\
\\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000"
),
 (23,256, 
"\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\
\\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\
\\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\
\\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\
\\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\021\
\\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\
\\000\021\000\021\000\021\000\021\000\021\000\021\000\021\000\021\
\\000\021\000\021\000\000\000\000\000\000\000\000\000\000\000\000\
\\000\000\000\021\000\021\000\021\000\021\000\021\000\021\000\021\
\\000\021\000\021\000\021\000\021\000\021\000\021\000\021\000\021\
\\000\021\000\021\000\021\000\021\000\021\000\021\000\021\000\021\
\\000\021\000\021\000\021\000\000\000\000\000\000\000\000\000\021\
\\000\000\000\021\000\021\000\021\000\021\000\024\000\021\000\021\
\\000\021\000\021\000\021\000\021\000\021\000\021\000\021\000\021\
\\000\021\000\021\000\021\000\021\000\021\000\021\000\021\000\021\
\\000\021\000\021\000\021\000\000\000\000\000\000\000\000\000\000\
\\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\
\\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\
\\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\
\\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\
\\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\
\\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\
\\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\
\\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\
\\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\
\\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\
\\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\
\\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\
\\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\
\\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\
\\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\
\\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000"
),
 (24,256, 
"\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\
\\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\
\\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\
\\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\
\\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\021\
\\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\
\\000\021\000\021\000\021\000\021\000\021\000\021\000\021\000\021\
\\000\021\000\021\000\000\000\000\000\000\000\000\000\000\000\000\
\\000\000\000\021\000\021\000\021\000\021\000\021\000\021\000\021\
\\000\021\000\021\000\021\000\021\000\021\000\021\000\021\000\021\
\\000\021\000\021\000\021\000\021\000\021\000\021\000\021\000\021\
\\000\021\000\021\000\021\000\000\000\000\000\000\000\000\000\021\
\\000\000\000\021\000\021\000\021\000\021\000\021\000\021\000\021\
\\000\021\000\021\000\021\000\021\000\021\000\021\000\021\000\021\
\\000\021\000\021\000\025\000\021\000\021\000\021\000\021\000\021\
\\000\021\000\021\000\021\000\000\000\000\000\000\000\000\000\000\
\\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\
\\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\
\\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\
\\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\
\\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\
\\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\
\\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\
\\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\
\\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\
\\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\
\\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\
\\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\
\\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\
\\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\
\\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\
\\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000"
),
 (25,256, 
"\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\
\\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\
\\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\
\\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\
\\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\021\
\\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\
\\000\021\000\021\000\021\000\021\000\021\000\021\000\021\000\021\
\\000\021\000\021\000\000\000\000\000\000\000\000\000\000\000\000\
\\000\000\000\021\000\021\000\021\000\021\000\021\000\021\000\021\
\\000\021\000\021\000\021\000\021\000\021\000\021\000\021\000\021\
\\000\021\000\021\000\021\000\021\000\021\000\021\000\021\000\021\
\\000\021\000\021\000\021\000\000\000\000\000\000\000\000\000\021\
\\000\000\000\021\000\021\000\021\000\021\000\026\000\021\000\021\
\\000\021\000\021\000\021\000\021\000\021\000\021\000\021\000\021\
\\000\021\000\021\000\021\000\021\000\021\000\021\000\021\000\021\
\\000\021\000\021\000\021\000\000\000\000\000\000\000\000\000\000\
\\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\
\\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\
\\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\
\\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\
\\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\
\\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\
\\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\
\\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\
\\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\
\\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\
\\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\
\\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\
\\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\
\\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\
\\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\
\\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000"
),
 (27,256, 
"\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\
\\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\
\\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\
\\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\
\\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\021\
\\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\
\\000\021\000\021\000\021\000\021\000\021\000\021\000\021\000\021\
\\000\021\000\021\000\000\000\000\000\000\000\000\000\000\000\000\
\\000\000\000\021\000\021\000\021\000\021\000\021\000\021\000\021\
\\000\021\000\021\000\021\000\021\000\021\000\021\000\021\000\021\
\\000\021\000\021\000\021\000\021\000\021\000\021\000\021\000\021\
\\000\021\000\021\000\021\000\000\000\000\000\000\000\000\000\021\
\\000\000\000\031\000\021\000\021\000\021\000\021\000\021\000\021\
\\000\021\000\028\000\021\000\021\000\021\000\021\000\021\000\021\
\\000\021\000\021\000\021\000\021\000\021\000\021\000\021\000\021\
\\000\021\000\021\000\021\000\000\000\000\000\000\000\000\000\000\
\\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\
\\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\
\\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\
\\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\
\\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\
\\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\
\\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\
\\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\
\\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\
\\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\
\\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\
\\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\
\\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\
\\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\
\\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\
\\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000"
),
 (28,256, 
"\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\
\\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\
\\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\
\\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\
\\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\021\
\\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\
\\000\021\000\021\000\021\000\021\000\021\000\021\000\021\000\021\
\\000\021\000\021\000\000\000\000\000\000\000\000\000\000\000\000\
\\000\000\000\021\000\021\000\021\000\021\000\021\000\021\000\021\
\\000\021\000\021\000\021\000\021\000\021\000\021\000\021\000\021\
\\000\021\000\021\000\021\000\021\000\021\000\021\000\021\000\021\
\\000\021\000\021\000\021\000\000\000\000\000\000\000\000\000\021\
\\000\000\000\021\000\021\000\021\000\021\000\029\000\021\000\021\
\\000\021\000\021\000\021\000\021\000\021\000\021\000\021\000\021\
\\000\021\000\021\000\021\000\021\000\021\000\021\000\021\000\021\
\\000\021\000\021\000\021\000\000\000\000\000\000\000\000\000\000\
\\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\
\\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\
\\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\
\\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\
\\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\
\\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\
\\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\
\\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\
\\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\
\\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\
\\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\
\\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\
\\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\
\\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\
\\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\
\\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000"
),
 (29,256, 
"\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\
\\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\
\\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\
\\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\
\\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\021\
\\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\
\\000\021\000\021\000\021\000\021\000\021\000\021\000\021\000\021\
\\000\021\000\021\000\000\000\000\000\000\000\000\000\000\000\000\
\\000\000\000\021\000\021\000\021\000\021\000\021\000\021\000\021\
\\000\021\000\021\000\021\000\021\000\021\000\021\000\021\000\021\
\\000\021\000\021\000\021\000\021\000\021\000\021\000\021\000\021\
\\000\021\000\021\000\021\000\000\000\000\000\000\000\000\000\021\
\\000\000\000\021\000\021\000\021\000\021\000\021\000\021\000\021\
\\000\021\000\021\000\021\000\021\000\021\000\021\000\021\000\021\
\\000\021\000\021\000\021\000\021\000\021\000\021\000\021\000\030\
\\000\021\000\021\000\021\000\000\000\000\000\000\000\000\000\000\
\\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\
\\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\
\\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\
\\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\
\\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\
\\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\
\\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\
\\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\
\\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\
\\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\
\\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\
\\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\
\\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\
\\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\
\\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\
\\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000"
),
 (31,256, 
"\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\
\\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\
\\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\
\\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\
\\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\021\
\\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\
\\000\021\000\021\000\021\000\021\000\021\000\021\000\021\000\021\
\\000\021\000\021\000\000\000\000\000\000\000\000\000\000\000\000\
\\000\000\000\021\000\021\000\021\000\021\000\021\000\021\000\021\
\\000\021\000\021\000\021\000\021\000\021\000\021\000\021\000\021\
\\000\021\000\021\000\021\000\021\000\021\000\021\000\021\000\021\
\\000\021\000\021\000\021\000\000\000\000\000\000\000\000\000\021\
\\000\000\000\021\000\021\000\021\000\021\000\021\000\021\000\021\
\\000\021\000\021\000\021\000\021\000\032\000\021\000\021\000\021\
\\000\021\000\021\000\021\000\021\000\021\000\021\000\021\000\021\
\\000\021\000\021\000\021\000\000\000\000\000\000\000\000\000\000\
\\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\
\\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\
\\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\
\\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\
\\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\
\\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\
\\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\
\\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\
\\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\
\\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\
\\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\
\\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\
\\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\
\\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\
\\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\
\\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000"
),
 (33,256, 
"\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\
\\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\
\\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\
\\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\
\\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\021\
\\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\
\\000\021\000\021\000\021\000\021\000\021\000\021\000\021\000\021\
\\000\021\000\021\000\000\000\000\000\000\000\000\000\000\000\000\
\\000\000\000\021\000\021\000\021\000\021\000\021\000\021\000\021\
\\000\021\000\021\000\021\000\021\000\021\000\021\000\021\000\021\
\\000\021\000\021\000\021\000\021\000\021\000\021\000\021\000\021\
\\000\021\000\021\000\021\000\000\000\000\000\000\000\000\000\021\
\\000\000\000\040\000\021\000\021\000\021\000\021\000\021\000\021\
\\000\037\000\021\000\021\000\021\000\021\000\021\000\021\000\021\
\\000\021\000\021\000\021\000\021\000\021\000\021\000\021\000\021\
\\000\021\000\034\000\021\000\000\000\000\000\000\000\000\000\000\
\\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\
\\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\
\\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\
\\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\
\\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\
\\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\
\\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\
\\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\
\\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\
\\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\
\\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\
\\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\
\\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\
\\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\
\\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\
\\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000"
),
 (34,256, 
"\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\
\\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\
\\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\
\\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\
\\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\021\
\\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\
\\000\021\000\021\000\021\000\021\000\021\000\021\000\021\000\021\
\\000\021\000\021\000\000\000\000\000\000\000\000\000\000\000\000\
\\000\000\000\021\000\021\000\021\000\021\000\021\000\021\000\021\
\\000\021\000\021\000\021\000\021\000\021\000\021\000\021\000\021\
\\000\021\000\021\000\021\000\021\000\021\000\021\000\021\000\021\
\\000\021\000\021\000\021\000\000\000\000\000\000\000\000\000\021\
\\000\000\000\021\000\021\000\021\000\021\000\021\000\021\000\021\
\\000\021\000\021\000\021\000\021\000\021\000\021\000\021\000\021\
\\000\035\000\021\000\021\000\021\000\021\000\021\000\021\000\021\
\\000\021\000\021\000\021\000\000\000\000\000\000\000\000\000\000\
\\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\
\\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\
\\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\
\\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\
\\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\
\\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\
\\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\
\\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\
\\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\
\\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\
\\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\
\\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\
\\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\
\\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\
\\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\
\\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000"
),
 (35,256, 
"\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\
\\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\
\\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\
\\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\
\\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\021\
\\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\
\\000\021\000\021\000\021\000\021\000\021\000\021\000\021\000\021\
\\000\021\000\021\000\000\000\000\000\000\000\000\000\000\000\000\
\\000\000\000\021\000\021\000\021\000\021\000\021\000\021\000\021\
\\000\021\000\021\000\021\000\021\000\021\000\021\000\021\000\021\
\\000\021\000\021\000\021\000\021\000\021\000\021\000\021\000\021\
\\000\021\000\021\000\021\000\000\000\000\000\000\000\000\000\021\
\\000\000\000\021\000\021\000\021\000\021\000\036\000\021\000\021\
\\000\021\000\021\000\021\000\021\000\021\000\021\000\021\000\021\
\\000\021\000\021\000\021\000\021\000\021\000\021\000\021\000\021\
\\000\021\000\021\000\021\000\000\000\000\000\000\000\000\000\000\
\\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\
\\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\
\\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\
\\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\
\\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\
\\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\
\\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\
\\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\
\\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\
\\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\
\\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\
\\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\
\\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\
\\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\
\\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\
\\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000"
),
 (37,256, 
"\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\
\\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\
\\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\
\\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\
\\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\021\
\\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\
\\000\021\000\021\000\021\000\021\000\021\000\021\000\021\000\021\
\\000\021\000\021\000\000\000\000\000\000\000\000\000\000\000\000\
\\000\000\000\021\000\021\000\021\000\021\000\021\000\021\000\021\
\\000\021\000\021\000\021\000\021\000\021\000\021\000\021\000\021\
\\000\021\000\021\000\021\000\021\000\021\000\021\000\021\000\021\
\\000\021\000\021\000\021\000\000\000\000\000\000\000\000\000\021\
\\000\000\000\021\000\021\000\021\000\021\000\038\000\021\000\021\
\\000\021\000\021\000\021\000\021\000\021\000\021\000\021\000\021\
\\000\021\000\021\000\021\000\021\000\021\000\021\000\021\000\021\
\\000\021\000\021\000\021\000\000\000\000\000\000\000\000\000\000\
\\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\
\\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\
\\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\
\\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\
\\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\
\\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\
\\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\
\\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\
\\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\
\\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\
\\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\
\\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\
\\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\
\\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\
\\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\
\\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000"
),
 (38,256, 
"\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\
\\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\
\\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\
\\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\
\\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\021\
\\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\
\\000\021\000\021\000\021\000\021\000\021\000\021\000\021\000\021\
\\000\021\000\021\000\000\000\000\000\000\000\000\000\000\000\000\
\\000\000\000\021\000\021\000\021\000\021\000\021\000\021\000\021\
\\000\021\000\021\000\021\000\021\000\021\000\021\000\021\000\021\
\\000\021\000\021\000\021\000\021\000\021\000\021\000\021\000\021\
\\000\021\000\021\000\021\000\000\000\000\000\000\000\000\000\021\
\\000\000\000\021\000\021\000\021\000\021\000\021\000\021\000\021\
\\000\021\000\021\000\021\000\021\000\021\000\021\000\039\000\021\
\\000\021\000\021\000\021\000\021\000\021\000\021\000\021\000\021\
\\000\021\000\021\000\021\000\000\000\000\000\000\000\000\000\000\
\\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\
\\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\
\\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\
\\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\
\\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\
\\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\
\\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\
\\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\
\\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\
\\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\
\\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\
\\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\
\\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\
\\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\
\\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\
\\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000"
),
 (40,256, 
"\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\
\\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\
\\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\
\\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\
\\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\021\
\\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\
\\000\021\000\021\000\021\000\021\000\021\000\021\000\021\000\021\
\\000\021\000\021\000\000\000\000\000\000\000\000\000\000\000\000\
\\000\000\000\021\000\021\000\021\000\021\000\021\000\021\000\021\
\\000\021\000\021\000\021\000\021\000\021\000\021\000\021\000\021\
\\000\021\000\021\000\021\000\021\000\021\000\021\000\021\000\021\
\\000\021\000\021\000\021\000\000\000\000\000\000\000\000\000\021\
\\000\000\000\021\000\043\000\021\000\021\000\021\000\021\000\021\
\\000\021\000\021\000\021\000\021\000\021\000\021\000\021\000\021\
\\000\021\000\021\000\021\000\041\000\021\000\021\000\021\000\021\
\\000\021\000\021\000\021\000\000\000\000\000\000\000\000\000\000\
\\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\
\\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\
\\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\
\\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\
\\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\
\\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\
\\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\
\\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\
\\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\
\\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\
\\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\
\\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\
\\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\
\\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\
\\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\
\\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000"
),
 (41,256, 
"\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\
\\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\
\\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\
\\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\
\\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\021\
\\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\
\\000\021\000\021\000\021\000\021\000\021\000\021\000\021\000\021\
\\000\021\000\021\000\000\000\000\000\000\000\000\000\000\000\000\
\\000\000\000\021\000\021\000\021\000\021\000\021\000\021\000\021\
\\000\021\000\021\000\021\000\021\000\021\000\021\000\021\000\021\
\\000\021\000\021\000\021\000\021\000\021\000\021\000\021\000\021\
\\000\021\000\021\000\021\000\000\000\000\000\000\000\000\000\021\
\\000\000\000\021\000\021\000\021\000\021\000\021\000\021\000\021\
\\000\021\000\021\000\021\000\042\000\021\000\021\000\021\000\021\
\\000\021\000\021\000\021\000\021\000\021\000\021\000\021\000\021\
\\000\021\000\021\000\021\000\000\000\000\000\000\000\000\000\000\
\\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\
\\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\
\\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\
\\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\
\\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\
\\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\
\\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\
\\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\
\\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\
\\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\
\\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\
\\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\
\\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\
\\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\
\\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\
\\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000"
),
 (43,256, 
"\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\
\\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\
\\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\
\\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\
\\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\021\
\\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\
\\000\021\000\021\000\021\000\021\000\021\000\021\000\021\000\021\
\\000\021\000\021\000\000\000\000\000\000\000\000\000\000\000\000\
\\000\000\000\021\000\021\000\021\000\021\000\021\000\021\000\021\
\\000\021\000\021\000\021\000\021\000\021\000\021\000\021\000\021\
\\000\021\000\021\000\021\000\021\000\021\000\021\000\021\000\021\
\\000\021\000\021\000\021\000\000\000\000\000\000\000\000\000\021\
\\000\000\000\021\000\021\000\021\000\021\000\021\000\021\000\021\
\\000\021\000\021\000\021\000\021\000\044\000\021\000\021\000\021\
\\000\021\000\021\000\021\000\021\000\021\000\021\000\021\000\021\
\\000\021\000\021\000\021\000\000\000\000\000\000\000\000\000\000\
\\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\
\\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\
\\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\
\\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\
\\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\
\\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\
\\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\
\\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\
\\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\
\\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\
\\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\
\\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\
\\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\
\\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\
\\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\
\\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000"
),
 (44,256, 
"\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\
\\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\
\\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\
\\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\
\\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\021\
\\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\
\\000\021\000\021\000\021\000\021\000\021\000\021\000\021\000\021\
\\000\021\000\021\000\000\000\000\000\000\000\000\000\000\000\000\
\\000\000\000\021\000\021\000\021\000\021\000\021\000\021\000\021\
\\000\021\000\021\000\021\000\021\000\021\000\021\000\021\000\021\
\\000\021\000\021\000\021\000\021\000\021\000\021\000\021\000\021\
\\000\021\000\021\000\021\000\000\000\000\000\000\000\000\000\021\
\\000\000\000\021\000\021\000\021\000\021\000\045\000\021\000\021\
\\000\021\000\021\000\021\000\021\000\021\000\021\000\021\000\021\
\\000\021\000\021\000\021\000\021\000\021\000\021\000\021\000\021\
\\000\021\000\021\000\021\000\000\000\000\000\000\000\000\000\000\
\\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\
\\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\
\\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\
\\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\
\\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\
\\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\
\\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\
\\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\
\\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\
\\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\
\\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\
\\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\
\\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\
\\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\
\\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\
\\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000"
),
 (46,256, 
"\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\
\\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\
\\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\
\\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\
\\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\021\
\\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\
\\000\021\000\021\000\021\000\021\000\021\000\021\000\021\000\021\
\\000\021\000\021\000\000\000\000\000\000\000\000\000\000\000\000\
\\000\000\000\021\000\021\000\021\000\021\000\021\000\021\000\021\
\\000\021\000\021\000\021\000\021\000\021\000\021\000\021\000\021\
\\000\021\000\021\000\021\000\021\000\021\000\021\000\021\000\021\
\\000\021\000\021\000\021\000\000\000\000\000\000\000\000\000\021\
\\000\000\000\021\000\021\000\021\000\021\000\066\000\021\000\021\
\\000\021\000\058\000\021\000\021\000\021\000\021\000\021\000\021\
\\000\021\000\021\000\021\000\021\000\047\000\021\000\021\000\021\
\\000\021\000\021\000\021\000\000\000\000\000\000\000\000\000\000\
\\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\
\\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\
\\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\
\\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\
\\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\
\\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\
\\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\
\\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\
\\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\
\\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\
\\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\
\\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\
\\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\
\\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\
\\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\
\\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000"
),
 (47,256, 
"\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\
\\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\
\\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\
\\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\
\\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\021\
\\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\
\\000\021\000\021\000\021\000\021\000\021\000\021\000\021\000\021\
\\000\021\000\021\000\000\000\000\000\000\000\000\000\000\000\000\
\\000\000\000\021\000\021\000\021\000\021\000\021\000\021\000\021\
\\000\021\000\021\000\021\000\021\000\021\000\021\000\021\000\021\
\\000\021\000\021\000\021\000\021\000\021\000\021\000\021\000\021\
\\000\021\000\021\000\021\000\000\000\000\000\000\000\000\000\021\
\\000\000\000\021\000\021\000\021\000\021\000\021\000\021\000\021\
\\000\021\000\021\000\021\000\021\000\021\000\021\000\021\000\021\
\\000\021\000\021\000\051\000\021\000\021\000\021\000\021\000\021\
\\000\021\000\048\000\021\000\000\000\000\000\000\000\000\000\000\
\\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\
\\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\
\\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\
\\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\
\\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\
\\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\
\\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\
\\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\
\\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\
\\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\
\\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\
\\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\
\\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\
\\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\
\\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\
\\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000"
),
 (48,256, 
"\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\
\\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\
\\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\
\\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\
\\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\021\
\\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\
\\000\021\000\021\000\021\000\021\000\021\000\021\000\021\000\021\
\\000\021\000\021\000\000\000\000\000\000\000\000\000\000\000\000\
\\000\000\000\021\000\021\000\021\000\021\000\021\000\021\000\021\
\\000\021\000\021\000\021\000\021\000\021\000\021\000\021\000\021\
\\000\021\000\021\000\021\000\021\000\021\000\021\000\021\000\021\
\\000\021\000\021\000\021\000\000\000\000\000\000\000\000\000\021\
\\000\000\000\021\000\021\000\021\000\021\000\021\000\021\000\021\
\\000\021\000\021\000\021\000\021\000\049\000\021\000\021\000\021\
\\000\021\000\021\000\021\000\021\000\021\000\021\000\021\000\021\
\\000\021\000\021\000\021\000\000\000\000\000\000\000\000\000\000\
\\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\
\\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\
\\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\
\\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\
\\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\
\\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\
\\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\
\\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\
\\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\
\\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\
\\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\
\\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\
\\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\
\\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\
\\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\
\\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000"
),
 (49,256, 
"\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\
\\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\
\\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\
\\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\
\\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\021\
\\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\
\\000\021\000\021\000\021\000\021\000\021\000\021\000\021\000\021\
\\000\021\000\021\000\000\000\000\000\000\000\000\000\000\000\000\
\\000\000\000\021\000\021\000\021\000\021\000\021\000\021\000\021\
\\000\021\000\021\000\021\000\021\000\021\000\021\000\021\000\021\
\\000\021\000\021\000\021\000\021\000\021\000\021\000\021\000\021\
\\000\021\000\021\000\021\000\000\000\000\000\000\000\000\000\021\
\\000\000\000\021\000\021\000\021\000\021\000\050\000\021\000\021\
\\000\021\000\021\000\021\000\021\000\021\000\021\000\021\000\021\
\\000\021\000\021\000\021\000\021\000\021\000\021\000\021\000\021\
\\000\021\000\021\000\021\000\000\000\000\000\000\000\000\000\000\
\\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\
\\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\
\\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\
\\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\
\\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\
\\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\
\\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\
\\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\
\\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\
\\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\
\\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\
\\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\
\\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\
\\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\
\\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\
\\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000"
),
 (51,256, 
"\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\
\\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\
\\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\
\\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\
\\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\021\
\\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\
\\000\021\000\021\000\021\000\021\000\021\000\021\000\021\000\021\
\\000\021\000\021\000\000\000\000\000\000\000\000\000\000\000\000\
\\000\000\000\021\000\021\000\021\000\021\000\021\000\021\000\021\
\\000\021\000\021\000\021\000\021\000\021\000\021\000\021\000\021\
\\000\021\000\021\000\021\000\021\000\021\000\021\000\021\000\021\
\\000\021\000\021\000\021\000\000\000\000\000\000\000\000\000\021\
\\000\000\000\021\000\021\000\021\000\021\000\021\000\021\000\021\
\\000\021\000\021\000\021\000\021\000\021\000\021\000\021\000\021\
\\000\021\000\021\000\021\000\021\000\021\000\052\000\021\000\021\
\\000\021\000\021\000\021\000\000\000\000\000\000\000\000\000\000\
\\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\
\\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\
\\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\
\\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\
\\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\
\\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\
\\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\
\\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\
\\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\
\\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\
\\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\
\\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\
\\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\
\\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\
\\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\
\\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000"
),
 (52,256, 
"\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\
\\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\
\\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\
\\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\
\\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\021\
\\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\
\\000\021\000\021\000\021\000\021\000\021\000\021\000\021\000\021\
\\000\021\000\021\000\000\000\000\000\000\000\000\000\000\000\000\
\\000\000\000\021\000\021\000\021\000\021\000\021\000\021\000\021\
\\000\021\000\021\000\021\000\021\000\021\000\021\000\021\000\021\
\\000\021\000\021\000\021\000\021\000\021\000\021\000\021\000\021\
\\000\021\000\021\000\021\000\000\000\000\000\000\000\000\000\021\
\\000\000\000\021\000\021\000\053\000\021\000\021\000\021\000\021\
\\000\021\000\021\000\021\000\021\000\021\000\021\000\021\000\021\
\\000\021\000\021\000\021\000\021\000\021\000\021\000\021\000\021\
\\000\021\000\021\000\021\000\000\000\000\000\000\000\000\000\000\
\\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\
\\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\
\\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\
\\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\
\\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\
\\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\
\\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\
\\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\
\\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\
\\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\
\\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\
\\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\
\\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\
\\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\
\\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\
\\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000"
),
 (53,256, 
"\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\
\\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\
\\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\
\\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\
\\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\021\
\\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\
\\000\021\000\021\000\021\000\021\000\021\000\021\000\021\000\021\
\\000\021\000\021\000\000\000\000\000\000\000\000\000\000\000\000\
\\000\000\000\021\000\021\000\021\000\021\000\021\000\021\000\021\
\\000\021\000\021\000\021\000\021\000\021\000\021\000\021\000\021\
\\000\021\000\021\000\021\000\021\000\021\000\021\000\021\000\021\
\\000\021\000\021\000\021\000\000\000\000\000\000\000\000\000\021\
\\000\000\000\021\000\021\000\021\000\021\000\021\000\021\000\021\
\\000\021\000\021\000\021\000\021\000\021\000\021\000\021\000\021\
\\000\021\000\021\000\021\000\021\000\054\000\021\000\021\000\021\
\\000\021\000\021\000\021\000\000\000\000\000\000\000\000\000\000\
\\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\
\\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\
\\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\
\\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\
\\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\
\\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\
\\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\
\\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\
\\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\
\\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\
\\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\
\\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\
\\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\
\\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\
\\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\
\\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000"
),
 (54,256, 
"\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\
\\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\
\\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\
\\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\
\\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\021\
\\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\
\\000\021\000\021\000\021\000\021\000\021\000\021\000\021\000\021\
\\000\021\000\021\000\000\000\000\000\000\000\000\000\000\000\000\
\\000\000\000\021\000\021\000\021\000\021\000\021\000\021\000\021\
\\000\021\000\021\000\021\000\021\000\021\000\021\000\021\000\021\
\\000\021\000\021\000\021\000\021\000\021\000\021\000\021\000\021\
\\000\021\000\021\000\021\000\000\000\000\000\000\000\000\000\021\
\\000\000\000\021\000\021\000\021\000\021\000\021\000\021\000\021\
\\000\021\000\021\000\021\000\021\000\021\000\021\000\021\000\021\
\\000\021\000\021\000\021\000\021\000\021\000\055\000\021\000\021\
\\000\021\000\021\000\021\000\000\000\000\000\000\000\000\000\000\
\\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\
\\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\
\\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\
\\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\
\\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\
\\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\
\\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\
\\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\
\\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\
\\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\
\\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\
\\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\
\\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\
\\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\
\\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\
\\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000"
),
 (55,256, 
"\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\
\\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\
\\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\
\\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\
\\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\021\
\\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\
\\000\021\000\021\000\021\000\021\000\021\000\021\000\021\000\021\
\\000\021\000\021\000\000\000\000\000\000\000\000\000\000\000\000\
\\000\000\000\021\000\021\000\021\000\021\000\021\000\021\000\021\
\\000\021\000\021\000\021\000\021\000\021\000\021\000\021\000\021\
\\000\021\000\021\000\021\000\021\000\021\000\021\000\021\000\021\
\\000\021\000\021\000\021\000\000\000\000\000\000\000\000\000\021\
\\000\000\000\021\000\021\000\021\000\021\000\021\000\021\000\021\
\\000\021\000\021\000\021\000\021\000\021\000\021\000\021\000\021\
\\000\021\000\021\000\056\000\021\000\021\000\021\000\021\000\021\
\\000\021\000\021\000\021\000\000\000\000\000\000\000\000\000\000\
\\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\
\\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\
\\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\
\\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\
\\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\
\\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\
\\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\
\\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\
\\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\
\\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\
\\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\
\\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\
\\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\
\\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\
\\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\
\\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000"
),
 (56,256, 
"\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\
\\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\
\\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\
\\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\
\\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\021\
\\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\
\\000\021\000\021\000\021\000\021\000\021\000\021\000\021\000\021\
\\000\021\000\021\000\000\000\000\000\000\000\000\000\000\000\000\
\\000\000\000\021\000\021\000\021\000\021\000\021\000\021\000\021\
\\000\021\000\021\000\021\000\021\000\021\000\021\000\021\000\021\
\\000\021\000\021\000\021\000\021\000\021\000\021\000\021\000\021\
\\000\021\000\021\000\021\000\000\000\000\000\000\000\000\000\021\
\\000\000\000\021\000\021\000\021\000\021\000\057\000\021\000\021\
\\000\021\000\021\000\021\000\021\000\021\000\021\000\021\000\021\
\\000\021\000\021\000\021\000\021\000\021\000\021\000\021\000\021\
\\000\021\000\021\000\021\000\000\000\000\000\000\000\000\000\000\
\\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\
\\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\
\\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\
\\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\
\\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\
\\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\
\\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\
\\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\
\\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\
\\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\
\\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\
\\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\
\\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\
\\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\
\\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\
\\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000"
),
 (58,256, 
"\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\
\\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\
\\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\
\\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\
\\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\021\
\\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\
\\000\021\000\021\000\021\000\021\000\021\000\021\000\021\000\021\
\\000\021\000\021\000\000\000\000\000\000\000\000\000\000\000\000\
\\000\000\000\021\000\021\000\021\000\021\000\021\000\021\000\021\
\\000\021\000\021\000\021\000\021\000\021\000\021\000\021\000\021\
\\000\021\000\021\000\021\000\021\000\021\000\021\000\021\000\021\
\\000\021\000\021\000\021\000\000\000\000\000\000\000\000\000\021\
\\000\000\000\021\000\021\000\021\000\021\000\021\000\021\000\059\
\\000\021\000\021\000\021\000\021\000\021\000\021\000\021\000\021\
\\000\021\000\021\000\021\000\021\000\021\000\021\000\021\000\021\
\\000\021\000\021\000\021\000\000\000\000\000\000\000\000\000\000\
\\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\
\\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\
\\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\
\\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\
\\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\
\\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\
\\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\
\\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\
\\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\
\\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\
\\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\
\\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\
\\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\
\\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\
\\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\
\\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000"
),
 (59,256, 
"\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\
\\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\
\\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\
\\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\
\\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\021\
\\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\
\\000\021\000\021\000\021\000\021\000\021\000\021\000\021\000\021\
\\000\021\000\021\000\000\000\000\000\000\000\000\000\000\000\000\
\\000\000\000\021\000\021\000\021\000\021\000\021\000\021\000\021\
\\000\021\000\021\000\021\000\021\000\021\000\021\000\021\000\021\
\\000\021\000\021\000\021\000\021\000\021\000\021\000\021\000\021\
\\000\021\000\021\000\021\000\000\000\000\000\000\000\000\000\021\
\\000\000\000\021\000\021\000\021\000\021\000\021\000\021\000\021\
\\000\021\000\021\000\021\000\021\000\021\000\021\000\060\000\021\
\\000\021\000\021\000\021\000\021\000\021\000\021\000\021\000\021\
\\000\021\000\021\000\021\000\000\000\000\000\000\000\000\000\000\
\\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\
\\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\
\\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\
\\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\
\\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\
\\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\
\\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\
\\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\
\\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\
\\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\
\\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\
\\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\
\\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\
\\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\
\\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\
\\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000"
),
 (60,256, 
"\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\
\\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\
\\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\
\\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\
\\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\021\
\\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\
\\000\021\000\021\000\021\000\021\000\021\000\021\000\021\000\021\
\\000\021\000\021\000\000\000\000\000\000\000\000\000\000\000\000\
\\000\000\000\021\000\021\000\021\000\021\000\021\000\021\000\021\
\\000\021\000\021\000\021\000\021\000\021\000\021\000\021\000\021\
\\000\021\000\021\000\021\000\021\000\021\000\021\000\021\000\021\
\\000\021\000\021\000\021\000\000\000\000\000\000\000\000\000\021\
\\000\000\000\061\000\021\000\021\000\021\000\021\000\021\000\021\
\\000\021\000\021\000\021\000\021\000\021\000\021\000\021\000\021\
\\000\021\000\021\000\021\000\021\000\021\000\021\000\021\000\021\
\\000\021\000\021\000\021\000\000\000\000\000\000\000\000\000\000\
\\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\
\\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\
\\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\
\\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\
\\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\
\\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\
\\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\
\\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\
\\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\
\\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\
\\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\
\\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\
\\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\
\\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\
\\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\
\\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000"
),
 (61,256, 
"\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\
\\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\
\\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\
\\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\
\\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\021\
\\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\
\\000\021\000\021\000\021\000\021\000\021\000\021\000\021\000\021\
\\000\021\000\021\000\000\000\000\000\000\000\000\000\000\000\000\
\\000\000\000\021\000\021\000\021\000\021\000\021\000\021\000\021\
\\000\021\000\021\000\021\000\021\000\021\000\021\000\021\000\021\
\\000\021\000\021\000\021\000\021\000\021\000\021\000\021\000\021\
\\000\021\000\021\000\021\000\000\000\000\000\000\000\000\000\021\
\\000\000\000\021\000\021\000\021\000\021\000\021\000\021\000\021\
\\000\021\000\021\000\021\000\021\000\021\000\021\000\021\000\021\
\\000\021\000\021\000\021\000\021\000\062\000\021\000\021\000\021\
\\000\021\000\021\000\021\000\000\000\000\000\000\000\000\000\000\
\\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\
\\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\
\\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\
\\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\
\\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\
\\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\
\\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\
\\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\
\\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\
\\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\
\\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\
\\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\
\\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\
\\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\
\\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\
\\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000"
),
 (62,256, 
"\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\
\\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\
\\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\
\\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\
\\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\021\
\\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\
\\000\021\000\021\000\021\000\021\000\021\000\021\000\021\000\021\
\\000\021\000\021\000\000\000\000\000\000\000\000\000\000\000\000\
\\000\000\000\021\000\021\000\021\000\021\000\021\000\021\000\021\
\\000\021\000\021\000\021\000\021\000\021\000\021\000\021\000\021\
\\000\021\000\021\000\021\000\021\000\021\000\021\000\021\000\021\
\\000\021\000\021\000\021\000\000\000\000\000\000\000\000\000\021\
\\000\000\000\021\000\021\000\021\000\021\000\021\000\021\000\021\
\\000\021\000\021\000\021\000\021\000\021\000\021\000\021\000\021\
\\000\021\000\021\000\021\000\021\000\021\000\063\000\021\000\021\
\\000\021\000\021\000\021\000\000\000\000\000\000\000\000\000\000\
\\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\
\\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\
\\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\
\\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\
\\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\
\\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\
\\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\
\\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\
\\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\
\\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\
\\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\
\\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\
\\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\
\\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\
\\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\
\\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000"
),
 (63,256, 
"\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\
\\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\
\\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\
\\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\
\\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\021\
\\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\
\\000\021\000\021\000\021\000\021\000\021\000\021\000\021\000\021\
\\000\021\000\021\000\000\000\000\000\000\000\000\000\000\000\000\
\\000\000\000\021\000\021\000\021\000\021\000\021\000\021\000\021\
\\000\021\000\021\000\021\000\021\000\021\000\021\000\021\000\021\
\\000\021\000\021\000\021\000\021\000\021\000\021\000\021\000\021\
\\000\021\000\021\000\021\000\000\000\000\000\000\000\000\000\021\
\\000\000\000\021\000\021\000\021\000\021\000\021\000\021\000\021\
\\000\021\000\021\000\021\000\021\000\021\000\021\000\021\000\021\
\\000\021\000\021\000\064\000\021\000\021\000\021\000\021\000\021\
\\000\021\000\021\000\021\000\000\000\000\000\000\000\000\000\000\
\\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\
\\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\
\\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\
\\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\
\\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\
\\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\
\\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\
\\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\
\\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\
\\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\
\\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\
\\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\
\\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\
\\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\
\\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\
\\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000"
),
 (64,256, 
"\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\
\\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\
\\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\
\\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\
\\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\021\
\\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\
\\000\021\000\021\000\021\000\021\000\021\000\021\000\021\000\021\
\\000\021\000\021\000\000\000\000\000\000\000\000\000\000\000\000\
\\000\000\000\021\000\021\000\021\000\021\000\021\000\021\000\021\
\\000\021\000\021\000\021\000\021\000\021\000\021\000\021\000\021\
\\000\021\000\021\000\021\000\021\000\021\000\021\000\021\000\021\
\\000\021\000\021\000\021\000\000\000\000\000\000\000\000\000\021\
\\000\000\000\021\000\021\000\021\000\021\000\065\000\021\000\021\
\\000\021\000\021\000\021\000\021\000\021\000\021\000\021\000\021\
\\000\021\000\021\000\021\000\021\000\021\000\021\000\021\000\021\
\\000\021\000\021\000\021\000\000\000\000\000\000\000\000\000\000\
\\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\
\\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\
\\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\
\\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\
\\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\
\\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\
\\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\
\\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\
\\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\
\\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\
\\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\
\\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\
\\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\
\\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\
\\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\
\\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000"
),
 (66,256, 
"\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\
\\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\
\\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\
\\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\
\\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\021\
\\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\
\\000\021\000\021\000\021\000\021\000\021\000\021\000\021\000\021\
\\000\021\000\021\000\000\000\000\000\000\000\000\000\000\000\000\
\\000\000\000\021\000\021\000\021\000\021\000\021\000\021\000\021\
\\000\021\000\021\000\021\000\021\000\021\000\021\000\021\000\021\
\\000\021\000\021\000\021\000\021\000\021\000\021\000\021\000\021\
\\000\021\000\021\000\021\000\000\000\000\000\000\000\000\000\021\
\\000\000\000\021\000\021\000\021\000\021\000\021\000\021\000\021\
\\000\021\000\021\000\021\000\021\000\021\000\021\000\021\000\021\
\\000\021\000\067\000\021\000\021\000\021\000\021\000\021\000\021\
\\000\021\000\021\000\021\000\000\000\000\000\000\000\000\000\000\
\\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\
\\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\
\\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\
\\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\
\\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\
\\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\
\\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\
\\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\
\\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\
\\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\
\\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\
\\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\
\\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\
\\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\
\\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\
\\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000"
),
 (67,256, 
"\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\
\\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\
\\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\
\\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\
\\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\021\
\\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\
\\000\021\000\021\000\021\000\021\000\021\000\021\000\021\000\021\
\\000\021\000\021\000\000\000\000\000\000\000\000\000\000\000\000\
\\000\000\000\021\000\021\000\021\000\021\000\021\000\021\000\021\
\\000\021\000\021\000\021\000\021\000\021\000\021\000\021\000\021\
\\000\021\000\021\000\021\000\021\000\021\000\021\000\021\000\021\
\\000\021\000\021\000\021\000\000\000\000\000\000\000\000\000\021\
\\000\000\000\021\000\021\000\021\000\021\000\021\000\021\000\021\
\\000\021\000\021\000\021\000\021\000\021\000\021\000\021\000\021\
\\000\021\000\021\000\021\000\021\000\021\000\068\000\021\000\021\
\\000\021\000\021\000\021\000\000\000\000\000\000\000\000\000\000\
\\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\
\\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\
\\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\
\\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\
\\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\
\\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\
\\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\
\\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\
\\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\
\\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\
\\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\
\\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\
\\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\
\\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\
\\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\
\\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000"
),
 (68,256, 
"\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\
\\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\
\\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\
\\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\
\\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\021\
\\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\
\\000\021\000\021\000\021\000\021\000\021\000\021\000\021\000\021\
\\000\021\000\021\000\000\000\000\000\000\000\000\000\000\000\000\
\\000\000\000\021\000\021\000\021\000\021\000\021\000\021\000\021\
\\000\021\000\021\000\021\000\021\000\021\000\021\000\021\000\021\
\\000\021\000\021\000\021\000\021\000\021\000\021\000\021\000\021\
\\000\021\000\021\000\021\000\000\000\000\000\000\000\000\000\021\
\\000\000\000\021\000\021\000\021\000\021\000\069\000\021\000\021\
\\000\021\000\021\000\021\000\021\000\021\000\021\000\021\000\021\
\\000\021\000\021\000\021\000\021\000\021\000\021\000\021\000\021\
\\000\021\000\021\000\021\000\000\000\000\000\000\000\000\000\000\
\\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\
\\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\
\\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\
\\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\
\\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\
\\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\
\\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\
\\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\
\\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\
\\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\
\\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\
\\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\
\\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\
\\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\
\\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\
\\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000"
),
 (69,256, 
"\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\
\\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\
\\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\
\\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\
\\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\021\
\\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\
\\000\021\000\021\000\021\000\021\000\021\000\021\000\021\000\021\
\\000\021\000\021\000\000\000\000\000\000\000\000\000\000\000\000\
\\000\000\000\021\000\021\000\021\000\021\000\021\000\021\000\021\
\\000\021\000\021\000\021\000\021\000\021\000\021\000\021\000\021\
\\000\021\000\021\000\021\000\021\000\021\000\021\000\021\000\021\
\\000\021\000\021\000\021\000\000\000\000\000\000\000\000\000\021\
\\000\000\000\021\000\021\000\021\000\021\000\021\000\021\000\021\
\\000\021\000\021\000\021\000\021\000\021\000\021\000\070\000\021\
\\000\021\000\021\000\021\000\021\000\021\000\021\000\021\000\021\
\\000\021\000\021\000\021\000\000\000\000\000\000\000\000\000\000\
\\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\
\\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\
\\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\
\\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\
\\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\
\\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\
\\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\
\\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\
\\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\
\\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\
\\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\
\\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\
\\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\
\\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\
\\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\
\\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000"
),
 (70,256, 
"\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\
\\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\
\\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\
\\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\
\\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\021\
\\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\
\\000\021\000\021\000\021\000\021\000\021\000\021\000\021\000\021\
\\000\021\000\021\000\000\000\000\000\000\000\000\000\000\000\000\
\\000\000\000\021\000\021\000\021\000\021\000\021\000\021\000\021\
\\000\021\000\021\000\021\000\021\000\021\000\021\000\021\000\021\
\\000\021\000\021\000\021\000\021\000\021\000\021\000\021\000\021\
\\000\021\000\021\000\021\000\000\000\000\000\000\000\000\000\021\
\\000\000\000\021\000\021\000\071\000\021\000\021\000\021\000\021\
\\000\021\000\021\000\021\000\021\000\021\000\021\000\021\000\021\
\\000\021\000\021\000\021\000\021\000\021\000\021\000\021\000\021\
\\000\021\000\021\000\021\000\000\000\000\000\000\000\000\000\000\
\\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\
\\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\
\\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\
\\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\
\\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\
\\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\
\\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\
\\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\
\\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\
\\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\
\\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\
\\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\
\\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\
\\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\
\\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\
\\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000"
),
 (71,256, 
"\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\
\\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\
\\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\
\\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\
\\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\021\
\\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\
\\000\021\000\021\000\021\000\021\000\021\000\021\000\021\000\021\
\\000\021\000\021\000\000\000\000\000\000\000\000\000\000\000\000\
\\000\000\000\021\000\021\000\021\000\021\000\021\000\021\000\021\
\\000\021\000\021\000\021\000\021\000\021\000\021\000\021\000\021\
\\000\021\000\021\000\021\000\021\000\021\000\021\000\021\000\021\
\\000\021\000\021\000\021\000\000\000\000\000\000\000\000\000\021\
\\000\000\000\021\000\021\000\021\000\021\000\072\000\021\000\021\
\\000\021\000\021\000\021\000\021\000\021\000\021\000\021\000\021\
\\000\021\000\021\000\021\000\021\000\021\000\021\000\021\000\021\
\\000\021\000\021\000\021\000\000\000\000\000\000\000\000\000\000\
\\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\
\\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\
\\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\
\\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\
\\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\
\\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\
\\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\
\\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\
\\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\
\\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\
\\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\
\\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\
\\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\
\\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\
\\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\
\\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000"
),
 (73,256, 
"\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\
\\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\
\\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\
\\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\
\\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\021\
\\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\
\\000\021\000\021\000\021\000\021\000\021\000\021\000\021\000\021\
\\000\021\000\021\000\000\000\000\000\000\000\000\000\000\000\000\
\\000\000\000\021\000\021\000\021\000\021\000\021\000\021\000\021\
\\000\021\000\021\000\021\000\021\000\021\000\021\000\021\000\021\
\\000\021\000\021\000\021\000\021\000\021\000\021\000\021\000\021\
\\000\021\000\021\000\021\000\000\000\000\000\000\000\000\000\021\
\\000\000\000\021\000\021\000\021\000\021\000\074\000\021\000\021\
\\000\021\000\021\000\021\000\021\000\021\000\021\000\021\000\021\
\\000\021\000\021\000\021\000\021\000\021\000\021\000\021\000\021\
\\000\021\000\021\000\021\000\000\000\000\000\000\000\000\000\000\
\\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\
\\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\
\\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\
\\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\
\\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\
\\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\
\\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\
\\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\
\\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\
\\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\
\\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\
\\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\
\\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\
\\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\
\\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\
\\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000"
),
 (74,256, 
"\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\
\\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\
\\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\
\\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\
\\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\021\
\\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\
\\000\021\000\021\000\021\000\021\000\021\000\021\000\021\000\021\
\\000\021\000\021\000\000\000\000\000\000\000\000\000\000\000\000\
\\000\000\000\021\000\021\000\021\000\021\000\021\000\021\000\021\
\\000\021\000\021\000\021\000\021\000\021\000\021\000\021\000\021\
\\000\021\000\021\000\021\000\021\000\021\000\021\000\021\000\021\
\\000\021\000\021\000\021\000\000\000\000\000\000\000\000\000\021\
\\000\000\000\021\000\021\000\075\000\021\000\021\000\021\000\021\
\\000\021\000\021\000\021\000\021\000\021\000\021\000\021\000\021\
\\000\021\000\021\000\021\000\021\000\021\000\021\000\021\000\021\
\\000\021\000\021\000\021\000\000\000\000\000\000\000\000\000\000\
\\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\
\\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\
\\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\
\\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\
\\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\
\\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\
\\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\
\\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\
\\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\
\\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\
\\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\
\\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\
\\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\
\\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\
\\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\
\\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000"
),
 (76,256, 
"\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\
\\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\
\\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\
\\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\
\\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\021\
\\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\
\\000\021\000\021\000\021\000\021\000\021\000\021\000\021\000\021\
\\000\021\000\021\000\000\000\000\000\000\000\000\000\000\000\000\
\\000\000\000\021\000\021\000\021\000\021\000\021\000\021\000\021\
\\000\021\000\021\000\021\000\021\000\021\000\021\000\021\000\021\
\\000\021\000\021\000\021\000\021\000\021\000\021\000\021\000\021\
\\000\021\000\021\000\021\000\000\000\000\000\000\000\000\000\021\
\\000\000\000\021\000\021\000\021\000\021\000\021\000\021\000\021\
\\000\021\000\021\000\021\000\021\000\021\000\021\000\021\000\077\
\\000\021\000\021\000\021\000\021\000\021\000\021\000\021\000\021\
\\000\021\000\021\000\021\000\000\000\000\000\000\000\000\000\000\
\\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\
\\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\
\\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\
\\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\
\\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\
\\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\
\\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\
\\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\
\\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\
\\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\
\\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\
\\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\
\\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\
\\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\
\\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\
\\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000"
),
 (77,256, 
"\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\
\\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\
\\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\
\\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\
\\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\021\
\\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\
\\000\021\000\021\000\021\000\021\000\021\000\021\000\021\000\021\
\\000\021\000\021\000\000\000\000\000\000\000\000\000\000\000\000\
\\000\000\000\021\000\021\000\021\000\021\000\021\000\021\000\021\
\\000\021\000\021\000\021\000\021\000\021\000\021\000\021\000\021\
\\000\021\000\021\000\021\000\021\000\021\000\021\000\021\000\021\
\\000\021\000\021\000\021\000\000\000\000\000\000\000\000\000\021\
\\000\000\000\021\000\021\000\021\000\021\000\021\000\021\000\021\
\\000\021\000\021\000\021\000\021\000\078\000\021\000\021\000\021\
\\000\021\000\021\000\021\000\021\000\021\000\021\000\021\000\021\
\\000\021\000\021\000\021\000\000\000\000\000\000\000\000\000\000\
\\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\
\\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\
\\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\
\\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\
\\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\
\\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\
\\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\
\\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\
\\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\
\\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\
\\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\
\\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\
\\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\
\\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\
\\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\
\\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000"
),
 (78,256, 
"\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\
\\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\
\\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\
\\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\
\\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\021\
\\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\
\\000\021\000\021\000\021\000\021\000\021\000\021\000\021\000\021\
\\000\021\000\021\000\000\000\000\000\000\000\000\000\000\000\000\
\\000\000\000\021\000\021\000\021\000\021\000\021\000\021\000\021\
\\000\021\000\021\000\021\000\021\000\021\000\021\000\021\000\021\
\\000\021\000\021\000\021\000\021\000\021\000\021\000\021\000\021\
\\000\021\000\021\000\021\000\000\000\000\000\000\000\000\000\021\
\\000\000\000\021\000\021\000\021\000\021\000\021\000\021\000\021\
\\000\021\000\079\000\021\000\021\000\021\000\021\000\021\000\021\
\\000\021\000\021\000\021\000\021\000\021\000\021\000\021\000\021\
\\000\021\000\021\000\021\000\000\000\000\000\000\000\000\000\000\
\\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\
\\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\
\\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\
\\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\
\\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\
\\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\
\\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\
\\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\
\\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\
\\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\
\\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\
\\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\
\\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\
\\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\
\\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\
\\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000"
),
 (79,256, 
"\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\
\\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\
\\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\
\\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\
\\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\021\
\\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\
\\000\021\000\021\000\021\000\021\000\021\000\021\000\021\000\021\
\\000\021\000\021\000\000\000\000\000\000\000\000\000\000\000\000\
\\000\000\000\021\000\021\000\021\000\021\000\021\000\021\000\021\
\\000\021\000\021\000\021\000\021\000\021\000\021\000\021\000\021\
\\000\021\000\021\000\021\000\021\000\021\000\021\000\021\000\021\
\\000\021\000\021\000\021\000\000\000\000\000\000\000\000\000\021\
\\000\000\000\021\000\021\000\080\000\021\000\021\000\021\000\021\
\\000\021\000\021\000\021\000\021\000\021\000\021\000\021\000\021\
\\000\021\000\021\000\021\000\021\000\021\000\021\000\021\000\021\
\\000\021\000\021\000\021\000\000\000\000\000\000\000\000\000\000\
\\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\
\\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\
\\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\
\\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\
\\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\
\\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\
\\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\
\\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\
\\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\
\\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\
\\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\
\\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\
\\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\
\\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\
\\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\
\\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000"
),
 (80,256, 
"\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\
\\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\
\\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\
\\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\
\\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\021\
\\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\
\\000\021\000\021\000\021\000\021\000\021\000\021\000\021\000\021\
\\000\021\000\021\000\000\000\000\000\000\000\000\000\000\000\000\
\\000\000\000\021\000\021\000\021\000\021\000\021\000\021\000\021\
\\000\021\000\021\000\021\000\021\000\021\000\021\000\021\000\021\
\\000\021\000\021\000\021\000\021\000\021\000\021\000\021\000\021\
\\000\021\000\021\000\021\000\000\000\000\000\000\000\000\000\021\
\\000\000\000\021\000\021\000\021\000\021\000\021\000\021\000\021\
\\000\021\000\021\000\021\000\021\000\021\000\021\000\021\000\021\
\\000\021\000\021\000\021\000\021\000\021\000\021\000\021\000\021\
\\000\021\000\081\000\021\000\000\000\000\000\000\000\000\000\000\
\\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\
\\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\
\\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\
\\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\
\\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\
\\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\
\\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\
\\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\
\\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\
\\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\
\\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\
\\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\
\\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\
\\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\
\\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\
\\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000"
),
 (82,256, 
"\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\
\\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\
\\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\
\\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\
\\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\021\
\\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\
\\000\021\000\021\000\021\000\021\000\021\000\021\000\021\000\021\
\\000\021\000\021\000\000\000\000\000\000\000\000\000\000\000\000\
\\000\000\000\021\000\021\000\021\000\021\000\021\000\021\000\021\
\\000\021\000\021\000\021\000\021\000\021\000\021\000\021\000\021\
\\000\021\000\021\000\021\000\021\000\021\000\021\000\021\000\021\
\\000\021\000\021\000\021\000\000\000\000\000\000\000\000\000\021\
\\000\000\000\021\000\021\000\021\000\021\000\021\000\086\000\021\
\\000\021\000\021\000\021\000\021\000\021\000\021\000\021\000\021\
\\000\083\000\021\000\021\000\021\000\021\000\021\000\021\000\021\
\\000\021\000\021\000\021\000\000\000\000\000\000\000\000\000\000\
\\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\
\\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\
\\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\
\\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\
\\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\
\\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\
\\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\
\\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\
\\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\
\\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\
\\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\
\\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\
\\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\
\\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\
\\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\
\\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000"
),
 (83,256, 
"\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\
\\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\
\\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\
\\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\
\\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\021\
\\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\
\\000\021\000\021\000\021\000\021\000\021\000\021\000\021\000\021\
\\000\021\000\021\000\000\000\000\000\000\000\000\000\000\000\000\
\\000\000\000\021\000\021\000\021\000\021\000\021\000\021\000\021\
\\000\021\000\021\000\021\000\021\000\021\000\021\000\021\000\021\
\\000\021\000\021\000\021\000\021\000\021\000\021\000\021\000\021\
\\000\021\000\021\000\021\000\000\000\000\000\000\000\000\000\021\
\\000\000\000\021\000\021\000\021\000\021\000\084\000\021\000\021\
\\000\021\000\021\000\021\000\021\000\021\000\021\000\021\000\021\
\\000\021\000\021\000\021\000\021\000\021\000\021\000\021\000\021\
\\000\021\000\021\000\021\000\000\000\000\000\000\000\000\000\000\
\\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\
\\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\
\\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\
\\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\
\\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\
\\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\
\\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\
\\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\
\\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\
\\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\
\\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\
\\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\
\\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\
\\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\
\\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\
\\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000"
),
 (84,256, 
"\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\
\\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\
\\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\
\\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\
\\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\021\
\\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\
\\000\021\000\021\000\021\000\021\000\021\000\021\000\021\000\021\
\\000\021\000\021\000\000\000\000\000\000\000\000\000\000\000\000\
\\000\000\000\021\000\021\000\021\000\021\000\021\000\021\000\021\
\\000\021\000\021\000\021\000\021\000\021\000\021\000\021\000\021\
\\000\021\000\021\000\021\000\021\000\021\000\021\000\021\000\021\
\\000\021\000\021\000\021\000\000\000\000\000\000\000\000\000\021\
\\000\000\000\021\000\021\000\021\000\021\000\021\000\021\000\021\
\\000\021\000\021\000\021\000\021\000\021\000\021\000\085\000\021\
\\000\021\000\021\000\021\000\021\000\021\000\021\000\021\000\021\
\\000\021\000\021\000\021\000\000\000\000\000\000\000\000\000\000\
\\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\
\\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\
\\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\
\\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\
\\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\
\\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\
\\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\
\\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\
\\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\
\\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\
\\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\
\\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\
\\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\
\\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\
\\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\
\\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000"
),
 (87,256, 
"\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\
\\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\
\\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\
\\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\
\\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\021\
\\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\
\\000\021\000\021\000\021\000\021\000\021\000\021\000\021\000\021\
\\000\021\000\021\000\000\000\000\000\000\000\000\000\000\000\000\
\\000\000\000\021\000\021\000\021\000\021\000\021\000\021\000\021\
\\000\021\000\021\000\021\000\021\000\021\000\021\000\021\000\021\
\\000\021\000\021\000\021\000\021\000\021\000\021\000\021\000\021\
\\000\021\000\021\000\021\000\000\000\000\000\000\000\000\000\021\
\\000\000\000\088\000\021\000\021\000\021\000\021\000\021\000\021\
\\000\021\000\021\000\021\000\021\000\021\000\021\000\021\000\021\
\\000\021\000\021\000\021\000\021\000\021\000\021\000\021\000\021\
\\000\021\000\021\000\021\000\000\000\000\000\000\000\000\000\000\
\\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\
\\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\
\\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\
\\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\
\\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\
\\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\
\\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\
\\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\
\\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\
\\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\
\\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\
\\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\
\\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\
\\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\
\\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\
\\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000"
),
 (88,256, 
"\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\
\\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\
\\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\
\\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\
\\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\021\
\\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\
\\000\021\000\021\000\021\000\021\000\021\000\021\000\021\000\021\
\\000\021\000\021\000\000\000\000\000\000\000\000\000\000\000\000\
\\000\000\000\021\000\021\000\021\000\021\000\021\000\021\000\021\
\\000\021\000\021\000\021\000\021\000\021\000\021\000\021\000\021\
\\000\021\000\021\000\021\000\021\000\021\000\021\000\021\000\021\
\\000\021\000\021\000\021\000\000\000\000\000\000\000\000\000\021\
\\000\000\000\021\000\021\000\021\000\021\000\021\000\021\000\021\
\\000\021\000\021\000\021\000\021\000\021\000\021\000\021\000\021\
\\000\089\000\021\000\021\000\021\000\021\000\021\000\021\000\021\
\\000\021\000\021\000\021\000\000\000\000\000\000\000\000\000\000\
\\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\
\\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\
\\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\
\\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\
\\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\
\\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\
\\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\
\\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\
\\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\
\\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\
\\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\
\\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\
\\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\
\\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\
\\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\
\\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000"
),
 (90,256, 
"\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\
\\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\
\\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\
\\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\
\\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\021\
\\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\
\\000\021\000\021\000\021\000\021\000\021\000\021\000\021\000\021\
\\000\021\000\021\000\000\000\000\000\000\000\000\000\000\000\000\
\\000\000\000\021\000\021\000\021\000\021\000\021\000\021\000\021\
\\000\021\000\021\000\021\000\021\000\021\000\021\000\021\000\021\
\\000\021\000\021\000\021\000\021\000\021\000\021\000\021\000\021\
\\000\021\000\021\000\021\000\000\000\000\000\000\000\000\000\021\
\\000\000\000\021\000\021\000\021\000\021\000\091\000\021\000\021\
\\000\021\000\021\000\021\000\021\000\021\000\021\000\021\000\021\
\\000\021\000\021\000\021\000\021\000\021\000\021\000\021\000\021\
\\000\021\000\021\000\021\000\000\000\000\000\000\000\000\000\000\
\\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\
\\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\
\\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\
\\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\
\\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\
\\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\
\\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\
\\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\
\\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\
\\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\
\\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\
\\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\
\\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\
\\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\
\\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\
\\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000"
),
 (91,256, 
"\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\
\\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\
\\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\
\\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\
\\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\021\
\\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\
\\000\021\000\021\000\021\000\021\000\021\000\021\000\021\000\021\
\\000\021\000\021\000\000\000\000\000\000\000\000\000\000\000\000\
\\000\000\000\021\000\021\000\021\000\021\000\021\000\021\000\021\
\\000\021\000\021\000\021\000\021\000\021\000\021\000\021\000\021\
\\000\021\000\021\000\021\000\021\000\021\000\021\000\021\000\021\
\\000\021\000\021\000\021\000\000\000\000\000\000\000\000\000\021\
\\000\000\000\021\000\021\000\021\000\021\000\021\000\021\000\021\
\\000\021\000\021\000\021\000\021\000\021\000\021\000\021\000\021\
\\000\021\000\021\000\021\000\021\000\092\000\021\000\021\000\021\
\\000\021\000\021\000\021\000\000\000\000\000\000\000\000\000\000\
\\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\
\\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\
\\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\
\\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\
\\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\
\\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\
\\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\
\\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\
\\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\
\\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\
\\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\
\\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\
\\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\
\\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\
\\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\
\\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000"
),
 (93,256, 
"\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\
\\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\
\\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\
\\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\
\\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\021\
\\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\
\\000\021\000\021\000\021\000\021\000\021\000\021\000\021\000\021\
\\000\021\000\021\000\000\000\000\000\000\000\000\000\000\000\000\
\\000\000\000\021\000\021\000\021\000\021\000\021\000\021\000\021\
\\000\021\000\021\000\021\000\021\000\021\000\021\000\021\000\021\
\\000\021\000\021\000\021\000\021\000\021\000\021\000\021\000\021\
\\000\021\000\021\000\021\000\000\000\000\000\000\000\000\000\021\
\\000\000\000\021\000\021\000\021\000\021\000\021\000\100\000\021\
\\000\021\000\021\000\021\000\021\000\021\000\021\000\094\000\021\
\\000\021\000\021\000\021\000\021\000\021\000\021\000\021\000\021\
\\000\021\000\021\000\021\000\000\000\000\000\000\000\000\000\000\
\\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\
\\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\
\\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\
\\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\
\\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\
\\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\
\\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\
\\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\
\\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\
\\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\
\\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\
\\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\
\\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\
\\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\
\\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\
\\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000"
),
 (94,256, 
"\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\
\\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\
\\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\
\\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\
\\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\021\
\\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\
\\000\021\000\021\000\021\000\021\000\021\000\021\000\021\000\021\
\\000\021\000\021\000\000\000\000\000\000\000\000\000\000\000\000\
\\000\000\000\021\000\021\000\021\000\021\000\021\000\021\000\021\
\\000\021\000\021\000\021\000\021\000\021\000\021\000\021\000\021\
\\000\021\000\021\000\021\000\021\000\021\000\021\000\021\000\021\
\\000\021\000\021\000\021\000\000\000\000\000\000\000\000\000\021\
\\000\000\000\021\000\021\000\095\000\021\000\021\000\021\000\021\
\\000\021\000\021\000\021\000\021\000\021\000\021\000\021\000\021\
\\000\021\000\021\000\021\000\021\000\021\000\021\000\021\000\021\
\\000\021\000\021\000\021\000\000\000\000\000\000\000\000\000\000\
\\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\
\\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\
\\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\
\\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\
\\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\
\\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\
\\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\
\\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\
\\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\
\\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\
\\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\
\\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\
\\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\
\\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\
\\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\
\\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000"
),
 (95,256, 
"\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\
\\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\
\\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\
\\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\
\\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\021\
\\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\
\\000\021\000\021\000\021\000\021\000\021\000\021\000\021\000\021\
\\000\021\000\021\000\000\000\000\000\000\000\000\000\000\000\000\
\\000\000\000\021\000\021\000\021\000\021\000\021\000\021\000\021\
\\000\021\000\021\000\021\000\021\000\021\000\021\000\021\000\021\
\\000\021\000\021\000\021\000\021\000\021\000\021\000\021\000\021\
\\000\021\000\021\000\021\000\000\000\000\000\000\000\000\000\021\
\\000\000\000\021\000\021\000\021\000\021\000\021\000\021\000\021\
\\000\021\000\021\000\021\000\021\000\096\000\021\000\021\000\021\
\\000\021\000\021\000\021\000\021\000\021\000\021\000\021\000\021\
\\000\021\000\021\000\021\000\000\000\000\000\000\000\000\000\000\
\\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\
\\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\
\\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\
\\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\
\\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\
\\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\
\\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\
\\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\
\\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\
\\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\
\\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\
\\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\
\\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\
\\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\
\\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\
\\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000"
),
 (96,256, 
"\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\
\\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\
\\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\
\\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\
\\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\021\
\\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\
\\000\021\000\021\000\021\000\021\000\021\000\021\000\021\000\021\
\\000\021\000\021\000\000\000\000\000\000\000\000\000\000\000\000\
\\000\000\000\021\000\021\000\021\000\021\000\021\000\021\000\021\
\\000\021\000\021\000\021\000\021\000\021\000\021\000\021\000\021\
\\000\021\000\021\000\021\000\021\000\021\000\021\000\021\000\021\
\\000\021\000\021\000\021\000\000\000\000\000\000\000\000\000\021\
\\000\000\000\021\000\021\000\021\000\021\000\021\000\021\000\021\
\\000\021\000\021\000\021\000\021\000\021\000\021\000\021\000\021\
\\000\021\000\021\000\021\000\021\000\021\000\097\000\021\000\021\
\\000\021\000\021\000\021\000\000\000\000\000\000\000\000\000\000\
\\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\
\\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\
\\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\
\\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\
\\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\
\\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\
\\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\
\\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\
\\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\
\\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\
\\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\
\\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\
\\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\
\\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\
\\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\
\\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000"
),
 (97,256, 
"\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\
\\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\
\\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\
\\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\
\\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\021\
\\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\
\\000\021\000\021\000\021\000\021\000\021\000\021\000\021\000\021\
\\000\021\000\021\000\000\000\000\000\000\000\000\000\000\000\000\
\\000\000\000\021\000\021\000\021\000\021\000\021\000\021\000\021\
\\000\021\000\021\000\021\000\021\000\021\000\021\000\021\000\021\
\\000\021\000\021\000\021\000\021\000\021\000\021\000\021\000\021\
\\000\021\000\021\000\021\000\000\000\000\000\000\000\000\000\021\
\\000\000\000\021\000\021\000\021\000\098\000\021\000\021\000\021\
\\000\021\000\021\000\021\000\021\000\021\000\021\000\021\000\021\
\\000\021\000\021\000\021\000\021\000\021\000\021\000\021\000\021\
\\000\021\000\021\000\021\000\000\000\000\000\000\000\000\000\000\
\\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\
\\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\
\\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\
\\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\
\\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\
\\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\
\\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\
\\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\
\\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\
\\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\
\\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\
\\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\
\\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\
\\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\
\\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\
\\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000"
),
 (98,256, 
"\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\
\\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\
\\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\
\\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\
\\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\021\
\\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\
\\000\021\000\021\000\021\000\021\000\021\000\021\000\021\000\021\
\\000\021\000\021\000\000\000\000\000\000\000\000\000\000\000\000\
\\000\000\000\021\000\021\000\021\000\021\000\021\000\021\000\021\
\\000\021\000\021\000\021\000\021\000\021\000\021\000\021\000\021\
\\000\021\000\021\000\021\000\021\000\021\000\021\000\021\000\021\
\\000\021\000\021\000\021\000\000\000\000\000\000\000\000\000\021\
\\000\000\000\021\000\021\000\021\000\021\000\099\000\021\000\021\
\\000\021\000\021\000\021\000\021\000\021\000\021\000\021\000\021\
\\000\021\000\021\000\021\000\021\000\021\000\021\000\021\000\021\
\\000\021\000\021\000\021\000\000\000\000\000\000\000\000\000\000\
\\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\
\\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\
\\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\
\\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\
\\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\
\\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\
\\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\
\\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\
\\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\
\\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\
\\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\
\\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\
\\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\
\\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\
\\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\
\\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000"
),
 (101,256, 
"\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\
\\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\
\\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\
\\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\
\\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\021\
\\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\
\\000\021\000\021\000\021\000\021\000\021\000\021\000\021\000\021\
\\000\021\000\021\000\000\000\000\000\000\000\000\000\000\000\000\
\\000\000\000\021\000\021\000\021\000\021\000\021\000\021\000\021\
\\000\021\000\021\000\021\000\021\000\021\000\021\000\021\000\021\
\\000\021\000\021\000\021\000\021\000\021\000\021\000\021\000\021\
\\000\021\000\021\000\021\000\000\000\000\000\000\000\000\000\021\
\\000\000\000\021\000\021\000\021\000\021\000\021\000\109\000\021\
\\000\021\000\021\000\021\000\021\000\021\000\021\000\108\000\021\
\\000\021\000\021\000\021\000\021\000\021\000\102\000\021\000\021\
\\000\021\000\021\000\021\000\000\000\000\000\000\000\000\000\000\
\\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\
\\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\
\\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\
\\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\
\\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\
\\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\
\\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\
\\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\
\\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\
\\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\
\\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\
\\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\
\\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\
\\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\
\\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\
\\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000"
),
 (102,256, 
"\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\
\\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\
\\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\
\\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\
\\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\021\
\\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\
\\000\021\000\021\000\021\000\021\000\021\000\021\000\021\000\021\
\\000\021\000\021\000\000\000\000\000\000\000\000\000\000\000\000\
\\000\000\000\021\000\021\000\021\000\021\000\021\000\021\000\021\
\\000\021\000\021\000\021\000\021\000\021\000\021\000\021\000\021\
\\000\021\000\021\000\021\000\021\000\021\000\021\000\021\000\021\
\\000\021\000\021\000\021\000\000\000\000\000\000\000\000\000\021\
\\000\000\000\021\000\021\000\021\000\021\000\021\000\021\000\021\
\\000\021\000\021\000\021\000\021\000\021\000\021\000\103\000\021\
\\000\021\000\021\000\021\000\021\000\021\000\021\000\021\000\021\
\\000\021\000\021\000\021\000\000\000\000\000\000\000\000\000\000\
\\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\
\\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\
\\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\
\\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\
\\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\
\\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\
\\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\
\\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\
\\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\
\\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\
\\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\
\\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\
\\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\
\\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\
\\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\
\\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000"
),
 (103,256, 
"\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\
\\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\
\\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\
\\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\
\\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\021\
\\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\
\\000\021\000\021\000\021\000\021\000\021\000\021\000\021\000\021\
\\000\021\000\021\000\000\000\000\000\000\000\000\000\000\000\000\
\\000\000\000\021\000\021\000\021\000\021\000\021\000\021\000\021\
\\000\021\000\021\000\021\000\021\000\021\000\021\000\021\000\021\
\\000\021\000\021\000\021\000\021\000\021\000\021\000\021\000\021\
\\000\021\000\021\000\021\000\000\000\000\000\000\000\000\000\021\
\\000\000\000\021\000\021\000\104\000\021\000\021\000\021\000\021\
\\000\021\000\021\000\021\000\021\000\021\000\021\000\021\000\021\
\\000\021\000\021\000\021\000\021\000\021\000\021\000\021\000\021\
\\000\021\000\021\000\021\000\000\000\000\000\000\000\000\000\000\
\\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\
\\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\
\\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\
\\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\
\\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\
\\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\
\\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\
\\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\
\\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\
\\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\
\\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\
\\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\
\\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\
\\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\
\\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\
\\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000"
),
 (104,256, 
"\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\
\\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\
\\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\
\\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\
\\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\021\
\\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\
\\000\021\000\021\000\021\000\021\000\021\000\021\000\021\000\021\
\\000\021\000\021\000\000\000\000\000\000\000\000\000\000\000\000\
\\000\000\000\021\000\021\000\021\000\021\000\021\000\021\000\021\
\\000\021\000\021\000\021\000\021\000\021\000\021\000\021\000\021\
\\000\021\000\021\000\021\000\021\000\021\000\021\000\021\000\021\
\\000\021\000\021\000\021\000\000\000\000\000\000\000\000\000\021\
\\000\000\000\021\000\021\000\021\000\021\000\021\000\021\000\021\
\\000\021\000\021\000\021\000\021\000\021\000\021\000\021\000\021\
\\000\021\000\021\000\021\000\021\000\105\000\021\000\021\000\021\
\\000\021\000\021\000\021\000\000\000\000\000\000\000\000\000\000\
\\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\
\\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\
\\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\
\\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\
\\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\
\\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\
\\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\
\\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\
\\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\
\\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\
\\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\
\\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\
\\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\
\\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\
\\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\
\\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000"
),
 (105,256, 
"\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\
\\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\
\\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\
\\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\
\\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\021\
\\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\
\\000\021\000\021\000\021\000\021\000\021\000\021\000\021\000\021\
\\000\021\000\021\000\000\000\000\000\000\000\000\000\000\000\000\
\\000\000\000\021\000\021\000\021\000\021\000\021\000\021\000\021\
\\000\021\000\021\000\021\000\021\000\021\000\021\000\021\000\021\
\\000\021\000\021\000\021\000\021\000\021\000\021\000\021\000\021\
\\000\021\000\021\000\021\000\000\000\000\000\000\000\000\000\021\
\\000\000\000\021\000\021\000\021\000\021\000\021\000\021\000\021\
\\000\021\000\021\000\021\000\021\000\021\000\021\000\021\000\106\
\\000\021\000\021\000\021\000\021\000\021\000\021\000\021\000\021\
\\000\021\000\021\000\021\000\000\000\000\000\000\000\000\000\000\
\\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\
\\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\
\\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\
\\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\
\\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\
\\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\
\\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\
\\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\
\\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\
\\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\
\\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\
\\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\
\\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\
\\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\
\\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\
\\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000"
),
 (106,256, 
"\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\
\\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\
\\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\
\\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\
\\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\021\
\\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\
\\000\021\000\021\000\021\000\021\000\021\000\021\000\021\000\021\
\\000\021\000\021\000\000\000\000\000\000\000\000\000\000\000\000\
\\000\000\000\021\000\021\000\021\000\021\000\021\000\021\000\021\
\\000\021\000\021\000\021\000\021\000\021\000\021\000\021\000\021\
\\000\021\000\021\000\021\000\021\000\021\000\021\000\021\000\021\
\\000\021\000\021\000\021\000\000\000\000\000\000\000\000\000\021\
\\000\000\000\021\000\021\000\021\000\021\000\021\000\021\000\021\
\\000\021\000\021\000\021\000\021\000\021\000\021\000\021\000\021\
\\000\021\000\021\000\107\000\021\000\021\000\021\000\021\000\021\
\\000\021\000\021\000\021\000\000\000\000\000\000\000\000\000\000\
\\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\
\\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\
\\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\
\\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\
\\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\
\\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\
\\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\
\\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\
\\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\
\\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\
\\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\
\\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\
\\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\
\\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\
\\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\
\\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000"
),
 (109,256, 
"\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\
\\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\
\\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\
\\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\
\\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\021\
\\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\
\\000\021\000\021\000\021\000\021\000\021\000\021\000\021\000\021\
\\000\021\000\021\000\000\000\000\000\000\000\000\000\000\000\000\
\\000\000\000\021\000\021\000\021\000\021\000\021\000\021\000\021\
\\000\021\000\021\000\021\000\021\000\021\000\021\000\021\000\021\
\\000\021\000\021\000\021\000\021\000\021\000\021\000\021\000\021\
\\000\021\000\021\000\021\000\000\000\000\000\000\000\000\000\021\
\\000\000\000\021\000\021\000\021\000\021\000\021\000\021\000\021\
\\000\021\000\110\000\021\000\021\000\021\000\021\000\021\000\021\
\\000\021\000\021\000\021\000\021\000\021\000\021\000\021\000\021\
\\000\021\000\021\000\021\000\000\000\000\000\000\000\000\000\000\
\\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\
\\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\
\\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\
\\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\
\\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\
\\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\
\\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\
\\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\
\\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\
\\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\
\\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\
\\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\
\\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\
\\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\
\\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\
\\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000"
),
 (111,256, 
"\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\
\\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\
\\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\
\\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\
\\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\021\
\\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\
\\000\021\000\021\000\021\000\021\000\021\000\021\000\021\000\021\
\\000\021\000\021\000\000\000\000\000\000\000\000\000\000\000\000\
\\000\000\000\021\000\021\000\021\000\021\000\021\000\021\000\021\
\\000\021\000\021\000\021\000\021\000\021\000\021\000\021\000\021\
\\000\021\000\021\000\021\000\021\000\021\000\021\000\021\000\021\
\\000\021\000\021\000\021\000\000\000\000\000\000\000\000\000\021\
\\000\000\000\021\000\021\000\021\000\021\000\021\000\021\000\021\
\\000\021\000\021\000\021\000\021\000\119\000\021\000\117\000\021\
\\000\021\000\021\000\021\000\021\000\021\000\021\000\021\000\021\
\\000\112\000\021\000\021\000\000\000\000\000\000\000\000\000\000\
\\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\
\\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\
\\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\
\\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\
\\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\
\\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\
\\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\
\\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\
\\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\
\\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\
\\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\
\\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\
\\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\
\\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\
\\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\
\\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000"
),
 (112,256, 
"\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\
\\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\
\\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\
\\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\
\\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\021\
\\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\
\\000\021\000\021\000\021\000\021\000\021\000\021\000\021\000\021\
\\000\021\000\021\000\000\000\000\000\000\000\000\000\000\000\000\
\\000\000\000\021\000\021\000\021\000\021\000\021\000\021\000\021\
\\000\021\000\021\000\021\000\021\000\021\000\021\000\021\000\021\
\\000\021\000\021\000\021\000\021\000\021\000\021\000\021\000\021\
\\000\021\000\021\000\021\000\000\000\000\000\000\000\000\000\021\
\\000\000\000\021\000\021\000\021\000\021\000\021\000\021\000\021\
\\000\021\000\021\000\021\000\021\000\021\000\021\000\021\000\021\
\\000\113\000\021\000\021\000\021\000\021\000\021\000\021\000\021\
\\000\021\000\021\000\021\000\000\000\000\000\000\000\000\000\000\
\\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\
\\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\
\\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\
\\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\
\\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\
\\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\
\\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\
\\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\
\\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\
\\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\
\\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\
\\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\
\\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\
\\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\
\\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\
\\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000"
),
 (113,256, 
"\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\
\\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\
\\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\
\\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\
\\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\021\
\\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\
\\000\021\000\021\000\021\000\021\000\021\000\021\000\021\000\021\
\\000\021\000\021\000\000\000\000\000\000\000\000\000\000\000\000\
\\000\000\000\021\000\021\000\021\000\021\000\021\000\021\000\021\
\\000\021\000\021\000\021\000\021\000\021\000\021\000\021\000\021\
\\000\021\000\021\000\021\000\021\000\021\000\021\000\021\000\021\
\\000\021\000\021\000\021\000\000\000\000\000\000\000\000\000\021\
\\000\000\000\021\000\021\000\021\000\021\000\021\000\021\000\021\
\\000\021\000\021\000\021\000\021\000\021\000\021\000\021\000\114\
\\000\021\000\021\000\021\000\021\000\021\000\021\000\021\000\021\
\\000\021\000\021\000\021\000\000\000\000\000\000\000\000\000\000\
\\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\
\\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\
\\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\
\\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\
\\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\
\\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\
\\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\
\\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\
\\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\
\\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\
\\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\
\\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\
\\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\
\\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\
\\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\
\\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000"
),
 (114,256, 
"\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\
\\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\
\\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\
\\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\
\\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\021\
\\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\
\\000\021\000\021\000\021\000\021\000\021\000\021\000\021\000\021\
\\000\021\000\021\000\000\000\000\000\000\000\000\000\000\000\000\
\\000\000\000\021\000\021\000\021\000\021\000\021\000\021\000\021\
\\000\021\000\021\000\021\000\021\000\021\000\021\000\021\000\021\
\\000\021\000\021\000\021\000\021\000\021\000\021\000\021\000\021\
\\000\021\000\021\000\021\000\000\000\000\000\000\000\000\000\021\
\\000\000\000\021\000\021\000\021\000\021\000\021\000\021\000\021\
\\000\021\000\021\000\021\000\021\000\021\000\021\000\021\000\021\
\\000\021\000\021\000\115\000\021\000\021\000\021\000\021\000\021\
\\000\021\000\021\000\021\000\000\000\000\000\000\000\000\000\000\
\\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\
\\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\
\\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\
\\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\
\\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\
\\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\
\\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\
\\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\
\\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\
\\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\
\\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\
\\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\
\\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\
\\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\
\\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\
\\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000"
),
 (115,256, 
"\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\
\\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\
\\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\
\\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\
\\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\021\
\\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\
\\000\021\000\021\000\021\000\021\000\021\000\021\000\021\000\021\
\\000\021\000\021\000\000\000\000\000\000\000\000\000\000\000\000\
\\000\000\000\021\000\021\000\021\000\021\000\021\000\021\000\021\
\\000\021\000\021\000\021\000\021\000\021\000\021\000\021\000\021\
\\000\021\000\021\000\021\000\021\000\021\000\021\000\021\000\021\
\\000\021\000\021\000\021\000\000\000\000\000\000\000\000\000\021\
\\000\000\000\021\000\021\000\021\000\021\000\021\000\021\000\021\
\\000\021\000\021\000\021\000\021\000\021\000\021\000\021\000\021\
\\000\021\000\021\000\021\000\021\000\116\000\021\000\021\000\021\
\\000\021\000\021\000\021\000\000\000\000\000\000\000\000\000\000\
\\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\
\\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\
\\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\
\\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\
\\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\
\\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\
\\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\
\\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\
\\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\
\\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\
\\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\
\\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\
\\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\
\\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\
\\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\
\\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000"
),
 (117,256, 
"\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\
\\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\
\\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\
\\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\
\\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\021\
\\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\
\\000\021\000\021\000\021\000\021\000\021\000\021\000\021\000\021\
\\000\021\000\021\000\000\000\000\000\000\000\000\000\000\000\000\
\\000\000\000\021\000\021\000\021\000\021\000\021\000\021\000\021\
\\000\021\000\021\000\021\000\021\000\021\000\021\000\021\000\021\
\\000\021\000\021\000\021\000\021\000\021\000\021\000\021\000\021\
\\000\021\000\021\000\021\000\000\000\000\000\000\000\000\000\021\
\\000\000\000\021\000\021\000\021\000\118\000\021\000\021\000\021\
\\000\021\000\021\000\021\000\021\000\021\000\021\000\021\000\021\
\\000\021\000\021\000\021\000\021\000\021\000\021\000\021\000\021\
\\000\021\000\021\000\021\000\000\000\000\000\000\000\000\000\000\
\\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\
\\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\
\\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\
\\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\
\\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\
\\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\
\\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\
\\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\
\\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\
\\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\
\\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\
\\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\
\\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\
\\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\
\\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\
\\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000"
),
 (119,256, 
"\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\
\\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\
\\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\
\\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\
\\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\021\
\\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\
\\000\021\000\021\000\021\000\021\000\021\000\021\000\021\000\021\
\\000\021\000\021\000\000\000\000\000\000\000\000\000\000\000\000\
\\000\000\000\021\000\021\000\021\000\021\000\021\000\021\000\021\
\\000\021\000\021\000\021\000\021\000\021\000\021\000\021\000\021\
\\000\021\000\021\000\021\000\021\000\021\000\021\000\021\000\021\
\\000\021\000\021\000\021\000\000\000\000\000\000\000\000\000\021\
\\000\000\000\021\000\021\000\021\000\021\000\021\000\021\000\021\
\\000\021\000\021\000\021\000\021\000\021\000\021\000\021\000\021\
\\000\021\000\021\000\021\000\120\000\021\000\021\000\021\000\021\
\\000\021\000\021\000\021\000\000\000\000\000\000\000\000\000\000\
\\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\
\\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\
\\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\
\\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\
\\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\
\\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\
\\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\
\\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\
\\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\
\\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\
\\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\
\\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\
\\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\
\\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\
\\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\
\\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000"
),
 (120,256, 
"\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\
\\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\
\\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\
\\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\
\\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\021\
\\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\
\\000\021\000\021\000\021\000\021\000\021\000\021\000\021\000\021\
\\000\021\000\021\000\000\000\000\000\000\000\000\000\000\000\000\
\\000\000\000\021\000\021\000\021\000\021\000\021\000\021\000\021\
\\000\021\000\021\000\021\000\021\000\021\000\021\000\021\000\021\
\\000\021\000\021\000\021\000\021\000\021\000\021\000\021\000\021\
\\000\021\000\021\000\021\000\000\000\000\000\000\000\000\000\021\
\\000\000\000\021\000\021\000\021\000\021\000\121\000\021\000\021\
\\000\021\000\021\000\021\000\021\000\021\000\021\000\021\000\021\
\\000\021\000\021\000\021\000\021\000\021\000\021\000\021\000\021\
\\000\021\000\021\000\021\000\000\000\000\000\000\000\000\000\000\
\\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\
\\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\
\\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\
\\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\
\\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\
\\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\
\\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\
\\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\
\\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\
\\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\
\\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\
\\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\
\\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\
\\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\
\\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\
\\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000"
),
 (122,256, 
"\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\
\\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\
\\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\
\\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\
\\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\021\
\\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\
\\000\021\000\021\000\021\000\021\000\021\000\021\000\021\000\021\
\\000\021\000\021\000\000\000\000\000\000\000\000\000\000\000\000\
\\000\000\000\021\000\021\000\021\000\021\000\021\000\021\000\021\
\\000\021\000\021\000\021\000\021\000\021\000\021\000\021\000\021\
\\000\021\000\021\000\021\000\021\000\021\000\021\000\021\000\021\
\\000\021\000\021\000\021\000\000\000\000\000\000\000\000\000\021\
\\000\000\000\123\000\021\000\021\000\021\000\021\000\021\000\021\
\\000\021\000\021\000\021\000\021\000\021\000\021\000\021\000\021\
\\000\021\000\021\000\021\000\021\000\021\000\021\000\021\000\021\
\\000\021\000\021\000\021\000\000\000\000\000\000\000\000\000\000\
\\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\
\\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\
\\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\
\\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\
\\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\
\\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\
\\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\
\\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\
\\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\
\\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\
\\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\
\\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\
\\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\
\\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\
\\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\
\\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000"
),
 (123,256, 
"\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\
\\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\
\\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\
\\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\
\\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\021\
\\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\
\\000\021\000\021\000\021\000\021\000\021\000\021\000\021\000\021\
\\000\021\000\021\000\000\000\000\000\000\000\000\000\000\000\000\
\\000\000\000\021\000\021\000\021\000\021\000\021\000\021\000\021\
\\000\021\000\021\000\021\000\021\000\021\000\021\000\021\000\021\
\\000\021\000\021\000\021\000\021\000\021\000\021\000\021\000\021\
\\000\021\000\021\000\021\000\000\000\000\000\000\000\000\000\021\
\\000\000\000\021\000\021\000\021\000\021\000\021\000\021\000\021\
\\000\021\000\021\000\021\000\021\000\021\000\021\000\021\000\021\
\\000\021\000\021\000\021\000\021\000\124\000\021\000\021\000\021\
\\000\021\000\021\000\021\000\000\000\000\000\000\000\000\000\000\
\\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\
\\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\
\\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\
\\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\
\\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\
\\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\
\\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\
\\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\
\\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\
\\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\
\\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\
\\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\
\\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\
\\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\
\\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\
\\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000"
),
 (124,256, 
"\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\
\\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\
\\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\
\\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\
\\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\021\
\\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\
\\000\021\000\021\000\021\000\021\000\021\000\021\000\021\000\021\
\\000\021\000\021\000\000\000\000\000\000\000\000\000\000\000\000\
\\000\000\000\021\000\021\000\021\000\021\000\021\000\021\000\021\
\\000\021\000\021\000\021\000\021\000\021\000\021\000\021\000\021\
\\000\021\000\021\000\021\000\021\000\021\000\021\000\021\000\021\
\\000\021\000\021\000\021\000\000\000\000\000\000\000\000\000\021\
\\000\000\000\125\000\021\000\021\000\021\000\021\000\021\000\021\
\\000\021\000\021\000\021\000\021\000\021\000\021\000\021\000\021\
\\000\021\000\021\000\021\000\021\000\021\000\021\000\021\000\021\
\\000\021\000\021\000\021\000\000\000\000\000\000\000\000\000\000\
\\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\
\\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\
\\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\
\\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\
\\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\
\\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\
\\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\
\\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\
\\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\
\\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\
\\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\
\\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\
\\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\
\\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\
\\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\
\\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000"
),
 (125,256, 
"\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\
\\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\
\\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\
\\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\
\\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\021\
\\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\
\\000\021\000\021\000\021\000\021\000\021\000\021\000\021\000\021\
\\000\021\000\021\000\000\000\000\000\000\000\000\000\000\000\000\
\\000\000\000\021\000\021\000\021\000\021\000\021\000\021\000\021\
\\000\021\000\021\000\021\000\021\000\021\000\021\000\021\000\021\
\\000\021\000\021\000\021\000\021\000\021\000\021\000\021\000\021\
\\000\021\000\021\000\021\000\000\000\000\000\000\000\000\000\021\
\\000\000\000\021\000\021\000\021\000\021\000\021\000\021\000\021\
\\000\021\000\021\000\021\000\021\000\021\000\021\000\021\000\021\
\\000\021\000\021\000\021\000\021\000\126\000\021\000\021\000\021\
\\000\021\000\021\000\021\000\000\000\000\000\000\000\000\000\000\
\\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\
\\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\
\\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\
\\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\
\\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\
\\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\
\\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\
\\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\
\\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\
\\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\
\\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\
\\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\
\\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\
\\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\
\\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\
\\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000"
),
 (126,256, 
"\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\
\\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\
\\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\
\\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\
\\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\021\
\\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\
\\000\021\000\021\000\021\000\021\000\021\000\021\000\021\000\021\
\\000\021\000\021\000\000\000\000\000\000\000\000\000\000\000\000\
\\000\000\000\021\000\021\000\021\000\021\000\021\000\021\000\021\
\\000\021\000\021\000\021\000\021\000\021\000\021\000\021\000\021\
\\000\021\000\021\000\021\000\021\000\021\000\021\000\021\000\021\
\\000\021\000\021\000\021\000\000\000\000\000\000\000\000\000\021\
\\000\000\000\021\000\021\000\021\000\021\000\021\000\021\000\021\
\\000\021\000\021\000\021\000\021\000\021\000\021\000\021\000\021\
\\000\021\000\021\000\021\000\021\000\021\000\021\000\021\000\021\
\\000\021\000\127\000\021\000\000\000\000\000\000\000\000\000\000\
\\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\
\\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\
\\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\
\\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\
\\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\
\\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\
\\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\
\\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\
\\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\
\\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\
\\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\
\\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\
\\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\
\\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\
\\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\
\\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000"
),
 (127,256, 
"\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\
\\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\
\\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\
\\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\
\\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\021\
\\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\
\\000\021\000\021\000\021\000\021\000\021\000\021\000\021\000\021\
\\000\021\000\021\000\000\000\000\000\000\000\000\000\000\000\000\
\\000\000\000\021\000\021\000\021\000\021\000\021\000\021\000\021\
\\000\021\000\021\000\021\000\021\000\021\000\021\000\021\000\021\
\\000\021\000\021\000\021\000\021\000\021\000\021\000\021\000\021\
\\000\021\000\021\000\021\000\000\000\000\000\000\000\000\000\021\
\\000\000\000\021\000\021\000\021\000\021\000\021\000\021\000\021\
\\000\021\000\021\000\021\000\021\000\021\000\021\000\021\000\021\
\\000\128\000\021\000\021\000\021\000\021\000\021\000\021\000\021\
\\000\021\000\021\000\021\000\000\000\000\000\000\000\000\000\000\
\\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\
\\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\
\\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\
\\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\
\\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\
\\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\
\\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\
\\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\
\\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\
\\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\
\\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\
\\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\
\\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\
\\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\
\\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\
\\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000"
),
 (128,256, 
"\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\
\\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\
\\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\
\\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\
\\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\021\
\\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\
\\000\021\000\021\000\021\000\021\000\021\000\021\000\021\000\021\
\\000\021\000\021\000\000\000\000\000\000\000\000\000\000\000\000\
\\000\000\000\021\000\021\000\021\000\021\000\021\000\021\000\021\
\\000\021\000\021\000\021\000\021\000\021\000\021\000\021\000\021\
\\000\021\000\021\000\021\000\021\000\021\000\021\000\021\000\021\
\\000\021\000\021\000\021\000\000\000\000\000\000\000\000\000\021\
\\000\000\000\021\000\021\000\021\000\021\000\129\000\021\000\021\
\\000\021\000\021\000\021\000\021\000\021\000\021\000\021\000\021\
\\000\021\000\021\000\021\000\021\000\021\000\021\000\021\000\021\
\\000\021\000\021\000\021\000\000\000\000\000\000\000\000\000\000\
\\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\
\\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\
\\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\
\\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\
\\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\
\\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\
\\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\
\\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\
\\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\
\\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\
\\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\
\\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\
\\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\
\\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\
\\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\
\\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000"
),
 (130,256, 
"\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\
\\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\
\\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\
\\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\
\\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\021\
\\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\
\\000\021\000\021\000\021\000\021\000\021\000\021\000\021\000\021\
\\000\021\000\021\000\000\000\000\000\000\000\000\000\000\000\000\
\\000\000\000\021\000\021\000\021\000\021\000\021\000\021\000\021\
\\000\021\000\021\000\021\000\021\000\021\000\021\000\021\000\021\
\\000\021\000\021\000\021\000\021\000\021\000\021\000\021\000\021\
\\000\021\000\021\000\021\000\000\000\000\000\000\000\000\000\021\
\\000\000\000\149\000\021\000\021\000\021\000\021\000\021\000\021\
\\000\021\000\021\000\021\000\021\000\145\000\021\000\021\000\131\
\\000\021\000\021\000\021\000\021\000\021\000\021\000\021\000\021\
\\000\021\000\021\000\021\000\000\000\000\000\000\000\000\000\000\
\\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\
\\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\
\\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\
\\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\
\\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\
\\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\
\\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\
\\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\
\\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\
\\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\
\\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\
\\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\
\\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\
\\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\
\\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\
\\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000"
),
 (131,256, 
"\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\
\\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\
\\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\
\\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\
\\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\021\
\\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\
\\000\021\000\021\000\021\000\021\000\021\000\021\000\021\000\021\
\\000\021\000\021\000\000\000\000\000\000\000\000\000\000\000\000\
\\000\000\000\021\000\021\000\021\000\021\000\021\000\021\000\021\
\\000\021\000\021\000\021\000\021\000\021\000\021\000\021\000\021\
\\000\021\000\021\000\021\000\021\000\021\000\021\000\021\000\021\
\\000\021\000\021\000\021\000\000\000\000\000\000\000\000\000\021\
\\000\000\000\021\000\021\000\021\000\021\000\021\000\021\000\021\
\\000\021\000\021\000\021\000\021\000\021\000\021\000\136\000\132\
\\000\021\000\021\000\021\000\021\000\021\000\021\000\021\000\021\
\\000\021\000\021\000\021\000\000\000\000\000\000\000\000\000\000\
\\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\
\\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\
\\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\
\\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\
\\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\
\\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\
\\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\
\\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\
\\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\
\\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\
\\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\
\\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\
\\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\
\\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\
\\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\
\\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000"
),
 (132,256, 
"\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\
\\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\
\\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\
\\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\
\\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\021\
\\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\
\\000\021\000\021\000\021\000\021\000\021\000\021\000\021\000\021\
\\000\021\000\021\000\000\000\000\000\000\000\000\000\000\000\000\
\\000\000\000\021\000\021\000\021\000\021\000\021\000\021\000\021\
\\000\021\000\021\000\021\000\021\000\021\000\021\000\021\000\021\
\\000\021\000\021\000\021\000\021\000\021\000\021\000\021\000\021\
\\000\021\000\021\000\021\000\000\000\000\000\000\000\000\000\021\
\\000\000\000\021\000\021\000\021\000\021\000\021\000\021\000\021\
\\000\021\000\021\000\021\000\133\000\021\000\021\000\021\000\021\
\\000\021\000\021\000\021\000\021\000\021\000\021\000\021\000\021\
\\000\021\000\021\000\021\000\000\000\000\000\000\000\000\000\000\
\\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\
\\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\
\\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\
\\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\
\\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\
\\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\
\\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\
\\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\
\\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\
\\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\
\\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\
\\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\
\\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\
\\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\
\\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\
\\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000"
),
 (133,256, 
"\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\
\\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\
\\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\
\\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\
\\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\021\
\\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\
\\000\021\000\021\000\021\000\021\000\021\000\021\000\021\000\021\
\\000\021\000\021\000\000\000\000\000\000\000\000\000\000\000\000\
\\000\000\000\021\000\021\000\021\000\021\000\021\000\021\000\021\
\\000\021\000\021\000\021\000\021\000\021\000\021\000\021\000\021\
\\000\021\000\021\000\021\000\021\000\021\000\021\000\021\000\021\
\\000\021\000\021\000\021\000\000\000\000\000\000\000\000\000\021\
\\000\000\000\021\000\021\000\021\000\021\000\021\000\021\000\021\
\\000\021\000\134\000\021\000\021\000\021\000\021\000\021\000\021\
\\000\021\000\021\000\021\000\021\000\021\000\021\000\021\000\021\
\\000\021\000\021\000\021\000\000\000\000\000\000\000\000\000\000\
\\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\
\\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\
\\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\
\\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\
\\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\
\\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\
\\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\
\\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\
\\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\
\\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\
\\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\
\\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\
\\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\
\\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\
\\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\
\\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000"
),
 (134,256, 
"\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\
\\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\
\\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\
\\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\
\\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\021\
\\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\
\\000\021\000\021\000\021\000\021\000\021\000\021\000\021\000\021\
\\000\021\000\021\000\000\000\000\000\000\000\000\000\000\000\000\
\\000\000\000\021\000\021\000\021\000\021\000\021\000\021\000\021\
\\000\021\000\021\000\021\000\021\000\021\000\021\000\021\000\021\
\\000\021\000\021\000\021\000\021\000\021\000\021\000\021\000\021\
\\000\021\000\021\000\021\000\000\000\000\000\000\000\000\000\021\
\\000\000\000\021\000\021\000\021\000\021\000\135\000\021\000\021\
\\000\021\000\021\000\021\000\021\000\021\000\021\000\021\000\021\
\\000\021\000\021\000\021\000\021\000\021\000\021\000\021\000\021\
\\000\021\000\021\000\021\000\000\000\000\000\000\000\000\000\000\
\\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\
\\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\
\\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\
\\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\
\\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\
\\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\
\\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\
\\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\
\\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\
\\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\
\\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\
\\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\
\\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\
\\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\
\\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\
\\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000"
),
 (136,256, 
"\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\
\\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\
\\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\
\\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\
\\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\021\
\\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\
\\000\021\000\021\000\021\000\021\000\021\000\021\000\021\000\021\
\\000\021\000\021\000\000\000\000\000\000\000\000\000\000\000\000\
\\000\000\000\021\000\021\000\021\000\021\000\021\000\021\000\021\
\\000\021\000\021\000\021\000\021\000\021\000\021\000\021\000\021\
\\000\021\000\021\000\021\000\021\000\021\000\021\000\021\000\021\
\\000\021\000\021\000\021\000\000\000\000\000\000\000\000\000\021\
\\000\000\000\021\000\021\000\021\000\021\000\021\000\021\000\021\
\\000\021\000\021\000\021\000\021\000\021\000\021\000\021\000\021\
\\000\021\000\021\000\021\000\137\000\021\000\021\000\021\000\021\
\\000\021\000\021\000\021\000\000\000\000\000\000\000\000\000\000\
\\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\
\\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\
\\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\
\\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\
\\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\
\\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\
\\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\
\\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\
\\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\
\\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\
\\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\
\\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\
\\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\
\\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\
\\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\
\\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000"
),
 (137,256, 
"\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\
\\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\
\\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\
\\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\
\\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\021\
\\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\
\\000\021\000\021\000\021\000\021\000\021\000\021\000\021\000\021\
\\000\021\000\021\000\000\000\000\000\000\000\000\000\000\000\000\
\\000\000\000\021\000\021\000\021\000\021\000\021\000\021\000\021\
\\000\021\000\021\000\021\000\021\000\021\000\021\000\021\000\021\
\\000\021\000\021\000\021\000\021\000\021\000\021\000\021\000\021\
\\000\021\000\021\000\021\000\000\000\000\000\000\000\000\000\021\
\\000\000\000\021\000\021\000\021\000\021\000\021\000\021\000\021\
\\000\021\000\021\000\021\000\021\000\021\000\021\000\021\000\021\
\\000\021\000\021\000\021\000\021\000\138\000\021\000\021\000\021\
\\000\021\000\021\000\021\000\000\000\000\000\000\000\000\000\000\
\\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\
\\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\
\\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\
\\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\
\\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\
\\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\
\\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\
\\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\
\\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\
\\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\
\\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\
\\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\
\\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\
\\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\
\\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\
\\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000"
),
 (138,256, 
"\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\
\\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\
\\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\
\\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\
\\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\021\
\\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\
\\000\021\000\021\000\021\000\021\000\021\000\021\000\021\000\021\
\\000\021\000\021\000\000\000\000\000\000\000\000\000\000\000\000\
\\000\000\000\021\000\021\000\021\000\021\000\021\000\021\000\021\
\\000\021\000\021\000\021\000\021\000\021\000\021\000\021\000\021\
\\000\021\000\021\000\021\000\021\000\021\000\021\000\021\000\021\
\\000\021\000\021\000\021\000\000\000\000\000\000\000\000\000\021\
\\000\000\000\021\000\021\000\021\000\021\000\021\000\021\000\021\
\\000\021\000\021\000\021\000\021\000\021\000\021\000\021\000\021\
\\000\021\000\021\000\139\000\021\000\021\000\021\000\021\000\021\
\\000\021\000\021\000\021\000\000\000\000\000\000\000\000\000\000\
\\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\
\\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\
\\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\
\\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\
\\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\
\\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\
\\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\
\\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\
\\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\
\\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\
\\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\
\\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\
\\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\
\\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\
\\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\
\\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000"
),
 (139,256, 
"\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\
\\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\
\\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\
\\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\
\\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\021\
\\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\
\\000\021\000\021\000\021\000\021\000\021\000\021\000\021\000\021\
\\000\021\000\021\000\000\000\000\000\000\000\000\000\000\000\000\
\\000\000\000\021\000\021\000\021\000\021\000\021\000\021\000\021\
\\000\021\000\021\000\021\000\021\000\021\000\021\000\021\000\021\
\\000\021\000\021\000\021\000\021\000\021\000\021\000\021\000\021\
\\000\021\000\021\000\021\000\000\000\000\000\000\000\000\000\021\
\\000\000\000\140\000\021\000\021\000\021\000\021\000\021\000\021\
\\000\021\000\021\000\021\000\021\000\021\000\021\000\021\000\021\
\\000\021\000\021\000\021\000\021\000\021\000\021\000\021\000\021\
\\000\021\000\021\000\021\000\000\000\000\000\000\000\000\000\000\
\\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\
\\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\
\\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\
\\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\
\\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\
\\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\
\\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\
\\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\
\\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\
\\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\
\\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\
\\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\
\\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\
\\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\
\\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\
\\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000"
),
 (140,256, 
"\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\
\\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\
\\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\
\\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\
\\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\021\
\\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\
\\000\021\000\021\000\021\000\021\000\021\000\021\000\021\000\021\
\\000\021\000\021\000\000\000\000\000\000\000\000\000\000\000\000\
\\000\000\000\021\000\021\000\021\000\021\000\021\000\021\000\021\
\\000\021\000\021\000\021\000\021\000\021\000\021\000\021\000\021\
\\000\021\000\021\000\021\000\021\000\021\000\021\000\021\000\021\
\\000\021\000\021\000\021\000\000\000\000\000\000\000\000\000\021\
\\000\000\000\021\000\021\000\021\000\021\000\021\000\021\000\021\
\\000\021\000\141\000\021\000\021\000\021\000\021\000\021\000\021\
\\000\021\000\021\000\021\000\021\000\021\000\021\000\021\000\021\
\\000\021\000\021\000\021\000\000\000\000\000\000\000\000\000\000\
\\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\
\\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\
\\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\
\\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\
\\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\
\\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\
\\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\
\\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\
\\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\
\\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\
\\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\
\\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\
\\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\
\\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\
\\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\
\\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000"
),
 (141,256, 
"\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\
\\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\
\\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\
\\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\
\\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\021\
\\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\
\\000\021\000\021\000\021\000\021\000\021\000\021\000\021\000\021\
\\000\021\000\021\000\000\000\000\000\000\000\000\000\000\000\000\
\\000\000\000\021\000\021\000\021\000\021\000\021\000\021\000\021\
\\000\021\000\021\000\021\000\021\000\021\000\021\000\021\000\021\
\\000\021\000\021\000\021\000\021\000\021\000\021\000\021\000\021\
\\000\021\000\021\000\021\000\000\000\000\000\000\000\000\000\021\
\\000\000\000\021\000\021\000\021\000\021\000\021\000\021\000\021\
\\000\021\000\021\000\021\000\021\000\021\000\021\000\142\000\021\
\\000\021\000\021\000\021\000\021\000\021\000\021\000\021\000\021\
\\000\021\000\021\000\021\000\000\000\000\000\000\000\000\000\000\
\\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\
\\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\
\\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\
\\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\
\\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\
\\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\
\\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\
\\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\
\\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\
\\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\
\\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\
\\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\
\\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\
\\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\
\\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\
\\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000"
),
 (142,256, 
"\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\
\\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\
\\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\
\\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\
\\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\021\
\\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\
\\000\021\000\021\000\021\000\021\000\021\000\021\000\021\000\021\
\\000\021\000\021\000\000\000\000\000\000\000\000\000\000\000\000\
\\000\000\000\021\000\021\000\021\000\021\000\021\000\021\000\021\
\\000\021\000\021\000\021\000\021\000\021\000\021\000\021\000\021\
\\000\021\000\021\000\021\000\021\000\021\000\021\000\021\000\021\
\\000\021\000\021\000\021\000\000\000\000\000\000\000\000\000\021\
\\000\000\000\021\000\021\000\021\000\021\000\021\000\021\000\021\
\\000\021\000\021\000\021\000\021\000\021\000\021\000\021\000\021\
\\000\021\000\021\000\021\000\021\000\143\000\021\000\021\000\021\
\\000\021\000\021\000\021\000\000\000\000\000\000\000\000\000\000\
\\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\
\\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\
\\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\
\\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\
\\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\
\\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\
\\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\
\\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\
\\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\
\\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\
\\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\
\\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\
\\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\
\\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\
\\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\
\\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000"
),
 (143,256, 
"\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\
\\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\
\\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\
\\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\
\\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\021\
\\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\
\\000\021\000\021\000\021\000\021\000\021\000\021\000\021\000\021\
\\000\021\000\021\000\000\000\000\000\000\000\000\000\000\000\000\
\\000\000\000\021\000\021\000\021\000\021\000\021\000\021\000\021\
\\000\021\000\021\000\021\000\021\000\021\000\021\000\021\000\021\
\\000\021\000\021\000\021\000\021\000\021\000\021\000\021\000\021\
\\000\021\000\021\000\021\000\000\000\000\000\000\000\000\000\021\
\\000\000\000\021\000\021\000\021\000\021\000\021\000\021\000\021\
\\000\021\000\021\000\021\000\021\000\021\000\021\000\021\000\021\
\\000\021\000\021\000\021\000\144\000\021\000\021\000\021\000\021\
\\000\021\000\021\000\021\000\000\000\000\000\000\000\000\000\000\
\\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\
\\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\
\\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\
\\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\
\\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\
\\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\
\\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\
\\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\
\\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\
\\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\
\\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\
\\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\
\\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\
\\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\
\\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\
\\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000"
),
 (145,256, 
"\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\
\\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\
\\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\
\\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\
\\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\021\
\\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\
\\000\021\000\021\000\021\000\021\000\021\000\021\000\021\000\021\
\\000\021\000\021\000\000\000\000\000\000\000\000\000\000\000\000\
\\000\000\000\021\000\021\000\021\000\021\000\021\000\021\000\021\
\\000\021\000\021\000\021\000\021\000\021\000\021\000\021\000\021\
\\000\021\000\021\000\021\000\021\000\021\000\021\000\021\000\021\
\\000\021\000\021\000\021\000\000\000\000\000\000\000\000\000\021\
\\000\000\000\146\000\021\000\021\000\021\000\021\000\021\000\021\
\\000\021\000\021\000\021\000\021\000\021\000\021\000\021\000\021\
\\000\021\000\021\000\021\000\021\000\021\000\021\000\021\000\021\
\\000\021\000\021\000\021\000\000\000\000\000\000\000\000\000\000\
\\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\
\\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\
\\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\
\\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\
\\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\
\\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\
\\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\
\\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\
\\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\
\\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\
\\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\
\\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\
\\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\
\\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\
\\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\
\\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000"
),
 (146,256, 
"\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\
\\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\
\\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\
\\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\
\\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\021\
\\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\
\\000\021\000\021\000\021\000\021\000\021\000\021\000\021\000\021\
\\000\021\000\021\000\000\000\000\000\000\000\000\000\000\000\000\
\\000\000\000\021\000\021\000\021\000\021\000\021\000\021\000\021\
\\000\021\000\021\000\021\000\021\000\021\000\021\000\021\000\021\
\\000\021\000\021\000\021\000\021\000\021\000\021\000\021\000\021\
\\000\021\000\021\000\021\000\000\000\000\000\000\000\000\000\021\
\\000\000\000\021\000\021\000\021\000\021\000\021\000\021\000\021\
\\000\021\000\021\000\021\000\021\000\021\000\021\000\021\000\021\
\\000\021\000\021\000\021\000\147\000\021\000\021\000\021\000\021\
\\000\021\000\021\000\021\000\000\000\000\000\000\000\000\000\000\
\\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\
\\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\
\\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\
\\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\
\\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\
\\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\
\\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\
\\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\
\\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\
\\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\
\\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\
\\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\
\\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\
\\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\
\\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\
\\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000"
),
 (147,256, 
"\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\
\\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\
\\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\
\\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\
\\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\021\
\\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\
\\000\021\000\021\000\021\000\021\000\021\000\021\000\021\000\021\
\\000\021\000\021\000\000\000\000\000\000\000\000\000\000\000\000\
\\000\000\000\021\000\021\000\021\000\021\000\021\000\021\000\021\
\\000\021\000\021\000\021\000\021\000\021\000\021\000\021\000\021\
\\000\021\000\021\000\021\000\021\000\021\000\021\000\021\000\021\
\\000\021\000\021\000\021\000\000\000\000\000\000\000\000\000\021\
\\000\000\000\021\000\021\000\021\000\021\000\021\000\021\000\021\
\\000\021\000\021\000\021\000\021\000\021\000\021\000\021\000\021\
\\000\021\000\021\000\021\000\148\000\021\000\021\000\021\000\021\
\\000\021\000\021\000\021\000\000\000\000\000\000\000\000\000\000\
\\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\
\\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\
\\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\
\\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\
\\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\
\\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\
\\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\
\\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\
\\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\
\\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\
\\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\
\\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\
\\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\
\\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\
\\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\
\\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000"
),
 (149,256, 
"\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\
\\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\
\\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\
\\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\
\\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\021\
\\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\
\\000\021\000\021\000\021\000\021\000\021\000\021\000\021\000\021\
\\000\021\000\021\000\000\000\000\000\000\000\000\000\000\000\000\
\\000\000\000\021\000\021\000\021\000\021\000\021\000\021\000\021\
\\000\021\000\021\000\021\000\021\000\021\000\021\000\021\000\021\
\\000\021\000\021\000\021\000\021\000\021\000\021\000\021\000\021\
\\000\021\000\021\000\021\000\000\000\000\000\000\000\000\000\021\
\\000\000\000\021\000\021\000\021\000\021\000\021\000\021\000\021\
\\000\021\000\021\000\021\000\021\000\021\000\021\000\021\000\021\
\\000\021\000\021\000\021\000\150\000\021\000\021\000\021\000\021\
\\000\021\000\021\000\021\000\000\000\000\000\000\000\000\000\000\
\\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\
\\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\
\\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\
\\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\
\\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\
\\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\
\\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\
\\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\
\\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\
\\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\
\\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\
\\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\
\\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\
\\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\
\\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\
\\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000"
),
 (150,256, 
"\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\
\\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\
\\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\
\\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\
\\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\021\
\\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\
\\000\021\000\021\000\021\000\021\000\021\000\021\000\021\000\021\
\\000\021\000\021\000\000\000\000\000\000\000\000\000\000\000\000\
\\000\000\000\021\000\021\000\021\000\021\000\021\000\021\000\021\
\\000\021\000\021\000\021\000\021\000\021\000\021\000\021\000\021\
\\000\021\000\021\000\021\000\021\000\021\000\021\000\021\000\021\
\\000\021\000\021\000\021\000\000\000\000\000\000\000\000\000\021\
\\000\000\000\021\000\021\000\021\000\021\000\151\000\021\000\021\
\\000\021\000\021\000\021\000\021\000\021\000\021\000\021\000\021\
\\000\021\000\021\000\021\000\021\000\021\000\021\000\021\000\021\
\\000\021\000\021\000\021\000\000\000\000\000\000\000\000\000\000\
\\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\
\\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\
\\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\
\\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\
\\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\
\\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\
\\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\
\\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\
\\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\
\\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\
\\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\
\\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\
\\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\
\\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\
\\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\
\\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000"
),
 (152,256, 
"\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\
\\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\
\\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\
\\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\
\\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\021\
\\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\
\\000\021\000\021\000\021\000\021\000\021\000\021\000\021\000\021\
\\000\021\000\021\000\000\000\000\000\000\000\000\000\000\000\000\
\\000\000\000\021\000\021\000\021\000\021\000\021\000\021\000\021\
\\000\021\000\021\000\021\000\021\000\021\000\021\000\021\000\021\
\\000\021\000\021\000\021\000\021\000\021\000\021\000\021\000\021\
\\000\021\000\021\000\021\000\000\000\000\000\000\000\000\000\021\
\\000\000\000\021\000\021\000\021\000\021\000\021\000\021\000\021\
\\000\021\000\021\000\021\000\021\000\021\000\021\000\153\000\021\
\\000\021\000\021\000\021\000\021\000\021\000\021\000\021\000\021\
\\000\021\000\021\000\021\000\000\000\000\000\000\000\000\000\000\
\\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\
\\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\
\\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\
\\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\
\\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\
\\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\
\\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\
\\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\
\\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\
\\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\
\\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\
\\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\
\\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\
\\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\
\\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\
\\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000"
),
 (153,256, 
"\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\
\\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\
\\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\
\\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\
\\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\021\
\\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\
\\000\021\000\021\000\021\000\021\000\021\000\021\000\021\000\021\
\\000\021\000\021\000\000\000\000\000\000\000\000\000\000\000\000\
\\000\000\000\021\000\021\000\021\000\021\000\021\000\021\000\021\
\\000\021\000\021\000\021\000\021\000\021\000\021\000\021\000\021\
\\000\021\000\021\000\021\000\021\000\021\000\021\000\021\000\021\
\\000\021\000\021\000\021\000\000\000\000\000\000\000\000\000\021\
\\000\000\000\021\000\021\000\021\000\154\000\021\000\021\000\021\
\\000\021\000\021\000\021\000\021\000\021\000\021\000\021\000\021\
\\000\021\000\021\000\021\000\021\000\021\000\021\000\021\000\021\
\\000\021\000\021\000\021\000\000\000\000\000\000\000\000\000\000\
\\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\
\\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\
\\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\
\\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\
\\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\
\\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\
\\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\
\\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\
\\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\
\\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\
\\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\
\\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\
\\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\
\\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\
\\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\
\\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000"
),
 (155,256, 
"\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\
\\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\
\\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\
\\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\
\\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\
\\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\
\\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\
\\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\
\\000\000\000\158\000\158\000\158\000\158\000\158\000\158\000\158\
\\000\158\000\158\000\158\000\158\000\158\000\158\000\158\000\158\
\\000\158\000\158\000\158\000\158\000\158\000\158\000\158\000\158\
\\000\158\000\158\000\158\000\000\000\000\000\000\000\000\000\156\
\\000\000\000\156\000\156\000\156\000\156\000\156\000\156\000\156\
\\000\156\000\156\000\156\000\156\000\156\000\156\000\156\000\156\
\\000\156\000\156\000\156\000\156\000\156\000\156\000\156\000\156\
\\000\156\000\156\000\156\000\000\000\000\000\000\000\000\000\000\
\\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\
\\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\
\\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\
\\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\
\\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\
\\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\
\\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\
\\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\
\\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\
\\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\
\\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\
\\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\
\\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\
\\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\
\\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\
\\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000"
),
 (156,256, 
"\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\
\\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\
\\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\
\\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\
\\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\156\
\\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\
\\000\156\000\156\000\156\000\156\000\156\000\156\000\156\000\156\
\\000\156\000\156\000\000\000\000\000\000\000\000\000\000\000\000\
\\000\000\000\156\000\156\000\156\000\156\000\156\000\156\000\156\
\\000\156\000\156\000\156\000\156\000\156\000\156\000\156\000\156\
\\000\156\000\156\000\156\000\156\000\156\000\156\000\156\000\156\
\\000\156\000\156\000\156\000\000\000\000\000\000\000\000\000\156\
\\000\157\000\156\000\156\000\156\000\156\000\156\000\156\000\156\
\\000\156\000\156\000\156\000\156\000\156\000\156\000\156\000\156\
\\000\156\000\156\000\156\000\156\000\156\000\156\000\156\000\156\
\\000\156\000\156\000\156\000\000\000\000\000\000\000\000\000\000\
\\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\
\\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\
\\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\
\\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\
\\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\
\\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\
\\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\
\\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\
\\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\
\\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\
\\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\
\\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\
\\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\
\\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\
\\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\
\\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000"
),
 (158,256, 
"\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\
\\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\
\\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\
\\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\
\\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\158\
\\000\000\000\000\000\000\000\000\000\000\000\000\000\159\000\000\
\\000\158\000\158\000\158\000\158\000\158\000\158\000\158\000\158\
\\000\158\000\158\000\000\000\000\000\000\000\000\000\000\000\000\
\\000\000\000\158\000\158\000\158\000\158\000\158\000\158\000\158\
\\000\158\000\158\000\158\000\158\000\158\000\158\000\158\000\158\
\\000\158\000\158\000\158\000\158\000\158\000\158\000\158\000\158\
\\000\158\000\158\000\158\000\000\000\000\000\000\000\000\000\158\
\\000\000\000\158\000\158\000\158\000\158\000\158\000\158\000\158\
\\000\158\000\158\000\158\000\158\000\158\000\158\000\158\000\158\
\\000\158\000\158\000\158\000\158\000\158\000\158\000\158\000\158\
\\000\158\000\158\000\158\000\000\000\000\000\000\000\000\000\000\
\\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\
\\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\
\\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\
\\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\
\\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\
\\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\
\\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\
\\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\
\\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\
\\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\
\\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\
\\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\
\\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\
\\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\
\\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\
\\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000"
),
 (160,256, 
"\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\
\\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\
\\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\
\\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\
\\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\021\
\\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\
\\000\021\000\021\000\021\000\021\000\021\000\021\000\021\000\021\
\\000\021\000\021\000\000\000\000\000\000\000\000\000\000\000\000\
\\000\000\000\021\000\021\000\021\000\021\000\021\000\021\000\021\
\\000\021\000\021\000\021\000\021\000\162\000\021\000\021\000\021\
\\000\021\000\021\000\021\000\021\000\021\000\021\000\021\000\021\
\\000\021\000\021\000\021\000\000\000\000\000\000\000\000\000\161\
\\000\000\000\021\000\021\000\021\000\021\000\021\000\021\000\021\
\\000\021\000\021\000\021\000\021\000\021\000\021\000\021\000\021\
\\000\021\000\021\000\021\000\021\000\021\000\021\000\021\000\021\
\\000\021\000\021\000\021\000\000\000\000\000\000\000\000\000\000\
\\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\
\\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\
\\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\
\\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\
\\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\
\\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\
\\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\
\\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\
\\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\
\\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\
\\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\
\\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\
\\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\
\\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\
\\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\
\\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000"
),
 (162,256, 
"\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\
\\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\
\\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\
\\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\
\\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\021\
\\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\
\\000\021\000\021\000\021\000\021\000\021\000\021\000\021\000\021\
\\000\021\000\021\000\000\000\000\000\000\000\000\000\000\000\000\
\\000\000\000\021\000\021\000\021\000\021\000\021\000\021\000\021\
\\000\021\000\021\000\021\000\021\000\021\000\021\000\021\000\163\
\\000\021\000\021\000\021\000\021\000\021\000\021\000\021\000\021\
\\000\021\000\021\000\021\000\000\000\000\000\000\000\000\000\021\
\\000\000\000\021\000\021\000\021\000\021\000\021\000\021\000\021\
\\000\021\000\021\000\021\000\021\000\021\000\021\000\021\000\021\
\\000\021\000\021\000\021\000\021\000\021\000\021\000\021\000\021\
\\000\021\000\021\000\021\000\000\000\000\000\000\000\000\000\000\
\\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\
\\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\
\\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\
\\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\
\\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\
\\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\
\\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\
\\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\
\\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\
\\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\
\\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\
\\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\
\\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\
\\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\
\\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\
\\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000"
),
 (163,256, 
"\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\
\\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\
\\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\
\\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\
\\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\021\
\\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\
\\000\021\000\021\000\021\000\021\000\021\000\021\000\021\000\021\
\\000\021\000\021\000\000\000\000\000\000\000\000\000\000\000\000\
\\000\000\000\021\000\021\000\164\000\021\000\021\000\021\000\021\
\\000\021\000\021\000\021\000\021\000\021\000\021\000\021\000\021\
\\000\021\000\021\000\021\000\021\000\021\000\021\000\021\000\021\
\\000\021\000\021\000\021\000\000\000\000\000\000\000\000\000\021\
\\000\000\000\021\000\021\000\021\000\021\000\021\000\021\000\021\
\\000\021\000\021\000\021\000\021\000\021\000\021\000\021\000\021\
\\000\021\000\021\000\021\000\021\000\021\000\021\000\021\000\021\
\\000\021\000\021\000\021\000\000\000\000\000\000\000\000\000\000\
\\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\
\\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\
\\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\
\\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\
\\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\
\\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\
\\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\
\\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\
\\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\
\\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\
\\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\
\\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\
\\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\
\\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\
\\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\
\\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000"
),
 (164,256, 
"\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\
\\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\
\\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\
\\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\
\\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\021\
\\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\
\\000\021\000\021\000\021\000\021\000\021\000\021\000\021\000\021\
\\000\021\000\021\000\000\000\000\000\000\000\000\000\000\000\000\
\\000\000\000\021\000\021\000\021\000\021\000\021\000\021\000\021\
\\000\021\000\021\000\021\000\021\000\021\000\021\000\021\000\021\
\\000\021\000\021\000\021\000\021\000\021\000\021\000\021\000\021\
\\000\021\000\021\000\021\000\000\000\000\000\000\000\000\000\165\
\\000\000\000\021\000\021\000\021\000\021\000\021\000\021\000\021\
\\000\021\000\021\000\021\000\021\000\021\000\021\000\021\000\021\
\\000\021\000\021\000\021\000\021\000\021\000\021\000\021\000\021\
\\000\021\000\021\000\021\000\000\000\000\000\000\000\000\000\000\
\\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\
\\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\
\\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\
\\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\
\\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\
\\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\
\\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\
\\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\
\\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\
\\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\
\\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\
\\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\
\\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\
\\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\
\\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\
\\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000"
),
 (169,256, 
"\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\
\\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\
\\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\
\\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\
\\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\170\
\\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\
\\000\170\000\170\000\170\000\170\000\170\000\170\000\170\000\170\
\\000\170\000\170\000\000\000\000\000\000\000\000\000\000\000\000\
\\000\000\000\170\000\170\000\170\000\170\000\170\000\170\000\170\
\\000\170\000\170\000\170\000\170\000\170\000\170\000\170\000\170\
\\000\170\000\170\000\170\000\170\000\170\000\170\000\170\000\170\
\\000\170\000\170\000\170\000\000\000\000\000\000\000\000\000\170\
\\000\000\000\170\000\170\000\170\000\170\000\170\000\170\000\170\
\\000\170\000\170\000\170\000\170\000\170\000\170\000\170\000\170\
\\000\170\000\170\000\170\000\170\000\170\000\170\000\170\000\170\
\\000\170\000\170\000\170\000\000\000\000\000\000\000\000\000\000\
\\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\
\\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\
\\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\
\\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\
\\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\
\\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\
\\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\
\\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\
\\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\
\\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\
\\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\
\\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\
\\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\
\\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\
\\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\
\\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000"
),
 (171,256, 
"\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\
\\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\
\\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\
\\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\
\\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\170\
\\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\
\\000\170\000\170\000\170\000\170\000\170\000\170\000\170\000\170\
\\000\170\000\170\000\000\000\000\000\000\000\000\000\000\000\000\
\\000\000\000\170\000\170\000\170\000\170\000\170\000\170\000\170\
\\000\172\000\170\000\170\000\170\000\170\000\170\000\170\000\170\
\\000\170\000\170\000\170\000\170\000\170\000\170\000\170\000\170\
\\000\170\000\170\000\170\000\000\000\000\000\000\000\000\000\170\
\\000\000\000\170\000\170\000\170\000\170\000\170\000\170\000\170\
\\000\170\000\170\000\170\000\170\000\170\000\170\000\170\000\170\
\\000\170\000\170\000\170\000\170\000\170\000\170\000\170\000\170\
\\000\170\000\170\000\170\000\000\000\000\000\000\000\000\000\000\
\\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\
\\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\
\\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\
\\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\
\\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\
\\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\
\\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\
\\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\
\\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\
\\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\
\\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\
\\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\
\\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\
\\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\
\\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\
\\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000"
),
 (172,256, 
"\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\
\\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\
\\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\
\\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\
\\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\170\
\\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\
\\000\170\000\170\000\170\000\170\000\170\000\170\000\170\000\170\
\\000\170\000\170\000\000\000\000\000\000\000\000\000\000\000\000\
\\000\000\000\170\000\170\000\170\000\170\000\173\000\170\000\170\
\\000\170\000\170\000\170\000\170\000\170\000\170\000\170\000\170\
\\000\170\000\170\000\170\000\170\000\170\000\170\000\170\000\170\
\\000\170\000\170\000\170\000\000\000\000\000\000\000\000\000\170\
\\000\000\000\170\000\170\000\170\000\170\000\170\000\170\000\170\
\\000\170\000\170\000\170\000\170\000\170\000\170\000\170\000\170\
\\000\170\000\170\000\170\000\170\000\170\000\170\000\170\000\170\
\\000\170\000\170\000\170\000\000\000\000\000\000\000\000\000\000\
\\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\
\\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\
\\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\
\\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\
\\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\
\\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\
\\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\
\\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\
\\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\
\\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\
\\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\
\\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\
\\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\
\\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\
\\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\
\\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000"
),
 (173,256, 
"\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\
\\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\
\\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\
\\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\
\\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\170\
\\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\
\\000\170\000\170\000\170\000\170\000\170\000\170\000\170\000\170\
\\000\170\000\170\000\000\000\000\000\000\000\000\000\000\000\000\
\\000\000\000\170\000\170\000\170\000\170\000\170\000\170\000\170\
\\000\170\000\170\000\170\000\170\000\170\000\170\000\170\000\170\
\\000\170\000\170\000\174\000\170\000\170\000\170\000\170\000\170\
\\000\170\000\170\000\170\000\000\000\000\000\000\000\000\000\170\
\\000\000\000\170\000\170\000\170\000\170\000\170\000\170\000\170\
\\000\170\000\170\000\170\000\170\000\170\000\170\000\170\000\170\
\\000\170\000\170\000\170\000\170\000\170\000\170\000\170\000\170\
\\000\170\000\170\000\170\000\000\000\000\000\000\000\000\000\000\
\\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\
\\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\
\\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\
\\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\
\\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\
\\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\
\\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\
\\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\
\\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\
\\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\
\\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\
\\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\
\\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\
\\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\
\\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\
\\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000"
),
 (174,256, 
"\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\
\\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\
\\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\
\\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\
\\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\170\
\\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\
\\000\170\000\170\000\170\000\170\000\170\000\170\000\170\000\170\
\\000\170\000\170\000\000\000\000\000\000\000\000\000\000\000\000\
\\000\000\000\170\000\170\000\170\000\170\000\175\000\170\000\170\
\\000\170\000\170\000\170\000\170\000\170\000\170\000\170\000\170\
\\000\170\000\170\000\170\000\170\000\170\000\170\000\170\000\170\
\\000\170\000\170\000\170\000\000\000\000\000\000\000\000\000\170\
\\000\000\000\170\000\170\000\170\000\170\000\170\000\170\000\170\
\\000\170\000\170\000\170\000\170\000\170\000\170\000\170\000\170\
\\000\170\000\170\000\170\000\170\000\170\000\170\000\170\000\170\
\\000\170\000\170\000\170\000\000\000\000\000\000\000\000\000\000\
\\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\
\\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\
\\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\
\\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\
\\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\
\\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\
\\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\
\\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\
\\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\
\\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\
\\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\
\\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\
\\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\
\\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\
\\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\
\\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000"
),
 (176,256, 
"\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\
\\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\
\\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\
\\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\
\\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\170\
\\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\
\\000\170\000\170\000\170\000\170\000\170\000\170\000\170\000\170\
\\000\170\000\170\000\000\000\000\000\000\000\000\000\000\000\000\
\\000\000\000\177\000\170\000\170\000\170\000\170\000\170\000\170\
\\000\170\000\170\000\170\000\170\000\170\000\170\000\170\000\170\
\\000\170\000\170\000\170\000\170\000\170\000\170\000\170\000\170\
\\000\170\000\170\000\170\000\000\000\000\000\000\000\000\000\170\
\\000\000\000\170\000\170\000\170\000\170\000\170\000\170\000\170\
\\000\170\000\170\000\170\000\170\000\170\000\170\000\170\000\170\
\\000\170\000\170\000\170\000\170\000\170\000\170\000\170\000\170\
\\000\170\000\170\000\170\000\000\000\000\000\000\000\000\000\000\
\\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\
\\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\
\\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\
\\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\
\\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\
\\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\
\\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\
\\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\
\\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\
\\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\
\\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\
\\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\
\\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\
\\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\
\\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\
\\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000"
),
 (177,256, 
"\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\
\\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\
\\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\
\\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\
\\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\170\
\\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\
\\000\170\000\170\000\170\000\170\000\170\000\170\000\170\000\170\
\\000\170\000\170\000\000\000\000\000\000\000\000\000\000\000\000\
\\000\000\000\170\000\170\000\170\000\170\000\170\000\170\000\170\
\\000\170\000\170\000\170\000\170\000\178\000\170\000\170\000\170\
\\000\170\000\170\000\170\000\170\000\170\000\170\000\170\000\170\
\\000\170\000\170\000\170\000\000\000\000\000\000\000\000\000\170\
\\000\000\000\170\000\170\000\170\000\170\000\170\000\170\000\170\
\\000\170\000\170\000\170\000\170\000\170\000\170\000\170\000\170\
\\000\170\000\170\000\170\000\170\000\170\000\170\000\170\000\170\
\\000\170\000\170\000\170\000\000\000\000\000\000\000\000\000\000\
\\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\
\\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\
\\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\
\\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\
\\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\
\\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\
\\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\
\\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\
\\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\
\\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\
\\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\
\\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\
\\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\
\\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\
\\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\
\\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000"
),
 (178,256, 
"\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\
\\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\
\\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\
\\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\
\\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\170\
\\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\
\\000\170\000\170\000\170\000\170\000\170\000\170\000\170\000\170\
\\000\170\000\170\000\000\000\000\000\000\000\000\000\000\000\000\
\\000\000\000\170\000\170\000\170\000\170\000\170\000\170\000\170\
\\000\170\000\170\000\170\000\170\000\170\000\170\000\170\000\170\
\\000\170\000\170\000\170\000\170\000\170\000\179\000\170\000\170\
\\000\170\000\170\000\170\000\000\000\000\000\000\000\000\000\170\
\\000\000\000\170\000\170\000\170\000\170\000\170\000\170\000\170\
\\000\170\000\170\000\170\000\170\000\170\000\170\000\170\000\170\
\\000\170\000\170\000\170\000\170\000\170\000\170\000\170\000\170\
\\000\170\000\170\000\170\000\000\000\000\000\000\000\000\000\000\
\\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\
\\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\
\\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\
\\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\
\\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\
\\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\
\\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\
\\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\
\\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\
\\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\
\\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\
\\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\
\\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\
\\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\
\\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\
\\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000"
),
 (179,256, 
"\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\
\\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\
\\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\
\\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\
\\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\170\
\\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\
\\000\170\000\170\000\170\000\170\000\170\000\170\000\170\000\170\
\\000\170\000\170\000\000\000\000\000\000\000\000\000\000\000\000\
\\000\000\000\170\000\170\000\170\000\170\000\180\000\170\000\170\
\\000\170\000\170\000\170\000\170\000\170\000\170\000\170\000\170\
\\000\170\000\170\000\170\000\170\000\170\000\170\000\170\000\170\
\\000\170\000\170\000\170\000\000\000\000\000\000\000\000\000\170\
\\000\000\000\170\000\170\000\170\000\170\000\170\000\170\000\170\
\\000\170\000\170\000\170\000\170\000\170\000\170\000\170\000\170\
\\000\170\000\170\000\170\000\170\000\170\000\170\000\170\000\170\
\\000\170\000\170\000\170\000\000\000\000\000\000\000\000\000\000\
\\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\
\\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\
\\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\
\\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\
\\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\
\\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\
\\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\
\\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\
\\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\
\\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\
\\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\
\\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\
\\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\
\\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\
\\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\
\\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000"
),
 (180,256, 
"\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\
\\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\
\\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\
\\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\
\\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\170\
\\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\
\\000\170\000\170\000\170\000\170\000\170\000\170\000\170\000\170\
\\000\170\000\170\000\000\000\000\000\000\000\000\000\000\000\000\
\\000\000\000\170\000\170\000\170\000\170\000\170\000\170\000\170\
\\000\170\000\170\000\170\000\170\000\170\000\170\000\170\000\170\
\\000\170\000\170\000\170\000\181\000\170\000\170\000\170\000\170\
\\000\170\000\170\000\170\000\000\000\000\000\000\000\000\000\170\
\\000\000\000\170\000\170\000\170\000\170\000\170\000\170\000\170\
\\000\170\000\170\000\170\000\170\000\170\000\170\000\170\000\170\
\\000\170\000\170\000\170\000\170\000\170\000\170\000\170\000\170\
\\000\170\000\170\000\170\000\000\000\000\000\000\000\000\000\000\
\\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\
\\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\
\\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\
\\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\
\\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\
\\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\
\\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\
\\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\
\\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\
\\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\
\\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\
\\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\
\\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\
\\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\
\\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\
\\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000"
),
 (182,256, 
"\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\
\\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\
\\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\
\\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\
\\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\170\
\\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\
\\000\170\000\170\000\170\000\170\000\170\000\170\000\170\000\170\
\\000\170\000\170\000\000\000\000\000\000\000\000\000\000\000\000\
\\000\000\000\170\000\170\000\170\000\170\000\170\000\170\000\170\
\\000\170\000\170\000\170\000\170\000\170\000\170\000\191\000\170\
\\000\186\000\170\000\170\000\170\000\170\000\170\000\170\000\170\
\\000\170\000\170\000\170\000\000\000\000\000\000\000\000\000\170\
\\000\000\000\170\000\170\000\170\000\170\000\170\000\170\000\170\
\\000\170\000\170\000\170\000\170\000\170\000\170\000\183\000\170\
\\000\170\000\170\000\170\000\170\000\170\000\170\000\170\000\170\
\\000\170\000\170\000\170\000\000\000\000\000\000\000\000\000\000\
\\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\
\\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\
\\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\
\\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\
\\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\
\\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\
\\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\
\\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\
\\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\
\\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\
\\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\
\\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\
\\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\
\\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\
\\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\
\\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000"
),
 (183,256, 
"\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\
\\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\
\\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\
\\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\
\\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\170\
\\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\
\\000\170\000\170\000\170\000\170\000\170\000\170\000\170\000\170\
\\000\170\000\170\000\000\000\000\000\000\000\000\000\000\000\000\
\\000\000\000\170\000\170\000\170\000\170\000\170\000\170\000\170\
\\000\170\000\170\000\170\000\170\000\170\000\170\000\170\000\170\
\\000\170\000\170\000\170\000\170\000\170\000\170\000\170\000\170\
\\000\170\000\170\000\170\000\000\000\000\000\000\000\000\000\170\
\\000\000\000\170\000\170\000\170\000\170\000\170\000\170\000\170\
\\000\170\000\184\000\170\000\170\000\170\000\170\000\170\000\170\
\\000\170\000\170\000\170\000\170\000\170\000\170\000\170\000\170\
\\000\170\000\170\000\170\000\000\000\000\000\000\000\000\000\000\
\\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\
\\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\
\\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\
\\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\
\\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\
\\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\
\\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\
\\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\
\\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\
\\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\
\\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\
\\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\
\\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\
\\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\
\\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\
\\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000"
),
 (184,256, 
"\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\
\\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\
\\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\
\\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\
\\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\170\
\\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\
\\000\170\000\170\000\170\000\170\000\170\000\170\000\170\000\170\
\\000\170\000\170\000\000\000\000\000\000\000\000\000\000\000\000\
\\000\000\000\170\000\170\000\170\000\170\000\170\000\170\000\170\
\\000\170\000\170\000\170\000\170\000\170\000\170\000\170\000\170\
\\000\170\000\170\000\170\000\170\000\170\000\170\000\170\000\170\
\\000\170\000\170\000\170\000\000\000\000\000\000\000\000\000\170\
\\000\000\000\170\000\170\000\170\000\170\000\170\000\170\000\170\
\\000\170\000\170\000\170\000\170\000\170\000\170\000\170\000\170\
\\000\170\000\170\000\170\000\170\000\185\000\170\000\170\000\170\
\\000\170\000\170\000\170\000\000\000\000\000\000\000\000\000\000\
\\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\
\\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\
\\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\
\\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\
\\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\
\\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\
\\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\
\\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\
\\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\
\\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\
\\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\
\\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\
\\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\
\\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\
\\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\
\\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000"
),
 (186,256, 
"\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\
\\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\
\\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\
\\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\
\\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\170\
\\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\
\\000\170\000\170\000\170\000\170\000\170\000\170\000\170\000\170\
\\000\170\000\170\000\000\000\000\000\000\000\000\000\000\000\000\
\\000\000\000\170\000\170\000\170\000\187\000\170\000\170\000\170\
\\000\170\000\170\000\170\000\170\000\170\000\170\000\170\000\170\
\\000\170\000\170\000\170\000\170\000\170\000\170\000\170\000\170\
\\000\170\000\170\000\170\000\000\000\000\000\000\000\000\000\170\
\\000\000\000\170\000\170\000\170\000\170\000\170\000\170\000\170\
\\000\170\000\170\000\170\000\170\000\170\000\170\000\170\000\170\
\\000\170\000\170\000\170\000\170\000\170\000\170\000\170\000\170\
\\000\170\000\170\000\170\000\000\000\000\000\000\000\000\000\000\
\\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\
\\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\
\\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\
\\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\
\\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\
\\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\
\\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\
\\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\
\\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\
\\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\
\\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\
\\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\
\\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\
\\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\
\\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\
\\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000"
),
 (187,256, 
"\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\
\\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\
\\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\
\\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\
\\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\170\
\\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\
\\000\170\000\170\000\170\000\170\000\170\000\170\000\170\000\170\
\\000\170\000\170\000\000\000\000\000\000\000\000\000\000\000\000\
\\000\000\000\188\000\170\000\170\000\170\000\170\000\170\000\170\
\\000\170\000\170\000\170\000\170\000\170\000\170\000\170\000\170\
\\000\170\000\170\000\170\000\170\000\170\000\170\000\170\000\170\
\\000\170\000\170\000\170\000\000\000\000\000\000\000\000\000\170\
\\000\000\000\170\000\170\000\170\000\170\000\170\000\170\000\170\
\\000\170\000\170\000\170\000\170\000\170\000\170\000\170\000\170\
\\000\170\000\170\000\170\000\170\000\170\000\170\000\170\000\170\
\\000\170\000\170\000\170\000\000\000\000\000\000\000\000\000\000\
\\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\
\\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\
\\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\
\\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\
\\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\
\\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\
\\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\
\\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\
\\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\
\\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\
\\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\
\\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\
\\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\
\\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\
\\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\
\\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000"
),
 (188,256, 
"\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\
\\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\
\\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\
\\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\
\\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\170\
\\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\
\\000\170\000\170\000\170\000\170\000\170\000\170\000\170\000\170\
\\000\170\000\170\000\000\000\000\000\000\000\000\000\000\000\000\
\\000\000\000\170\000\170\000\170\000\170\000\170\000\170\000\170\
\\000\170\000\170\000\170\000\170\000\170\000\170\000\170\000\170\
\\000\170\000\170\000\170\000\170\000\189\000\170\000\170\000\170\
\\000\170\000\170\000\170\000\000\000\000\000\000\000\000\000\170\
\\000\000\000\170\000\170\000\170\000\170\000\170\000\170\000\170\
\\000\170\000\170\000\170\000\170\000\170\000\170\000\170\000\170\
\\000\170\000\170\000\170\000\170\000\170\000\170\000\170\000\170\
\\000\170\000\170\000\170\000\000\000\000\000\000\000\000\000\000\
\\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\
\\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\
\\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\
\\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\
\\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\
\\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\
\\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\
\\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\
\\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\
\\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\
\\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\
\\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\
\\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\
\\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\
\\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\
\\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000"
),
 (189,256, 
"\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\
\\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\
\\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\
\\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\
\\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\170\
\\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\
\\000\170\000\170\000\170\000\170\000\170\000\170\000\170\000\170\
\\000\170\000\170\000\000\000\000\000\000\000\000\000\000\000\000\
\\000\000\000\170\000\170\000\170\000\170\000\190\000\170\000\170\
\\000\170\000\170\000\170\000\170\000\170\000\170\000\170\000\170\
\\000\170\000\170\000\170\000\170\000\170\000\170\000\170\000\170\
\\000\170\000\170\000\170\000\000\000\000\000\000\000\000\000\170\
\\000\000\000\170\000\170\000\170\000\170\000\170\000\170\000\170\
\\000\170\000\170\000\170\000\170\000\170\000\170\000\170\000\170\
\\000\170\000\170\000\170\000\170\000\170\000\170\000\170\000\170\
\\000\170\000\170\000\170\000\000\000\000\000\000\000\000\000\000\
\\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\
\\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\
\\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\
\\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\
\\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\
\\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\
\\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\
\\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\
\\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\
\\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\
\\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\
\\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\
\\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\
\\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\
\\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\
\\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000"
),
 (191,256, 
"\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\
\\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\
\\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\
\\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\
\\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\170\
\\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\
\\000\170\000\170\000\170\000\170\000\170\000\170\000\170\000\170\
\\000\170\000\170\000\000\000\000\000\000\000\000\000\000\000\000\
\\000\000\000\170\000\170\000\170\000\170\000\170\000\170\000\170\
\\000\170\000\192\000\170\000\170\000\170\000\170\000\170\000\170\
\\000\170\000\170\000\170\000\170\000\170\000\170\000\170\000\170\
\\000\170\000\170\000\170\000\000\000\000\000\000\000\000\000\170\
\\000\000\000\170\000\170\000\170\000\170\000\170\000\170\000\170\
\\000\170\000\170\000\170\000\170\000\170\000\170\000\170\000\170\
\\000\170\000\170\000\170\000\170\000\170\000\170\000\170\000\170\
\\000\170\000\170\000\170\000\000\000\000\000\000\000\000\000\000\
\\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\
\\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\
\\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\
\\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\
\\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\
\\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\
\\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\
\\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\
\\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\
\\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\
\\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\
\\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\
\\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\
\\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\
\\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\
\\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000"
),
 (192,256, 
"\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\
\\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\
\\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\
\\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\
\\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\170\
\\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\
\\000\170\000\170\000\170\000\170\000\170\000\170\000\170\000\170\
\\000\170\000\170\000\000\000\000\000\000\000\000\000\000\000\000\
\\000\000\000\170\000\170\000\170\000\170\000\170\000\170\000\170\
\\000\170\000\170\000\170\000\170\000\170\000\170\000\170\000\196\
\\000\170\000\193\000\170\000\170\000\170\000\170\000\170\000\170\
\\000\170\000\170\000\170\000\000\000\000\000\000\000\000\000\170\
\\000\000\000\170\000\170\000\170\000\170\000\170\000\170\000\170\
\\000\170\000\170\000\170\000\170\000\170\000\170\000\170\000\170\
\\000\170\000\170\000\170\000\170\000\170\000\170\000\170\000\170\
\\000\170\000\170\000\170\000\000\000\000\000\000\000\000\000\000\
\\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\
\\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\
\\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\
\\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\
\\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\
\\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\
\\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\
\\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\
\\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\
\\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\
\\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\
\\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\
\\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\
\\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\
\\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\
\\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000"
),
 (193,256, 
"\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\
\\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\
\\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\
\\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\
\\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\170\
\\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\
\\000\170\000\170\000\170\000\170\000\170\000\170\000\170\000\170\
\\000\170\000\170\000\000\000\000\000\000\000\000\000\000\000\000\
\\000\000\000\170\000\170\000\170\000\170\000\170\000\170\000\170\
\\000\170\000\170\000\170\000\170\000\170\000\170\000\170\000\170\
\\000\170\000\170\000\170\000\170\000\170\000\194\000\170\000\170\
\\000\170\000\170\000\170\000\000\000\000\000\000\000\000\000\170\
\\000\000\000\170\000\170\000\170\000\170\000\170\000\170\000\170\
\\000\170\000\170\000\170\000\170\000\170\000\170\000\170\000\170\
\\000\170\000\170\000\170\000\170\000\170\000\170\000\170\000\170\
\\000\170\000\170\000\170\000\000\000\000\000\000\000\000\000\000\
\\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\
\\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\
\\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\
\\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\
\\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\
\\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\
\\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\
\\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\
\\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\
\\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\
\\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\
\\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\
\\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\
\\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\
\\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\
\\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000"
),
 (194,256, 
"\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\
\\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\
\\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\
\\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\
\\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\170\
\\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\
\\000\170\000\170\000\170\000\170\000\170\000\170\000\170\000\170\
\\000\170\000\170\000\000\000\000\000\000\000\000\000\000\000\000\
\\000\000\000\170\000\170\000\170\000\170\000\195\000\170\000\170\
\\000\170\000\170\000\170\000\170\000\170\000\170\000\170\000\170\
\\000\170\000\170\000\170\000\170\000\170\000\170\000\170\000\170\
\\000\170\000\170\000\170\000\000\000\000\000\000\000\000\000\170\
\\000\000\000\170\000\170\000\170\000\170\000\170\000\170\000\170\
\\000\170\000\170\000\170\000\170\000\170\000\170\000\170\000\170\
\\000\170\000\170\000\170\000\170\000\170\000\170\000\170\000\170\
\\000\170\000\170\000\170\000\000\000\000\000\000\000\000\000\000\
\\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\
\\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\
\\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\
\\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\
\\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\
\\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\
\\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\
\\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\
\\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\
\\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\
\\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\
\\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\
\\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\
\\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\
\\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\
\\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000"
),
 (196,256, 
"\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\
\\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\
\\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\
\\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\
\\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\170\
\\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\
\\000\170\000\170\000\170\000\170\000\170\000\170\000\170\000\170\
\\000\170\000\170\000\000\000\000\000\000\000\000\000\000\000\000\
\\000\000\000\170\000\170\000\170\000\170\000\170\000\170\000\170\
\\000\170\000\170\000\170\000\170\000\170\000\170\000\197\000\170\
\\000\170\000\170\000\170\000\170\000\170\000\170\000\170\000\170\
\\000\170\000\170\000\170\000\000\000\000\000\000\000\000\000\170\
\\000\000\000\170\000\170\000\170\000\170\000\170\000\170\000\170\
\\000\170\000\170\000\170\000\170\000\170\000\170\000\170\000\170\
\\000\170\000\170\000\170\000\170\000\170\000\170\000\170\000\170\
\\000\170\000\170\000\170\000\000\000\000\000\000\000\000\000\000\
\\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\
\\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\
\\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\
\\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\
\\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\
\\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\
\\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\
\\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\
\\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\
\\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\
\\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\
\\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\
\\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\
\\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\
\\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\
\\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000"
),
 (198,256, 
"\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\
\\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\
\\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\
\\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\
\\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\170\
\\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\
\\000\170\000\170\000\170\000\170\000\170\000\170\000\170\000\170\
\\000\170\000\170\000\000\000\000\000\000\000\000\000\000\000\000\
\\000\000\000\170\000\170\000\170\000\170\000\170\000\170\000\170\
\\000\205\000\170\000\170\000\170\000\170\000\170\000\170\000\170\
\\000\170\000\170\000\202\000\170\000\170\000\170\000\170\000\170\
\\000\170\000\170\000\170\000\000\000\000\000\000\000\000\000\170\
\\000\000\000\170\000\170\000\170\000\170\000\170\000\170\000\170\
\\000\170\000\170\000\170\000\170\000\170\000\170\000\170\000\170\
\\000\170\000\170\000\170\000\170\000\170\000\170\000\170\000\170\
\\000\170\000\199\000\170\000\000\000\000\000\000\000\000\000\000\
\\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\
\\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\
\\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\
\\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\
\\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\
\\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\
\\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\
\\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\
\\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\
\\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\
\\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\
\\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\
\\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\
\\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\
\\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\
\\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000"
),
 (199,256, 
"\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\
\\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\
\\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\
\\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\
\\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\170\
\\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\
\\000\170\000\170\000\170\000\170\000\170\000\170\000\170\000\170\
\\000\170\000\170\000\000\000\000\000\000\000\000\000\000\000\000\
\\000\000\000\170\000\170\000\170\000\170\000\170\000\170\000\170\
\\000\170\000\170\000\170\000\170\000\170\000\170\000\170\000\170\
\\000\170\000\170\000\170\000\170\000\170\000\170\000\170\000\170\
\\000\170\000\170\000\170\000\000\000\000\000\000\000\000\000\170\
\\000\000\000\170\000\170\000\170\000\170\000\170\000\170\000\170\
\\000\170\000\170\000\170\000\170\000\170\000\170\000\170\000\170\
\\000\200\000\170\000\170\000\170\000\170\000\170\000\170\000\170\
\\000\170\000\170\000\170\000\000\000\000\000\000\000\000\000\000\
\\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\
\\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\
\\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\
\\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\
\\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\
\\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\
\\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\
\\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\
\\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\
\\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\
\\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\
\\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\
\\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\
\\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\
\\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\
\\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000"
),
 (200,256, 
"\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\
\\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\
\\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\
\\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\
\\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\170\
\\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\
\\000\170\000\170\000\170\000\170\000\170\000\170\000\170\000\170\
\\000\170\000\170\000\000\000\000\000\000\000\000\000\000\000\000\
\\000\000\000\170\000\170\000\170\000\170\000\170\000\170\000\170\
\\000\170\000\170\000\170\000\170\000\170\000\170\000\170\000\170\
\\000\170\000\170\000\170\000\170\000\170\000\170\000\170\000\170\
\\000\170\000\170\000\170\000\000\000\000\000\000\000\000\000\170\
\\000\000\000\170\000\170\000\170\000\170\000\201\000\170\000\170\
\\000\170\000\170\000\170\000\170\000\170\000\170\000\170\000\170\
\\000\170\000\170\000\170\000\170\000\170\000\170\000\170\000\170\
\\000\170\000\170\000\170\000\000\000\000\000\000\000\000\000\000\
\\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\
\\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\
\\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\
\\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\
\\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\
\\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\
\\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\
\\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\
\\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\
\\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\
\\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\
\\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\
\\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\
\\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\
\\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\
\\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000"
),
 (202,256, 
"\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\
\\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\
\\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\
\\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\
\\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\170\
\\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\
\\000\170\000\170\000\170\000\170\000\170\000\170\000\170\000\170\
\\000\170\000\170\000\000\000\000\000\000\000\000\000\000\000\000\
\\000\000\000\170\000\170\000\170\000\170\000\170\000\170\000\170\
\\000\170\000\170\000\170\000\170\000\170\000\170\000\170\000\170\
\\000\170\000\170\000\170\000\170\000\170\000\203\000\170\000\170\
\\000\170\000\170\000\170\000\000\000\000\000\000\000\000\000\170\
\\000\000\000\170\000\170\000\170\000\170\000\170\000\170\000\170\
\\000\170\000\170\000\170\000\170\000\170\000\170\000\170\000\170\
\\000\170\000\170\000\170\000\170\000\170\000\170\000\170\000\170\
\\000\170\000\170\000\170\000\000\000\000\000\000\000\000\000\000\
\\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\
\\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\
\\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\
\\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\
\\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\
\\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\
\\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\
\\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\
\\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\
\\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\
\\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\
\\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\
\\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\
\\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\
\\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\
\\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000"
),
 (203,256, 
"\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\
\\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\
\\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\
\\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\
\\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\170\
\\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\
\\000\170\000\170\000\170\000\170\000\170\000\170\000\170\000\170\
\\000\170\000\170\000\000\000\000\000\000\000\000\000\000\000\000\
\\000\000\000\170\000\170\000\170\000\170\000\204\000\170\000\170\
\\000\170\000\170\000\170\000\170\000\170\000\170\000\170\000\170\
\\000\170\000\170\000\170\000\170\000\170\000\170\000\170\000\170\
\\000\170\000\170\000\170\000\000\000\000\000\000\000\000\000\170\
\\000\000\000\170\000\170\000\170\000\170\000\170\000\170\000\170\
\\000\170\000\170\000\170\000\170\000\170\000\170\000\170\000\170\
\\000\170\000\170\000\170\000\170\000\170\000\170\000\170\000\170\
\\000\170\000\170\000\170\000\000\000\000\000\000\000\000\000\000\
\\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\
\\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\
\\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\
\\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\
\\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\
\\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\
\\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\
\\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\
\\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\
\\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\
\\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\
\\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\
\\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\
\\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\
\\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\
\\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000"
),
 (205,256, 
"\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\
\\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\
\\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\
\\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\
\\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\170\
\\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\
\\000\170\000\170\000\170\000\170\000\170\000\170\000\170\000\170\
\\000\170\000\170\000\000\000\000\000\000\000\000\000\000\000\000\
\\000\000\000\170\000\170\000\170\000\170\000\206\000\170\000\170\
\\000\170\000\170\000\170\000\170\000\170\000\170\000\170\000\170\
\\000\170\000\170\000\170\000\170\000\170\000\170\000\170\000\170\
\\000\170\000\170\000\170\000\000\000\000\000\000\000\000\000\170\
\\000\000\000\170\000\170\000\170\000\170\000\170\000\170\000\170\
\\000\170\000\170\000\170\000\170\000\170\000\170\000\170\000\170\
\\000\170\000\170\000\170\000\170\000\170\000\170\000\170\000\170\
\\000\170\000\170\000\170\000\000\000\000\000\000\000\000\000\000\
\\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\
\\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\
\\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\
\\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\
\\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\
\\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\
\\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\
\\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\
\\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\
\\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\
\\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\
\\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\
\\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\
\\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\
\\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\
\\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000"
),
 (206,256, 
"\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\
\\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\
\\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\
\\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\
\\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\170\
\\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\
\\000\170\000\170\000\170\000\170\000\170\000\170\000\170\000\170\
\\000\170\000\170\000\000\000\000\000\000\000\000\000\000\000\000\
\\000\000\000\170\000\170\000\170\000\170\000\170\000\170\000\170\
\\000\170\000\170\000\170\000\170\000\170\000\170\000\207\000\170\
\\000\170\000\170\000\170\000\170\000\170\000\170\000\170\000\170\
\\000\170\000\170\000\170\000\000\000\000\000\000\000\000\000\170\
\\000\000\000\170\000\170\000\170\000\170\000\170\000\170\000\170\
\\000\170\000\170\000\170\000\170\000\170\000\170\000\170\000\170\
\\000\170\000\170\000\170\000\170\000\170\000\170\000\170\000\170\
\\000\170\000\170\000\170\000\000\000\000\000\000\000\000\000\000\
\\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\
\\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\
\\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\
\\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\
\\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\
\\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\
\\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\
\\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\
\\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\
\\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\
\\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\
\\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\
\\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\
\\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\
\\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\
\\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000"
),
 (208,256, 
"\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\
\\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\
\\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\
\\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\
\\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\170\
\\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\
\\000\170\000\170\000\170\000\170\000\170\000\170\000\170\000\170\
\\000\170\000\170\000\000\000\000\000\000\000\000\000\000\000\000\
\\000\000\000\170\000\170\000\170\000\170\000\213\000\170\000\170\
\\000\170\000\170\000\170\000\170\000\170\000\170\000\170\000\170\
\\000\170\000\211\000\170\000\170\000\170\000\209\000\170\000\170\
\\000\170\000\170\000\170\000\000\000\000\000\000\000\000\000\170\
\\000\000\000\170\000\170\000\170\000\170\000\170\000\170\000\170\
\\000\170\000\170\000\170\000\170\000\170\000\170\000\170\000\170\
\\000\170\000\170\000\170\000\170\000\170\000\170\000\170\000\170\
\\000\170\000\170\000\170\000\000\000\000\000\000\000\000\000\000\
\\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\
\\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\
\\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\
\\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\
\\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\
\\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\
\\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\
\\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\
\\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\
\\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\
\\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\
\\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\
\\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\
\\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\
\\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\
\\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000"
),
 (209,256, 
"\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\
\\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\
\\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\
\\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\
\\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\170\
\\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\
\\000\170\000\170\000\170\000\170\000\170\000\170\000\170\000\170\
\\000\170\000\170\000\000\000\000\000\000\000\000\000\000\000\000\
\\000\000\000\170\000\170\000\170\000\170\000\170\000\170\000\170\
\\000\170\000\170\000\170\000\170\000\170\000\210\000\170\000\170\
\\000\170\000\170\000\170\000\170\000\170\000\170\000\170\000\170\
\\000\170\000\170\000\170\000\000\000\000\000\000\000\000\000\170\
\\000\000\000\170\000\170\000\170\000\170\000\170\000\170\000\170\
\\000\170\000\170\000\170\000\170\000\170\000\170\000\170\000\170\
\\000\170\000\170\000\170\000\170\000\170\000\170\000\170\000\170\
\\000\170\000\170\000\170\000\000\000\000\000\000\000\000\000\000\
\\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\
\\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\
\\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\
\\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\
\\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\
\\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\
\\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\
\\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\
\\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\
\\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\
\\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\
\\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\
\\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\
\\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\
\\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\
\\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000"
),
 (211,256, 
"\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\
\\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\
\\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\
\\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\
\\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\170\
\\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\
\\000\170\000\170\000\170\000\170\000\170\000\170\000\170\000\170\
\\000\170\000\170\000\000\000\000\000\000\000\000\000\000\000\000\
\\000\000\000\170\000\170\000\170\000\170\000\170\000\170\000\170\
\\000\170\000\170\000\170\000\170\000\212\000\170\000\170\000\170\
\\000\170\000\170\000\170\000\170\000\170\000\170\000\170\000\170\
\\000\170\000\170\000\170\000\000\000\000\000\000\000\000\000\170\
\\000\000\000\170\000\170\000\170\000\170\000\170\000\170\000\170\
\\000\170\000\170\000\170\000\170\000\170\000\170\000\170\000\170\
\\000\170\000\170\000\170\000\170\000\170\000\170\000\170\000\170\
\\000\170\000\170\000\170\000\000\000\000\000\000\000\000\000\000\
\\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\
\\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\
\\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\
\\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\
\\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\
\\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\
\\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\
\\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\
\\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\
\\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\
\\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\
\\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\
\\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\
\\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\
\\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\
\\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000"
),
 (213,256, 
"\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\
\\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\
\\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\
\\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\
\\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\170\
\\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\
\\000\170\000\170\000\170\000\170\000\170\000\170\000\170\000\170\
\\000\170\000\170\000\000\000\000\000\000\000\000\000\000\000\000\
\\000\000\000\170\000\170\000\170\000\170\000\170\000\170\000\170\
\\000\170\000\170\000\170\000\170\000\215\000\170\000\170\000\170\
\\000\170\000\170\000\170\000\170\000\214\000\170\000\170\000\170\
\\000\170\000\170\000\170\000\000\000\000\000\000\000\000\000\170\
\\000\000\000\170\000\170\000\170\000\170\000\170\000\170\000\170\
\\000\170\000\170\000\170\000\170\000\170\000\170\000\170\000\170\
\\000\170\000\170\000\170\000\170\000\170\000\170\000\170\000\170\
\\000\170\000\170\000\170\000\000\000\000\000\000\000\000\000\000\
\\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\
\\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\
\\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\
\\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\
\\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\
\\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\
\\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\
\\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\
\\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\
\\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\
\\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\
\\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\
\\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\
\\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\
\\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\
\\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000"
),
 (215,256, 
"\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\
\\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\
\\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\
\\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\
\\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\170\
\\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\
\\000\170\000\170\000\170\000\170\000\170\000\170\000\170\000\170\
\\000\170\000\170\000\000\000\000\000\000\000\000\000\000\000\000\
\\000\000\000\170\000\170\000\170\000\170\000\216\000\170\000\170\
\\000\170\000\170\000\170\000\170\000\170\000\170\000\170\000\170\
\\000\170\000\170\000\170\000\170\000\170\000\170\000\170\000\170\
\\000\170\000\170\000\170\000\000\000\000\000\000\000\000\000\170\
\\000\000\000\170\000\170\000\170\000\170\000\170\000\170\000\170\
\\000\170\000\170\000\170\000\170\000\170\000\170\000\170\000\170\
\\000\170\000\170\000\170\000\170\000\170\000\170\000\170\000\170\
\\000\170\000\170\000\170\000\000\000\000\000\000\000\000\000\000\
\\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\
\\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\
\\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\
\\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\
\\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\
\\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\
\\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\
\\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\
\\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\
\\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\
\\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\
\\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\
\\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\
\\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\
\\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\
\\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000"
),
 (216,256, 
"\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\
\\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\
\\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\
\\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\
\\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\170\
\\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\
\\000\170\000\170\000\170\000\170\000\170\000\170\000\170\000\170\
\\000\170\000\170\000\000\000\000\000\000\000\000\000\000\000\000\
\\000\000\000\170\000\170\000\217\000\170\000\170\000\170\000\170\
\\000\170\000\170\000\170\000\170\000\170\000\170\000\170\000\170\
\\000\170\000\170\000\170\000\170\000\170\000\170\000\170\000\170\
\\000\170\000\170\000\170\000\000\000\000\000\000\000\000\000\170\
\\000\000\000\170\000\170\000\170\000\170\000\170\000\170\000\170\
\\000\170\000\170\000\170\000\170\000\170\000\170\000\170\000\170\
\\000\170\000\170\000\170\000\170\000\170\000\170\000\170\000\170\
\\000\170\000\170\000\170\000\000\000\000\000\000\000\000\000\000\
\\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\
\\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\
\\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\
\\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\
\\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\
\\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\
\\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\
\\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\
\\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\
\\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\
\\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\
\\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\
\\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\
\\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\
\\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\
\\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000"
),
 (217,256, 
"\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\
\\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\
\\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\
\\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\
\\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\170\
\\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\
\\000\170\000\170\000\170\000\170\000\170\000\170\000\170\000\170\
\\000\170\000\170\000\000\000\000\000\000\000\000\000\000\000\000\
\\000\000\000\170\000\170\000\170\000\170\000\170\000\170\000\170\
\\000\170\000\170\000\170\000\170\000\170\000\170\000\170\000\170\
\\000\170\000\170\000\170\000\170\000\218\000\170\000\170\000\170\
\\000\170\000\170\000\170\000\000\000\000\000\000\000\000\000\170\
\\000\000\000\170\000\170\000\170\000\170\000\170\000\170\000\170\
\\000\170\000\170\000\170\000\170\000\170\000\170\000\170\000\170\
\\000\170\000\170\000\170\000\170\000\170\000\170\000\170\000\170\
\\000\170\000\170\000\170\000\000\000\000\000\000\000\000\000\000\
\\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\
\\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\
\\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\
\\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\
\\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\
\\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\
\\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\
\\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\
\\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\
\\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\
\\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\
\\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\
\\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\
\\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\
\\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\
\\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000"
),
 (218,256, 
"\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\
\\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\
\\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\
\\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\
\\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\170\
\\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\
\\000\170\000\219\000\170\000\170\000\170\000\170\000\170\000\170\
\\000\170\000\170\000\000\000\000\000\000\000\000\000\000\000\000\
\\000\000\000\170\000\170\000\170\000\170\000\170\000\170\000\170\
\\000\170\000\170\000\170\000\170\000\170\000\170\000\170\000\170\
\\000\170\000\170\000\170\000\170\000\170\000\170\000\170\000\170\
\\000\170\000\170\000\170\000\000\000\000\000\000\000\000\000\170\
\\000\000\000\170\000\170\000\170\000\170\000\170\000\170\000\170\
\\000\170\000\170\000\170\000\170\000\170\000\170\000\170\000\170\
\\000\170\000\170\000\170\000\170\000\170\000\170\000\170\000\170\
\\000\170\000\170\000\170\000\000\000\000\000\000\000\000\000\000\
\\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\
\\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\
\\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\
\\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\
\\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\
\\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\
\\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\
\\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\
\\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\
\\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\
\\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\
\\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\
\\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\
\\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\
\\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\
\\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000"
),
 (220,256, 
"\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\
\\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\
\\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\
\\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\
\\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\170\
\\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\
\\000\170\000\170\000\170\000\170\000\170\000\170\000\170\000\170\
\\000\170\000\170\000\000\000\000\000\000\000\000\000\000\000\000\
\\000\000\000\240\000\170\000\170\000\170\000\225\000\170\000\170\
\\000\170\000\221\000\170\000\170\000\170\000\170\000\170\000\170\
\\000\170\000\170\000\170\000\170\000\170\000\170\000\170\000\170\
\\000\170\000\170\000\170\000\000\000\000\000\000\000\000\000\170\
\\000\000\000\170\000\170\000\170\000\170\000\170\000\170\000\170\
\\000\170\000\170\000\170\000\170\000\170\000\170\000\170\000\170\
\\000\170\000\170\000\170\000\170\000\170\000\170\000\170\000\170\
\\000\170\000\170\000\170\000\000\000\000\000\000\000\000\000\000\
\\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\
\\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\
\\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\
\\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\
\\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\
\\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\
\\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\
\\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\
\\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\
\\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\
\\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\
\\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\
\\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\
\\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\
\\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\
\\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000"
),
 (221,256, 
"\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\
\\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\
\\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\
\\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\
\\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\170\
\\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\
\\000\170\000\170\000\170\000\170\000\170\000\170\000\170\000\170\
\\000\170\000\170\000\000\000\000\000\000\000\000\000\000\000\000\
\\000\000\000\170\000\170\000\170\000\170\000\170\000\170\000\222\
\\000\170\000\170\000\170\000\170\000\170\000\170\000\170\000\170\
\\000\170\000\170\000\170\000\170\000\170\000\170\000\170\000\170\
\\000\170\000\170\000\170\000\000\000\000\000\000\000\000\000\170\
\\000\000\000\170\000\170\000\170\000\170\000\170\000\170\000\170\
\\000\170\000\170\000\170\000\170\000\170\000\170\000\170\000\170\
\\000\170\000\170\000\170\000\170\000\170\000\170\000\170\000\170\
\\000\170\000\170\000\170\000\000\000\000\000\000\000\000\000\000\
\\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\
\\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\
\\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\
\\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\
\\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\
\\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\
\\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\
\\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\
\\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\
\\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\
\\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\
\\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\
\\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\
\\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\
\\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\
\\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000"
),
 (222,256, 
"\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\
\\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\
\\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\
\\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\
\\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\170\
\\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\
\\000\170\000\170\000\170\000\170\000\170\000\170\000\170\000\170\
\\000\170\000\170\000\000\000\000\000\000\000\000\000\000\000\000\
\\000\000\000\170\000\170\000\170\000\170\000\170\000\170\000\170\
\\000\223\000\170\000\170\000\170\000\170\000\170\000\170\000\170\
\\000\170\000\170\000\170\000\170\000\170\000\170\000\170\000\170\
\\000\170\000\170\000\170\000\000\000\000\000\000\000\000\000\170\
\\000\000\000\170\000\170\000\170\000\170\000\170\000\170\000\170\
\\000\170\000\170\000\170\000\170\000\170\000\170\000\170\000\170\
\\000\170\000\170\000\170\000\170\000\170\000\170\000\170\000\170\
\\000\170\000\170\000\170\000\000\000\000\000\000\000\000\000\000\
\\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\
\\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\
\\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\
\\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\
\\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\
\\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\
\\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\
\\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\
\\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\
\\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\
\\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\
\\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\
\\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\
\\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\
\\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\
\\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000"
),
 (223,256, 
"\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\
\\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\
\\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\
\\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\
\\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\170\
\\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\
\\000\170\000\170\000\170\000\170\000\170\000\170\000\170\000\170\
\\000\170\000\170\000\000\000\000\000\000\000\000\000\000\000\000\
\\000\000\000\170\000\170\000\170\000\170\000\170\000\170\000\170\
\\000\170\000\170\000\170\000\170\000\170\000\170\000\170\000\170\
\\000\170\000\170\000\170\000\170\000\224\000\170\000\170\000\170\
\\000\170\000\170\000\170\000\000\000\000\000\000\000\000\000\170\
\\000\000\000\170\000\170\000\170\000\170\000\170\000\170\000\170\
\\000\170\000\170\000\170\000\170\000\170\000\170\000\170\000\170\
\\000\170\000\170\000\170\000\170\000\170\000\170\000\170\000\170\
\\000\170\000\170\000\170\000\000\000\000\000\000\000\000\000\000\
\\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\
\\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\
\\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\
\\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\
\\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\
\\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\
\\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\
\\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\
\\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\
\\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\
\\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\
\\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\
\\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\
\\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\
\\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\
\\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000"
),
 (225,256, 
"\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\
\\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\
\\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\
\\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\
\\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\170\
\\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\
\\000\170\000\170\000\170\000\170\000\170\000\170\000\170\000\170\
\\000\170\000\170\000\000\000\000\000\000\000\000\000\000\000\000\
\\000\000\000\170\000\170\000\170\000\170\000\170\000\232\000\170\
\\000\170\000\170\000\170\000\170\000\170\000\170\000\170\000\170\
\\000\170\000\170\000\170\000\226\000\170\000\170\000\170\000\170\
\\000\170\000\170\000\170\000\000\000\000\000\000\000\000\000\170\
\\000\000\000\170\000\170\000\170\000\170\000\170\000\170\000\170\
\\000\170\000\170\000\170\000\170\000\170\000\170\000\170\000\170\
\\000\170\000\170\000\170\000\170\000\170\000\170\000\170\000\170\
\\000\170\000\170\000\170\000\000\000\000\000\000\000\000\000\000\
\\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\
\\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\
\\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\
\\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\
\\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\
\\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\
\\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\
\\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\
\\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\
\\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\
\\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\
\\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\
\\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\
\\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\
\\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\
\\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000"
),
 (226,256, 
"\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\
\\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\
\\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\
\\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\
\\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\170\
\\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\
\\000\170\000\170\000\170\000\170\000\170\000\170\000\170\000\170\
\\000\170\000\170\000\000\000\000\000\000\000\000\000\000\000\000\
\\000\000\000\170\000\170\000\170\000\170\000\170\000\170\000\170\
\\000\170\000\170\000\170\000\170\000\170\000\170\000\170\000\170\
\\000\170\000\170\000\170\000\170\000\227\000\170\000\170\000\170\
\\000\170\000\170\000\170\000\000\000\000\000\000\000\000\000\170\
\\000\000\000\170\000\170\000\170\000\170\000\170\000\170\000\170\
\\000\170\000\170\000\170\000\170\000\170\000\170\000\170\000\170\
\\000\170\000\170\000\170\000\170\000\170\000\170\000\170\000\170\
\\000\170\000\170\000\170\000\000\000\000\000\000\000\000\000\000\
\\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\
\\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\
\\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\
\\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\
\\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\
\\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\
\\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\
\\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\
\\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\
\\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\
\\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\
\\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\
\\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\
\\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\
\\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\
\\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000"
),
 (227,256, 
"\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\
\\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\
\\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\
\\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\
\\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\170\
\\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\
\\000\170\000\170\000\170\000\170\000\170\000\170\000\170\000\170\
\\000\170\000\170\000\000\000\000\000\000\000\000\000\000\000\000\
\\000\000\000\170\000\170\000\170\000\170\000\170\000\170\000\170\
\\000\170\000\170\000\170\000\170\000\170\000\170\000\170\000\170\
\\000\170\000\170\000\228\000\170\000\170\000\170\000\170\000\170\
\\000\170\000\170\000\170\000\000\000\000\000\000\000\000\000\170\
\\000\000\000\170\000\170\000\170\000\170\000\170\000\170\000\170\
\\000\170\000\170\000\170\000\170\000\170\000\170\000\170\000\170\
\\000\170\000\170\000\170\000\170\000\170\000\170\000\170\000\170\
\\000\170\000\170\000\170\000\000\000\000\000\000\000\000\000\000\
\\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\
\\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\
\\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\
\\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\
\\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\
\\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\
\\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\
\\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\
\\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\
\\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\
\\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\
\\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\
\\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\
\\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\
\\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\
\\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000"
),
 (228,256, 
"\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\
\\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\
\\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\
\\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\
\\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\170\
\\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\
\\000\170\000\170\000\170\000\170\000\170\000\170\000\170\000\170\
\\000\170\000\170\000\000\000\000\000\000\000\000\000\000\000\000\
\\000\000\000\170\000\170\000\170\000\170\000\170\000\170\000\170\
\\000\170\000\229\000\170\000\170\000\170\000\170\000\170\000\170\
\\000\170\000\170\000\170\000\170\000\170\000\170\000\170\000\170\
\\000\170\000\170\000\170\000\000\000\000\000\000\000\000\000\170\
\\000\000\000\170\000\170\000\170\000\170\000\170\000\170\000\170\
\\000\170\000\170\000\170\000\170\000\170\000\170\000\170\000\170\
\\000\170\000\170\000\170\000\170\000\170\000\170\000\170\000\170\
\\000\170\000\170\000\170\000\000\000\000\000\000\000\000\000\000\
\\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\
\\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\
\\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\
\\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\
\\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\
\\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\
\\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\
\\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\
\\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\
\\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\
\\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\
\\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\
\\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\
\\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\
\\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\
\\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000"
),
 (229,256, 
"\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\
\\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\
\\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\
\\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\
\\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\170\
\\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\
\\000\170\000\170\000\170\000\170\000\170\000\170\000\170\000\170\
\\000\170\000\170\000\000\000\000\000\000\000\000\000\000\000\000\
\\000\000\000\170\000\170\000\230\000\170\000\170\000\170\000\170\
\\000\170\000\170\000\170\000\170\000\170\000\170\000\170\000\170\
\\000\170\000\170\000\170\000\170\000\170\000\170\000\170\000\170\
\\000\170\000\170\000\170\000\000\000\000\000\000\000\000\000\170\
\\000\000\000\170\000\170\000\170\000\170\000\170\000\170\000\170\
\\000\170\000\170\000\170\000\170\000\170\000\170\000\170\000\170\
\\000\170\000\170\000\170\000\170\000\170\000\170\000\170\000\170\
\\000\170\000\170\000\170\000\000\000\000\000\000\000\000\000\000\
\\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\
\\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\
\\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\
\\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\
\\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\
\\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\
\\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\
\\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\
\\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\
\\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\
\\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\
\\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\
\\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\
\\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\
\\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\
\\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000"
),
 (230,256, 
"\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\
\\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\
\\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\
\\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\
\\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\170\
\\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\
\\000\170\000\170\000\170\000\170\000\170\000\170\000\170\000\170\
\\000\170\000\170\000\000\000\000\000\000\000\000\000\000\000\000\
\\000\000\000\170\000\170\000\170\000\170\000\170\000\170\000\170\
\\000\170\000\170\000\170\000\170\000\170\000\170\000\170\000\170\
\\000\170\000\170\000\170\000\170\000\231\000\170\000\170\000\170\
\\000\170\000\170\000\170\000\000\000\000\000\000\000\000\000\170\
\\000\000\000\170\000\170\000\170\000\170\000\170\000\170\000\170\
\\000\170\000\170\000\170\000\170\000\170\000\170\000\170\000\170\
\\000\170\000\170\000\170\000\170\000\170\000\170\000\170\000\170\
\\000\170\000\170\000\170\000\000\000\000\000\000\000\000\000\000\
\\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\
\\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\
\\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\
\\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\
\\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\
\\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\
\\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\
\\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\
\\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\
\\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\
\\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\
\\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\
\\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\
\\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\
\\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\
\\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000"
),
 (232,256, 
"\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\
\\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\
\\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\
\\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\
\\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\170\
\\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\
\\000\170\000\170\000\170\000\170\000\170\000\170\000\170\000\170\
\\000\170\000\170\000\000\000\000\000\000\000\000\000\000\000\000\
\\000\000\000\170\000\170\000\170\000\170\000\233\000\170\000\170\
\\000\170\000\170\000\170\000\170\000\170\000\170\000\170\000\170\
\\000\170\000\170\000\170\000\170\000\170\000\170\000\170\000\170\
\\000\170\000\170\000\170\000\000\000\000\000\000\000\000\000\170\
\\000\000\000\170\000\170\000\170\000\170\000\170\000\170\000\170\
\\000\170\000\170\000\170\000\170\000\170\000\170\000\170\000\170\
\\000\170\000\170\000\170\000\170\000\170\000\170\000\170\000\170\
\\000\170\000\170\000\170\000\000\000\000\000\000\000\000\000\000\
\\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\
\\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\
\\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\
\\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\
\\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\
\\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\
\\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\
\\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\
\\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\
\\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\
\\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\
\\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\
\\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\
\\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\
\\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\
\\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000"
),
 (233,256, 
"\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\
\\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\
\\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\
\\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\
\\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\170\
\\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\
\\000\170\000\170\000\170\000\170\000\170\000\170\000\170\000\170\
\\000\170\000\170\000\000\000\000\000\000\000\000\000\000\000\000\
\\000\000\000\170\000\170\000\170\000\170\000\170\000\170\000\170\
\\000\170\000\170\000\170\000\170\000\170\000\170\000\170\000\170\
\\000\170\000\170\000\234\000\170\000\170\000\170\000\170\000\170\
\\000\170\000\170\000\170\000\000\000\000\000\000\000\000\000\170\
\\000\000\000\170\000\170\000\170\000\170\000\170\000\170\000\170\
\\000\170\000\170\000\170\000\170\000\170\000\170\000\170\000\170\
\\000\170\000\170\000\170\000\170\000\170\000\170\000\170\000\170\
\\000\170\000\170\000\170\000\000\000\000\000\000\000\000\000\000\
\\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\
\\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\
\\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\
\\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\
\\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\
\\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\
\\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\
\\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\
\\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\
\\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\
\\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\
\\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\
\\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\
\\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\
\\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\
\\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000"
),
 (234,256, 
"\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\
\\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\
\\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\
\\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\
\\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\170\
\\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\
\\000\170\000\170\000\170\000\170\000\170\000\170\000\170\000\170\
\\000\170\000\170\000\000\000\000\000\000\000\000\000\000\000\000\
\\000\000\000\170\000\170\000\170\000\170\000\235\000\170\000\170\
\\000\170\000\170\000\170\000\170\000\170\000\170\000\170\000\170\
\\000\170\000\170\000\170\000\170\000\170\000\170\000\170\000\170\
\\000\170\000\170\000\170\000\000\000\000\000\000\000\000\000\170\
\\000\000\000\170\000\170\000\170\000\170\000\170\000\170\000\170\
\\000\170\000\170\000\170\000\170\000\170\000\170\000\170\000\170\
\\000\170\000\170\000\170\000\170\000\170\000\170\000\170\000\170\
\\000\170\000\170\000\170\000\000\000\000\000\000\000\000\000\000\
\\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\
\\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\
\\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\
\\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\
\\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\
\\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\
\\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\
\\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\
\\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\
\\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\
\\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\
\\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\
\\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\
\\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\
\\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\
\\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000"
),
 (235,256, 
"\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\
\\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\
\\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\
\\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\
\\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\170\
\\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\
\\000\170\000\170\000\170\000\170\000\170\000\170\000\170\000\170\
\\000\170\000\170\000\000\000\000\000\000\000\000\000\000\000\000\
\\000\000\000\170\000\170\000\170\000\170\000\170\000\170\000\170\
\\000\170\000\170\000\170\000\170\000\170\000\170\000\236\000\170\
\\000\170\000\170\000\170\000\170\000\170\000\170\000\170\000\170\
\\000\170\000\170\000\170\000\000\000\000\000\000\000\000\000\170\
\\000\000\000\170\000\170\000\170\000\170\000\170\000\170\000\170\
\\000\170\000\170\000\170\000\170\000\170\000\170\000\170\000\170\
\\000\170\000\170\000\170\000\170\000\170\000\170\000\170\000\170\
\\000\170\000\170\000\170\000\000\000\000\000\000\000\000\000\000\
\\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\
\\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\
\\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\
\\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\
\\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\
\\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\
\\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\
\\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\
\\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\
\\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\
\\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\
\\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\
\\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\
\\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\
\\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\
\\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000"
),
 (236,256, 
"\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\
\\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\
\\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\
\\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\
\\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\170\
\\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\
\\000\170\000\170\000\170\000\170\000\170\000\170\000\170\000\170\
\\000\170\000\170\000\000\000\000\000\000\000\000\000\000\000\000\
\\000\000\000\170\000\170\000\237\000\170\000\170\000\170\000\170\
\\000\170\000\170\000\170\000\170\000\170\000\170\000\170\000\170\
\\000\170\000\170\000\170\000\170\000\170\000\170\000\170\000\170\
\\000\170\000\170\000\170\000\000\000\000\000\000\000\000\000\170\
\\000\000\000\170\000\170\000\170\000\170\000\170\000\170\000\170\
\\000\170\000\170\000\170\000\170\000\170\000\170\000\170\000\170\
\\000\170\000\170\000\170\000\170\000\170\000\170\000\170\000\170\
\\000\170\000\170\000\170\000\000\000\000\000\000\000\000\000\000\
\\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\
\\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\
\\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\
\\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\
\\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\
\\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\
\\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\
\\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\
\\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\
\\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\
\\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\
\\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\
\\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\
\\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\
\\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\
\\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000"
),
 (237,256, 
"\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\
\\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\
\\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\
\\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\
\\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\170\
\\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\
\\000\170\000\170\000\170\000\170\000\170\000\170\000\170\000\170\
\\000\170\000\170\000\000\000\000\000\000\000\000\000\000\000\000\
\\000\000\000\170\000\170\000\170\000\170\000\238\000\170\000\170\
\\000\170\000\170\000\170\000\170\000\170\000\170\000\170\000\170\
\\000\170\000\170\000\170\000\170\000\170\000\170\000\170\000\170\
\\000\170\000\170\000\170\000\000\000\000\000\000\000\000\000\170\
\\000\000\000\170\000\170\000\170\000\170\000\170\000\170\000\170\
\\000\170\000\170\000\170\000\170\000\170\000\170\000\170\000\170\
\\000\170\000\170\000\170\000\170\000\170\000\170\000\170\000\170\
\\000\170\000\170\000\170\000\000\000\000\000\000\000\000\000\000\
\\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\
\\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\
\\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\
\\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\
\\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\
\\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\
\\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\
\\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\
\\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\
\\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\
\\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\
\\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\
\\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\
\\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\
\\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\
\\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000"
),
 (238,256, 
"\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\
\\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\
\\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\
\\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\
\\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\170\
\\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\
\\000\170\000\170\000\170\000\170\000\170\000\170\000\170\000\170\
\\000\170\000\170\000\000\000\000\000\000\000\000\000\000\000\000\
\\000\000\000\170\000\170\000\170\000\170\000\170\000\170\000\170\
\\000\170\000\170\000\170\000\170\000\170\000\170\000\170\000\170\
\\000\170\000\170\000\170\000\239\000\170\000\170\000\170\000\170\
\\000\170\000\170\000\170\000\000\000\000\000\000\000\000\000\170\
\\000\000\000\170\000\170\000\170\000\170\000\170\000\170\000\170\
\\000\170\000\170\000\170\000\170\000\170\000\170\000\170\000\170\
\\000\170\000\170\000\170\000\170\000\170\000\170\000\170\000\170\
\\000\170\000\170\000\170\000\000\000\000\000\000\000\000\000\000\
\\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\
\\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\
\\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\
\\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\
\\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\
\\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\
\\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\
\\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\
\\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\
\\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\
\\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\
\\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\
\\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\
\\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\
\\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\
\\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000"
),
 (240,256, 
"\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\
\\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\
\\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\
\\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\
\\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\170\
\\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\
\\000\170\000\170\000\170\000\170\000\170\000\170\000\170\000\170\
\\000\170\000\170\000\000\000\000\000\000\000\000\000\000\000\000\
\\000\000\000\170\000\170\000\170\000\170\000\170\000\170\000\170\
\\000\170\000\170\000\170\000\170\000\170\000\170\000\241\000\170\
\\000\170\000\170\000\170\000\170\000\170\000\170\000\170\000\170\
\\000\170\000\170\000\170\000\000\000\000\000\000\000\000\000\170\
\\000\000\000\170\000\170\000\170\000\170\000\170\000\170\000\170\
\\000\170\000\170\000\170\000\170\000\170\000\170\000\170\000\170\
\\000\170\000\170\000\170\000\170\000\170\000\170\000\170\000\170\
\\000\170\000\170\000\170\000\000\000\000\000\000\000\000\000\000\
\\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\
\\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\
\\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\
\\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\
\\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\
\\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\
\\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\
\\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\
\\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\
\\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\
\\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\
\\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\
\\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\
\\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\
\\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\
\\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000"
),
 (241,256, 
"\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\
\\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\
\\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\
\\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\
\\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\170\
\\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\
\\000\170\000\170\000\170\000\170\000\170\000\170\000\170\000\170\
\\000\170\000\170\000\000\000\000\000\000\000\000\000\000\000\000\
\\000\000\000\170\000\170\000\170\000\243\000\170\000\170\000\170\
\\000\170\000\170\000\170\000\242\000\170\000\170\000\170\000\170\
\\000\170\000\170\000\170\000\170\000\170\000\170\000\170\000\170\
\\000\170\000\170\000\170\000\000\000\000\000\000\000\000\000\170\
\\000\000\000\170\000\170\000\170\000\170\000\170\000\170\000\170\
\\000\170\000\170\000\170\000\170\000\170\000\170\000\170\000\170\
\\000\170\000\170\000\170\000\170\000\170\000\170\000\170\000\170\
\\000\170\000\170\000\170\000\000\000\000\000\000\000\000\000\000\
\\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\
\\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\
\\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\
\\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\
\\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\
\\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\
\\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\
\\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\
\\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\
\\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\
\\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\
\\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\
\\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\
\\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\
\\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\
\\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000"
),
 (243,256, 
"\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\
\\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\
\\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\
\\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\
\\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\170\
\\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\
\\000\170\000\170\000\170\000\170\000\170\000\170\000\170\000\170\
\\000\170\000\170\000\000\000\000\000\000\000\000\000\000\000\000\
\\000\000\000\170\000\170\000\170\000\170\000\170\000\170\000\170\
\\000\170\000\170\000\170\000\170\000\170\000\170\000\170\000\244\
\\000\170\000\170\000\170\000\170\000\170\000\170\000\170\000\170\
\\000\170\000\170\000\170\000\000\000\000\000\000\000\000\000\170\
\\000\000\000\170\000\170\000\170\000\170\000\170\000\170\000\170\
\\000\170\000\170\000\170\000\170\000\170\000\170\000\170\000\170\
\\000\170\000\170\000\170\000\170\000\170\000\170\000\170\000\170\
\\000\170\000\170\000\170\000\000\000\000\000\000\000\000\000\000\
\\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\
\\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\
\\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\
\\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\
\\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\
\\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\
\\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\
\\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\
\\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\
\\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\
\\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\
\\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\
\\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\
\\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\
\\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\
\\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000"
),
 (244,256, 
"\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\
\\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\
\\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\
\\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\
\\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\170\
\\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\
\\000\170\000\170\000\170\000\170\000\170\000\170\000\170\000\170\
\\000\170\000\170\000\000\000\000\000\000\000\000\000\000\000\000\
\\000\000\000\170\000\170\000\170\000\170\000\170\000\170\000\170\
\\000\170\000\170\000\170\000\170\000\170\000\245\000\170\000\170\
\\000\170\000\170\000\170\000\170\000\170\000\170\000\170\000\170\
\\000\170\000\170\000\170\000\000\000\000\000\000\000\000\000\170\
\\000\000\000\170\000\170\000\170\000\170\000\170\000\170\000\170\
\\000\170\000\170\000\170\000\170\000\170\000\170\000\170\000\170\
\\000\170\000\170\000\170\000\170\000\170\000\170\000\170\000\170\
\\000\170\000\170\000\170\000\000\000\000\000\000\000\000\000\000\
\\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\
\\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\
\\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\
\\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\
\\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\
\\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\
\\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\
\\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\
\\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\
\\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\
\\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\
\\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\
\\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\
\\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\
\\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\
\\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000"
),
 (246,256, 
"\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\
\\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\
\\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\
\\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\
\\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\170\
\\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\
\\000\170\000\170\000\170\000\170\000\170\000\170\000\170\000\170\
\\000\170\000\170\000\000\000\000\000\000\000\000\000\000\000\000\
\\000\000\000\253\000\170\000\170\000\170\000\170\000\170\000\170\
\\000\170\000\170\000\170\000\170\000\170\000\170\000\170\000\170\
\\000\170\000\170\000\247\000\170\000\170\000\170\000\170\000\170\
\\000\170\000\170\000\170\000\000\000\000\000\000\000\000\000\170\
\\000\000\000\170\000\170\000\170\000\170\000\170\000\170\000\170\
\\000\170\000\170\000\170\000\170\000\170\000\170\000\170\000\170\
\\000\170\000\170\000\170\000\170\000\170\000\170\000\170\000\170\
\\000\170\000\170\000\170\000\000\000\000\000\000\000\000\000\000\
\\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\
\\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\
\\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\
\\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\
\\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\
\\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\
\\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\
\\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\
\\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\
\\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\
\\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\
\\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\
\\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\
\\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\
\\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\
\\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000"
),
 (247,256, 
"\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\
\\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\
\\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\
\\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\
\\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\170\
\\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\
\\000\170\000\170\000\170\000\170\000\170\000\170\000\170\000\170\
\\000\170\000\170\000\000\000\000\000\000\000\000\000\000\000\000\
\\000\000\000\170\000\170\000\170\000\170\000\170\000\170\000\170\
\\000\170\000\248\000\170\000\170\000\170\000\170\000\170\000\170\
\\000\170\000\170\000\170\000\170\000\170\000\170\000\170\000\170\
\\000\170\000\170\000\170\000\000\000\000\000\000\000\000\000\170\
\\000\000\000\170\000\170\000\170\000\170\000\170\000\170\000\170\
\\000\170\000\170\000\170\000\170\000\170\000\170\000\170\000\170\
\\000\170\000\170\000\170\000\170\000\170\000\170\000\170\000\170\
\\000\170\000\170\000\170\000\000\000\000\000\000\000\000\000\000\
\\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\
\\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\
\\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\
\\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\
\\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\
\\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\
\\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\
\\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\
\\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\
\\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\
\\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\
\\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\
\\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\
\\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\
\\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\
\\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000"
),
 (248,256, 
"\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\
\\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\
\\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\
\\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\
\\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\170\
\\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\
\\000\170\000\170\000\170\000\170\000\170\000\170\000\170\000\170\
\\000\170\000\170\000\000\000\000\000\000\000\000\000\000\000\000\
\\000\000\000\170\000\170\000\170\000\170\000\170\000\170\000\170\
\\000\170\000\170\000\170\000\170\000\170\000\249\000\170\000\170\
\\000\170\000\170\000\170\000\170\000\170\000\170\000\170\000\170\
\\000\170\000\170\000\170\000\000\000\000\000\000\000\000\000\170\
\\000\000\000\170\000\170\000\170\000\170\000\170\000\170\000\170\
\\000\170\000\170\000\170\000\170\000\170\000\170\000\170\000\170\
\\000\170\000\170\000\170\000\170\000\170\000\170\000\170\000\170\
\\000\170\000\170\000\170\000\000\000\000\000\000\000\000\000\000\
\\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\
\\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\
\\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\
\\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\
\\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\
\\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\
\\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\
\\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\
\\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\
\\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\
\\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\
\\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\
\\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\
\\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\
\\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\
\\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000"
),
 (249,256, 
"\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\
\\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\
\\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\
\\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\
\\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\170\
\\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\
\\000\170\000\170\000\170\000\170\000\170\000\170\000\170\000\170\
\\000\170\000\170\000\000\000\000\000\000\000\000\000\000\000\000\
\\000\000\000\250\000\170\000\170\000\170\000\170\000\170\000\170\
\\000\170\000\170\000\170\000\170\000\170\000\170\000\170\000\170\
\\000\170\000\170\000\170\000\170\000\170\000\170\000\170\000\170\
\\000\170\000\170\000\170\000\000\000\000\000\000\000\000\000\170\
\\000\000\000\170\000\170\000\170\000\170\000\170\000\170\000\170\
\\000\170\000\170\000\170\000\170\000\170\000\170\000\170\000\170\
\\000\170\000\170\000\170\000\170\000\170\000\170\000\170\000\170\
\\000\170\000\170\000\170\000\000\000\000\000\000\000\000\000\000\
\\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\
\\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\
\\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\
\\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\
\\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\
\\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\
\\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\
\\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\
\\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\
\\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\
\\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\
\\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\
\\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\
\\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\
\\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\
\\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000"
),
 (250,256, 
"\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\
\\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\
\\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\
\\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\
\\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\170\
\\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\
\\000\170\000\170\000\170\000\170\000\170\000\170\000\170\000\170\
\\000\170\000\170\000\000\000\000\000\000\000\000\000\000\000\000\
\\000\000\000\170\000\170\000\170\000\170\000\170\000\170\000\170\
\\000\170\000\170\000\170\000\170\000\170\000\170\000\170\000\170\
\\000\170\000\170\000\251\000\170\000\170\000\170\000\170\000\170\
\\000\170\000\170\000\170\000\000\000\000\000\000\000\000\000\170\
\\000\000\000\170\000\170\000\170\000\170\000\170\000\170\000\170\
\\000\170\000\170\000\170\000\170\000\170\000\170\000\170\000\170\
\\000\170\000\170\000\170\000\170\000\170\000\170\000\170\000\170\
\\000\170\000\170\000\170\000\000\000\000\000\000\000\000\000\000\
\\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\
\\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\
\\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\
\\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\
\\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\
\\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\
\\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\
\\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\
\\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\
\\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\
\\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\
\\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\
\\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\
\\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\
\\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\
\\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000"
),
 (251,256, 
"\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\
\\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\
\\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\
\\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\
\\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\170\
\\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\
\\000\170\000\170\000\170\000\170\000\170\000\170\000\170\000\170\
\\000\170\000\170\000\000\000\000\000\000\000\000\000\000\000\000\
\\000\000\000\170\000\170\000\170\000\170\000\170\000\170\000\170\
\\000\170\000\170\000\170\000\170\000\170\000\170\000\170\000\170\
\\000\170\000\170\000\170\000\170\000\170\000\170\000\170\000\170\
\\000\170\000\252\000\170\000\000\000\000\000\000\000\000\000\170\
\\000\000\000\170\000\170\000\170\000\170\000\170\000\170\000\170\
\\000\170\000\170\000\170\000\170\000\170\000\170\000\170\000\170\
\\000\170\000\170\000\170\000\170\000\170\000\170\000\170\000\170\
\\000\170\000\170\000\170\000\000\000\000\000\000\000\000\000\000\
\\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\
\\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\
\\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\
\\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\
\\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\
\\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\
\\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\
\\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\
\\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\
\\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\
\\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\
\\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\
\\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\
\\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\
\\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\
\\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000"
),
 (253,256, 
"\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\
\\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\
\\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\
\\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\
\\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\170\
\\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\
\\000\170\000\170\000\170\000\170\000\170\000\170\000\170\000\170\
\\000\170\000\170\000\000\000\000\000\000\000\000\000\000\000\000\
\\000\000\000\170\000\170\000\170\000\170\000\170\000\170\000\170\
\\000\170\000\170\000\170\000\170\000\170\000\170\000\170\000\170\
\\000\170\000\170\000\254\000\170\000\170\000\170\000\170\000\170\
\\000\170\000\170\000\170\000\000\000\000\000\000\000\000\000\170\
\\000\000\000\170\000\170\000\170\000\170\000\170\000\170\000\170\
\\000\170\000\170\000\170\000\170\000\170\000\170\000\170\000\170\
\\000\170\000\170\000\170\000\170\000\170\000\170\000\170\000\170\
\\000\170\000\170\000\170\000\000\000\000\000\000\000\000\000\000\
\\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\
\\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\
\\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\
\\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\
\\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\
\\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\
\\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\
\\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\
\\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\
\\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\
\\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\
\\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\
\\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\
\\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\
\\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\
\\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000"
),
 (254,256, 
"\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\
\\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\
\\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\
\\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\
\\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\170\
\\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\
\\000\170\000\170\000\170\000\170\000\170\000\170\000\170\000\170\
\\000\170\000\170\000\000\000\000\000\000\000\000\000\000\000\000\
\\000\000\000\170\000\170\000\170\000\170\000\170\000\170\000\170\
\\000\170\000\170\000\170\000\170\000\170\000\170\000\170\000\170\
\\000\170\000\170\000\170\000\170\000\255\000\170\000\170\000\170\
\\000\170\000\170\000\170\000\000\000\000\000\000\000\000\000\170\
\\000\000\000\170\000\170\000\170\000\170\000\170\000\170\000\170\
\\000\170\000\170\000\170\000\170\000\170\000\170\000\170\000\170\
\\000\170\000\170\000\170\000\170\000\170\000\170\000\170\000\170\
\\000\170\000\170\000\170\000\000\000\000\000\000\000\000\000\000\
\\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\
\\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\
\\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\
\\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\
\\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\
\\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\
\\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\
\\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\
\\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\
\\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\
\\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\
\\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\
\\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\
\\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\
\\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\
\\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000"
),
 (255,256, 
"\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\
\\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\
\\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\
\\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\
\\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\170\
\\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\
\\000\170\000\170\000\170\000\170\000\170\000\170\000\170\000\170\
\\000\170\000\170\000\000\000\000\000\000\000\000\000\000\000\000\
\\000\000\000\170\000\170\000\170\000\170\000\170\000\170\000\170\
\\000\170\001\000\000\170\000\170\000\170\000\170\000\170\000\170\
\\000\170\000\170\000\170\000\170\000\170\000\170\000\170\000\170\
\\000\170\000\170\000\170\000\000\000\000\000\000\000\000\000\170\
\\000\000\000\170\000\170\000\170\000\170\000\170\000\170\000\170\
\\000\170\000\170\000\170\000\170\000\170\000\170\000\170\000\170\
\\000\170\000\170\000\170\000\170\000\170\000\170\000\170\000\170\
\\000\170\000\170\000\170\000\000\000\000\000\000\000\000\000\000\
\\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\
\\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\
\\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\
\\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\
\\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\
\\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\
\\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\
\\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\
\\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\
\\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\
\\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\
\\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\
\\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\
\\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\
\\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\
\\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000"
),
 (256,256, 
"\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\
\\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\
\\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\
\\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\
\\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\170\
\\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\
\\000\170\000\170\000\170\000\170\000\170\000\170\000\170\000\170\
\\000\170\000\170\000\000\000\000\000\000\000\000\000\000\000\000\
\\000\000\000\170\000\170\000\170\000\170\000\170\000\170\000\170\
\\000\170\000\170\000\170\000\170\000\170\000\170\000\170\000\170\
\\000\170\000\170\000\170\000\170\001\001\000\170\000\170\000\170\
\\000\170\000\170\000\170\000\000\000\000\000\000\000\000\000\170\
\\000\000\000\170\000\170\000\170\000\170\000\170\000\170\000\170\
\\000\170\000\170\000\170\000\170\000\170\000\170\000\170\000\170\
\\000\170\000\170\000\170\000\170\000\170\000\170\000\170\000\170\
\\000\170\000\170\000\170\000\000\000\000\000\000\000\000\000\000\
\\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\
\\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\
\\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\
\\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\
\\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\
\\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\
\\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\
\\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\
\\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\
\\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\
\\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\
\\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\
\\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\
\\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\
\\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\
\\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000"
),
 (257,256, 
"\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\
\\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\
\\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\
\\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\
\\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\170\
\\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\
\\000\170\000\170\000\170\000\170\000\170\000\170\000\170\000\170\
\\000\170\000\170\000\000\000\000\000\000\000\000\000\000\000\000\
\\000\000\000\170\000\170\000\170\000\170\000\170\000\170\000\170\
\\000\170\001\002\000\170\000\170\000\170\000\170\000\170\000\170\
\\000\170\000\170\000\170\000\170\000\170\000\170\000\170\000\170\
\\000\170\000\170\000\170\000\000\000\000\000\000\000\000\000\170\
\\000\000\000\170\000\170\000\170\000\170\000\170\000\170\000\170\
\\000\170\000\170\000\170\000\170\000\170\000\170\000\170\000\170\
\\000\170\000\170\000\170\000\170\000\170\000\170\000\170\000\170\
\\000\170\000\170\000\170\000\000\000\000\000\000\000\000\000\000\
\\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\
\\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\
\\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\
\\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\
\\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\
\\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\
\\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\
\\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\
\\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\
\\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\
\\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\
\\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\
\\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\
\\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\
\\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\
\\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000"
),
 (258,256, 
"\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\
\\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\
\\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\
\\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\
\\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\170\
\\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\
\\000\170\000\170\000\170\000\170\000\170\000\170\000\170\000\170\
\\000\170\000\170\000\000\000\000\000\000\000\000\000\000\000\000\
\\000\000\000\170\000\170\000\170\000\170\000\170\000\170\000\170\
\\000\170\000\170\000\170\000\170\000\170\000\170\000\170\001\003\
\\000\170\000\170\000\170\000\170\000\170\000\170\000\170\000\170\
\\000\170\000\170\000\170\000\000\000\000\000\000\000\000\000\170\
\\000\000\000\170\000\170\000\170\000\170\000\170\000\170\000\170\
\\000\170\000\170\000\170\000\170\000\170\000\170\000\170\000\170\
\\000\170\000\170\000\170\000\170\000\170\000\170\000\170\000\170\
\\000\170\000\170\000\170\000\000\000\000\000\000\000\000\000\000\
\\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\
\\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\
\\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\
\\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\
\\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\
\\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\
\\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\
\\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\
\\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\
\\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\
\\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\
\\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\
\\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\
\\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\
\\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\
\\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000"
),
 (259,256, 
"\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\
\\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\
\\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\
\\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\
\\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\170\
\\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\
\\000\170\000\170\000\170\000\170\000\170\000\170\000\170\000\170\
\\000\170\000\170\000\000\000\000\000\000\000\000\000\000\000\000\
\\000\000\000\170\000\170\000\170\000\170\000\170\000\170\000\170\
\\000\170\000\170\000\170\000\170\000\170\000\170\001\004\000\170\
\\000\170\000\170\000\170\000\170\000\170\000\170\000\170\000\170\
\\000\170\000\170\000\170\000\000\000\000\000\000\000\000\000\170\
\\000\000\000\170\000\170\000\170\000\170\000\170\000\170\000\170\
\\000\170\000\170\000\170\000\170\000\170\000\170\000\170\000\170\
\\000\170\000\170\000\170\000\170\000\170\000\170\000\170\000\170\
\\000\170\000\170\000\170\000\000\000\000\000\000\000\000\000\000\
\\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\
\\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\
\\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\
\\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\
\\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\
\\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\
\\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\
\\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\
\\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\
\\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\
\\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\
\\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\
\\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\
\\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\
\\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\
\\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000"
),
 (261,256, 
"\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\
\\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\
\\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\
\\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\
\\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\170\
\\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\
\\000\170\000\170\000\170\000\170\000\170\000\170\000\170\000\170\
\\000\170\000\170\000\000\000\000\000\000\000\000\000\000\000\000\
\\000\000\000\170\000\170\000\170\000\170\000\170\001\018\000\170\
\\000\170\000\170\000\170\000\170\000\170\000\170\001\017\000\170\
\\000\170\000\170\001\013\000\170\000\170\001\009\001\006\000\170\
\\000\170\000\170\000\170\000\000\000\000\000\000\000\000\000\170\
\\000\000\000\170\000\170\000\170\000\170\000\170\000\170\000\170\
\\000\170\000\170\000\170\000\170\000\170\000\170\000\170\000\170\
\\000\170\000\170\000\170\000\170\000\170\000\170\000\170\000\170\
\\000\170\000\170\000\170\000\000\000\000\000\000\000\000\000\000\
\\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\
\\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\
\\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\
\\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\
\\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\
\\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\
\\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\
\\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\
\\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\
\\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\
\\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\
\\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\
\\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\
\\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\
\\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\
\\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000"
),
 (262,256, 
"\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\
\\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\
\\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\
\\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\
\\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\170\
\\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\
\\000\170\000\170\000\170\000\170\000\170\000\170\000\170\000\170\
\\000\170\000\170\000\000\000\000\000\000\000\000\000\000\000\000\
\\000\000\000\170\000\170\000\170\000\170\001\007\000\170\000\170\
\\000\170\000\170\000\170\000\170\000\170\000\170\000\170\000\170\
\\000\170\000\170\000\170\000\170\000\170\000\170\000\170\000\170\
\\000\170\000\170\000\170\000\000\000\000\000\000\000\000\000\170\
\\000\000\000\170\000\170\000\170\000\170\000\170\000\170\000\170\
\\000\170\000\170\000\170\000\170\000\170\000\170\000\170\000\170\
\\000\170\000\170\000\170\000\170\000\170\000\170\000\170\000\170\
\\000\170\000\170\000\170\000\000\000\000\000\000\000\000\000\000\
\\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\
\\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\
\\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\
\\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\
\\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\
\\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\
\\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\
\\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\
\\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\
\\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\
\\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\
\\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\
\\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\
\\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\
\\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\
\\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000"
),
 (263,256, 
"\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\
\\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\
\\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\
\\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\
\\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\170\
\\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\
\\000\170\000\170\000\170\000\170\000\170\000\170\000\170\000\170\
\\000\170\000\170\000\000\000\000\000\000\000\000\000\000\000\000\
\\000\000\000\170\000\170\000\170\000\170\000\170\000\170\000\170\
\\000\170\000\170\000\170\000\170\000\170\000\170\000\170\000\170\
\\000\170\000\170\001\008\000\170\000\170\000\170\000\170\000\170\
\\000\170\000\170\000\170\000\000\000\000\000\000\000\000\000\170\
\\000\000\000\170\000\170\000\170\000\170\000\170\000\170\000\170\
\\000\170\000\170\000\170\000\170\000\170\000\170\000\170\000\170\
\\000\170\000\170\000\170\000\170\000\170\000\170\000\170\000\170\
\\000\170\000\170\000\170\000\000\000\000\000\000\000\000\000\000\
\\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\
\\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\
\\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\
\\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\
\\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\
\\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\
\\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\
\\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\
\\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\
\\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\
\\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\
\\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\
\\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\
\\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\
\\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\
\\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000"
),
 (265,256, 
"\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\
\\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\
\\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\
\\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\
\\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\170\
\\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\
\\000\170\000\170\000\170\000\170\000\170\000\170\000\170\000\170\
\\000\170\000\170\000\000\000\000\000\000\000\000\000\000\000\000\
\\000\000\000\170\000\170\000\170\000\170\000\170\000\170\000\170\
\\000\170\000\170\000\170\000\170\000\170\000\170\000\170\000\170\
\\000\170\000\170\000\170\000\170\001\010\000\170\000\170\000\170\
\\000\170\000\170\000\170\000\000\000\000\000\000\000\000\000\170\
\\000\000\000\170\000\170\000\170\000\170\000\170\000\170\000\170\
\\000\170\000\170\000\170\000\170\000\170\000\170\000\170\000\170\
\\000\170\000\170\000\170\000\170\000\170\000\170\000\170\000\170\
\\000\170\000\170\000\170\000\000\000\000\000\000\000\000\000\000\
\\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\
\\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\
\\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\
\\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\
\\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\
\\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\
\\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\
\\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\
\\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\
\\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\
\\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\
\\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\
\\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\
\\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\
\\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\
\\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000"
),
 (266,256, 
"\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\
\\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\
\\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\
\\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\
\\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\170\
\\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\
\\000\170\000\170\000\170\000\170\000\170\000\170\000\170\000\170\
\\000\170\000\170\000\000\000\000\000\000\000\000\000\000\000\000\
\\000\000\000\170\000\170\000\170\000\170\001\011\000\170\000\170\
\\000\170\000\170\000\170\000\170\000\170\000\170\000\170\000\170\
\\000\170\000\170\000\170\000\170\000\170\000\170\000\170\000\170\
\\000\170\000\170\000\170\000\000\000\000\000\000\000\000\000\170\
\\000\000\000\170\000\170\000\170\000\170\000\170\000\170\000\170\
\\000\170\000\170\000\170\000\170\000\170\000\170\000\170\000\170\
\\000\170\000\170\000\170\000\170\000\170\000\170\000\170\000\170\
\\000\170\000\170\000\170\000\000\000\000\000\000\000\000\000\000\
\\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\
\\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\
\\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\
\\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\
\\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\
\\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\
\\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\
\\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\
\\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\
\\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\
\\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\
\\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\
\\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\
\\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\
\\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\
\\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000"
),
 (267,256, 
"\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\
\\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\
\\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\
\\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\
\\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\170\
\\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\
\\000\170\000\170\000\170\000\170\000\170\000\170\000\170\000\170\
\\000\170\000\170\000\000\000\000\000\000\000\000\000\000\000\000\
\\000\000\000\170\000\170\000\170\000\170\000\170\000\170\000\170\
\\000\170\000\170\000\170\000\170\000\170\000\170\000\170\000\170\
\\000\170\000\170\001\012\000\170\000\170\000\170\000\170\000\170\
\\000\170\000\170\000\170\000\000\000\000\000\000\000\000\000\170\
\\000\000\000\170\000\170\000\170\000\170\000\170\000\170\000\170\
\\000\170\000\170\000\170\000\170\000\170\000\170\000\170\000\170\
\\000\170\000\170\000\170\000\170\000\170\000\170\000\170\000\170\
\\000\170\000\170\000\170\000\000\000\000\000\000\000\000\000\000\
\\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\
\\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\
\\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\
\\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\
\\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\
\\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\
\\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\
\\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\
\\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\
\\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\
\\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\
\\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\
\\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\
\\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\
\\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\
\\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000"
),
 (269,256, 
"\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\
\\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\
\\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\
\\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\
\\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\170\
\\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\
\\000\170\000\170\000\170\000\170\000\170\000\170\000\170\000\170\
\\000\170\000\170\000\000\000\000\000\000\000\000\000\000\000\000\
\\000\000\000\170\000\170\000\170\001\014\000\170\000\170\000\170\
\\000\170\000\170\000\170\000\170\000\170\000\170\000\170\000\170\
\\000\170\000\170\000\170\000\170\000\170\000\170\000\170\000\170\
\\000\170\000\170\000\170\000\000\000\000\000\000\000\000\000\170\
\\000\000\000\170\000\170\000\170\000\170\000\170\000\170\000\170\
\\000\170\000\170\000\170\000\170\000\170\000\170\000\170\000\170\
\\000\170\000\170\000\170\000\170\000\170\000\170\000\170\000\170\
\\000\170\000\170\000\170\000\000\000\000\000\000\000\000\000\000\
\\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\
\\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\
\\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\
\\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\
\\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\
\\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\
\\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\
\\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\
\\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\
\\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\
\\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\
\\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\
\\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\
\\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\
\\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\
\\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000"
),
 (270,256, 
"\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\
\\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\
\\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\
\\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\
\\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\170\
\\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\
\\000\170\000\170\000\170\000\170\000\170\000\170\000\170\000\170\
\\000\170\000\170\000\000\000\000\000\000\000\000\000\000\000\000\
\\000\000\000\170\000\170\000\170\000\170\001\015\000\170\000\170\
\\000\170\000\170\000\170\000\170\000\170\000\170\000\170\000\170\
\\000\170\000\170\000\170\000\170\000\170\000\170\000\170\000\170\
\\000\170\000\170\000\170\000\000\000\000\000\000\000\000\000\170\
\\000\000\000\170\000\170\000\170\000\170\000\170\000\170\000\170\
\\000\170\000\170\000\170\000\170\000\170\000\170\000\170\000\170\
\\000\170\000\170\000\170\000\170\000\170\000\170\000\170\000\170\
\\000\170\000\170\000\170\000\000\000\000\000\000\000\000\000\000\
\\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\
\\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\
\\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\
\\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\
\\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\
\\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\
\\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\
\\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\
\\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\
\\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\
\\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\
\\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\
\\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\
\\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\
\\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\
\\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000"
),
 (271,256, 
"\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\
\\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\
\\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\
\\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\
\\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\170\
\\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\
\\000\170\000\170\000\170\000\170\000\170\000\170\000\170\000\170\
\\000\170\000\170\000\000\000\000\000\000\000\000\000\000\000\000\
\\000\000\000\170\000\170\000\170\000\170\000\170\000\170\000\170\
\\000\170\000\170\000\170\000\170\000\170\000\170\000\170\000\170\
\\000\170\000\170\001\016\000\170\000\170\000\170\000\170\000\170\
\\000\170\000\170\000\170\000\000\000\000\000\000\000\000\000\170\
\\000\000\000\170\000\170\000\170\000\170\000\170\000\170\000\170\
\\000\170\000\170\000\170\000\170\000\170\000\170\000\170\000\170\
\\000\170\000\170\000\170\000\170\000\170\000\170\000\170\000\170\
\\000\170\000\170\000\170\000\000\000\000\000\000\000\000\000\000\
\\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\
\\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\
\\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\
\\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\
\\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\
\\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\
\\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\
\\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\
\\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\
\\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\
\\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\
\\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\
\\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\
\\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\
\\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\
\\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000"
),
 (274,256, 
"\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\
\\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\
\\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\
\\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\
\\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\170\
\\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\
\\000\170\000\170\000\170\000\170\000\170\000\170\000\170\000\170\
\\000\170\000\170\000\000\000\000\000\000\000\000\000\000\000\000\
\\000\000\000\170\000\170\000\170\000\170\000\170\001\019\000\170\
\\000\170\000\170\000\170\000\170\000\170\000\170\000\170\000\170\
\\000\170\000\170\000\170\000\170\000\170\000\170\000\170\000\170\
\\000\170\000\170\000\170\000\000\000\000\000\000\000\000\000\170\
\\000\000\000\170\000\170\000\170\000\170\000\170\000\170\000\170\
\\000\170\000\170\000\170\000\170\000\170\000\170\000\170\000\170\
\\000\170\000\170\000\170\000\170\000\170\000\170\000\170\000\170\
\\000\170\000\170\000\170\000\000\000\000\000\000\000\000\000\000\
\\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\
\\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\
\\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\
\\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\
\\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\
\\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\
\\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\
\\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\
\\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\
\\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\
\\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\
\\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\
\\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\
\\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\
\\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\
\\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000"
),
 (275,256, 
"\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\
\\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\
\\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\
\\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\
\\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\170\
\\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\
\\000\170\000\170\000\170\000\170\000\170\000\170\000\170\000\170\
\\000\170\000\170\000\000\000\000\000\000\000\000\000\000\000\000\
\\000\000\000\170\000\170\000\170\000\170\000\170\000\170\000\170\
\\000\170\000\170\000\170\000\170\000\170\000\170\000\170\000\170\
\\000\170\000\170\000\170\001\020\000\170\000\170\000\170\000\170\
\\000\170\000\170\000\170\000\000\000\000\000\000\000\000\000\170\
\\000\000\000\170\000\170\000\170\000\170\000\170\000\170\000\170\
\\000\170\000\170\000\170\000\170\000\170\000\170\000\170\000\170\
\\000\170\000\170\000\170\000\170\000\170\000\170\000\170\000\170\
\\000\170\000\170\000\170\000\000\000\000\000\000\000\000\000\000\
\\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\
\\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\
\\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\
\\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\
\\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\
\\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\
\\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\
\\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\
\\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\
\\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\
\\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\
\\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\
\\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\
\\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\
\\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\
\\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000"
),
 (276,256, 
"\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\
\\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\
\\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\
\\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\
\\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\170\
\\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\
\\000\170\000\170\000\170\000\170\000\170\000\170\000\170\000\170\
\\000\170\000\170\000\000\000\000\000\000\000\000\000\000\000\000\
\\000\000\000\170\000\170\000\170\000\170\001\021\000\170\000\170\
\\000\170\000\170\000\170\000\170\000\170\000\170\000\170\000\170\
\\000\170\000\170\000\170\000\170\000\170\000\170\000\170\000\170\
\\000\170\000\170\000\170\000\000\000\000\000\000\000\000\000\170\
\\000\000\000\170\000\170\000\170\000\170\000\170\000\170\000\170\
\\000\170\000\170\000\170\000\170\000\170\000\170\000\170\000\170\
\\000\170\000\170\000\170\000\170\000\170\000\170\000\170\000\170\
\\000\170\000\170\000\170\000\000\000\000\000\000\000\000\000\000\
\\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\
\\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\
\\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\
\\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\
\\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\
\\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\
\\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\
\\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\
\\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\
\\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\
\\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\
\\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\
\\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\
\\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\
\\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\
\\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000"
),
 (277,256, 
"\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\
\\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\
\\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\
\\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\
\\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\170\
\\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\
\\000\170\000\170\000\170\000\170\000\170\000\170\000\170\000\170\
\\000\170\000\170\000\000\000\000\000\000\000\000\000\000\000\000\
\\000\000\000\170\000\170\000\170\000\170\000\170\000\170\000\170\
\\000\170\000\170\000\170\000\170\000\170\000\170\000\170\000\170\
\\000\170\000\170\000\170\000\170\001\022\000\170\000\170\000\170\
\\000\170\000\170\000\170\000\000\000\000\000\000\000\000\000\170\
\\000\000\000\170\000\170\000\170\000\170\000\170\000\170\000\170\
\\000\170\000\170\000\170\000\170\000\170\000\170\000\170\000\170\
\\000\170\000\170\000\170\000\170\000\170\000\170\000\170\000\170\
\\000\170\000\170\000\170\000\000\000\000\000\000\000\000\000\000\
\\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\
\\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\
\\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\
\\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\
\\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\
\\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\
\\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\
\\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\
\\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\
\\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\
\\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\
\\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\
\\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\
\\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\
\\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\
\\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000"
),
 (279,256, 
"\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\
\\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\
\\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\
\\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\
\\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\170\
\\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\
\\000\170\000\170\000\170\000\170\000\170\000\170\000\170\000\170\
\\000\170\000\170\000\000\000\000\000\000\000\000\000\000\000\000\
\\000\000\000\170\000\170\000\170\000\170\000\170\000\170\000\170\
\\000\170\000\170\000\170\000\170\000\170\000\170\000\170\001\030\
\\000\170\000\170\000\170\000\170\000\170\001\027\000\170\000\170\
\\000\170\000\170\000\170\000\000\000\000\000\000\000\000\000\170\
\\000\000\001\024\000\170\000\170\000\170\000\170\000\170\000\170\
\\000\170\000\170\000\170\000\170\000\170\000\170\000\170\000\170\
\\000\170\000\170\000\170\000\170\000\170\000\170\000\170\000\170\
\\000\170\000\170\000\170\000\000\000\000\000\000\000\000\000\000\
\\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\
\\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\
\\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\
\\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\
\\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\
\\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\
\\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\
\\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\
\\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\
\\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\
\\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\
\\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\
\\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\
\\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\
\\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\
\\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000"
),
 (280,256, 
"\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\
\\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\
\\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\
\\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\
\\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\170\
\\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\
\\000\170\000\170\000\170\000\170\000\170\000\170\000\170\000\170\
\\000\170\000\170\000\000\000\000\000\000\000\000\000\000\000\000\
\\000\000\000\170\000\170\000\170\000\170\000\170\000\170\000\170\
\\000\170\000\170\000\170\000\170\000\170\000\170\000\170\000\170\
\\000\170\000\170\000\170\000\170\000\170\000\170\000\170\000\170\
\\000\170\000\170\000\170\000\000\000\000\000\000\000\000\000\170\
\\000\000\000\170\000\170\000\170\000\170\000\170\000\170\000\170\
\\000\170\000\170\000\170\000\170\000\170\001\025\000\170\000\170\
\\000\170\000\170\000\170\000\170\000\170\000\170\000\170\000\170\
\\000\170\000\170\000\170\000\000\000\000\000\000\000\000\000\000\
\\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\
\\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\
\\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\
\\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\
\\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\
\\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\
\\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\
\\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\
\\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\
\\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\
\\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\
\\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\
\\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\
\\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\
\\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\
\\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000"
),
 (281,256, 
"\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\
\\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\
\\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\
\\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\
\\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\170\
\\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\
\\000\170\000\170\000\170\000\170\000\170\000\170\000\170\000\170\
\\000\170\000\170\000\000\000\000\000\000\000\000\000\000\000\000\
\\000\000\000\170\000\170\000\170\000\170\000\170\000\170\000\170\
\\000\170\000\170\000\170\000\170\000\170\000\170\000\170\000\170\
\\000\170\000\170\000\170\000\170\000\170\000\170\000\170\000\170\
\\000\170\000\170\000\170\000\000\000\000\000\000\000\000\000\170\
\\000\000\000\170\000\170\000\170\000\170\001\026\000\170\000\170\
\\000\170\000\170\000\170\000\170\000\170\000\170\000\170\000\170\
\\000\170\000\170\000\170\000\170\000\170\000\170\000\170\000\170\
\\000\170\000\170\000\170\000\000\000\000\000\000\000\000\000\000\
\\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\
\\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\
\\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\
\\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\
\\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\
\\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\
\\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\
\\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\
\\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\
\\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\
\\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\
\\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\
\\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\
\\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\
\\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\
\\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000"
),
 (283,256, 
"\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\
\\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\
\\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\
\\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\
\\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\170\
\\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\
\\000\170\000\170\000\170\000\170\000\170\000\170\000\170\000\170\
\\000\170\000\170\000\000\000\000\000\000\000\000\000\000\000\000\
\\000\000\000\170\000\170\000\170\000\170\000\170\000\170\000\170\
\\000\170\000\170\000\170\000\170\001\028\000\170\000\170\000\170\
\\000\170\000\170\000\170\000\170\000\170\000\170\000\170\000\170\
\\000\170\000\170\000\170\000\000\000\000\000\000\000\000\000\170\
\\000\000\000\170\000\170\000\170\000\170\000\170\000\170\000\170\
\\000\170\000\170\000\170\000\170\000\170\000\170\000\170\000\170\
\\000\170\000\170\000\170\000\170\000\170\000\170\000\170\000\170\
\\000\170\000\170\000\170\000\000\000\000\000\000\000\000\000\000\
\\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\
\\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\
\\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\
\\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\
\\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\
\\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\
\\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\
\\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\
\\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\
\\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\
\\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\
\\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\
\\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\
\\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\
\\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\
\\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000"
),
 (284,256, 
"\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\
\\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\
\\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\
\\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\
\\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\170\
\\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\
\\000\170\000\170\000\170\000\170\000\170\000\170\000\170\000\170\
\\000\170\000\170\000\000\000\000\000\000\000\000\000\000\000\000\
\\000\000\000\170\000\170\000\170\000\170\000\170\000\170\000\170\
\\000\170\000\170\000\170\000\170\001\029\000\170\000\170\000\170\
\\000\170\000\170\000\170\000\170\000\170\000\170\000\170\000\170\
\\000\170\000\170\000\170\000\000\000\000\000\000\000\000\000\170\
\\000\000\000\170\000\170\000\170\000\170\000\170\000\170\000\170\
\\000\170\000\170\000\170\000\170\000\170\000\170\000\170\000\170\
\\000\170\000\170\000\170\000\170\000\170\000\170\000\170\000\170\
\\000\170\000\170\000\170\000\000\000\000\000\000\000\000\000\000\
\\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\
\\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\
\\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\
\\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\
\\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\
\\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\
\\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\
\\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\
\\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\
\\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\
\\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\
\\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\
\\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\
\\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\
\\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\
\\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000"
),
 (286,256, 
"\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\
\\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\
\\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\
\\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\
\\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\170\
\\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\
\\000\170\000\170\000\170\000\170\000\170\000\170\000\170\000\170\
\\000\170\000\170\000\000\000\000\000\000\000\000\000\000\000\000\
\\000\000\000\170\000\170\000\170\000\170\000\170\000\170\000\170\
\\000\170\000\170\000\170\000\170\000\170\000\170\000\170\000\170\
\\000\170\000\170\000\170\000\170\001\031\000\170\000\170\000\170\
\\000\170\000\170\000\170\000\000\000\000\000\000\000\000\000\170\
\\000\000\000\170\000\170\000\170\000\170\000\170\000\170\000\170\
\\000\170\000\170\000\170\000\170\000\170\000\170\000\170\000\170\
\\000\170\000\170\000\170\000\170\000\170\000\170\000\170\000\170\
\\000\170\000\170\000\170\000\000\000\000\000\000\000\000\000\000\
\\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\
\\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\
\\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\
\\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\
\\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\
\\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\
\\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\
\\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\
\\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\
\\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\
\\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\
\\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\
\\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\
\\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\
\\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\
\\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000"
),
 (288,256, 
"\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\
\\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\
\\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\
\\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\
\\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\170\
\\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\
\\000\170\000\170\000\170\000\170\000\170\000\170\000\170\000\170\
\\000\170\000\170\000\000\000\000\000\000\000\000\000\000\000\000\
\\000\000\001\035\000\170\000\170\000\170\000\170\000\170\000\170\
\\000\170\001\033\000\170\000\170\000\170\000\170\000\170\000\170\
\\000\170\000\170\000\170\000\170\000\170\000\170\000\170\000\170\
\\000\170\000\170\000\170\000\000\000\000\000\000\000\000\000\170\
\\000\000\000\170\000\170\000\170\000\170\000\170\000\170\000\170\
\\000\170\000\170\000\170\000\170\000\170\000\170\000\170\000\170\
\\000\170\000\170\000\170\000\170\000\170\000\170\000\170\000\170\
\\000\170\000\170\000\170\000\000\000\000\000\000\000\000\000\000\
\\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\
\\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\
\\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\
\\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\
\\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\
\\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\
\\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\
\\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\
\\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\
\\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\
\\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\
\\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\
\\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\
\\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\
\\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\
\\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000"
),
 (289,256, 
"\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\
\\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\
\\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\
\\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\
\\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\170\
\\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\
\\000\170\000\170\000\170\000\170\000\170\000\170\000\170\000\170\
\\000\170\000\170\000\000\000\000\000\000\000\000\000\000\000\000\
\\000\000\000\170\000\170\000\170\000\170\000\170\000\170\000\170\
\\000\170\000\170\000\170\000\170\000\170\000\170\001\034\000\170\
\\000\170\000\170\000\170\000\170\000\170\000\170\000\170\000\170\
\\000\170\000\170\000\170\000\000\000\000\000\000\000\000\000\170\
\\000\000\000\170\000\170\000\170\000\170\000\170\000\170\000\170\
\\000\170\000\170\000\170\000\170\000\170\000\170\000\170\000\170\
\\000\170\000\170\000\170\000\170\000\170\000\170\000\170\000\170\
\\000\170\000\170\000\170\000\000\000\000\000\000\000\000\000\000\
\\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\
\\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\
\\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\
\\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\
\\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\
\\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\
\\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\
\\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\
\\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\
\\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\
\\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\
\\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\
\\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\
\\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\
\\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\
\\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000"
),
 (291,256, 
"\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\
\\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\
\\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\
\\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\
\\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\170\
\\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\
\\000\170\000\170\000\170\000\170\000\170\000\170\000\170\000\170\
\\000\170\000\170\000\000\000\000\000\000\000\000\000\000\000\000\
\\000\000\000\170\000\170\000\170\000\170\000\170\000\170\000\170\
\\000\170\000\170\000\170\000\170\000\170\000\170\000\170\000\170\
\\000\170\000\170\000\170\000\170\000\170\000\170\000\170\000\170\
\\001\036\000\170\000\170\000\000\000\000\000\000\000\000\000\170\
\\000\000\000\170\000\170\000\170\000\170\000\170\000\170\000\170\
\\000\170\000\170\000\170\000\170\000\170\000\170\000\170\000\170\
\\000\170\000\170\000\170\000\170\000\170\000\170\000\170\000\170\
\\000\170\000\170\000\170\000\000\000\000\000\000\000\000\000\000\
\\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\
\\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\
\\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\
\\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\
\\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\
\\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\
\\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\
\\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\
\\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\
\\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\
\\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\
\\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\
\\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\
\\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\
\\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\
\\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000"
),
 (293,256, 
"\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\
\\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\
\\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\
\\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\
\\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\170\
\\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\
\\000\170\000\170\000\170\000\170\000\170\000\170\000\170\000\170\
\\000\170\000\170\000\000\000\000\000\000\000\000\000\000\000\000\
\\000\000\000\170\000\170\000\170\000\170\001\044\000\170\000\170\
\\000\170\001\038\000\170\000\170\000\170\000\170\000\170\000\170\
\\000\170\000\170\000\170\000\170\000\170\000\170\000\170\000\170\
\\000\170\000\170\000\170\000\000\000\000\000\000\000\000\000\170\
\\000\000\000\170\000\170\000\170\000\170\000\170\000\170\000\170\
\\000\170\000\170\000\170\000\170\000\170\000\170\000\170\000\170\
\\000\170\000\170\000\170\000\170\000\170\000\170\000\170\000\170\
\\000\170\000\170\000\170\000\000\000\000\000\000\000\000\000\000\
\\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\
\\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\
\\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\
\\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\
\\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\
\\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\
\\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\
\\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\
\\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\
\\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\
\\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\
\\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\
\\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\
\\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\
\\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\
\\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000"
),
 (294,256, 
"\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\
\\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\
\\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\
\\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\
\\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\170\
\\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\
\\000\170\000\170\000\170\000\170\000\170\000\170\000\170\000\170\
\\000\170\000\170\000\000\000\000\000\000\000\000\000\000\000\000\
\\000\000\000\170\000\170\000\170\000\170\000\170\000\170\000\170\
\\000\170\000\170\000\170\001\042\000\170\001\039\000\170\000\170\
\\000\170\000\170\000\170\000\170\000\170\000\170\000\170\000\170\
\\000\170\000\170\000\170\000\000\000\000\000\000\000\000\000\170\
\\000\000\000\170\000\170\000\170\000\170\000\170\000\170\000\170\
\\000\170\000\170\000\170\000\170\000\170\000\170\000\170\000\170\
\\000\170\000\170\000\170\000\170\000\170\000\170\000\170\000\170\
\\000\170\000\170\000\170\000\000\000\000\000\000\000\000\000\000\
\\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\
\\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\
\\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\
\\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\
\\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\
\\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\
\\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\
\\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\
\\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\
\\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\
\\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\
\\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\
\\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\
\\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\
\\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\
\\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000"
),
 (295,256, 
"\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\
\\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\
\\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\
\\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\
\\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\170\
\\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\
\\000\170\000\170\000\170\000\170\000\170\000\170\000\170\000\170\
\\000\170\000\170\000\000\000\000\000\000\000\000\000\000\000\000\
\\000\000\000\170\000\170\000\170\000\170\000\170\000\170\000\170\
\\000\170\001\040\000\170\000\170\000\170\000\170\000\170\000\170\
\\000\170\000\170\000\170\000\170\000\170\000\170\000\170\000\170\
\\000\170\000\170\000\170\000\000\000\000\000\000\000\000\000\170\
\\000\000\000\170\000\170\000\170\000\170\000\170\000\170\000\170\
\\000\170\000\170\000\170\000\170\000\170\000\170\000\170\000\170\
\\000\170\000\170\000\170\000\170\000\170\000\170\000\170\000\170\
\\000\170\000\170\000\170\000\000\000\000\000\000\000\000\000\000\
\\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\
\\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\
\\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\
\\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\
\\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\
\\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\
\\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\
\\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\
\\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\
\\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\
\\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\
\\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\
\\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\
\\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\
\\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\
\\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000"
),
 (296,256, 
"\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\
\\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\
\\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\
\\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\
\\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\170\
\\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\
\\000\170\000\170\000\170\000\170\000\170\000\170\000\170\000\170\
\\000\170\000\170\000\000\000\000\000\000\000\000\000\000\000\000\
\\000\000\000\170\000\170\000\170\000\170\000\170\000\170\000\170\
\\000\170\000\170\000\170\000\170\000\170\000\170\000\170\000\170\
\\000\170\000\170\000\170\000\170\001\041\000\170\000\170\000\170\
\\000\170\000\170\000\170\000\000\000\000\000\000\000\000\000\170\
\\000\000\000\170\000\170\000\170\000\170\000\170\000\170\000\170\
\\000\170\000\170\000\170\000\170\000\170\000\170\000\170\000\170\
\\000\170\000\170\000\170\000\170\000\170\000\170\000\170\000\170\
\\000\170\000\170\000\170\000\000\000\000\000\000\000\000\000\000\
\\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\
\\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\
\\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\
\\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\
\\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\
\\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\
\\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\
\\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\
\\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\
\\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\
\\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\
\\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\
\\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\
\\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\
\\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\
\\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000"
),
 (298,256, 
"\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\
\\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\
\\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\
\\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\
\\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\170\
\\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\
\\000\170\000\170\000\170\000\170\000\170\000\170\000\170\000\170\
\\000\170\000\170\000\000\000\000\000\000\000\000\000\000\000\000\
\\000\000\000\170\000\170\000\170\000\170\001\043\000\170\000\170\
\\000\170\000\170\000\170\000\170\000\170\000\170\000\170\000\170\
\\000\170\000\170\000\170\000\170\000\170\000\170\000\170\000\170\
\\000\170\000\170\000\170\000\000\000\000\000\000\000\000\000\170\
\\000\000\000\170\000\170\000\170\000\170\000\170\000\170\000\170\
\\000\170\000\170\000\170\000\170\000\170\000\170\000\170\000\170\
\\000\170\000\170\000\170\000\170\000\170\000\170\000\170\000\170\
\\000\170\000\170\000\170\000\000\000\000\000\000\000\000\000\000\
\\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\
\\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\
\\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\
\\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\
\\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\
\\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\
\\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\
\\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\
\\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\
\\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\
\\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\
\\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\
\\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\
\\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\
\\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\
\\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000"
),
 (300,256, 
"\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\
\\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\
\\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\
\\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\
\\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\170\
\\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\
\\000\170\000\170\000\170\000\170\000\170\000\170\000\170\000\170\
\\000\170\000\170\000\000\000\000\000\000\000\000\000\000\000\000\
\\000\000\000\170\000\170\000\170\000\170\000\170\001\045\000\170\
\\000\170\000\170\000\170\000\170\000\170\000\170\000\170\000\170\
\\000\170\000\170\000\170\000\170\000\170\000\170\000\170\000\170\
\\000\170\000\170\000\170\000\000\000\000\000\000\000\000\000\170\
\\000\000\000\170\000\170\000\170\000\170\000\170\000\170\000\170\
\\000\170\000\170\000\170\000\170\000\170\000\170\000\170\000\170\
\\000\170\000\170\000\170\000\170\000\170\000\170\000\170\000\170\
\\000\170\000\170\000\170\000\000\000\000\000\000\000\000\000\000\
\\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\
\\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\
\\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\
\\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\
\\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\
\\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\
\\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\
\\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\
\\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\
\\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\
\\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\
\\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\
\\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\
\\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\
\\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\
\\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000"
),
 (301,256, 
"\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\
\\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\
\\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\
\\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\
\\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\170\
\\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\
\\000\170\000\170\000\170\000\170\000\170\000\170\000\170\000\170\
\\000\170\000\170\000\000\000\000\000\000\000\000\000\000\000\000\
\\000\000\000\170\000\170\000\170\000\170\000\170\000\170\000\170\
\\000\170\000\170\000\170\000\170\000\170\000\170\000\170\000\170\
\\000\170\000\170\000\170\000\170\001\046\000\170\000\170\000\170\
\\000\170\000\170\000\170\000\000\000\000\000\000\000\000\000\170\
\\000\000\000\170\000\170\000\170\000\170\000\170\000\170\000\170\
\\000\170\000\170\000\170\000\170\000\170\000\170\000\170\000\170\
\\000\170\000\170\000\170\000\170\000\170\000\170\000\170\000\170\
\\000\170\000\170\000\170\000\000\000\000\000\000\000\000\000\000\
\\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\
\\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\
\\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\
\\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\
\\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\
\\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\
\\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\
\\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\
\\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\
\\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\
\\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\
\\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\
\\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\
\\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\
\\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\
\\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000"
),
 (303,256, 
"\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\
\\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\
\\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\
\\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\
\\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\170\
\\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\
\\000\170\000\170\000\170\000\170\000\170\000\170\000\170\000\170\
\\000\170\000\170\000\000\000\000\000\000\000\000\000\000\000\000\
\\000\000\000\170\000\170\000\170\000\170\001\048\000\170\000\170\
\\000\170\000\170\000\170\000\170\000\170\000\170\000\170\000\170\
\\000\170\000\170\000\170\000\170\000\170\000\170\000\170\000\170\
\\000\170\000\170\000\170\000\000\000\000\000\000\000\000\000\170\
\\000\000\000\170\000\170\000\170\000\170\000\170\000\170\000\170\
\\000\170\000\170\000\170\000\170\000\170\000\170\000\170\000\170\
\\000\170\000\170\000\170\000\170\000\170\000\170\000\170\000\170\
\\000\170\000\170\000\170\000\000\000\000\000\000\000\000\000\000\
\\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\
\\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\
\\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\
\\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\
\\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\
\\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\
\\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\
\\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\
\\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\
\\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\
\\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\
\\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\
\\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\
\\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\
\\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\
\\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000"
),
 (304,256, 
"\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\
\\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\
\\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\
\\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\
\\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\170\
\\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\
\\000\170\000\170\000\170\000\170\000\170\000\170\000\170\000\170\
\\000\170\000\170\000\000\000\000\000\000\000\000\000\000\000\000\
\\000\000\000\170\000\170\000\170\000\170\000\170\000\170\000\170\
\\000\170\000\170\000\170\000\170\000\170\000\170\000\170\000\170\
\\000\170\000\170\000\170\000\170\000\170\000\170\000\170\000\170\
\\000\170\001\049\000\170\000\000\000\000\000\000\000\000\000\170\
\\000\000\000\170\000\170\000\170\000\170\000\170\000\170\000\170\
\\000\170\000\170\000\170\000\170\000\170\000\170\000\170\000\170\
\\000\170\000\170\000\170\000\170\000\170\000\170\000\170\000\170\
\\000\170\000\170\000\170\000\000\000\000\000\000\000\000\000\000\
\\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\
\\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\
\\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\
\\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\
\\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\
\\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\
\\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\
\\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\
\\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\
\\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\
\\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\
\\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\
\\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\
\\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\
\\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\
\\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000"
),
 (306,256, 
"\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\
\\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\
\\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\
\\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\
\\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\170\
\\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\
\\000\170\000\170\000\170\000\170\000\170\000\170\000\170\000\170\
\\000\170\000\170\000\000\000\000\000\000\000\000\000\000\000\000\
\\000\000\000\170\000\170\000\170\000\170\000\170\000\170\000\170\
\\000\170\000\170\000\170\000\170\000\170\000\170\000\170\001\051\
\\000\170\000\170\000\170\000\170\000\170\000\170\000\170\000\170\
\\000\170\000\170\000\170\000\000\000\000\000\000\000\000\000\170\
\\000\000\000\170\000\170\000\170\000\170\000\170\000\170\000\170\
\\000\170\000\170\000\170\000\170\000\170\000\170\000\170\000\170\
\\000\170\000\170\000\170\000\170\000\170\000\170\000\170\000\170\
\\000\170\000\170\000\170\000\000\000\000\000\000\000\000\000\000\
\\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\
\\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\
\\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\
\\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\
\\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\
\\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\
\\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\
\\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\
\\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\
\\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\
\\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\
\\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\
\\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\
\\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\
\\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\
\\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000"
),
 (307,256, 
"\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\
\\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\
\\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\
\\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\
\\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\170\
\\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\
\\000\170\000\170\000\170\000\170\000\170\000\170\000\170\000\170\
\\000\170\000\170\000\000\000\000\000\000\000\000\000\000\000\000\
\\000\000\000\170\000\170\000\170\000\170\000\170\000\170\000\170\
\\000\170\001\052\000\170\000\170\000\170\000\170\000\170\000\170\
\\000\170\000\170\000\170\000\170\000\170\000\170\000\170\000\170\
\\000\170\000\170\000\170\000\000\000\000\000\000\000\000\000\170\
\\000\000\000\170\000\170\000\170\000\170\000\170\000\170\000\170\
\\000\170\000\170\000\170\000\170\000\170\000\170\000\170\000\170\
\\000\170\000\170\000\170\000\170\000\170\000\170\000\170\000\170\
\\000\170\000\170\000\170\000\000\000\000\000\000\000\000\000\000\
\\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\
\\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\
\\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\
\\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\
\\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\
\\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\
\\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\
\\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\
\\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\
\\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\
\\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\
\\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\
\\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\
\\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\
\\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\
\\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000"
),
 (308,256, 
"\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\
\\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\
\\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\
\\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\
\\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\170\
\\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\
\\000\170\000\170\000\170\000\170\000\170\000\170\000\170\000\170\
\\000\170\000\170\000\000\000\000\000\000\000\000\000\000\000\000\
\\000\000\000\170\000\170\000\170\000\170\000\170\000\170\000\170\
\\000\170\000\170\000\170\000\170\000\170\000\170\001\053\000\170\
\\000\170\000\170\000\170\000\170\000\170\000\170\000\170\000\170\
\\000\170\000\170\000\170\000\000\000\000\000\000\000\000\000\170\
\\000\000\000\170\000\170\000\170\000\170\000\170\000\170\000\170\
\\000\170\000\170\000\170\000\170\000\170\000\170\000\170\000\170\
\\000\170\000\170\000\170\000\170\000\170\000\170\000\170\000\170\
\\000\170\000\170\000\170\000\000\000\000\000\000\000\000\000\000\
\\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\
\\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\
\\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\
\\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\
\\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\
\\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\
\\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\
\\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\
\\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\
\\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\
\\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\
\\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\
\\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\
\\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\
\\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\
\\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000"
),
 (310,256, 
"\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\
\\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\
\\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\
\\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\
\\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\170\
\\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\
\\000\170\000\170\000\170\000\170\000\170\000\170\000\170\000\170\
\\000\170\000\170\000\000\000\000\000\000\000\000\000\000\000\000\
\\000\000\000\170\000\170\000\170\000\170\000\170\001\072\000\170\
\\000\170\000\170\000\170\000\170\000\170\000\170\001\056\000\170\
\\000\170\000\170\000\170\001\055\000\170\000\170\000\170\000\170\
\\000\170\000\170\000\170\000\000\000\000\000\000\000\000\000\170\
\\000\000\000\170\000\170\000\170\000\170\000\170\000\170\000\170\
\\000\170\000\170\000\170\000\170\000\170\000\170\000\170\000\170\
\\000\170\000\170\000\170\000\170\000\170\000\170\000\170\000\170\
\\000\170\000\170\000\170\000\000\000\000\000\000\000\000\000\000\
\\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\
\\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\
\\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\
\\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\
\\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\
\\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\
\\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\
\\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\
\\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\
\\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\
\\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\
\\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\
\\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\
\\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\
\\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\
\\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000"
),
 (312,256, 
"\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\
\\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\
\\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\
\\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\
\\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\170\
\\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\
\\000\170\000\170\000\170\000\170\000\170\000\170\000\170\000\170\
\\000\170\000\170\000\000\000\000\000\000\000\000\000\000\000\000\
\\000\000\000\170\000\170\000\170\000\170\000\170\000\170\000\170\
\\000\170\000\170\000\170\000\170\000\170\000\170\001\069\000\170\
\\000\170\000\170\000\170\001\065\001\057\000\170\000\170\000\170\
\\000\170\000\170\000\170\000\000\000\000\000\000\000\000\000\170\
\\000\000\000\170\000\170\000\170\000\170\000\170\000\170\000\170\
\\000\170\000\170\000\170\000\170\000\170\000\170\000\170\000\170\
\\000\170\000\170\000\170\000\170\000\170\000\170\000\170\000\170\
\\000\170\000\170\000\170\000\000\000\000\000\000\000\000\000\000\
\\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\
\\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\
\\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\
\\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\
\\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\
\\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\
\\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\
\\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\
\\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\
\\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\
\\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\
\\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\
\\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\
\\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\
\\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\
\\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000"
),
 (313,256, 
"\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\
\\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\
\\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\
\\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\
\\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\170\
\\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\
\\000\170\000\170\000\170\000\170\000\170\000\170\000\170\000\170\
\\000\170\000\170\000\000\000\000\000\000\000\000\000\000\000\000\
\\000\000\000\170\000\170\000\170\000\170\001\059\000\170\000\170\
\\000\170\000\170\000\170\000\170\000\170\000\170\000\170\001\058\
\\000\170\000\170\000\170\000\170\000\170\000\170\000\170\000\170\
\\000\170\000\170\000\170\000\000\000\000\000\000\000\000\000\170\
\\000\000\000\170\000\170\000\170\000\170\000\170\000\170\000\170\
\\000\170\000\170\000\170\000\170\000\170\000\170\000\170\000\170\
\\000\170\000\170\000\170\000\170\000\170\000\170\000\170\000\170\
\\000\170\000\170\000\170\000\000\000\000\000\000\000\000\000\000\
\\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\
\\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\
\\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\
\\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\
\\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\
\\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\
\\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\
\\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\
\\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\
\\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\
\\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\
\\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\
\\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\
\\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\
\\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\
\\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000"
),
 (315,256, 
"\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\
\\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\
\\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\
\\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\
\\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\170\
\\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\
\\000\170\000\170\000\170\000\170\000\170\000\170\000\170\000\170\
\\000\170\000\170\000\000\000\000\000\000\000\000\000\000\000\000\
\\000\000\000\170\000\170\000\170\000\170\000\170\000\170\000\170\
\\000\170\000\170\000\170\000\170\000\170\000\170\000\170\000\170\
\\000\170\000\170\001\060\000\170\000\170\000\170\000\170\000\170\
\\000\170\000\170\000\170\000\000\000\000\000\000\000\000\000\170\
\\000\000\000\170\000\170\000\170\000\170\000\170\000\170\000\170\
\\000\170\000\170\000\170\000\170\000\170\000\170\000\170\000\170\
\\000\170\000\170\000\170\000\170\000\170\000\170\000\170\000\170\
\\000\170\000\170\000\170\000\000\000\000\000\000\000\000\000\000\
\\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\
\\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\
\\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\
\\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\
\\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\
\\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\
\\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\
\\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\
\\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\
\\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\
\\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\
\\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\
\\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\
\\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\
\\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\
\\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000"
),
 (316,256, 
"\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\
\\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\
\\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\
\\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\
\\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\170\
\\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\
\\000\170\000\170\000\170\000\170\000\170\000\170\000\170\000\170\
\\000\170\000\170\000\000\000\000\000\000\000\000\000\000\000\000\
\\000\000\000\170\000\170\000\170\000\170\000\170\000\170\000\170\
\\000\170\000\170\000\170\000\170\000\170\000\170\000\170\000\170\
\\000\170\000\170\000\170\001\061\000\170\000\170\000\170\000\170\
\\000\170\000\170\000\170\000\000\000\000\000\000\000\000\000\170\
\\000\000\000\170\000\170\000\170\000\170\000\170\000\170\000\170\
\\000\170\000\170\000\170\000\170\000\170\000\170\000\170\000\170\
\\000\170\000\170\000\170\000\170\000\170\000\170\000\170\000\170\
\\000\170\000\170\000\170\000\000\000\000\000\000\000\000\000\000\
\\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\
\\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\
\\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\
\\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\
\\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\
\\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\
\\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\
\\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\
\\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\
\\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\
\\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\
\\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\
\\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\
\\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\
\\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\
\\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000"
),
 (317,256, 
"\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\
\\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\
\\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\
\\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\
\\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\170\
\\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\
\\000\170\000\170\000\170\000\170\000\170\000\170\000\170\000\170\
\\000\170\000\170\000\000\000\000\000\000\000\000\000\000\000\000\
\\000\000\000\170\000\170\000\170\000\170\001\062\000\170\000\170\
\\000\170\000\170\000\170\000\170\000\170\000\170\000\170\000\170\
\\000\170\000\170\000\170\000\170\000\170\000\170\000\170\000\170\
\\000\170\000\170\000\170\000\000\000\000\000\000\000\000\000\170\
\\000\000\000\170\000\170\000\170\000\170\000\170\000\170\000\170\
\\000\170\000\170\000\170\000\170\000\170\000\170\000\170\000\170\
\\000\170\000\170\000\170\000\170\000\170\000\170\000\170\000\170\
\\000\170\000\170\000\170\000\000\000\000\000\000\000\000\000\000\
\\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\
\\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\
\\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\
\\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\
\\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\
\\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\
\\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\
\\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\
\\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\
\\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\
\\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\
\\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\
\\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\
\\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\
\\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\
\\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000"
),
 (318,256, 
"\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\
\\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\
\\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\
\\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\
\\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\170\
\\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\
\\000\170\000\170\000\170\000\170\000\170\000\170\000\170\000\170\
\\000\170\000\170\000\000\000\000\000\000\000\000\000\000\000\000\
\\000\000\000\170\000\170\001\063\000\170\000\170\000\170\000\170\
\\000\170\000\170\000\170\000\170\000\170\000\170\000\170\000\170\
\\000\170\000\170\000\170\000\170\000\170\000\170\000\170\000\170\
\\000\170\000\170\000\170\000\000\000\000\000\000\000\000\000\170\
\\000\000\000\170\000\170\000\170\000\170\000\170\000\170\000\170\
\\000\170\000\170\000\170\000\170\000\170\000\170\000\170\000\170\
\\000\170\000\170\000\170\000\170\000\170\000\170\000\170\000\170\
\\000\170\000\170\000\170\000\000\000\000\000\000\000\000\000\000\
\\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\
\\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\
\\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\
\\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\
\\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\
\\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\
\\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\
\\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\
\\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\
\\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\
\\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\
\\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\
\\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\
\\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\
\\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\
\\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000"
),
 (319,256, 
"\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\
\\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\
\\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\
\\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\
\\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\170\
\\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\
\\000\170\000\170\000\170\000\170\000\170\000\170\000\170\000\170\
\\000\170\000\170\000\000\000\000\000\000\000\000\000\000\000\000\
\\000\000\000\170\000\170\000\170\000\170\000\170\000\170\000\170\
\\000\170\000\170\000\170\000\170\000\170\000\170\000\170\000\170\
\\000\170\000\170\000\170\000\170\001\064\000\170\000\170\000\170\
\\000\170\000\170\000\170\000\000\000\000\000\000\000\000\000\170\
\\000\000\000\170\000\170\000\170\000\170\000\170\000\170\000\170\
\\000\170\000\170\000\170\000\170\000\170\000\170\000\170\000\170\
\\000\170\000\170\000\170\000\170\000\170\000\170\000\170\000\170\
\\000\170\000\170\000\170\000\000\000\000\000\000\000\000\000\000\
\\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\
\\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\
\\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\
\\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\
\\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\
\\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\
\\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\
\\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\
\\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\
\\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\
\\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\
\\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\
\\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\
\\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\
\\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\
\\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000"
),
 (321,256, 
"\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\
\\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\
\\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\
\\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\
\\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\170\
\\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\
\\000\170\000\170\000\170\000\170\000\170\000\170\000\170\000\170\
\\000\170\000\170\000\000\000\000\000\000\000\000\000\000\000\000\
\\000\000\000\170\000\170\000\170\000\170\001\066\000\170\000\170\
\\000\170\000\170\000\170\000\170\000\170\000\170\000\170\000\170\
\\000\170\000\170\000\170\000\170\000\170\000\170\000\170\000\170\
\\000\170\000\170\000\170\000\000\000\000\000\000\000\000\000\170\
\\000\000\000\170\000\170\000\170\000\170\000\170\000\170\000\170\
\\000\170\000\170\000\170\000\170\000\170\000\170\000\170\000\170\
\\000\170\000\170\000\170\000\170\000\170\000\170\000\170\000\170\
\\000\170\000\170\000\170\000\000\000\000\000\000\000\000\000\000\
\\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\
\\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\
\\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\
\\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\
\\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\
\\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\
\\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\
\\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\
\\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\
\\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\
\\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\
\\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\
\\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\
\\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\
\\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\
\\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000"
),
 (322,256, 
"\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\
\\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\
\\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\
\\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\
\\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\170\
\\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\
\\000\170\000\170\000\170\000\170\000\170\000\170\000\170\000\170\
\\000\170\000\170\000\000\000\000\000\000\000\000\000\000\000\000\
\\000\000\000\170\000\170\000\170\000\170\000\170\000\170\000\170\
\\000\170\000\170\000\170\000\170\000\170\000\170\000\170\000\170\
\\000\170\000\170\001\067\000\170\000\170\000\170\000\170\000\170\
\\000\170\000\170\000\170\000\000\000\000\000\000\000\000\000\170\
\\000\000\000\170\000\170\000\170\000\170\000\170\000\170\000\170\
\\000\170\000\170\000\170\000\170\000\170\000\170\000\170\000\170\
\\000\170\000\170\000\170\000\170\000\170\000\170\000\170\000\170\
\\000\170\000\170\000\170\000\000\000\000\000\000\000\000\000\000\
\\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\
\\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\
\\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\
\\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\
\\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\
\\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\
\\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\
\\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\
\\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\
\\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\
\\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\
\\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\
\\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\
\\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\
\\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\
\\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000"
),
 (323,256, 
"\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\
\\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\
\\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\
\\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\
\\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\170\
\\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\
\\000\170\000\170\000\170\000\170\000\170\000\170\000\170\000\170\
\\000\170\000\170\000\000\000\000\000\000\000\000\000\000\000\000\
\\000\000\000\170\000\170\000\170\000\170\000\170\000\170\000\170\
\\000\170\000\170\000\170\000\170\000\170\000\170\000\170\000\170\
\\000\170\000\170\000\170\000\170\001\068\000\170\000\170\000\170\
\\000\170\000\170\000\170\000\000\000\000\000\000\000\000\000\170\
\\000\000\000\170\000\170\000\170\000\170\000\170\000\170\000\170\
\\000\170\000\170\000\170\000\170\000\170\000\170\000\170\000\170\
\\000\170\000\170\000\170\000\170\000\170\000\170\000\170\000\170\
\\000\170\000\170\000\170\000\000\000\000\000\000\000\000\000\000\
\\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\
\\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\
\\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\
\\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\
\\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\
\\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\
\\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\
\\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\
\\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\
\\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\
\\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\
\\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\
\\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\
\\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\
\\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\
\\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000"
),
 (325,256, 
"\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\
\\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\
\\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\
\\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\
\\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\170\
\\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\
\\000\170\000\170\000\170\000\170\000\170\000\170\000\170\000\170\
\\000\170\000\170\000\000\000\000\000\000\000\000\000\000\000\000\
\\000\000\000\170\000\170\000\170\000\170\001\070\000\170\000\170\
\\000\170\000\170\000\170\000\170\000\170\000\170\000\170\000\170\
\\000\170\000\170\000\170\000\170\000\170\000\170\000\170\000\170\
\\000\170\000\170\000\170\000\000\000\000\000\000\000\000\000\170\
\\000\000\000\170\000\170\000\170\000\170\000\170\000\170\000\170\
\\000\170\000\170\000\170\000\170\000\170\000\170\000\170\000\170\
\\000\170\000\170\000\170\000\170\000\170\000\170\000\170\000\170\
\\000\170\000\170\000\170\000\000\000\000\000\000\000\000\000\000\
\\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\
\\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\
\\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\
\\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\
\\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\
\\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\
\\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\
\\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\
\\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\
\\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\
\\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\
\\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\
\\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\
\\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\
\\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\
\\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000"
),
 (326,256, 
"\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\
\\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\
\\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\
\\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\
\\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\170\
\\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\
\\000\170\000\170\000\170\000\170\000\170\000\170\000\170\000\170\
\\000\170\000\170\000\000\000\000\000\000\000\000\000\000\000\000\
\\000\000\000\170\000\170\000\170\000\170\000\170\000\170\000\170\
\\000\170\000\170\000\170\000\170\000\170\000\170\000\170\000\170\
\\000\170\000\170\001\071\000\170\000\170\000\170\000\170\000\170\
\\000\170\000\170\000\170\000\000\000\000\000\000\000\000\000\170\
\\000\000\000\170\000\170\000\170\000\170\000\170\000\170\000\170\
\\000\170\000\170\000\170\000\170\000\170\000\170\000\170\000\170\
\\000\170\000\170\000\170\000\170\000\170\000\170\000\170\000\170\
\\000\170\000\170\000\170\000\000\000\000\000\000\000\000\000\000\
\\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\
\\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\
\\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\
\\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\
\\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\
\\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\
\\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\
\\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\
\\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\
\\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\
\\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\
\\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\
\\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\
\\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\
\\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\
\\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000"
),
 (329,256, 
"\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\
\\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\
\\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\
\\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\
\\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\170\
\\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\
\\000\170\000\170\000\170\000\170\000\170\000\170\000\170\000\170\
\\000\170\000\170\000\000\000\000\000\000\000\000\000\000\000\000\
\\000\000\001\074\000\170\000\170\000\170\000\170\000\170\000\170\
\\000\170\000\170\000\170\000\170\000\170\000\170\000\170\000\170\
\\000\170\000\170\000\170\000\170\000\170\000\170\000\170\000\170\
\\000\170\000\170\000\170\000\000\000\000\000\000\000\000\000\170\
\\000\000\000\170\000\170\000\170\000\170\000\170\000\170\000\170\
\\000\170\000\170\000\170\000\170\000\170\000\170\000\170\000\170\
\\000\170\000\170\000\170\000\170\000\170\000\170\000\170\000\170\
\\000\170\000\170\000\170\000\000\000\000\000\000\000\000\000\000\
\\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\
\\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\
\\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\
\\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\
\\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\
\\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\
\\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\
\\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\
\\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\
\\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\
\\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\
\\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\
\\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\
\\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\
\\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\
\\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000"
),
 (330,256, 
"\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\
\\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\
\\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\
\\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\
\\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\170\
\\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\
\\000\170\000\170\000\170\000\170\000\170\000\170\000\170\000\170\
\\000\170\000\170\000\000\000\000\000\000\000\000\000\000\000\000\
\\000\000\000\170\000\170\000\170\000\170\000\170\000\170\000\170\
\\000\170\000\170\000\170\000\170\000\170\000\170\000\170\000\170\
\\000\170\000\170\000\170\000\170\000\170\000\170\001\075\000\170\
\\000\170\000\170\000\170\000\000\000\000\000\000\000\000\000\170\
\\000\000\000\170\000\170\000\170\000\170\000\170\000\170\000\170\
\\000\170\000\170\000\170\000\170\000\170\000\170\000\170\000\170\
\\000\170\000\170\000\170\000\170\000\170\000\170\000\170\000\170\
\\000\170\000\170\000\170\000\000\000\000\000\000\000\000\000\000\
\\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\
\\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\
\\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\
\\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\
\\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\
\\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\
\\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\
\\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\
\\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\
\\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\
\\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\
\\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\
\\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\
\\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\
\\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\
\\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000"
),
 (331,256, 
"\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\
\\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\
\\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\
\\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\
\\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\170\
\\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\
\\000\170\000\170\000\170\000\170\000\170\000\170\000\170\000\170\
\\000\170\000\170\000\000\000\000\000\000\000\000\000\000\000\000\
\\000\000\000\170\000\170\000\170\000\170\000\170\000\170\000\170\
\\000\170\001\076\000\170\000\170\000\170\000\170\000\170\000\170\
\\000\170\000\170\000\170\000\170\000\170\000\170\000\170\000\170\
\\000\170\000\170\000\170\000\000\000\000\000\000\000\000\000\170\
\\000\000\000\170\000\170\000\170\000\170\000\170\000\170\000\170\
\\000\170\000\170\000\170\000\170\000\170\000\170\000\170\000\170\
\\000\170\000\170\000\170\000\170\000\170\000\170\000\170\000\170\
\\000\170\000\170\000\170\000\000\000\000\000\000\000\000\000\000\
\\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\
\\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\
\\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\
\\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\
\\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\
\\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\
\\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\
\\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\
\\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\
\\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\
\\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\
\\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\
\\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\
\\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\
\\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\
\\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000"
),
 (332,256, 
"\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\
\\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\
\\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\
\\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\
\\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\170\
\\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\
\\000\170\000\170\000\170\000\170\000\170\000\170\000\170\000\170\
\\000\170\000\170\000\000\000\000\000\000\000\000\000\000\000\000\
\\000\000\000\170\000\170\000\170\000\170\000\170\000\170\000\170\
\\000\170\000\170\000\170\000\170\000\170\000\170\001\077\000\170\
\\000\170\000\170\000\170\000\170\000\170\000\170\000\170\000\170\
\\000\170\000\170\000\170\000\000\000\000\000\000\000\000\000\170\
\\000\000\000\170\000\170\000\170\000\170\000\170\000\170\000\170\
\\000\170\000\170\000\170\000\170\000\170\000\170\000\170\000\170\
\\000\170\000\170\000\170\000\170\000\170\000\170\000\170\000\170\
\\000\170\000\170\000\170\000\000\000\000\000\000\000\000\000\000\
\\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\
\\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\
\\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\
\\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\
\\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\
\\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\
\\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\
\\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\
\\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\
\\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\
\\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\
\\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\
\\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\
\\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\
\\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\
\\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000"
),
 (333,256, 
"\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\
\\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\
\\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\
\\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\
\\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\170\
\\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\
\\000\170\000\170\000\170\000\170\000\170\000\170\000\170\000\170\
\\000\170\000\170\000\000\000\000\000\000\000\000\000\000\000\000\
\\000\000\000\170\000\170\000\170\000\170\000\170\000\170\001\078\
\\000\170\000\170\000\170\000\170\000\170\000\170\000\170\000\170\
\\000\170\000\170\000\170\000\170\000\170\000\170\000\170\000\170\
\\000\170\000\170\000\170\000\000\000\000\000\000\000\000\000\170\
\\000\000\000\170\000\170\000\170\000\170\000\170\000\170\000\170\
\\000\170\000\170\000\170\000\170\000\170\000\170\000\170\000\170\
\\000\170\000\170\000\170\000\170\000\170\000\170\000\170\000\170\
\\000\170\000\170\000\170\000\000\000\000\000\000\000\000\000\000\
\\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\
\\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\
\\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\
\\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\
\\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\
\\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\
\\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\
\\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\
\\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\
\\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\
\\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\
\\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\
\\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\
\\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\
\\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\
\\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000"
),
 (335,256, 
"\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\
\\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\
\\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\
\\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\
\\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\170\
\\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\
\\000\170\000\170\000\170\000\170\000\170\000\170\000\170\000\170\
\\000\170\000\170\000\000\000\000\000\000\000\000\000\000\000\000\
\\000\000\000\170\000\170\000\170\000\170\000\170\000\170\000\170\
\\000\170\000\170\000\170\000\170\000\170\000\170\000\170\000\170\
\\000\170\000\170\001\080\000\170\000\170\000\170\000\170\000\170\
\\000\170\000\170\000\170\000\000\000\000\000\000\000\000\000\170\
\\000\000\000\170\000\170\000\170\000\170\000\170\000\170\000\170\
\\000\170\000\170\000\170\000\170\000\170\000\170\000\170\000\170\
\\000\170\000\170\000\170\000\170\000\170\000\170\000\170\000\170\
\\000\170\000\170\000\170\000\000\000\000\000\000\000\000\000\000\
\\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\
\\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\
\\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\
\\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\
\\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\
\\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\
\\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\
\\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\
\\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\
\\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\
\\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\
\\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\
\\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\
\\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\
\\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\
\\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000"
),
 (336,256, 
"\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\
\\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\
\\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\
\\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\
\\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\170\
\\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\
\\000\170\000\170\000\170\000\170\000\170\000\170\000\170\000\170\
\\000\170\000\170\000\000\000\000\000\000\000\000\000\000\000\000\
\\000\000\000\170\000\170\000\170\000\170\000\170\000\170\000\170\
\\000\170\000\170\000\170\000\170\000\170\000\170\000\170\001\081\
\\000\170\000\170\000\170\000\170\000\170\000\170\000\170\000\170\
\\000\170\000\170\000\170\000\000\000\000\000\000\000\000\000\170\
\\000\000\000\170\000\170\000\170\000\170\000\170\000\170\000\170\
\\000\170\000\170\000\170\000\170\000\170\000\170\000\170\000\170\
\\000\170\000\170\000\170\000\170\000\170\000\170\000\170\000\170\
\\000\170\000\170\000\170\000\000\000\000\000\000\000\000\000\000\
\\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\
\\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\
\\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\
\\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\
\\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\
\\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\
\\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\
\\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\
\\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\
\\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\
\\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\
\\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\
\\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\
\\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\
\\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\
\\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000"
),
 (337,256, 
"\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\
\\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\
\\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\
\\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\
\\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\170\
\\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\
\\000\170\000\170\000\170\000\170\000\170\000\170\000\170\000\170\
\\000\170\000\170\000\000\000\000\000\000\000\000\000\000\000\000\
\\000\000\000\170\000\170\000\170\000\170\000\170\000\170\000\170\
\\000\170\000\170\000\170\000\170\000\170\000\170\000\170\000\170\
\\000\170\000\170\000\170\000\170\000\170\001\082\000\170\000\170\
\\000\170\000\170\000\170\000\000\000\000\000\000\000\000\000\170\
\\000\000\000\170\000\170\000\170\000\170\000\170\000\170\000\170\
\\000\170\000\170\000\170\000\170\000\170\000\170\000\170\000\170\
\\000\170\000\170\000\170\000\170\000\170\000\170\000\170\000\170\
\\000\170\000\170\000\170\000\000\000\000\000\000\000\000\000\000\
\\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\
\\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\
\\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\
\\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\
\\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\
\\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\
\\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\
\\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\
\\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\
\\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\
\\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\
\\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\
\\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\
\\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\
\\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\
\\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000"
),
 (338,256, 
"\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\
\\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\
\\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\
\\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\
\\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\170\
\\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\
\\000\170\000\170\000\170\000\170\000\170\000\170\000\170\000\170\
\\000\170\000\170\000\000\000\000\000\000\000\000\000\000\000\000\
\\000\000\000\170\000\170\000\170\000\170\000\170\000\170\000\170\
\\000\170\000\170\000\170\000\170\000\170\000\170\000\170\000\170\
\\001\083\000\170\000\170\000\170\000\170\000\170\000\170\000\170\
\\000\170\000\170\000\170\000\000\000\000\000\000\000\000\000\170\
\\000\000\000\170\000\170\000\170\000\170\000\170\000\170\000\170\
\\000\170\000\170\000\170\000\170\000\170\000\170\000\170\000\170\
\\000\170\000\170\000\170\000\170\000\170\000\170\000\170\000\170\
\\000\170\000\170\000\170\000\000\000\000\000\000\000\000\000\000\
\\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\
\\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\
\\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\
\\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\
\\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\
\\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\
\\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\
\\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\
\\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\
\\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\
\\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\
\\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\
\\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\
\\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\
\\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\
\\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000"
),
 (340,256, 
"\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\
\\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\
\\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\
\\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\
\\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\170\
\\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\
\\000\170\000\170\000\170\000\170\000\170\000\170\000\170\000\170\
\\000\170\000\170\000\000\000\000\000\000\000\000\000\000\000\000\
\\000\000\001\097\000\170\000\170\000\170\000\170\000\170\000\170\
\\000\170\000\170\000\170\000\170\000\170\000\170\000\170\001\091\
\\000\170\000\170\001\088\000\170\000\170\001\085\000\170\000\170\
\\000\170\000\170\000\170\000\000\000\000\000\000\000\000\000\170\
\\000\000\000\170\000\170\000\170\000\170\000\170\000\170\000\170\
\\000\170\000\170\000\170\000\170\000\170\000\170\000\170\000\170\
\\000\170\000\170\000\170\000\170\000\170\000\170\000\170\000\170\
\\000\170\000\170\000\170\000\000\000\000\000\000\000\000\000\000\
\\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\
\\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\
\\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\
\\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\
\\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\
\\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\
\\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\
\\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\
\\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\
\\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\
\\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\
\\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\
\\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\
\\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\
\\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\
\\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000"
),
 (341,256, 
"\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\
\\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\
\\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\
\\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\
\\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\170\
\\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\
\\000\170\000\170\000\170\000\170\000\170\000\170\000\170\000\170\
\\000\170\000\170\000\000\000\000\000\000\000\000\000\000\000\000\
\\000\000\000\170\000\170\000\170\000\170\000\170\000\170\000\170\
\\000\170\000\170\000\170\000\170\001\086\000\170\000\170\000\170\
\\000\170\000\170\000\170\000\170\000\170\000\170\000\170\000\170\
\\000\170\000\170\000\170\000\000\000\000\000\000\000\000\000\170\
\\000\000\000\170\000\170\000\170\000\170\000\170\000\170\000\170\
\\000\170\000\170\000\170\000\170\000\170\000\170\000\170\000\170\
\\000\170\000\170\000\170\000\170\000\170\000\170\000\170\000\170\
\\000\170\000\170\000\170\000\000\000\000\000\000\000\000\000\000\
\\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\
\\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\
\\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\
\\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\
\\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\
\\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\
\\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\
\\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\
\\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\
\\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\
\\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\
\\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\
\\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\
\\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\
\\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\
\\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000"
),
 (342,256, 
"\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\
\\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\
\\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\
\\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\
\\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\170\
\\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\
\\000\170\000\170\000\170\000\170\000\170\000\170\000\170\000\170\
\\000\170\000\170\000\000\000\000\000\000\000\000\000\000\000\000\
\\000\000\000\170\000\170\000\170\000\170\000\170\000\170\000\170\
\\000\170\000\170\000\170\000\170\001\087\000\170\000\170\000\170\
\\000\170\000\170\000\170\000\170\000\170\000\170\000\170\000\170\
\\000\170\000\170\000\170\000\000\000\000\000\000\000\000\000\170\
\\000\000\000\170\000\170\000\170\000\170\000\170\000\170\000\170\
\\000\170\000\170\000\170\000\170\000\170\000\170\000\170\000\170\
\\000\170\000\170\000\170\000\170\000\170\000\170\000\170\000\170\
\\000\170\000\170\000\170\000\000\000\000\000\000\000\000\000\000\
\\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\
\\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\
\\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\
\\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\
\\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\
\\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\
\\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\
\\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\
\\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\
\\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\
\\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\
\\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\
\\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\
\\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\
\\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\
\\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000"
),
 (344,256, 
"\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\
\\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\
\\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\
\\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\
\\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\170\
\\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\
\\000\170\000\170\000\170\000\170\000\170\000\170\000\170\000\170\
\\000\170\000\170\000\000\000\000\000\000\000\000\000\000\000\000\
\\000\000\000\170\000\170\000\170\000\170\000\170\000\170\000\170\
\\000\170\000\170\000\170\000\170\000\170\000\170\000\170\001\089\
\\000\170\000\170\000\170\000\170\000\170\000\170\000\170\000\170\
\\000\170\000\170\000\170\000\000\000\000\000\000\000\000\000\170\
\\000\000\000\170\000\170\000\170\000\170\000\170\000\170\000\170\
\\000\170\000\170\000\170\000\170\000\170\000\170\000\170\000\170\
\\000\170\000\170\000\170\000\170\000\170\000\170\000\170\000\170\
\\000\170\000\170\000\170\000\000\000\000\000\000\000\000\000\000\
\\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\
\\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\
\\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\
\\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\
\\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\
\\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\
\\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\
\\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\
\\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\
\\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\
\\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\
\\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\
\\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\
\\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\
\\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\
\\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000"
),
 (345,256, 
"\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\
\\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\
\\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\
\\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\
\\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\170\
\\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\
\\000\170\000\170\000\170\000\170\000\170\000\170\000\170\000\170\
\\000\170\000\170\000\000\000\000\000\000\000\000\000\000\000\000\
\\000\000\000\170\000\170\000\170\000\170\000\170\000\170\000\170\
\\000\170\000\170\000\170\000\170\000\170\001\090\000\170\000\170\
\\000\170\000\170\000\170\000\170\000\170\000\170\000\170\000\170\
\\000\170\000\170\000\170\000\000\000\000\000\000\000\000\000\170\
\\000\000\000\170\000\170\000\170\000\170\000\170\000\170\000\170\
\\000\170\000\170\000\170\000\170\000\170\000\170\000\170\000\170\
\\000\170\000\170\000\170\000\170\000\170\000\170\000\170\000\170\
\\000\170\000\170\000\170\000\000\000\000\000\000\000\000\000\000\
\\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\
\\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\
\\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\
\\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\
\\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\
\\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\
\\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\
\\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\
\\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\
\\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\
\\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\
\\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\
\\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\
\\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\
\\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\
\\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000"
),
 (347,256, 
"\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\
\\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\
\\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\
\\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\
\\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\170\
\\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\
\\000\170\000\170\000\170\000\170\000\170\000\170\000\170\000\170\
\\000\170\000\170\000\000\000\000\000\000\000\000\000\000\000\000\
\\000\000\000\170\000\170\000\170\000\170\000\170\000\170\000\170\
\\000\170\000\170\000\170\000\170\000\170\000\170\000\170\000\170\
\\000\170\000\170\001\092\000\170\000\170\000\170\000\170\000\170\
\\000\170\000\170\000\170\000\000\000\000\000\000\000\000\000\170\
\\000\000\000\170\000\170\000\170\000\170\000\170\000\170\000\170\
\\000\170\000\170\000\170\000\170\000\170\000\170\000\170\000\170\
\\000\170\000\170\000\170\000\170\000\170\000\170\000\170\000\170\
\\000\170\000\170\000\170\000\000\000\000\000\000\000\000\000\000\
\\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\
\\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\
\\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\
\\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\
\\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\
\\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\
\\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\
\\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\
\\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\
\\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\
\\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\
\\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\
\\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\
\\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\
\\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\
\\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000"
),
 (348,256, 
"\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\
\\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\
\\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\
\\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\
\\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\170\
\\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\
\\000\170\000\170\000\170\000\170\000\170\000\170\000\170\000\170\
\\000\170\000\170\000\000\000\000\000\000\000\000\000\000\000\000\
\\000\000\000\170\000\170\000\170\000\170\001\093\000\170\000\170\
\\000\170\000\170\000\170\000\170\000\170\000\170\000\170\000\170\
\\000\170\000\170\000\170\000\170\000\170\000\170\000\170\000\170\
\\000\170\000\170\000\170\000\000\000\000\000\000\000\000\000\170\
\\000\000\000\170\000\170\000\170\000\170\000\170\000\170\000\170\
\\000\170\000\170\000\170\000\170\000\170\000\170\000\170\000\170\
\\000\170\000\170\000\170\000\170\000\170\000\170\000\170\000\170\
\\000\170\000\170\000\170\000\000\000\000\000\000\000\000\000\000\
\\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\
\\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\
\\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\
\\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\
\\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\
\\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\
\\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\
\\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\
\\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\
\\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\
\\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\
\\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\
\\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\
\\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\
\\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\
\\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000"
),
 (349,256, 
"\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\
\\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\
\\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\
\\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\
\\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\170\
\\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\
\\000\170\000\170\000\170\000\170\000\170\000\170\000\170\000\170\
\\000\170\000\170\000\000\000\000\000\000\000\000\000\000\000\000\
\\000\000\000\170\000\170\000\170\000\170\000\170\000\170\000\170\
\\000\170\001\094\000\170\000\170\000\170\000\170\000\170\000\170\
\\000\170\000\170\000\170\000\170\000\170\000\170\000\170\000\170\
\\000\170\000\170\000\170\000\000\000\000\000\000\000\000\000\170\
\\000\000\000\170\000\170\000\170\000\170\000\170\000\170\000\170\
\\000\170\000\170\000\170\000\170\000\170\000\170\000\170\000\170\
\\000\170\000\170\000\170\000\170\000\170\000\170\000\170\000\170\
\\000\170\000\170\000\170\000\000\000\000\000\000\000\000\000\000\
\\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\
\\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\
\\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\
\\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\
\\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\
\\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\
\\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\
\\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\
\\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\
\\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\
\\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\
\\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\
\\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\
\\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\
\\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\
\\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000"
),
 (350,256, 
"\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\
\\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\
\\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\
\\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\
\\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\170\
\\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\
\\000\170\000\170\000\170\000\170\000\170\000\170\000\170\000\170\
\\000\170\000\170\000\000\000\000\000\000\000\000\000\000\000\000\
\\000\000\000\170\000\170\000\170\000\170\000\170\000\170\001\095\
\\000\170\000\170\000\170\000\170\000\170\000\170\000\170\000\170\
\\000\170\000\170\000\170\000\170\000\170\000\170\000\170\000\170\
\\000\170\000\170\000\170\000\000\000\000\000\000\000\000\000\170\
\\000\000\000\170\000\170\000\170\000\170\000\170\000\170\000\170\
\\000\170\000\170\000\170\000\170\000\170\000\170\000\170\000\170\
\\000\170\000\170\000\170\000\170\000\170\000\170\000\170\000\170\
\\000\170\000\170\000\170\000\000\000\000\000\000\000\000\000\000\
\\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\
\\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\
\\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\
\\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\
\\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\
\\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\
\\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\
\\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\
\\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\
\\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\
\\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\
\\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\
\\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\
\\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\
\\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\
\\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000"
),
 (351,256, 
"\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\
\\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\
\\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\
\\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\
\\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\170\
\\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\
\\000\170\000\170\000\170\000\170\000\170\000\170\000\170\000\170\
\\000\170\000\170\000\000\000\000\000\000\000\000\000\000\000\000\
\\000\000\000\170\000\170\000\170\000\170\000\170\000\170\000\170\
\\000\170\000\170\000\170\000\170\000\170\000\170\001\096\000\170\
\\000\170\000\170\000\170\000\170\000\170\000\170\000\170\000\170\
\\000\170\000\170\000\170\000\000\000\000\000\000\000\000\000\170\
\\000\000\000\170\000\170\000\170\000\170\000\170\000\170\000\170\
\\000\170\000\170\000\170\000\170\000\170\000\170\000\170\000\170\
\\000\170\000\170\000\170\000\170\000\170\000\170\000\170\000\170\
\\000\170\000\170\000\170\000\000\000\000\000\000\000\000\000\000\
\\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\
\\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\
\\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\
\\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\
\\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\
\\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\
\\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\
\\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\
\\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\
\\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\
\\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\
\\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\
\\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\
\\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\
\\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\
\\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000"
),
 (353,256, 
"\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\
\\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\
\\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\
\\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\
\\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\170\
\\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\
\\000\170\000\170\000\170\000\170\000\170\000\170\000\170\000\170\
\\000\170\000\170\000\000\000\000\000\000\000\000\000\000\000\000\
\\000\000\000\170\000\170\000\170\000\170\000\170\000\170\000\170\
\\000\170\000\170\000\170\000\170\001\098\000\170\000\170\000\170\
\\000\170\000\170\000\170\000\170\000\170\000\170\000\170\000\170\
\\000\170\000\170\000\170\000\000\000\000\000\000\000\000\000\170\
\\000\000\000\170\000\170\000\170\000\170\000\170\000\170\000\170\
\\000\170\000\170\000\170\000\170\000\170\000\170\000\170\000\170\
\\000\170\000\170\000\170\000\170\000\170\000\170\000\170\000\170\
\\000\170\000\170\000\170\000\000\000\000\000\000\000\000\000\000\
\\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\
\\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\
\\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\
\\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\
\\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\
\\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\
\\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\
\\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\
\\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\
\\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\
\\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\
\\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\
\\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\
\\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\
\\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\
\\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000"
),
 (354,256, 
"\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\
\\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\
\\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\
\\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\
\\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\170\
\\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\
\\000\170\000\170\000\170\000\170\000\170\000\170\000\170\000\170\
\\000\170\000\170\000\000\000\000\000\000\000\000\000\000\000\000\
\\000\000\000\170\000\170\000\170\000\170\000\170\000\170\000\170\
\\000\170\000\170\000\170\000\170\000\170\000\170\000\170\000\170\
\\000\170\000\170\000\170\001\099\000\170\000\170\000\170\000\170\
\\000\170\000\170\000\170\000\000\000\000\000\000\000\000\000\170\
\\000\000\000\170\000\170\000\170\000\170\000\170\000\170\000\170\
\\000\170\000\170\000\170\000\170\000\170\000\170\000\170\000\170\
\\000\170\000\170\000\170\000\170\000\170\000\170\000\170\000\170\
\\000\170\000\170\000\170\000\000\000\000\000\000\000\000\000\000\
\\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\
\\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\
\\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\
\\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\
\\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\
\\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\
\\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\
\\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\
\\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\
\\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\
\\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\
\\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\
\\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\
\\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\
\\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\
\\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000"
),
 (355,256, 
"\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\
\\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\
\\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\
\\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\
\\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\170\
\\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\
\\000\170\000\170\000\170\000\170\000\170\000\170\000\170\000\170\
\\000\170\000\170\000\000\000\000\000\000\000\000\000\000\000\000\
\\000\000\000\170\000\170\000\170\000\170\001\100\000\170\000\170\
\\000\170\000\170\000\170\000\170\000\170\000\170\000\170\000\170\
\\000\170\000\170\000\170\000\170\000\170\000\170\000\170\000\170\
\\000\170\000\170\000\170\000\000\000\000\000\000\000\000\000\170\
\\000\000\000\170\000\170\000\170\000\170\000\170\000\170\000\170\
\\000\170\000\170\000\170\000\170\000\170\000\170\000\170\000\170\
\\000\170\000\170\000\170\000\170\000\170\000\170\000\170\000\170\
\\000\170\000\170\000\170\000\000\000\000\000\000\000\000\000\000\
\\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\
\\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\
\\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\
\\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\
\\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\
\\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\
\\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\
\\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\
\\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\
\\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\
\\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\
\\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\
\\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\
\\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\
\\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\
\\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000"
),
 (357,256, 
"\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\
\\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\
\\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\
\\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\
\\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\170\
\\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\
\\000\170\000\170\000\170\000\170\000\170\000\170\000\170\000\170\
\\000\170\000\170\000\000\000\000\000\000\000\000\000\000\000\000\
\\000\000\000\170\000\170\000\170\000\170\000\170\000\170\000\170\
\\000\170\000\170\000\170\000\170\001\107\000\170\000\170\000\170\
\\000\170\000\170\000\170\000\170\000\170\000\170\000\170\000\170\
\\001\102\000\170\000\170\000\000\000\000\000\000\000\000\000\170\
\\000\000\000\170\000\170\000\170\000\170\000\170\000\170\000\170\
\\000\170\000\170\000\170\000\170\000\170\000\170\000\170\000\170\
\\000\170\000\170\000\170\000\170\000\170\000\170\000\170\000\170\
\\000\170\000\170\000\170\000\000\000\000\000\000\000\000\000\000\
\\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\
\\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\
\\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\
\\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\
\\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\
\\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\
\\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\
\\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\
\\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\
\\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\
\\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\
\\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\
\\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\
\\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\
\\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\
\\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000"
),
 (358,256, 
"\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\
\\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\
\\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\
\\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\
\\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\170\
\\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\
\\000\170\000\170\000\170\000\170\000\170\000\170\000\170\000\170\
\\000\170\000\170\000\000\000\000\000\000\000\000\000\000\000\000\
\\000\000\000\170\000\170\001\103\000\170\000\170\000\170\000\170\
\\000\170\000\170\000\170\000\170\000\170\000\170\000\170\000\170\
\\000\170\000\170\000\170\000\170\000\170\000\170\000\170\000\170\
\\000\170\000\170\000\170\000\000\000\000\000\000\000\000\000\170\
\\000\000\000\170\000\170\000\170\000\170\000\170\000\170\000\170\
\\000\170\000\170\000\170\000\170\000\170\000\170\000\170\000\170\
\\000\170\000\170\000\170\000\170\000\170\000\170\000\170\000\170\
\\000\170\000\170\000\170\000\000\000\000\000\000\000\000\000\000\
\\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\
\\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\
\\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\
\\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\
\\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\
\\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\
\\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\
\\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\
\\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\
\\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\
\\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\
\\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\
\\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\
\\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\
\\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\
\\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000"
),
 (359,256, 
"\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\
\\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\
\\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\
\\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\
\\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\170\
\\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\
\\000\170\000\170\000\170\000\170\000\170\000\170\000\170\000\170\
\\000\170\000\170\000\000\000\000\000\000\000\000\000\000\000\000\
\\000\000\000\170\000\170\000\170\000\170\001\104\000\170\000\170\
\\000\170\000\170\000\170\000\170\000\170\000\170\000\170\000\170\
\\000\170\000\170\000\170\000\170\000\170\000\170\000\170\000\170\
\\000\170\000\170\000\170\000\000\000\000\000\000\000\000\000\170\
\\000\000\000\170\000\170\000\170\000\170\000\170\000\170\000\170\
\\000\170\000\170\000\170\000\170\000\170\000\170\000\170\000\170\
\\000\170\000\170\000\170\000\170\000\170\000\170\000\170\000\170\
\\000\170\000\170\000\170\000\000\000\000\000\000\000\000\000\000\
\\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\
\\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\
\\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\
\\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\
\\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\
\\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\
\\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\
\\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\
\\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\
\\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\
\\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\
\\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\
\\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\
\\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\
\\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\
\\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000"
),
 (360,256, 
"\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\
\\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\
\\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\
\\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\
\\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\170\
\\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\
\\000\170\000\170\000\170\000\170\000\170\000\170\000\170\000\170\
\\000\170\000\170\000\000\000\000\000\000\000\000\000\000\000\000\
\\000\000\000\170\000\170\000\170\000\170\000\170\000\170\000\170\
\\000\170\000\170\000\170\000\170\000\170\000\170\000\170\000\170\
\\001\105\000\170\000\170\000\170\000\170\000\170\000\170\000\170\
\\000\170\000\170\000\170\000\000\000\000\000\000\000\000\000\170\
\\000\000\000\170\000\170\000\170\000\170\000\170\000\170\000\170\
\\000\170\000\170\000\170\000\170\000\170\000\170\000\170\000\170\
\\000\170\000\170\000\170\000\170\000\170\000\170\000\170\000\170\
\\000\170\000\170\000\170\000\000\000\000\000\000\000\000\000\000\
\\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\
\\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\
\\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\
\\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\
\\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\
\\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\
\\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\
\\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\
\\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\
\\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\
\\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\
\\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\
\\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\
\\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\
\\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\
\\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000"
),
 (361,256, 
"\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\
\\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\
\\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\
\\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\
\\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\170\
\\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\
\\000\170\000\170\000\170\000\170\000\170\000\170\000\170\000\170\
\\000\170\000\170\000\000\000\000\000\000\000\000\000\000\000\000\
\\000\000\000\170\000\170\000\170\000\170\000\170\000\170\000\170\
\\000\170\000\170\000\170\000\170\000\170\000\170\000\170\000\170\
\\000\170\000\170\000\170\000\170\001\106\000\170\000\170\000\170\
\\000\170\000\170\000\170\000\000\000\000\000\000\000\000\000\170\
\\000\000\000\170\000\170\000\170\000\170\000\170\000\170\000\170\
\\000\170\000\170\000\170\000\170\000\170\000\170\000\170\000\170\
\\000\170\000\170\000\170\000\170\000\170\000\170\000\170\000\170\
\\000\170\000\170\000\170\000\000\000\000\000\000\000\000\000\000\
\\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\
\\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\
\\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\
\\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\
\\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\
\\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\
\\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\
\\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\
\\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\
\\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\
\\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\
\\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\
\\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\
\\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\
\\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\
\\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000"
),
 (363,256, 
"\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\
\\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\
\\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\
\\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\
\\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\170\
\\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\
\\000\170\000\170\000\170\000\170\000\170\000\170\000\170\000\170\
\\000\170\000\170\000\000\000\000\000\000\000\000\000\000\000\000\
\\000\000\000\170\000\170\000\170\000\170\000\170\000\170\000\170\
\\000\170\000\170\000\170\000\170\000\170\000\170\000\170\000\170\
\\000\170\000\170\000\170\001\108\000\170\000\170\000\170\000\170\
\\000\170\000\170\000\170\000\000\000\000\000\000\000\000\000\170\
\\000\000\000\170\000\170\000\170\000\170\000\170\000\170\000\170\
\\000\170\000\170\000\170\000\170\000\170\000\170\000\170\000\170\
\\000\170\000\170\000\170\000\170\000\170\000\170\000\170\000\170\
\\000\170\000\170\000\170\000\000\000\000\000\000\000\000\000\000\
\\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\
\\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\
\\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\
\\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\
\\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\
\\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\
\\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\
\\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\
\\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\
\\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\
\\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\
\\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\
\\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\
\\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\
\\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\
\\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000"
),
 (364,256, 
"\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\
\\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\
\\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\
\\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\
\\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\170\
\\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\
\\000\170\000\170\000\170\000\170\000\170\000\170\000\170\000\170\
\\000\170\000\170\000\000\000\000\000\000\000\000\000\000\000\000\
\\000\000\000\170\000\170\000\170\000\170\001\109\000\170\000\170\
\\000\170\000\170\000\170\000\170\000\170\000\170\000\170\000\170\
\\000\170\000\170\000\170\000\170\000\170\000\170\000\170\000\170\
\\000\170\000\170\000\170\000\000\000\000\000\000\000\000\000\170\
\\000\000\000\170\000\170\000\170\000\170\000\170\000\170\000\170\
\\000\170\000\170\000\170\000\170\000\170\000\170\000\170\000\170\
\\000\170\000\170\000\170\000\170\000\170\000\170\000\170\000\170\
\\000\170\000\170\000\170\000\000\000\000\000\000\000\000\000\000\
\\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\
\\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\
\\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\
\\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\
\\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\
\\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\
\\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\
\\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\
\\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\
\\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\
\\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\
\\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\
\\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\
\\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\
\\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\
\\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000"
),
 (366,256, 
"\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\
\\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\
\\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\
\\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\
\\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\170\
\\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\
\\000\170\000\170\000\170\000\170\000\170\000\170\000\170\000\170\
\\000\170\000\170\000\000\000\000\000\000\000\000\000\000\000\000\
\\000\000\000\170\000\170\000\170\000\170\001\118\000\170\000\170\
\\000\170\001\111\000\170\000\170\000\170\000\170\000\170\000\170\
\\000\170\000\170\000\170\000\170\000\170\000\170\000\170\000\170\
\\000\170\000\170\000\170\000\000\000\000\000\000\000\000\000\170\
\\000\000\000\170\000\170\000\170\000\170\000\170\000\170\000\170\
\\000\170\000\170\000\170\000\170\000\170\000\170\000\170\000\170\
\\000\170\000\170\000\170\000\170\000\170\000\170\000\170\000\170\
\\000\170\000\170\000\170\000\000\000\000\000\000\000\000\000\000\
\\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\
\\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\
\\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\
\\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\
\\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\
\\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\
\\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\
\\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\
\\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\
\\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\
\\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\
\\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\
\\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\
\\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\
\\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\
\\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000"
),
 (367,256, 
"\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\
\\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\
\\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\
\\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\
\\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\170\
\\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\
\\000\170\000\170\000\170\000\170\000\170\000\170\000\170\000\170\
\\000\170\000\170\000\000\000\000\000\000\000\000\000\000\000\000\
\\000\000\000\170\000\170\000\170\000\170\000\170\000\170\000\170\
\\000\170\000\170\000\170\000\170\000\170\000\170\000\170\000\170\
\\000\170\000\170\000\170\001\112\000\170\000\170\000\170\000\170\
\\000\170\000\170\000\170\000\000\000\000\000\000\000\000\000\170\
\\000\000\000\170\000\170\000\170\000\170\000\170\000\170\000\170\
\\000\170\000\170\000\170\000\170\000\170\000\170\000\170\000\170\
\\000\170\000\170\000\170\000\170\000\170\000\170\000\170\000\170\
\\000\170\000\170\000\170\000\000\000\000\000\000\000\000\000\000\
\\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\
\\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\
\\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\
\\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\
\\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\
\\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\
\\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\
\\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\
\\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\
\\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\
\\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\
\\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\
\\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\
\\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\
\\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\
\\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000"
),
 (368,256, 
"\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\
\\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\
\\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\
\\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\
\\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\170\
\\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\
\\000\170\000\170\000\170\000\170\000\170\000\170\000\170\000\170\
\\000\170\000\170\000\000\000\000\000\000\000\000\000\000\000\000\
\\000\000\000\170\000\170\000\170\000\170\000\170\000\170\000\170\
\\000\170\000\170\000\170\000\170\000\170\000\170\000\170\000\170\
\\000\170\000\170\000\170\000\170\001\113\000\170\000\170\000\170\
\\000\170\000\170\000\170\000\000\000\000\000\000\000\000\000\170\
\\000\000\000\170\000\170\000\170\000\170\000\170\000\170\000\170\
\\000\170\000\170\000\170\000\170\000\170\000\170\000\170\000\170\
\\000\170\000\170\000\170\000\170\000\170\000\170\000\170\000\170\
\\000\170\000\170\000\170\000\000\000\000\000\000\000\000\000\000\
\\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\
\\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\
\\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\
\\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\
\\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\
\\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\
\\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\
\\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\
\\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\
\\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\
\\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\
\\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\
\\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\
\\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\
\\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\
\\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000"
),
 (369,256, 
"\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\
\\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\
\\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\
\\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\
\\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\170\
\\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\
\\000\170\000\170\000\170\000\170\000\170\000\170\000\170\000\170\
\\000\170\000\170\000\000\000\000\000\000\000\000\000\000\000\000\
\\000\000\000\170\000\170\000\170\000\170\000\170\000\170\000\170\
\\000\170\001\114\000\170\000\170\000\170\000\170\000\170\000\170\
\\000\170\000\170\000\170\000\170\000\170\000\170\000\170\000\170\
\\000\170\000\170\000\170\000\000\000\000\000\000\000\000\000\170\
\\000\000\000\170\000\170\000\170\000\170\000\170\000\170\000\170\
\\000\170\000\170\000\170\000\170\000\170\000\170\000\170\000\170\
\\000\170\000\170\000\170\000\170\000\170\000\170\000\170\000\170\
\\000\170\000\170\000\170\000\000\000\000\000\000\000\000\000\000\
\\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\
\\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\
\\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\
\\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\
\\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\
\\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\
\\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\
\\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\
\\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\
\\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\
\\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\
\\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\
\\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\
\\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\
\\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\
\\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000"
),
 (370,256, 
"\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\
\\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\
\\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\
\\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\
\\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\170\
\\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\
\\000\170\000\170\000\170\000\170\000\170\000\170\000\170\000\170\
\\000\170\000\170\000\000\000\000\000\000\000\000\000\000\000\000\
\\000\000\000\170\000\170\000\170\000\170\000\170\000\170\000\170\
\\000\170\000\170\000\170\000\170\000\170\000\170\001\115\000\170\
\\000\170\000\170\000\170\000\170\000\170\000\170\000\170\000\170\
\\000\170\000\170\000\170\000\000\000\000\000\000\000\000\000\170\
\\000\000\000\170\000\170\000\170\000\170\000\170\000\170\000\170\
\\000\170\000\170\000\170\000\170\000\170\000\170\000\170\000\170\
\\000\170\000\170\000\170\000\170\000\170\000\170\000\170\000\170\
\\000\170\000\170\000\170\000\000\000\000\000\000\000\000\000\000\
\\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\
\\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\
\\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\
\\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\
\\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\
\\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\
\\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\
\\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\
\\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\
\\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\
\\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\
\\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\
\\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\
\\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\
\\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\
\\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000"
),
 (371,256, 
"\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\
\\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\
\\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\
\\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\
\\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\170\
\\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\
\\000\170\000\170\000\170\000\170\000\170\000\170\000\170\000\170\
\\000\170\000\170\000\000\000\000\000\000\000\000\000\000\000\000\
\\000\000\000\170\000\170\001\116\000\170\000\170\000\170\000\170\
\\000\170\000\170\000\170\000\170\000\170\000\170\000\170\000\170\
\\000\170\000\170\000\170\000\170\000\170\000\170\000\170\000\170\
\\000\170\000\170\000\170\000\000\000\000\000\000\000\000\000\170\
\\000\000\000\170\000\170\000\170\000\170\000\170\000\170\000\170\
\\000\170\000\170\000\170\000\170\000\170\000\170\000\170\000\170\
\\000\170\000\170\000\170\000\170\000\170\000\170\000\170\000\170\
\\000\170\000\170\000\170\000\000\000\000\000\000\000\000\000\000\
\\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\
\\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\
\\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\
\\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\
\\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\
\\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\
\\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\
\\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\
\\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\
\\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\
\\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\
\\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\
\\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\
\\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\
\\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\
\\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000"
),
 (372,256, 
"\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\
\\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\
\\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\
\\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\
\\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\170\
\\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\
\\000\170\000\170\000\170\000\170\000\170\000\170\000\170\000\170\
\\000\170\000\170\000\000\000\000\000\000\000\000\000\000\000\000\
\\000\000\000\170\000\170\000\170\000\170\000\170\000\170\000\170\
\\000\170\000\170\000\170\000\170\000\170\000\170\000\170\000\170\
\\000\170\000\170\000\170\000\170\001\117\000\170\000\170\000\170\
\\000\170\000\170\000\170\000\000\000\000\000\000\000\000\000\170\
\\000\000\000\170\000\170\000\170\000\170\000\170\000\170\000\170\
\\000\170\000\170\000\170\000\170\000\170\000\170\000\170\000\170\
\\000\170\000\170\000\170\000\170\000\170\000\170\000\170\000\170\
\\000\170\000\170\000\170\000\000\000\000\000\000\000\000\000\000\
\\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\
\\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\
\\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\
\\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\
\\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\
\\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\
\\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\
\\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\
\\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\
\\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\
\\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\
\\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\
\\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\
\\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\
\\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\
\\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000"
),
 (374,256, 
"\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\
\\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\
\\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\
\\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\
\\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\170\
\\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\
\\000\170\000\170\000\170\000\170\000\170\000\170\000\170\000\170\
\\000\170\000\170\000\000\000\000\000\000\000\000\000\000\000\000\
\\000\000\000\170\000\170\000\170\000\170\000\170\000\170\000\170\
\\000\170\000\170\000\170\000\170\001\121\000\170\000\170\000\170\
\\000\170\000\170\000\170\001\119\000\170\000\170\000\170\000\170\
\\000\170\000\170\000\170\000\000\000\000\000\000\000\000\000\170\
\\000\000\000\170\000\170\000\170\000\170\000\170\000\170\000\170\
\\000\170\000\170\000\170\000\170\000\170\000\170\000\170\000\170\
\\000\170\000\170\000\170\000\170\000\170\000\170\000\170\000\170\
\\000\170\000\170\000\170\000\000\000\000\000\000\000\000\000\000\
\\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\
\\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\
\\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\
\\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\
\\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\
\\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\
\\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\
\\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\
\\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\
\\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\
\\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\
\\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\
\\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\
\\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\
\\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\
\\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000"
),
 (375,256, 
"\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\
\\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\
\\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\
\\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\
\\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\170\
\\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\
\\000\170\000\170\000\170\000\170\000\170\000\170\000\170\000\170\
\\000\170\000\170\000\000\000\000\000\000\000\000\000\000\000\000\
\\000\000\000\170\000\170\001\120\000\170\000\170\000\170\000\170\
\\000\170\000\170\000\170\000\170\000\170\000\170\000\170\000\170\
\\000\170\000\170\000\170\000\170\000\170\000\170\000\170\000\170\
\\000\170\000\170\000\170\000\000\000\000\000\000\000\000\000\170\
\\000\000\000\170\000\170\000\170\000\170\000\170\000\170\000\170\
\\000\170\000\170\000\170\000\170\000\170\000\170\000\170\000\170\
\\000\170\000\170\000\170\000\170\000\170\000\170\000\170\000\170\
\\000\170\000\170\000\170\000\000\000\000\000\000\000\000\000\000\
\\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\
\\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\
\\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\
\\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\
\\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\
\\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\
\\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\
\\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\
\\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\
\\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\
\\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\
\\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\
\\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\
\\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\
\\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\
\\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000"
),
 (377,256, 
"\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\
\\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\
\\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\
\\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\
\\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\170\
\\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\
\\000\170\000\170\000\170\000\170\000\170\000\170\000\170\000\170\
\\000\170\000\170\000\000\000\000\000\000\000\000\000\000\000\000\
\\000\000\000\170\000\170\000\170\000\170\001\122\000\170\000\170\
\\000\170\000\170\000\170\000\170\000\170\000\170\000\170\000\170\
\\000\170\000\170\000\170\000\170\000\170\000\170\000\170\000\170\
\\000\170\000\170\000\170\000\000\000\000\000\000\000\000\000\170\
\\000\000\000\170\000\170\000\170\000\170\000\170\000\170\000\170\
\\000\170\000\170\000\170\000\170\000\170\000\170\000\170\000\170\
\\000\170\000\170\000\170\000\170\000\170\000\170\000\170\000\170\
\\000\170\000\170\000\170\000\000\000\000\000\000\000\000\000\000\
\\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\
\\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\
\\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\
\\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\
\\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\
\\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\
\\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\
\\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\
\\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\
\\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\
\\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\
\\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\
\\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\
\\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\
\\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\
\\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000"
),
 (378,256, 
"\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\
\\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\
\\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\
\\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\
\\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\170\
\\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\
\\000\170\000\170\000\170\000\170\000\170\000\170\000\170\000\170\
\\000\170\000\170\000\000\000\000\000\000\000\000\000\000\000\000\
\\000\000\000\170\000\170\000\170\000\170\000\170\000\170\000\170\
\\000\170\000\170\000\170\000\170\000\170\000\170\000\170\000\170\
\\000\170\000\170\000\170\000\170\001\123\000\170\000\170\000\170\
\\000\170\000\170\000\170\000\000\000\000\000\000\000\000\000\170\
\\000\000\000\170\000\170\000\170\000\170\000\170\000\170\000\170\
\\000\170\000\170\000\170\000\170\000\170\000\170\000\170\000\170\
\\000\170\000\170\000\170\000\170\000\170\000\170\000\170\000\170\
\\000\170\000\170\000\170\000\000\000\000\000\000\000\000\000\000\
\\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\
\\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\
\\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\
\\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\
\\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\
\\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\
\\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\
\\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\
\\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\
\\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\
\\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\
\\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\
\\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\
\\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\
\\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\
\\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000"
),
 (379,256, 
"\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\
\\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\
\\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\
\\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\
\\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\170\
\\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\
\\000\170\000\170\000\170\000\170\000\170\000\170\000\170\000\170\
\\000\170\000\170\000\000\000\000\000\000\000\000\000\000\000\000\
\\000\000\000\170\000\170\000\170\000\170\001\124\000\170\000\170\
\\000\170\000\170\000\170\000\170\000\170\000\170\000\170\000\170\
\\000\170\000\170\000\170\000\170\000\170\000\170\000\170\000\170\
\\000\170\000\170\000\170\000\000\000\000\000\000\000\000\000\170\
\\000\000\000\170\000\170\000\170\000\170\000\170\000\170\000\170\
\\000\170\000\170\000\170\000\170\000\170\000\170\000\170\000\170\
\\000\170\000\170\000\170\000\170\000\170\000\170\000\170\000\170\
\\000\170\000\170\000\170\000\000\000\000\000\000\000\000\000\000\
\\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\
\\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\
\\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\
\\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\
\\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\
\\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\
\\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\
\\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\
\\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\
\\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\
\\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\
\\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\
\\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\
\\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\
\\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\
\\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000"
),
 (381,256, 
"\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\
\\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\
\\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\
\\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\
\\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\170\
\\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\
\\000\170\000\170\000\170\000\170\000\170\000\170\000\170\000\170\
\\000\170\000\170\000\000\000\000\000\000\000\000\000\000\000\000\
\\000\000\001\168\000\170\000\170\000\170\000\170\000\170\000\170\
\\001\164\000\170\000\170\000\170\000\170\000\170\000\170\001\146\
\\000\170\000\170\001\142\000\170\000\170\001\126\000\170\000\170\
\\000\170\000\170\000\170\000\000\000\000\000\000\000\000\000\170\
\\000\000\000\170\000\170\000\170\000\170\000\170\000\170\000\170\
\\000\170\000\170\000\170\000\170\000\170\000\170\000\170\000\170\
\\000\170\000\170\000\170\000\170\000\170\000\170\000\170\000\170\
\\000\170\000\170\000\170\000\000\000\000\000\000\000\000\000\000\
\\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\
\\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\
\\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\
\\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\
\\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\
\\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\
\\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\
\\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\
\\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\
\\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\
\\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\
\\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\
\\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\
\\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\
\\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\
\\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000"
),
 (382,256, 
"\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\
\\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\
\\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\
\\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\
\\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\170\
\\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\
\\000\170\000\170\000\170\000\170\000\170\000\170\000\170\000\170\
\\000\170\000\170\000\000\000\000\000\000\000\000\000\000\000\000\
\\000\000\000\170\000\170\000\170\000\170\000\170\000\170\000\170\
\\000\170\000\170\000\170\000\170\000\170\000\170\000\170\000\170\
\\000\170\000\170\001\127\000\170\000\170\000\170\000\170\000\170\
\\000\170\000\170\000\170\000\000\000\000\000\000\000\000\000\170\
\\000\000\000\170\000\170\000\170\000\170\000\170\000\170\000\170\
\\000\170\000\170\000\170\000\170\000\170\000\170\000\170\000\170\
\\000\170\000\170\000\170\000\170\000\170\000\170\000\170\000\170\
\\000\170\000\170\000\170\000\000\000\000\000\000\000\000\000\000\
\\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\
\\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\
\\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\
\\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\
\\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\
\\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\
\\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\
\\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\
\\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\
\\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\
\\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\
\\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\
\\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\
\\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\
\\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\
\\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000"
),
 (383,256, 
"\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\
\\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\
\\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\
\\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\
\\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\170\
\\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\
\\000\170\000\170\000\170\000\170\000\170\000\170\000\170\000\170\
\\000\170\000\170\000\000\000\000\000\000\000\000\000\000\000\000\
\\000\000\000\170\000\170\000\170\000\170\000\170\000\170\000\170\
\\000\170\000\170\000\170\000\170\000\170\000\170\000\170\000\170\
\\000\170\000\170\001\128\000\170\000\170\000\170\000\170\000\170\
\\000\170\000\170\000\170\000\000\000\000\000\000\000\000\000\170\
\\000\000\000\170\000\170\000\170\000\170\000\170\000\170\000\170\
\\000\170\000\170\000\170\000\170\000\170\000\170\000\170\000\170\
\\000\170\000\170\000\170\000\170\000\170\000\170\000\170\000\170\
\\000\170\000\170\000\170\000\000\000\000\000\000\000\000\000\000\
\\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\
\\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\
\\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\
\\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\
\\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\
\\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\
\\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\
\\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\
\\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\
\\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\
\\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\
\\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\
\\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\
\\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\
\\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\
\\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000"
),
 (384,256, 
"\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\
\\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\
\\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\
\\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\
\\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\170\
\\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\
\\000\170\000\170\000\170\000\170\000\170\000\170\000\170\000\170\
\\000\170\000\170\000\000\000\000\000\000\000\000\000\000\000\000\
\\000\000\000\170\000\170\000\170\000\170\001\129\000\170\000\170\
\\000\170\000\170\000\170\000\170\000\170\000\170\000\170\000\170\
\\000\170\000\170\000\170\000\170\000\170\000\170\000\170\000\170\
\\000\170\000\170\000\170\000\000\000\000\000\000\000\000\000\170\
\\000\000\000\170\000\170\000\170\000\170\000\170\000\170\000\170\
\\000\170\000\170\000\170\000\170\000\170\000\170\000\170\000\170\
\\000\170\000\170\000\170\000\170\000\170\000\170\000\170\000\170\
\\000\170\000\170\000\170\000\000\000\000\000\000\000\000\000\000\
\\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\
\\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\
\\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\
\\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\
\\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\
\\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\
\\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\
\\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\
\\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\
\\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\
\\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\
\\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\
\\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\
\\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\
\\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\
\\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000"
),
 (385,256, 
"\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\
\\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\
\\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\
\\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\
\\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\170\
\\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\
\\000\170\000\170\000\170\000\170\000\170\000\170\000\170\000\170\
\\000\170\000\170\000\000\000\000\000\000\000\000\000\000\000\000\
\\000\000\000\170\000\170\000\170\000\170\000\170\000\170\000\170\
\\000\170\000\170\000\170\000\170\000\170\000\170\001\130\000\170\
\\000\170\000\170\000\170\000\170\000\170\000\170\000\170\000\170\
\\000\170\000\170\000\170\000\000\000\000\000\000\000\000\000\170\
\\000\000\000\170\000\170\000\170\000\170\000\170\000\170\000\170\
\\000\170\000\170\000\170\000\170\000\170\000\170\000\170\000\170\
\\000\170\000\170\000\170\000\170\000\170\000\170\000\170\000\170\
\\000\170\000\170\000\170\000\000\000\000\000\000\000\000\000\000\
\\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\
\\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\
\\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\
\\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\
\\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\
\\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\
\\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\
\\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\
\\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\
\\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\
\\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\
\\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\
\\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\
\\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\
\\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\
\\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000"
),
 (386,256, 
"\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\
\\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\
\\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\
\\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\
\\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\170\
\\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\
\\000\170\000\170\000\170\000\170\000\170\000\170\000\170\000\170\
\\000\170\000\170\000\000\000\000\000\000\000\000\000\000\000\000\
\\000\000\000\170\000\170\000\170\000\170\000\170\000\170\000\170\
\\000\170\000\170\000\170\000\170\000\170\000\170\000\170\000\170\
\\000\170\000\170\000\170\000\170\001\131\000\170\000\170\000\170\
\\000\170\000\170\000\170\000\000\000\000\000\000\000\000\000\170\
\\000\000\000\170\000\170\000\170\000\170\000\170\000\170\000\170\
\\000\170\000\170\000\170\000\170\000\170\000\170\000\170\000\170\
\\000\170\000\170\000\170\000\170\000\170\000\170\000\170\000\170\
\\000\170\000\170\000\170\000\000\000\000\000\000\000\000\000\000\
\\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\
\\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\
\\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\
\\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\
\\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\
\\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\
\\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\
\\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\
\\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\
\\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\
\\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\
\\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\
\\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\
\\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\
\\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\
\\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000"
),
 (387,256, 
"\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\
\\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\
\\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\
\\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\
\\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\170\
\\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\
\\000\170\000\170\000\170\000\170\000\170\000\170\000\170\000\170\
\\000\170\000\170\000\000\000\000\000\000\000\000\000\000\000\000\
\\000\000\000\170\000\170\000\170\000\170\000\170\000\170\000\170\
\\000\170\000\170\000\170\000\170\000\170\000\170\000\170\000\170\
\\000\170\000\170\000\170\000\170\000\170\000\170\000\170\000\170\
\\000\170\000\170\000\170\000\000\000\000\000\000\000\000\001\132\
\\000\000\000\170\000\170\000\170\000\170\000\170\000\170\000\170\
\\000\170\000\170\000\170\000\170\000\170\000\170\000\170\000\170\
\\000\170\000\170\000\170\000\170\000\170\000\170\000\170\000\170\
\\000\170\000\170\000\170\000\000\000\000\000\000\000\000\000\000\
\\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\
\\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\
\\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\
\\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\
\\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\
\\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\
\\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\
\\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\
\\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\
\\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\
\\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\
\\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\
\\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\
\\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\
\\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\
\\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000"
),
 (388,256, 
"\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\
\\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\
\\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\
\\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\
\\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\170\
\\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\
\\000\170\000\170\000\170\000\170\000\170\000\170\000\170\000\170\
\\000\170\000\170\000\000\000\000\000\000\000\000\000\000\000\000\
\\000\000\000\170\000\170\000\170\000\170\000\170\000\170\000\170\
\\000\170\000\170\000\170\000\170\000\170\000\170\000\170\000\170\
\\000\170\000\170\000\170\000\170\001\133\000\170\000\170\000\170\
\\000\170\000\170\000\170\000\000\000\000\000\000\000\000\000\170\
\\000\000\000\170\000\170\000\170\000\170\000\170\000\170\000\170\
\\000\170\000\170\000\170\000\170\000\170\000\170\000\170\000\170\
\\000\170\000\170\000\170\000\170\000\170\000\170\000\170\000\170\
\\000\170\000\170\000\170\000\000\000\000\000\000\000\000\000\000\
\\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\
\\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\
\\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\
\\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\
\\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\
\\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\
\\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\
\\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\
\\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\
\\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\
\\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\
\\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\
\\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\
\\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\
\\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\
\\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000"
),
 (389,256, 
"\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\
\\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\
\\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\
\\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\
\\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\170\
\\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\
\\000\170\000\170\000\170\000\170\000\170\000\170\000\170\000\170\
\\000\170\000\170\000\000\000\000\000\000\000\000\000\000\000\000\
\\000\000\000\170\000\170\000\170\000\170\000\170\000\170\000\170\
\\000\170\001\134\000\170\000\170\000\170\000\170\000\170\000\170\
\\000\170\000\170\000\170\000\170\000\170\000\170\000\170\000\170\
\\000\170\000\170\000\170\000\000\000\000\000\000\000\000\000\170\
\\000\000\000\170\000\170\000\170\000\170\000\170\000\170\000\170\
\\000\170\000\170\000\170\000\170\000\170\000\170\000\170\000\170\
\\000\170\000\170\000\170\000\170\000\170\000\170\000\170\000\170\
\\000\170\000\170\000\170\000\000\000\000\000\000\000\000\000\000\
\\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\
\\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\
\\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\
\\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\
\\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\
\\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\
\\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\
\\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\
\\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\
\\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\
\\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\
\\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\
\\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\
\\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\
\\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\
\\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000"
),
 (390,256, 
"\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\
\\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\
\\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\
\\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\
\\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\170\
\\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\
\\000\170\000\170\000\170\000\170\000\170\000\170\000\170\000\170\
\\000\170\000\170\000\000\000\000\000\000\000\000\000\000\000\000\
\\000\000\000\170\000\170\000\170\000\170\000\170\000\170\000\170\
\\000\170\000\170\000\170\000\170\000\170\001\135\000\170\000\170\
\\000\170\000\170\000\170\000\170\000\170\000\170\000\170\000\170\
\\000\170\000\170\000\170\000\000\000\000\000\000\000\000\000\170\
\\000\000\000\170\000\170\000\170\000\170\000\170\000\170\000\170\
\\000\170\000\170\000\170\000\170\000\170\000\170\000\170\000\170\
\\000\170\000\170\000\170\000\170\000\170\000\170\000\170\000\170\
\\000\170\000\170\000\170\000\000\000\000\000\000\000\000\000\000\
\\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\
\\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\
\\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\
\\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\
\\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\
\\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\
\\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\
\\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\
\\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\
\\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\
\\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\
\\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\
\\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\
\\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\
\\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\
\\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000"
),
 (391,256, 
"\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\
\\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\
\\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\
\\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\
\\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\170\
\\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\
\\000\170\000\170\000\170\000\170\000\170\000\170\000\170\000\170\
\\000\170\000\170\000\000\000\000\000\000\000\000\000\000\000\000\
\\000\000\000\170\000\170\000\170\000\170\001\136\000\170\000\170\
\\000\170\000\170\000\170\000\170\000\170\000\170\000\170\000\170\
\\000\170\000\170\000\170\000\170\000\170\000\170\000\170\000\170\
\\000\170\000\170\000\170\000\000\000\000\000\000\000\000\000\170\
\\000\000\000\170\000\170\000\170\000\170\000\170\000\170\000\170\
\\000\170\000\170\000\170\000\170\000\170\000\170\000\170\000\170\
\\000\170\000\170\000\170\000\170\000\170\000\170\000\170\000\170\
\\000\170\000\170\000\170\000\000\000\000\000\000\000\000\000\000\
\\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\
\\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\
\\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\
\\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\
\\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\
\\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\
\\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\
\\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\
\\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\
\\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\
\\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\
\\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\
\\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\
\\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\
\\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\
\\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000"
),
 (392,256, 
"\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\
\\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\
\\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\
\\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\
\\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\170\
\\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\
\\000\170\000\170\000\170\000\170\000\170\000\170\000\170\000\170\
\\000\170\000\170\000\000\000\000\000\000\000\000\000\000\000\000\
\\000\000\000\170\000\170\000\170\000\170\000\170\000\170\000\170\
\\000\170\000\170\000\170\000\170\000\170\000\170\000\170\000\170\
\\000\170\000\170\000\170\001\137\000\170\000\170\000\170\000\170\
\\000\170\000\170\000\170\000\000\000\000\000\000\000\000\000\170\
\\000\000\000\170\000\170\000\170\000\170\000\170\000\170\000\170\
\\000\170\000\170\000\170\000\170\000\170\000\170\000\170\000\170\
\\000\170\000\170\000\170\000\170\000\170\000\170\000\170\000\170\
\\000\170\000\170\000\170\000\000\000\000\000\000\000\000\000\000\
\\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\
\\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\
\\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\
\\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\
\\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\
\\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\
\\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\
\\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\
\\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\
\\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\
\\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\
\\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\
\\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\
\\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\
\\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\
\\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000"
),
 (393,256, 
"\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\
\\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\
\\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\
\\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\
\\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\170\
\\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\
\\000\170\000\170\000\170\000\170\000\170\000\170\000\170\000\170\
\\000\170\000\170\000\000\000\000\000\000\000\000\000\000\000\000\
\\000\000\000\170\000\170\000\170\000\170\000\170\000\170\000\170\
\\000\170\000\170\000\170\000\170\000\170\000\170\000\170\000\170\
\\000\170\000\170\000\170\000\170\001\138\000\170\000\170\000\170\
\\000\170\000\170\000\170\000\000\000\000\000\000\000\000\000\170\
\\000\000\000\170\000\170\000\170\000\170\000\170\000\170\000\170\
\\000\170\000\170\000\170\000\170\000\170\000\170\000\170\000\170\
\\000\170\000\170\000\170\000\170\000\170\000\170\000\170\000\170\
\\000\170\000\170\000\170\000\000\000\000\000\000\000\000\000\000\
\\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\
\\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\
\\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\
\\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\
\\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\
\\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\
\\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\
\\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\
\\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\
\\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\
\\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\
\\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\
\\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\
\\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\
\\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\
\\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000"
),
 (394,256, 
"\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\
\\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\
\\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\
\\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\
\\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\170\
\\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\
\\000\170\000\170\000\170\000\170\000\170\000\170\000\170\000\170\
\\000\170\000\170\000\000\000\000\000\000\000\000\000\000\000\000\
\\000\000\001\139\000\170\000\170\000\170\000\170\000\170\000\170\
\\000\170\000\170\000\170\000\170\000\170\000\170\000\170\000\170\
\\000\170\000\170\000\170\000\170\000\170\000\170\000\170\000\170\
\\000\170\000\170\000\170\000\000\000\000\000\000\000\000\000\170\
\\000\000\000\170\000\170\000\170\000\170\000\170\000\170\000\170\
\\000\170\000\170\000\170\000\170\000\170\000\170\000\170\000\170\
\\000\170\000\170\000\170\000\170\000\170\000\170\000\170\000\170\
\\000\170\000\170\000\170\000\000\000\000\000\000\000\000\000\000\
\\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\
\\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\
\\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\
\\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\
\\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\
\\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\
\\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\
\\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\
\\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\
\\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\
\\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\
\\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\
\\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\
\\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\
\\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\
\\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000"
),
 (395,256, 
"\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\
\\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\
\\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\
\\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\
\\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\170\
\\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\
\\000\170\000\170\000\170\000\170\000\170\000\170\000\170\000\170\
\\000\170\000\170\000\000\000\000\000\000\000\000\000\000\000\000\
\\000\000\000\170\000\170\000\170\000\170\000\170\000\170\000\170\
\\000\170\000\170\000\170\000\170\000\170\001\140\000\170\000\170\
\\000\170\000\170\000\170\000\170\000\170\000\170\000\170\000\170\
\\000\170\000\170\000\170\000\000\000\000\000\000\000\000\000\170\
\\000\000\000\170\000\170\000\170\000\170\000\170\000\170\000\170\
\\000\170\000\170\000\170\000\170\000\170\000\170\000\170\000\170\
\\000\170\000\170\000\170\000\170\000\170\000\170\000\170\000\170\
\\000\170\000\170\000\170\000\000\000\000\000\000\000\000\000\000\
\\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\
\\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\
\\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\
\\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\
\\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\
\\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\
\\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\
\\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\
\\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\
\\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\
\\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\
\\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\
\\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\
\\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\
\\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\
\\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000"
),
 (396,256, 
"\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\
\\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\
\\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\
\\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\
\\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\170\
\\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\
\\000\170\000\170\000\170\000\170\000\170\000\170\000\170\000\170\
\\000\170\000\170\000\000\000\000\000\000\000\000\000\000\000\000\
\\000\000\000\170\000\170\000\170\000\170\000\170\000\170\000\170\
\\000\170\000\170\000\170\000\170\000\170\000\170\000\170\000\170\
\\001\141\000\170\000\170\000\170\000\170\000\170\000\170\000\170\
\\000\170\000\170\000\170\000\000\000\000\000\000\000\000\000\170\
\\000\000\000\170\000\170\000\170\000\170\000\170\000\170\000\170\
\\000\170\000\170\000\170\000\170\000\170\000\170\000\170\000\170\
\\000\170\000\170\000\170\000\170\000\170\000\170\000\170\000\170\
\\000\170\000\170\000\170\000\000\000\000\000\000\000\000\000\000\
\\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\
\\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\
\\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\
\\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\
\\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\
\\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\
\\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\
\\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\
\\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\
\\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\
\\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\
\\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\
\\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\
\\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\
\\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\
\\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000"
),
 (398,256, 
"\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\
\\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\
\\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\
\\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\
\\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\170\
\\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\
\\000\170\000\170\000\170\000\170\000\170\000\170\000\170\000\170\
\\000\170\000\170\000\000\000\000\000\000\000\000\000\000\000\000\
\\000\000\000\170\000\170\000\170\000\170\000\170\000\170\000\170\
\\000\170\000\170\000\170\000\170\000\170\000\170\000\170\001\143\
\\000\170\000\170\000\170\000\170\000\170\000\170\000\170\000\170\
\\000\170\000\170\000\170\000\000\000\000\000\000\000\000\000\170\
\\000\000\000\170\000\170\000\170\000\170\000\170\000\170\000\170\
\\000\170\000\170\000\170\000\170\000\170\000\170\000\170\000\170\
\\000\170\000\170\000\170\000\170\000\170\000\170\000\170\000\170\
\\000\170\000\170\000\170\000\000\000\000\000\000\000\000\000\000\
\\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\
\\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\
\\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\
\\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\
\\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\
\\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\
\\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\
\\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\
\\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\
\\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\
\\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\
\\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\
\\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\
\\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\
\\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\
\\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000"
),
 (399,256, 
"\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\
\\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\
\\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\
\\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\
\\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\170\
\\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\
\\000\170\000\170\000\170\000\170\000\170\000\170\000\170\000\170\
\\000\170\000\170\000\000\000\000\000\000\000\000\000\000\000\000\
\\000\000\000\170\000\170\000\170\000\170\000\170\000\170\000\170\
\\000\170\000\170\000\170\000\170\000\170\000\170\000\170\000\170\
\\000\170\000\170\000\170\001\144\000\170\000\170\000\170\000\170\
\\000\170\000\170\000\170\000\000\000\000\000\000\000\000\000\170\
\\000\000\000\170\000\170\000\170\000\170\000\170\000\170\000\170\
\\000\170\000\170\000\170\000\170\000\170\000\170\000\170\000\170\
\\000\170\000\170\000\170\000\170\000\170\000\170\000\170\000\170\
\\000\170\000\170\000\170\000\000\000\000\000\000\000\000\000\000\
\\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\
\\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\
\\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\
\\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\
\\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\
\\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\
\\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\
\\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\
\\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\
\\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\
\\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\
\\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\
\\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\
\\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\
\\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\
\\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000"
),
 (400,256, 
"\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\
\\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\
\\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\
\\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\
\\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\170\
\\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\
\\000\170\000\170\000\170\000\170\000\170\000\170\000\170\000\170\
\\000\170\000\170\000\000\000\000\000\000\000\000\000\000\000\000\
\\000\000\000\170\000\170\000\170\000\170\000\170\000\170\000\170\
\\000\170\000\170\000\170\000\170\000\170\000\170\000\170\000\170\
\\000\170\000\170\000\170\001\145\000\170\000\170\000\170\000\170\
\\000\170\000\170\000\170\000\000\000\000\000\000\000\000\000\170\
\\000\000\000\170\000\170\000\170\000\170\000\170\000\170\000\170\
\\000\170\000\170\000\170\000\170\000\170\000\170\000\170\000\170\
\\000\170\000\170\000\170\000\170\000\170\000\170\000\170\000\170\
\\000\170\000\170\000\170\000\000\000\000\000\000\000\000\000\000\
\\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\
\\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\
\\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\
\\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\
\\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\
\\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\
\\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\
\\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\
\\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\
\\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\
\\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\
\\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\
\\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\
\\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\
\\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\
\\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000"
),
 (402,256, 
"\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\
\\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\
\\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\
\\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\
\\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\170\
\\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\
\\000\170\000\170\000\170\000\170\000\170\000\170\000\170\000\170\
\\000\170\000\170\000\000\000\000\000\000\000\000\000\000\000\000\
\\000\000\001\158\000\170\000\170\000\170\000\170\000\170\000\170\
\\000\170\000\170\000\170\000\170\000\170\000\170\001\150\000\170\
\\000\170\000\170\000\170\000\170\000\170\001\147\000\170\000\170\
\\000\170\000\170\000\170\000\000\000\000\000\000\000\000\000\170\
\\000\000\000\170\000\170\000\170\000\170\000\170\000\170\000\170\
\\000\170\000\170\000\170\000\170\000\170\000\170\000\170\000\170\
\\000\170\000\170\000\170\000\170\000\170\000\170\000\170\000\170\
\\000\170\000\170\000\170\000\000\000\000\000\000\000\000\000\000\
\\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\
\\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\
\\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\
\\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\
\\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\
\\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\
\\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\
\\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\
\\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\
\\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\
\\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\
\\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\
\\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\
\\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\
\\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\
\\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000"
),
 (403,256, 
"\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\
\\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\
\\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\
\\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\
\\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\170\
\\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\
\\000\170\000\170\000\170\000\170\000\170\000\170\000\170\000\170\
\\000\170\000\170\000\000\000\000\000\000\000\000\000\000\000\000\
\\000\000\000\170\000\170\000\170\000\170\000\170\000\170\000\170\
\\000\170\000\170\000\170\000\170\000\170\000\170\001\148\000\170\
\\000\170\000\170\000\170\000\170\000\170\000\170\000\170\000\170\
\\000\170\000\170\000\170\000\000\000\000\000\000\000\000\000\170\
\\000\000\000\170\000\170\000\170\000\170\000\170\000\170\000\170\
\\000\170\000\170\000\170\000\170\000\170\000\170\000\170\000\170\
\\000\170\000\170\000\170\000\170\000\170\000\170\000\170\000\170\
\\000\170\000\170\000\170\000\000\000\000\000\000\000\000\000\000\
\\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\
\\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\
\\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\
\\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\
\\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\
\\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\
\\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\
\\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\
\\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\
\\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\
\\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\
\\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\
\\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\
\\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\
\\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\
\\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000"
),
 (404,256, 
"\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\
\\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\
\\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\
\\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\
\\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\170\
\\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\
\\000\170\000\170\000\170\000\170\000\170\000\170\000\170\000\170\
\\000\170\000\170\000\000\000\000\000\000\000\000\000\000\000\000\
\\000\000\000\170\000\170\000\170\000\170\000\170\000\170\000\170\
\\000\170\000\170\000\170\000\170\000\170\000\170\000\170\000\170\
\\000\170\000\170\000\170\000\170\001\149\000\170\000\170\000\170\
\\000\170\000\170\000\170\000\000\000\000\000\000\000\000\000\170\
\\000\000\000\170\000\170\000\170\000\170\000\170\000\170\000\170\
\\000\170\000\170\000\170\000\170\000\170\000\170\000\170\000\170\
\\000\170\000\170\000\170\000\170\000\170\000\170\000\170\000\170\
\\000\170\000\170\000\170\000\000\000\000\000\000\000\000\000\000\
\\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\
\\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\
\\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\
\\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\
\\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\
\\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\
\\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\
\\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\
\\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\
\\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\
\\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\
\\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\
\\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\
\\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\
\\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\
\\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000"
),
 (406,256, 
"\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\
\\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\
\\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\
\\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\
\\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\170\
\\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\
\\000\170\000\170\000\170\000\170\000\170\000\170\000\170\000\170\
\\000\170\000\170\000\000\000\000\000\000\000\000\000\000\000\000\
\\000\000\000\170\000\170\000\170\000\170\000\170\000\170\000\170\
\\000\170\000\170\000\170\000\170\000\170\000\170\000\170\000\170\
\\000\170\000\170\000\170\001\151\000\170\000\170\000\170\000\170\
\\000\170\000\170\000\170\000\000\000\000\000\000\000\000\000\170\
\\000\000\000\170\000\170\000\170\000\170\000\170\000\170\000\170\
\\000\170\000\170\000\170\000\170\000\170\000\170\000\170\000\170\
\\000\170\000\170\000\170\000\170\000\170\000\170\000\170\000\170\
\\000\170\000\170\000\170\000\000\000\000\000\000\000\000\000\000\
\\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\
\\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\
\\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\
\\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\
\\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\
\\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\
\\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\
\\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\
\\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\
\\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\
\\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\
\\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\
\\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\
\\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\
\\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\
\\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000"
),
 (407,256, 
"\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\
\\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\
\\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\
\\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\
\\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\170\
\\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\
\\000\170\000\170\000\170\000\170\000\170\000\170\000\170\000\170\
\\000\170\000\170\000\000\000\000\000\000\000\000\000\000\000\000\
\\000\000\000\170\000\170\000\170\000\170\000\170\000\170\000\170\
\\000\170\000\170\000\170\000\170\000\170\000\170\000\170\000\170\
\\000\170\000\170\000\170\000\170\001\152\000\170\000\170\000\170\
\\000\170\000\170\000\170\000\000\000\000\000\000\000\000\000\170\
\\000\000\000\170\000\170\000\170\000\170\000\170\000\170\000\170\
\\000\170\000\170\000\170\000\170\000\170\000\170\000\170\000\170\
\\000\170\000\170\000\170\000\170\000\170\000\170\000\170\000\170\
\\000\170\000\170\000\170\000\000\000\000\000\000\000\000\000\000\
\\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\
\\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\
\\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\
\\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\
\\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\
\\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\
\\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\
\\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\
\\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\
\\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\
\\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\
\\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\
\\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\
\\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\
\\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\
\\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000"
),
 (408,256, 
"\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\
\\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\
\\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\
\\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\
\\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\170\
\\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\
\\000\170\000\170\000\170\000\170\000\170\000\170\000\170\000\170\
\\000\170\000\170\000\000\000\000\000\000\000\000\000\000\000\000\
\\000\000\000\170\000\170\000\170\000\170\000\170\000\170\000\170\
\\000\170\000\170\000\170\000\170\000\170\000\170\000\170\000\170\
\\000\170\000\170\001\153\000\170\000\170\000\170\000\170\000\170\
\\000\170\000\170\000\170\000\000\000\000\000\000\000\000\000\170\
\\000\000\000\170\000\170\000\170\000\170\000\170\000\170\000\170\
\\000\170\000\170\000\170\000\170\000\170\000\170\000\170\000\170\
\\000\170\000\170\000\170\000\170\000\170\000\170\000\170\000\170\
\\000\170\000\170\000\170\000\000\000\000\000\000\000\000\000\000\
\\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\
\\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\
\\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\
\\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\
\\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\
\\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\
\\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\
\\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\
\\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\
\\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\
\\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\
\\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\
\\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\
\\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\
\\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\
\\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000"
),
 (409,256, 
"\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\
\\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\
\\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\
\\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\
\\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\170\
\\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\
\\000\170\000\170\000\170\000\170\000\170\000\170\000\170\000\170\
\\000\170\000\170\000\000\000\000\000\000\000\000\000\000\000\000\
\\000\000\001\154\000\170\000\170\000\170\000\170\000\170\000\170\
\\000\170\000\170\000\170\000\170\000\170\000\170\000\170\000\170\
\\000\170\000\170\000\170\000\170\000\170\000\170\000\170\000\170\
\\000\170\000\170\000\170\000\000\000\000\000\000\000\000\000\170\
\\000\000\000\170\000\170\000\170\000\170\000\170\000\170\000\170\
\\000\170\000\170\000\170\000\170\000\170\000\170\000\170\000\170\
\\000\170\000\170\000\170\000\170\000\170\000\170\000\170\000\170\
\\000\170\000\170\000\170\000\000\000\000\000\000\000\000\000\000\
\\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\
\\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\
\\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\
\\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\
\\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\
\\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\
\\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\
\\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\
\\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\
\\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\
\\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\
\\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\
\\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\
\\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\
\\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\
\\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000"
),
 (410,256, 
"\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\
\\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\
\\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\
\\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\
\\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\170\
\\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\
\\000\170\000\170\000\170\000\170\000\170\000\170\000\170\000\170\
\\000\170\000\170\000\000\000\000\000\000\000\000\000\000\000\000\
\\000\000\000\170\000\170\000\170\000\170\000\170\000\170\000\170\
\\000\170\001\155\000\170\000\170\000\170\000\170\000\170\000\170\
\\000\170\000\170\000\170\000\170\000\170\000\170\000\170\000\170\
\\000\170\000\170\000\170\000\000\000\000\000\000\000\000\000\170\
\\000\000\000\170\000\170\000\170\000\170\000\170\000\170\000\170\
\\000\170\000\170\000\170\000\170\000\170\000\170\000\170\000\170\
\\000\170\000\170\000\170\000\170\000\170\000\170\000\170\000\170\
\\000\170\000\170\000\170\000\000\000\000\000\000\000\000\000\000\
\\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\
\\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\
\\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\
\\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\
\\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\
\\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\
\\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\
\\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\
\\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\
\\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\
\\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\
\\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\
\\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\
\\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\
\\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\
\\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000"
),
 (411,256, 
"\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\
\\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\
\\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\
\\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\
\\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\170\
\\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\
\\000\170\000\170\000\170\000\170\000\170\000\170\000\170\000\170\
\\000\170\000\170\000\000\000\000\000\000\000\000\000\000\000\000\
\\000\000\000\170\000\170\000\170\000\170\000\170\000\170\000\170\
\\000\170\000\170\000\170\000\170\000\170\000\170\001\156\000\170\
\\000\170\000\170\000\170\000\170\000\170\000\170\000\170\000\170\
\\000\170\000\170\000\170\000\000\000\000\000\000\000\000\000\170\
\\000\000\000\170\000\170\000\170\000\170\000\170\000\170\000\170\
\\000\170\000\170\000\170\000\170\000\170\000\170\000\170\000\170\
\\000\170\000\170\000\170\000\170\000\170\000\170\000\170\000\170\
\\000\170\000\170\000\170\000\000\000\000\000\000\000\000\000\000\
\\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\
\\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\
\\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\
\\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\
\\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\
\\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\
\\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\
\\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\
\\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\
\\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\
\\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\
\\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\
\\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\
\\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\
\\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\
\\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000"
),
 (412,256, 
"\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\
\\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\
\\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\
\\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\
\\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\170\
\\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\
\\000\170\000\170\000\170\000\170\000\170\000\170\000\170\000\170\
\\000\170\000\170\000\000\000\000\000\000\000\000\000\000\000\000\
\\000\000\000\170\000\170\000\170\000\170\000\170\000\170\000\170\
\\000\170\000\170\000\170\000\170\000\170\000\170\000\170\000\170\
\\000\170\000\170\000\170\000\170\001\157\000\170\000\170\000\170\
\\000\170\000\170\000\170\000\000\000\000\000\000\000\000\000\170\
\\000\000\000\170\000\170\000\170\000\170\000\170\000\170\000\170\
\\000\170\000\170\000\170\000\170\000\170\000\170\000\170\000\170\
\\000\170\000\170\000\170\000\170\000\170\000\170\000\170\000\170\
\\000\170\000\170\000\170\000\000\000\000\000\000\000\000\000\000\
\\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\
\\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\
\\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\
\\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\
\\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\
\\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\
\\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\
\\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\
\\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\
\\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\
\\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\
\\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\
\\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\
\\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\
\\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\
\\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000"
),
 (414,256, 
"\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\
\\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\
\\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\
\\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\
\\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\170\
\\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\
\\000\170\000\170\000\170\000\170\000\170\000\170\000\170\000\170\
\\000\170\000\170\000\000\000\000\000\000\000\000\000\000\000\000\
\\000\000\000\170\000\170\000\170\000\170\000\170\000\170\000\170\
\\000\170\000\170\000\170\000\170\001\159\000\170\000\170\000\170\
\\000\170\000\170\000\170\000\170\000\170\000\170\000\170\000\170\
\\000\170\000\170\000\170\000\000\000\000\000\000\000\000\000\170\
\\000\000\000\170\000\170\000\170\000\170\000\170\000\170\000\170\
\\000\170\000\170\000\170\000\170\000\170\000\170\000\170\000\170\
\\000\170\000\170\000\170\000\170\000\170\000\170\000\170\000\170\
\\000\170\000\170\000\170\000\000\000\000\000\000\000\000\000\000\
\\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\
\\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\
\\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\
\\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\
\\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\
\\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\
\\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\
\\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\
\\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\
\\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\
\\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\
\\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\
\\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\
\\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\
\\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\
\\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000"
),
 (415,256, 
"\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\
\\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\
\\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\
\\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\
\\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\170\
\\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\
\\000\170\000\170\000\170\000\170\000\170\000\170\000\170\000\170\
\\000\170\000\170\000\000\000\000\000\000\000\000\000\000\000\000\
\\000\000\000\170\000\170\000\170\000\170\001\160\000\170\000\170\
\\000\170\000\170\000\170\000\170\000\170\000\170\000\170\000\170\
\\000\170\000\170\000\170\000\170\000\170\000\170\000\170\000\170\
\\000\170\000\170\000\170\000\000\000\000\000\000\000\000\000\170\
\\000\000\000\170\000\170\000\170\000\170\000\170\000\170\000\170\
\\000\170\000\170\000\170\000\170\000\170\000\170\000\170\000\170\
\\000\170\000\170\000\170\000\170\000\170\000\170\000\170\000\170\
\\000\170\000\170\000\170\000\000\000\000\000\000\000\000\000\000\
\\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\
\\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\
\\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\
\\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\
\\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\
\\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\
\\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\
\\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\
\\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\
\\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\
\\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\
\\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\
\\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\
\\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\
\\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\
\\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000"
),
 (416,256, 
"\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\
\\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\
\\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\
\\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\
\\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\170\
\\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\
\\000\170\000\170\000\170\000\170\000\170\000\170\000\170\000\170\
\\000\170\000\170\000\000\000\000\000\000\000\000\000\000\000\000\
\\000\000\000\170\000\170\000\170\000\170\000\170\000\170\000\170\
\\000\170\000\170\000\170\000\170\000\170\000\170\000\170\000\170\
\\000\170\000\170\000\170\001\161\000\170\000\170\000\170\000\170\
\\000\170\000\170\000\170\000\000\000\000\000\000\000\000\000\170\
\\000\000\000\170\000\170\000\170\000\170\000\170\000\170\000\170\
\\000\170\000\170\000\170\000\170\000\170\000\170\000\170\000\170\
\\000\170\000\170\000\170\000\170\000\170\000\170\000\170\000\170\
\\000\170\000\170\000\170\000\000\000\000\000\000\000\000\000\000\
\\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\
\\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\
\\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\
\\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\
\\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\
\\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\
\\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\
\\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\
\\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\
\\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\
\\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\
\\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\
\\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\
\\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\
\\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\
\\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000"
),
 (417,256, 
"\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\
\\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\
\\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\
\\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\
\\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\170\
\\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\
\\000\170\000\170\000\170\000\170\000\170\000\170\000\170\000\170\
\\000\170\000\170\000\000\000\000\000\000\000\000\000\000\000\000\
\\000\000\000\170\000\170\001\162\000\170\000\170\000\170\000\170\
\\000\170\000\170\000\170\000\170\000\170\000\170\000\170\000\170\
\\000\170\000\170\000\170\000\170\000\170\000\170\000\170\000\170\
\\000\170\000\170\000\170\000\000\000\000\000\000\000\000\000\170\
\\000\000\000\170\000\170\000\170\000\170\000\170\000\170\000\170\
\\000\170\000\170\000\170\000\170\000\170\000\170\000\170\000\170\
\\000\170\000\170\000\170\000\170\000\170\000\170\000\170\000\170\
\\000\170\000\170\000\170\000\000\000\000\000\000\000\000\000\000\
\\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\
\\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\
\\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\
\\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\
\\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\
\\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\
\\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\
\\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\
\\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\
\\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\
\\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\
\\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\
\\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\
\\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\
\\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\
\\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000"
),
 (418,256, 
"\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\
\\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\
\\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\
\\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\
\\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\170\
\\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\
\\000\170\000\170\000\170\000\170\000\170\000\170\000\170\000\170\
\\000\170\000\170\000\000\000\000\000\000\000\000\000\000\000\000\
\\000\000\000\170\000\170\000\170\000\170\001\163\000\170\000\170\
\\000\170\000\170\000\170\000\170\000\170\000\170\000\170\000\170\
\\000\170\000\170\000\170\000\170\000\170\000\170\000\170\000\170\
\\000\170\000\170\000\170\000\000\000\000\000\000\000\000\000\170\
\\000\000\000\170\000\170\000\170\000\170\000\170\000\170\000\170\
\\000\170\000\170\000\170\000\170\000\170\000\170\000\170\000\170\
\\000\170\000\170\000\170\000\170\000\170\000\170\000\170\000\170\
\\000\170\000\170\000\170\000\000\000\000\000\000\000\000\000\000\
\\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\
\\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\
\\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\
\\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\
\\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\
\\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\
\\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\
\\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\
\\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\
\\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\
\\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\
\\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\
\\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\
\\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\
\\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\
\\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000"
),
 (420,256, 
"\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\
\\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\
\\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\
\\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\
\\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\170\
\\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\
\\000\170\000\170\000\170\000\170\000\170\000\170\000\170\000\170\
\\000\170\000\170\000\000\000\000\000\000\000\000\000\000\000\000\
\\000\000\000\170\000\170\000\170\000\170\001\165\000\170\000\170\
\\000\170\000\170\000\170\000\170\000\170\000\170\000\170\000\170\
\\000\170\000\170\000\170\000\170\000\170\000\170\000\170\000\170\
\\000\170\000\170\000\170\000\000\000\000\000\000\000\000\000\170\
\\000\000\000\170\000\170\000\170\000\170\000\170\000\170\000\170\
\\000\170\000\170\000\170\000\170\000\170\000\170\000\170\000\170\
\\000\170\000\170\000\170\000\170\000\170\000\170\000\170\000\170\
\\000\170\000\170\000\170\000\000\000\000\000\000\000\000\000\000\
\\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\
\\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\
\\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\
\\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\
\\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\
\\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\
\\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\
\\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\
\\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\
\\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\
\\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\
\\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\
\\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\
\\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\
\\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\
\\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000"
),
 (421,256, 
"\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\
\\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\
\\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\
\\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\
\\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\170\
\\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\
\\000\170\000\170\000\170\000\170\000\170\000\170\000\170\000\170\
\\000\170\000\170\000\000\000\000\000\000\000\000\000\000\000\000\
\\000\000\000\170\000\170\001\166\000\170\000\170\000\170\000\170\
\\000\170\000\170\000\170\000\170\000\170\000\170\000\170\000\170\
\\000\170\000\170\000\170\000\170\000\170\000\170\000\170\000\170\
\\000\170\000\170\000\170\000\000\000\000\000\000\000\000\000\170\
\\000\000\000\170\000\170\000\170\000\170\000\170\000\170\000\170\
\\000\170\000\170\000\170\000\170\000\170\000\170\000\170\000\170\
\\000\170\000\170\000\170\000\170\000\170\000\170\000\170\000\170\
\\000\170\000\170\000\170\000\000\000\000\000\000\000\000\000\000\
\\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\
\\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\
\\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\
\\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\
\\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\
\\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\
\\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\
\\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\
\\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\
\\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\
\\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\
\\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\
\\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\
\\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\
\\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\
\\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000"
),
 (422,256, 
"\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\
\\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\
\\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\
\\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\
\\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\170\
\\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\
\\000\170\000\170\000\170\000\170\000\170\000\170\000\170\000\170\
\\000\170\000\170\000\000\000\000\000\000\000\000\000\000\000\000\
\\000\000\000\170\000\170\000\170\000\170\000\170\000\170\000\170\
\\000\170\000\170\000\170\001\167\000\170\000\170\000\170\000\170\
\\000\170\000\170\000\170\000\170\000\170\000\170\000\170\000\170\
\\000\170\000\170\000\170\000\000\000\000\000\000\000\000\000\170\
\\000\000\000\170\000\170\000\170\000\170\000\170\000\170\000\170\
\\000\170\000\170\000\170\000\170\000\170\000\170\000\170\000\170\
\\000\170\000\170\000\170\000\170\000\170\000\170\000\170\000\170\
\\000\170\000\170\000\170\000\000\000\000\000\000\000\000\000\000\
\\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\
\\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\
\\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\
\\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\
\\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\
\\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\
\\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\
\\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\
\\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\
\\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\
\\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\
\\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\
\\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\
\\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\
\\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\
\\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000"
),
 (424,256, 
"\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\
\\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\
\\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\
\\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\
\\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\170\
\\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\
\\000\170\000\170\000\170\000\170\000\170\000\170\000\170\000\170\
\\000\170\000\170\000\000\000\000\000\000\000\000\000\000\000\000\
\\000\000\000\170\000\170\000\170\000\170\000\170\000\170\000\170\
\\000\170\000\170\000\170\000\170\000\170\000\170\000\170\000\170\
\\000\170\000\170\000\170\001\169\000\170\000\170\000\170\000\170\
\\000\170\000\170\000\170\000\000\000\000\000\000\000\000\000\170\
\\000\000\000\170\000\170\000\170\000\170\000\170\000\170\000\170\
\\000\170\000\170\000\170\000\170\000\170\000\170\000\170\000\170\
\\000\170\000\170\000\170\000\170\000\170\000\170\000\170\000\170\
\\000\170\000\170\000\170\000\000\000\000\000\000\000\000\000\000\
\\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\
\\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\
\\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\
\\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\
\\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\
\\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\
\\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\
\\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\
\\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\
\\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\
\\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\
\\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\
\\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\
\\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\
\\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\
\\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000"
),
 (425,256, 
"\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\
\\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\
\\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\
\\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\
\\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\170\
\\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\
\\000\170\000\170\000\170\000\170\000\170\000\170\000\170\000\170\
\\000\170\000\170\000\000\000\000\000\000\000\000\000\000\000\000\
\\000\000\000\170\000\170\001\170\000\170\000\170\000\170\000\170\
\\000\170\000\170\000\170\000\170\000\170\000\170\000\170\000\170\
\\000\170\000\170\000\170\000\170\000\170\000\170\000\170\000\170\
\\000\170\000\170\000\170\000\000\000\000\000\000\000\000\000\170\
\\000\000\000\170\000\170\000\170\000\170\000\170\000\170\000\170\
\\000\170\000\170\000\170\000\170\000\170\000\170\000\170\000\170\
\\000\170\000\170\000\170\000\170\000\170\000\170\000\170\000\170\
\\000\170\000\170\000\170\000\000\000\000\000\000\000\000\000\000\
\\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\
\\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\
\\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\
\\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\
\\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\
\\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\
\\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\
\\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\
\\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\
\\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\
\\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\
\\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\
\\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\
\\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\
\\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\
\\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000"
),
 (426,256, 
"\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\
\\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\
\\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\
\\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\
\\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\170\
\\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\
\\000\170\000\170\000\170\000\170\000\170\000\170\000\170\000\170\
\\000\170\000\170\000\000\000\000\000\000\000\000\000\000\000\000\
\\000\000\001\171\000\170\000\170\000\170\000\170\000\170\000\170\
\\000\170\000\170\000\170\000\170\000\170\000\170\000\170\000\170\
\\000\170\000\170\000\170\000\170\000\170\000\170\000\170\000\170\
\\000\170\000\170\000\170\000\000\000\000\000\000\000\000\000\170\
\\000\000\000\170\000\170\000\170\000\170\000\170\000\170\000\170\
\\000\170\000\170\000\170\000\170\000\170\000\170\000\170\000\170\
\\000\170\000\170\000\170\000\170\000\170\000\170\000\170\000\170\
\\000\170\000\170\000\170\000\000\000\000\000\000\000\000\000\000\
\\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\
\\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\
\\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\
\\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\
\\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\
\\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\
\\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\
\\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\
\\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\
\\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\
\\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\
\\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\
\\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\
\\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\
\\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\
\\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000"
),
 (427,256, 
"\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\
\\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\
\\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\
\\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\
\\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\170\
\\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\
\\000\170\000\170\000\170\000\170\000\170\000\170\000\170\000\170\
\\000\170\000\170\000\000\000\000\000\000\000\000\000\000\000\000\
\\000\000\000\170\000\170\000\170\001\172\000\170\000\170\000\170\
\\000\170\000\170\000\170\000\170\000\170\000\170\000\170\000\170\
\\000\170\000\170\000\170\000\170\000\170\000\170\000\170\000\170\
\\000\170\000\170\000\170\000\000\000\000\000\000\000\000\000\170\
\\000\000\000\170\000\170\000\170\000\170\000\170\000\170\000\170\
\\000\170\000\170\000\170\000\170\000\170\000\170\000\170\000\170\
\\000\170\000\170\000\170\000\170\000\170\000\170\000\170\000\170\
\\000\170\000\170\000\170\000\000\000\000\000\000\000\000\000\000\
\\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\
\\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\
\\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\
\\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\
\\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\
\\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\
\\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\
\\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\
\\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\
\\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\
\\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\
\\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\
\\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\
\\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\
\\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\
\\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000"
),
 (428,256, 
"\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\
\\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\
\\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\
\\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\
\\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\170\
\\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\
\\000\170\000\170\000\170\000\170\000\170\000\170\000\170\000\170\
\\000\170\000\170\000\000\000\000\000\000\000\000\000\000\000\000\
\\000\000\000\170\000\170\000\170\000\170\001\173\000\170\000\170\
\\000\170\000\170\000\170\000\170\000\170\000\170\000\170\000\170\
\\000\170\000\170\000\170\000\170\000\170\000\170\000\170\000\170\
\\000\170\000\170\000\170\000\000\000\000\000\000\000\000\000\170\
\\000\000\000\170\000\170\000\170\000\170\000\170\000\170\000\170\
\\000\170\000\170\000\170\000\170\000\170\000\170\000\170\000\170\
\\000\170\000\170\000\170\000\170\000\170\000\170\000\170\000\170\
\\000\170\000\170\000\170\000\000\000\000\000\000\000\000\000\000\
\\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\
\\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\
\\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\
\\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\
\\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\
\\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\
\\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\
\\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\
\\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\
\\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\
\\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\
\\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\
\\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\
\\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\
\\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\
\\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000"
),
 (430,256, 
"\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\
\\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\
\\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\
\\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\
\\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\170\
\\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\
\\000\170\000\170\000\170\000\170\000\170\000\170\000\170\000\170\
\\000\170\000\170\000\000\000\000\000\000\000\000\000\000\000\000\
\\000\000\000\170\000\170\000\170\000\170\000\170\000\170\000\170\
\\000\170\000\170\000\170\000\170\000\170\000\170\000\170\000\170\
\\000\170\000\170\000\170\000\170\000\170\000\170\000\170\000\170\
\\000\170\001\175\000\170\000\000\000\000\000\000\000\000\000\170\
\\000\000\000\170\000\170\000\170\000\170\000\170\000\170\000\170\
\\000\170\000\170\000\170\000\170\000\170\000\170\000\170\000\170\
\\000\170\000\170\000\170\000\170\000\170\000\170\000\170\000\170\
\\000\170\000\170\000\170\000\000\000\000\000\000\000\000\000\000\
\\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\
\\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\
\\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\
\\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\
\\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\
\\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\
\\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\
\\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\
\\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\
\\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\
\\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\
\\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\
\\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\
\\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\
\\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\
\\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000"
),
 (432,256, 
"\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\
\\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\
\\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\
\\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\
\\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\170\
\\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\
\\000\170\000\170\000\170\000\170\000\170\000\170\000\170\000\170\
\\000\170\000\170\000\000\000\000\000\000\000\000\000\000\000\000\
\\000\000\000\170\000\170\001\185\000\170\000\170\000\170\000\170\
\\000\170\000\170\000\170\000\170\001\183\000\170\001\181\000\170\
\\000\170\000\170\000\170\001\179\000\170\000\170\001\177\000\170\
\\000\170\000\170\000\170\000\000\000\000\000\000\000\000\000\170\
\\000\000\000\170\000\170\000\170\000\170\000\170\000\170\000\170\
\\000\170\000\170\000\170\000\170\000\170\000\170\000\170\000\170\
\\000\170\000\170\000\170\000\170\000\170\000\170\000\170\000\170\
\\000\170\000\170\000\170\000\000\000\000\000\000\000\000\000\000\
\\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\
\\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\
\\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\
\\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\
\\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\
\\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\
\\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\
\\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\
\\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\
\\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\
\\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\
\\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\
\\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\
\\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\
\\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\
\\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000"
),
 (433,256, 
"\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\
\\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\
\\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\
\\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\
\\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\170\
\\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\
\\000\170\000\170\000\170\000\170\000\170\000\170\000\170\000\170\
\\000\170\000\170\000\000\000\000\000\000\000\000\000\000\000\000\
\\000\000\000\170\000\170\000\170\000\170\000\170\000\170\001\178\
\\000\170\000\170\000\170\000\170\000\170\000\170\000\170\000\170\
\\000\170\000\170\000\170\000\170\000\170\000\170\000\170\000\170\
\\000\170\000\170\000\170\000\000\000\000\000\000\000\000\000\170\
\\000\000\000\170\000\170\000\170\000\170\000\170\000\170\000\170\
\\000\170\000\170\000\170\000\170\000\170\000\170\000\170\000\170\
\\000\170\000\170\000\170\000\170\000\170\000\170\000\170\000\170\
\\000\170\000\170\000\170\000\000\000\000\000\000\000\000\000\000\
\\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\
\\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\
\\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\
\\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\
\\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\
\\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\
\\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\
\\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\
\\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\
\\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\
\\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\
\\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\
\\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\
\\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\
\\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\
\\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000"
),
 (435,256, 
"\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\
\\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\
\\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\
\\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\
\\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\170\
\\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\
\\000\170\000\170\000\170\000\170\000\170\000\170\000\170\000\170\
\\000\170\000\170\000\000\000\000\000\000\000\000\000\000\000\000\
\\000\000\000\170\000\170\001\180\000\170\000\170\000\170\000\170\
\\000\170\000\170\000\170\000\170\000\170\000\170\000\170\000\170\
\\000\170\000\170\000\170\000\170\000\170\000\170\000\170\000\170\
\\000\170\000\170\000\170\000\000\000\000\000\000\000\000\000\170\
\\000\000\000\170\000\170\000\170\000\170\000\170\000\170\000\170\
\\000\170\000\170\000\170\000\170\000\170\000\170\000\170\000\170\
\\000\170\000\170\000\170\000\170\000\170\000\170\000\170\000\170\
\\000\170\000\170\000\170\000\000\000\000\000\000\000\000\000\000\
\\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\
\\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\
\\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\
\\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\
\\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\
\\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\
\\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\
\\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\
\\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\
\\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\
\\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\
\\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\
\\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\
\\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\
\\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\
\\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000"
),
 (437,256, 
"\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\
\\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\
\\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\
\\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\
\\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\170\
\\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\
\\000\170\000\170\000\170\000\170\000\170\000\170\000\170\000\170\
\\000\170\000\170\000\000\000\000\000\000\000\000\000\000\000\000\
\\000\000\000\170\000\170\000\170\001\182\000\170\000\170\000\170\
\\000\170\000\170\000\170\000\170\000\170\000\170\000\170\000\170\
\\000\170\000\170\000\170\000\170\000\170\000\170\000\170\000\170\
\\000\170\000\170\000\170\000\000\000\000\000\000\000\000\000\170\
\\000\000\000\170\000\170\000\170\000\170\000\170\000\170\000\170\
\\000\170\000\170\000\170\000\170\000\170\000\170\000\170\000\170\
\\000\170\000\170\000\170\000\170\000\170\000\170\000\170\000\170\
\\000\170\000\170\000\170\000\000\000\000\000\000\000\000\000\000\
\\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\
\\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\
\\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\
\\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\
\\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\
\\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\
\\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\
\\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\
\\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\
\\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\
\\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\
\\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\
\\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\
\\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\
\\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\
\\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000"
),
 (439,256, 
"\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\
\\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\
\\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\
\\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\
\\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\170\
\\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\
\\000\170\000\170\000\170\000\170\000\170\000\170\000\170\000\170\
\\000\170\000\170\000\000\000\000\000\000\000\000\000\000\000\000\
\\000\000\000\170\000\170\000\170\000\170\000\170\000\170\000\170\
\\000\170\000\170\000\170\000\170\001\184\000\170\000\170\000\170\
\\000\170\000\170\000\170\000\170\000\170\000\170\000\170\000\170\
\\000\170\000\170\000\170\000\000\000\000\000\000\000\000\000\170\
\\000\000\000\170\000\170\000\170\000\170\000\170\000\170\000\170\
\\000\170\000\170\000\170\000\170\000\170\000\170\000\170\000\170\
\\000\170\000\170\000\170\000\170\000\170\000\170\000\170\000\170\
\\000\170\000\170\000\170\000\000\000\000\000\000\000\000\000\000\
\\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\
\\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\
\\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\
\\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\
\\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\
\\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\
\\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\
\\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\
\\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\
\\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\
\\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\
\\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\
\\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\
\\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\
\\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\
\\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000"
),
 (441,256, 
"\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\
\\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\
\\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\
\\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\
\\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\170\
\\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\
\\000\170\000\170\000\170\000\170\000\170\000\170\000\170\000\170\
\\000\170\000\170\000\000\000\000\000\000\000\000\000\000\000\000\
\\000\000\000\170\000\170\000\170\000\170\000\170\000\170\000\170\
\\000\170\000\170\000\170\000\170\000\170\000\170\000\170\000\170\
\\000\170\000\170\000\170\000\170\001\186\000\170\000\170\000\170\
\\000\170\000\170\000\170\000\000\000\000\000\000\000\000\000\170\
\\000\000\000\170\000\170\000\170\000\170\000\170\000\170\000\170\
\\000\170\000\170\000\170\000\170\000\170\000\170\000\170\000\170\
\\000\170\000\170\000\170\000\170\000\170\000\170\000\170\000\170\
\\000\170\000\170\000\170\000\000\000\000\000\000\000\000\000\000\
\\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\
\\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\
\\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\
\\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\
\\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\
\\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\
\\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\
\\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\
\\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\
\\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\
\\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\
\\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\
\\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\
\\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\
\\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\
\\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000"
),
 (442,256, 
"\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\
\\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\
\\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\
\\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\
\\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\170\
\\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\
\\000\170\000\170\000\170\000\170\000\170\000\170\000\170\000\170\
\\000\170\000\170\000\000\000\000\000\000\000\000\000\000\000\000\
\\000\000\000\170\000\170\000\170\000\170\000\170\000\170\000\170\
\\000\170\001\187\000\170\000\170\000\170\000\170\000\170\000\170\
\\000\170\000\170\000\170\000\170\000\170\000\170\000\170\000\170\
\\000\170\000\170\000\170\000\000\000\000\000\000\000\000\000\170\
\\000\000\000\170\000\170\000\170\000\170\000\170\000\170\000\170\
\\000\170\000\170\000\170\000\170\000\170\000\170\000\170\000\170\
\\000\170\000\170\000\170\000\170\000\170\000\170\000\170\000\170\
\\000\170\000\170\000\170\000\000\000\000\000\000\000\000\000\000\
\\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\
\\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\
\\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\
\\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\
\\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\
\\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\
\\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\
\\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\
\\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\
\\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\
\\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\
\\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\
\\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\
\\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\
\\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\
\\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000"
),
 (443,256, 
"\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\
\\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\
\\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\
\\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\
\\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\170\
\\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\
\\000\170\000\170\000\170\000\170\000\170\000\170\000\170\000\170\
\\000\170\000\170\000\000\000\000\000\000\000\000\000\000\000\000\
\\000\000\000\170\000\170\000\170\000\170\000\170\000\170\000\170\
\\000\170\000\170\000\170\000\170\000\170\000\170\000\170\001\188\
\\000\170\000\170\000\170\000\170\000\170\000\170\000\170\000\170\
\\000\170\000\170\000\170\000\000\000\000\000\000\000\000\000\170\
\\000\000\000\170\000\170\000\170\000\170\000\170\000\170\000\170\
\\000\170\000\170\000\170\000\170\000\170\000\170\000\170\000\170\
\\000\170\000\170\000\170\000\170\000\170\000\170\000\170\000\170\
\\000\170\000\170\000\170\000\000\000\000\000\000\000\000\000\000\
\\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\
\\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\
\\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\
\\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\
\\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\
\\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\
\\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\
\\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\
\\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\
\\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\
\\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\
\\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\
\\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\
\\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\
\\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\
\\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000"
),
 (444,256, 
"\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\
\\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\
\\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\
\\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\
\\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\170\
\\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\
\\000\170\000\170\000\170\000\170\000\170\000\170\000\170\000\170\
\\000\170\000\170\000\000\000\000\000\000\000\000\000\000\000\000\
\\000\000\000\170\000\170\000\170\000\170\000\170\000\170\000\170\
\\000\170\000\170\000\170\000\170\000\170\000\170\001\189\000\170\
\\000\170\000\170\000\170\000\170\000\170\000\170\000\170\000\170\
\\000\170\000\170\000\170\000\000\000\000\000\000\000\000\000\170\
\\000\000\000\170\000\170\000\170\000\170\000\170\000\170\000\170\
\\000\170\000\170\000\170\000\170\000\170\000\170\000\170\000\170\
\\000\170\000\170\000\170\000\170\000\170\000\170\000\170\000\170\
\\000\170\000\170\000\170\000\000\000\000\000\000\000\000\000\000\
\\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\
\\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\
\\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\
\\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\
\\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\
\\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\
\\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\
\\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\
\\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\
\\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\
\\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\
\\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\
\\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\
\\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\
\\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\
\\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000"
),
 (447,256, 
"\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\
\\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\
\\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\
\\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\
\\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\
\\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\
\\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\
\\000\000\000\000\000\000\000\000\000\000\001\194\001\192\000\000\
\\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\
\\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\
\\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\
\\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\
\\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\
\\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\
\\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\
\\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\
\\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\
\\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\
\\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\
\\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\
\\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\
\\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\
\\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\
\\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\
\\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\
\\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\
\\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\
\\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\
\\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\
\\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\
\\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\
\\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000"
),
 (448,256, 
"\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\
\\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\
\\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\
\\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\
\\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\
\\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\
\\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\
\\000\000\000\000\000\000\000\000\000\000\000\000\001\193\000\000\
\\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\
\\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\
\\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\
\\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\
\\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\
\\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\
\\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\
\\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\
\\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\
\\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\
\\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\
\\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\
\\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\
\\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\
\\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\
\\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\
\\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\
\\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\
\\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\
\\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\
\\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\
\\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\
\\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\
\\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000"
),
 (451,256, 
"\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\
\\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\
\\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\
\\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\
\\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\
\\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\
\\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\
\\000\000\000\000\000\000\000\000\000\000\001\197\001\196\000\000\
\\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\
\\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\
\\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\
\\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\
\\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\
\\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\
\\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\
\\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\
\\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\
\\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\
\\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\
\\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\
\\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\
\\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\
\\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\
\\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\
\\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\
\\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\
\\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\
\\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\
\\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\
\\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\
\\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\
\\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000"
),
 (453,256, 
"\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\
\\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\
\\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\
\\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\
\\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\
\\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\
\\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\
\\000\000\000\000\000\000\000\000\000\000\000\000\001\198\000\000\
\\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\
\\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\
\\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\
\\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\
\\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\
\\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\
\\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\
\\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\
\\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\
\\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\
\\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\
\\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\
\\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\
\\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\
\\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\
\\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\
\\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\
\\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\
\\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\
\\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\
\\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\
\\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\
\\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\
\\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000"
),
 (455,256, 
"\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\
\\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\
\\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\
\\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\
\\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\
\\000\000\000\000\000\000\000\000\000\000\001\209\000\000\000\000\
\\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\
\\000\000\000\000\000\000\000\000\001\207\001\206\001\205\000\000\
\\000\000\001\201\001\201\001\201\001\201\001\201\001\201\001\201\
\\001\201\001\201\001\201\001\201\001\201\001\201\001\201\001\201\
\\001\201\001\201\001\201\001\201\001\201\001\201\001\201\001\201\
\\001\201\001\201\001\201\000\000\000\000\000\000\000\000\000\000\
\\000\000\001\201\001\201\001\201\001\201\001\201\001\201\001\201\
\\001\201\001\201\001\201\001\201\001\201\001\201\001\201\001\201\
\\001\201\001\201\001\201\001\201\001\201\001\201\001\201\001\201\
\\001\201\001\201\001\201\000\000\001\200\000\000\000\000\000\000\
\\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\
\\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\
\\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\
\\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\
\\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\
\\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\
\\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\
\\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\
\\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\
\\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\
\\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\
\\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\
\\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\
\\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\
\\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\
\\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000"
),
 (457,256, 
"\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\
\\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\
\\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\
\\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\
\\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\
\\000\000\000\000\000\000\000\000\000\000\001\201\000\000\001\203\
\\001\201\001\201\001\201\001\201\001\201\001\201\001\201\001\201\
\\001\201\001\201\000\000\000\000\000\000\000\000\001\202\000\000\
\\000\000\001\201\001\201\001\201\001\201\001\201\001\201\001\201\
\\001\201\001\201\001\201\001\201\001\201\001\201\001\201\001\201\
\\001\201\001\201\001\201\001\201\001\201\001\201\001\201\001\201\
\\001\201\001\201\001\201\000\000\000\000\000\000\000\000\001\201\
\\000\000\001\201\001\201\001\201\001\201\001\201\001\201\001\201\
\\001\201\001\201\001\201\001\201\001\201\001\201\001\201\001\201\
\\001\201\001\201\001\201\001\201\001\201\001\201\001\201\001\201\
\\001\201\001\201\001\201\000\000\000\000\000\000\000\000\000\000\
\\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\
\\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\
\\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\
\\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\
\\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\
\\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\
\\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\
\\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\
\\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\
\\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\
\\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\
\\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\
\\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\
\\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\
\\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\
\\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000"
),
 (459,256, 
"\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\
\\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\
\\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\
\\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\
\\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\
\\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\
\\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\
\\000\000\000\000\000\000\000\000\000\000\000\000\001\204\000\000\
\\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\
\\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\
\\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\
\\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\
\\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\
\\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\
\\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\
\\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\
\\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\
\\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\
\\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\
\\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\
\\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\
\\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\
\\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\
\\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\
\\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\
\\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\
\\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\
\\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\
\\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\
\\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\
\\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\
\\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000"
),
 (463,256, 
"\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\
\\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\
\\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\
\\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\
\\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\
\\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\
\\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\
\\000\000\000\000\000\000\000\000\001\208\000\000\000\000\000\000\
\\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\
\\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\
\\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\
\\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\
\\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\
\\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\
\\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\
\\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\
\\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\
\\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\
\\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\
\\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\
\\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\
\\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\
\\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\
\\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\
\\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\
\\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\
\\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\
\\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\
\\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\
\\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\
\\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\
\\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000"
),
 (467,256, 
"\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\
\\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\
\\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\
\\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\
\\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\
\\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\
\\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\
\\000\000\000\000\001\212\000\000\000\000\000\000\000\000\000\000\
\\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\
\\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\
\\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\
\\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\
\\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\
\\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\
\\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\
\\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\
\\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\
\\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\
\\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\
\\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\
\\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\
\\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\
\\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\
\\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\
\\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\
\\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\
\\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\
\\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\
\\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\
\\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\
\\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\
\\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000"
),
 (468,256, 
"\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\
\\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\
\\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\
\\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\
\\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\
\\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\
\\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\
\\000\000\000\000\001\214\000\000\000\000\000\000\000\000\000\000\
\\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\
\\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\
\\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\
\\000\000\000\000\000\000\000\000\000\000\000\000\000\000\001\213\
\\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\
\\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\
\\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\
\\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\
\\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\
\\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\
\\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\
\\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\
\\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\
\\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\
\\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\
\\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\
\\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\
\\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\
\\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\
\\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\
\\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\
\\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\
\\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\
\\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000"
),
 (470,256, 
"\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\
\\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\
\\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\
\\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\
\\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\
\\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\
\\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\
\\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\
\\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\
\\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\
\\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\
\\000\000\000\000\000\000\000\000\000\000\000\000\000\000\001\215\
\\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\
\\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\
\\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\
\\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\
\\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\
\\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\
\\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\
\\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\
\\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\
\\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\
\\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\
\\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\
\\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\
\\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\
\\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\
\\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\
\\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\
\\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\
\\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\
\\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000"
),
 (472,256, 
"\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\
\\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\
\\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\
\\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\
\\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\
\\000\000\000\000\000\000\000\000\000\000\000\000\001\218\000\000\
\\001\217\001\217\001\217\001\217\001\217\001\217\001\217\001\217\
\\001\217\001\217\000\000\000\000\000\000\000\000\000\000\000\000\
\\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\
\\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\
\\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\
\\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\
\\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\
\\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\
\\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\
\\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\
\\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\
\\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\
\\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\
\\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\
\\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\
\\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\
\\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\
\\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\
\\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\
\\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\
\\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\
\\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\
\\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\
\\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\
\\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\
\\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000"
),
 (474,256, 
"\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\
\\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\
\\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\
\\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\
\\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\
\\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\
\\001\218\001\218\001\218\001\218\001\218\001\218\001\218\001\218\
\\001\218\001\218\000\000\000\000\000\000\000\000\000\000\000\000\
\\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\
\\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\
\\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\
\\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\
\\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\
\\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\
\\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\
\\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\
\\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\
\\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\
\\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\
\\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\
\\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\
\\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\
\\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\
\\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\
\\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\
\\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\
\\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\
\\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\
\\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\
\\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\
\\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\
\\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000"
),
 (475,256, 
"\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\
\\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\
\\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\
\\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\
\\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\
\\000\000\000\000\000\000\000\000\000\000\000\000\001\218\000\000\
\\001\217\001\217\001\217\001\217\001\217\001\217\001\217\001\217\
\\001\217\001\217\000\000\000\000\000\000\000\000\000\000\000\000\
\\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\
\\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\
\\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\
\\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\
\\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\
\\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\
\\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\
\\001\220\000\000\000\000\000\000\000\000\000\000\000\000\000\000\
\\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\
\\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\
\\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\
\\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\
\\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\
\\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\
\\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\
\\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\
\\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\
\\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\
\\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\
\\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\
\\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\
\\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\
\\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\
\\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000"
),
 (476,256, 
"\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\
\\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\
\\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\
\\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\
\\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\
\\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\
\\001\221\001\221\001\221\001\221\001\221\001\221\001\221\001\221\
\\001\221\001\221\000\000\000\000\000\000\000\000\000\000\000\000\
\\000\000\001\221\001\221\001\221\001\221\001\221\001\221\000\000\
\\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\
\\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\
\\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\
\\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\
\\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\
\\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\
\\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\
\\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\
\\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\
\\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\
\\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\
\\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\
\\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\
\\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\
\\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\
\\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\
\\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\
\\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\
\\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\
\\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\
\\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\
\\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\
\\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000"
),
 (479,256, 
"\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\
\\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\
\\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\
\\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\
\\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\
\\000\000\000\000\000\000\000\000\000\000\000\000\001\224\000\000\
\\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\
\\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\
\\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\
\\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\
\\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\
\\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\
\\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\
\\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\
\\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\
\\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\
\\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\
\\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\
\\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\
\\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\
\\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\
\\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\
\\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\
\\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\
\\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\
\\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\
\\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\
\\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\
\\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\
\\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\
\\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\
\\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000"
),
 (480,256, 
"\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\
\\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\
\\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\
\\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\
\\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\
\\000\000\000\000\000\000\000\000\000\000\000\000\001\225\000\000\
\\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\
\\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\
\\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\
\\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\
\\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\
\\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\
\\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\
\\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\
\\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\
\\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\
\\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\
\\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\
\\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\
\\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\
\\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\
\\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\
\\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\
\\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\
\\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\
\\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\
\\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\
\\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\
\\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\
\\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\
\\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\
\\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000"
),
 (482,256, 
"\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\
\\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\
\\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\
\\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\
\\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\
\\000\000\000\000\000\000\000\000\000\000\001\228\000\000\000\000\
\\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\
\\000\000\000\000\000\000\000\000\000\000\000\000\001\227\000\000\
\\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\
\\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\
\\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\
\\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\
\\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\
\\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\
\\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\
\\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\
\\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\
\\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\
\\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\
\\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\
\\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\
\\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\
\\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\
\\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\
\\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\
\\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\
\\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\
\\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\
\\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\
\\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\
\\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\
\\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000"
),
 (484,256, 
"\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\
\\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\
\\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\
\\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\
\\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\
\\000\000\000\000\000\000\000\000\000\000\001\230\000\000\000\000\
\\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\
\\000\000\000\000\000\000\000\000\000\000\000\000\001\229\000\000\
\\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\
\\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\
\\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\
\\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\
\\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\
\\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\
\\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\
\\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\
\\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\
\\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\
\\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\
\\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\
\\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\
\\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\
\\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\
\\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\
\\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\
\\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\
\\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\
\\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\
\\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\
\\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\
\\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\
\\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000"
),
 (488,256, 
"\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\
\\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\
\\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\
\\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\
\\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\
\\000\000\000\000\000\000\001\233\000\000\000\000\000\000\000\000\
\\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\
\\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\
\\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\
\\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\
\\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\
\\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\
\\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\
\\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\
\\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\
\\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\
\\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\
\\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\
\\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\
\\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\
\\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\
\\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\
\\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\
\\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\
\\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\
\\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\
\\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\
\\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\
\\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\
\\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\
\\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\
\\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000"
),
 (490,256, 
"\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\
\\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\
\\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\
\\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\
\\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\
\\000\000\001\235\000\000\000\000\000\000\000\000\000\000\000\000\
\\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\
\\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\
\\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\
\\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\
\\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\
\\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\
\\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\
\\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\
\\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\
\\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\
\\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\
\\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\
\\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\
\\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\
\\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\
\\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\
\\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\
\\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\
\\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\
\\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\
\\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\
\\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\
\\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\
\\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\
\\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\
\\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000"
),
 (493,256, 
"\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\
\\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\
\\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\
\\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\
\\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\
\\000\000\001\239\001\238\000\000\000\000\000\000\000\000\000\000\
\\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\
\\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\
\\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\
\\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\
\\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\
\\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\
\\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\
\\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\
\\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\
\\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\
\\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\
\\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\
\\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\
\\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\
\\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\
\\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\
\\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\
\\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\
\\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\
\\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\
\\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\
\\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\
\\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\
\\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\
\\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\
\\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000"
),
 (497,256, 
"\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\
\\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\
\\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\
\\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\
\\000\000\000\000\000\000\000\000\000\000\000\000\001\242\000\000\
\\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\
\\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\
\\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\
\\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\
\\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\
\\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\
\\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\
\\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\
\\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\
\\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\
\\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\
\\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\
\\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\
\\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\
\\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\
\\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\
\\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\
\\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\
\\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\
\\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\
\\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\
\\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\
\\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\
\\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\
\\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\
\\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\
\\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000"
),
 (501,256, 
"\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\
\\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\
\\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\
\\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\
\\000\000\000\000\001\246\000\000\000\000\000\000\000\000\000\000\
\\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\
\\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\
\\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\
\\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\
\\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\
\\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\
\\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\
\\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\
\\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\
\\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\
\\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\
\\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\
\\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\
\\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\
\\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\
\\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\
\\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\
\\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\
\\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\
\\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\
\\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\
\\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\
\\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\
\\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\
\\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\
\\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\
\\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000"
),
 (505,256, 
"\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\
\\000\000\001\250\000\000\000\000\001\250\001\250\000\000\000\000\
\\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\
\\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\
\\001\250\000\000\000\000\000\000\000\000\000\000\000\000\000\000\
\\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\
\\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\
\\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\
\\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\
\\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\
\\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\
\\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\
\\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\
\\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\
\\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\
\\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\
\\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\
\\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\
\\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\
\\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\
\\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\
\\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\
\\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\
\\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\
\\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\
\\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\
\\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\
\\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\
\\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\
\\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\
\\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\
\\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000"
),
 (509,256, 
"\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\
\\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\
\\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\
\\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\
\\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\
\\000\000\001\254\000\000\000\000\000\000\000\000\000\000\000\000\
\\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\
\\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\
\\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\
\\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\
\\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\
\\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\
\\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\
\\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\
\\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\
\\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\
\\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\
\\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\
\\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\
\\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\
\\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\
\\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\
\\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\
\\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\
\\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\
\\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\
\\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\
\\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\
\\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\
\\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\
\\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\
\\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000"
),
 (511,256, 
"\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\
\\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\
\\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\
\\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\
\\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\
\\000\000\000\000\002\000\000\000\000\000\000\000\000\000\000\000\
\\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\
\\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\
\\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\
\\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\
\\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\
\\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\
\\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\
\\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\
\\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\
\\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\
\\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\
\\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\
\\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\
\\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\
\\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\
\\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\
\\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\
\\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\
\\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\
\\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\
\\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\
\\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\
\\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\
\\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\
\\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\
\\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000"
),
 (514,256, 
"\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\
\\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\
\\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\
\\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\
\\000\000\000\000\002\014\000\000\000\000\000\000\000\000\002\013\
\\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\
\\002\010\002\010\002\010\002\010\002\010\002\010\002\010\002\010\
\\002\010\002\010\000\000\000\000\000\000\000\000\000\000\000\000\
\\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\
\\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\
\\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\
\\000\000\000\000\000\000\000\000\002\009\000\000\000\000\000\000\
\\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\
\\000\000\000\000\000\000\000\000\000\000\000\000\002\008\000\000\
\\000\000\000\000\002\007\000\000\002\006\000\000\000\000\000\000\
\\002\003\000\000\000\000\000\000\000\000\000\000\000\000\000\000\
\\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\
\\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\
\\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\
\\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\
\\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\
\\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\
\\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\
\\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\
\\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\
\\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\
\\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\
\\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\
\\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\
\\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\
\\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\
\\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000"
),
 (515,256, 
"\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\
\\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\
\\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\
\\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\
\\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\
\\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\
\\002\004\002\004\002\004\002\004\002\004\002\004\002\004\002\004\
\\002\004\002\004\000\000\000\000\000\000\000\000\000\000\000\000\
\\000\000\002\004\002\004\002\004\002\004\002\004\002\004\000\000\
\\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\
\\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\
\\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\
\\000\000\002\004\002\004\002\004\002\004\002\004\002\004\000\000\
\\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\
\\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\
\\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\
\\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\
\\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\
\\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\
\\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\
\\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\
\\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\
\\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\
\\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\
\\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\
\\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\
\\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\
\\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\
\\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\
\\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\
\\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\
\\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000"
),
 (516,256, 
"\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\
\\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\
\\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\
\\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\
\\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\
\\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\
\\002\005\002\005\002\005\002\005\002\005\002\005\002\005\002\005\
\\002\005\002\005\000\000\000\000\000\000\000\000\000\000\000\000\
\\000\000\002\005\002\005\002\005\002\005\002\005\002\005\000\000\
\\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\
\\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\
\\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\
\\000\000\002\005\002\005\002\005\002\005\002\005\002\005\000\000\
\\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\
\\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\
\\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\
\\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\
\\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\
\\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\
\\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\
\\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\
\\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\
\\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\
\\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\
\\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\
\\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\
\\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\
\\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\
\\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\
\\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\
\\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\
\\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000"
),
 (522,256, 
"\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\
\\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\
\\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\
\\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\
\\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\
\\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\
\\002\011\002\011\002\011\002\011\002\011\002\011\002\011\002\011\
\\002\011\002\011\000\000\000\000\000\000\000\000\000\000\000\000\
\\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\
\\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\
\\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\
\\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\
\\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\
\\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\
\\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\
\\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\
\\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\
\\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\
\\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\
\\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\
\\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\
\\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\
\\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\
\\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\
\\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\
\\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\
\\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\
\\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\
\\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\
\\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\
\\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\
\\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000"
),
 (523,256, 
"\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\
\\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\
\\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\
\\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\
\\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\
\\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\
\\002\012\002\012\002\012\002\012\002\012\002\012\002\012\002\012\
\\002\012\002\012\000\000\000\000\000\000\000\000\000\000\000\000\
\\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\
\\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\
\\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\
\\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\
\\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\
\\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\
\\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\
\\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\
\\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\
\\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\
\\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\
\\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\
\\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\
\\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\
\\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\
\\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\
\\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\
\\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\
\\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\
\\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\
\\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\
\\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\
\\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\
\\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000"
),
 (530,256, 
"\002\019\002\019\002\019\002\019\002\019\002\019\002\019\002\019\
\\002\019\002\019\000\000\002\019\002\019\002\019\002\019\002\019\
\\002\019\002\019\002\019\002\019\002\019\002\019\002\019\002\019\
\\002\019\002\019\002\019\002\019\002\019\002\019\002\019\002\019\
\\002\019\002\019\002\019\002\019\002\019\002\019\002\019\002\019\
\\002\020\002\019\002\019\002\019\002\019\002\019\002\019\002\019\
\\002\019\002\019\002\019\002\019\002\019\002\019\002\019\002\019\
\\002\019\002\019\002\019\002\019\000\000\002\019\002\019\002\019\
\\002\019\002\019\002\019\002\019\002\019\002\019\002\019\002\019\
\\002\019\002\019\002\019\002\019\002\019\002\019\002\019\002\019\
\\002\019\002\019\002\019\002\019\002\019\002\019\002\019\002\019\
\\002\019\002\019\002\019\002\019\002\019\002\019\002\019\002\019\
\\002\019\002\019\002\019\002\019\002\019\002\019\002\019\002\019\
\\002\019\002\019\002\019\002\019\002\019\002\019\002\019\002\019\
\\002\019\002\019\002\019\002\019\002\019\002\019\002\019\002\019\
\\002\019\002\019\002\019\000\000\002\019\002\019\002\019\002\019\
\\002\019\002\019\002\019\002\019\002\019\002\019\002\019\002\019\
\\002\019\002\019\002\019\002\019\002\019\002\019\002\019\002\019\
\\002\019\002\019\002\019\002\019\002\019\002\019\002\019\002\019\
\\002\019\002\019\002\019\002\019\002\019\002\019\002\019\002\019\
\\002\019\002\019\002\019\002\019\002\019\002\019\002\019\002\019\
\\002\019\002\019\002\019\002\019\002\019\002\019\002\019\002\019\
\\002\019\002\019\002\019\002\019\002\019\002\019\002\019\002\019\
\\002\019\002\019\002\019\002\019\002\019\002\019\002\019\002\019\
\\002\019\002\019\002\019\002\019\002\019\002\019\002\019\002\019\
\\002\019\002\019\002\019\002\019\002\019\002\019\002\019\002\019\
\\002\019\002\019\002\019\002\019\002\019\002\019\002\019\002\019\
\\002\019\002\019\002\019\002\019\002\019\002\019\002\019\002\019\
\\002\019\002\019\002\019\002\019\002\019\002\019\002\019\002\019\
\\002\019\002\019\002\019\002\019\002\019\002\019\002\019\002\019\
\\002\019\002\019\002\019\002\019\002\019\002\019\002\019\002\019\
\\002\019\002\019\002\019\002\019\002\019\002\019\002\019\002\019"
),
 (532,256, 
"\002\019\002\019\002\019\002\019\002\019\002\019\002\019\002\019\
\\002\019\002\019\000\000\002\019\002\019\002\019\002\019\002\019\
\\002\019\002\019\002\019\002\019\002\019\002\019\002\019\002\019\
\\002\019\002\019\002\019\002\019\002\019\002\019\002\019\002\019\
\\002\019\002\019\002\019\002\019\002\019\002\019\002\019\002\019\
\\002\019\002\019\000\000\002\019\002\019\002\019\002\019\002\019\
\\002\019\002\019\002\019\002\019\002\019\002\019\002\019\002\019\
\\002\019\002\019\002\019\002\019\000\000\002\019\002\019\002\019\
\\002\019\002\019\002\019\002\019\002\019\002\019\002\019\002\019\
\\002\019\002\019\002\019\002\019\002\019\002\019\002\019\002\019\
\\002\019\002\019\002\019\002\019\002\019\002\019\002\019\002\019\
\\002\019\002\019\002\019\002\019\002\019\002\019\002\019\002\019\
\\002\019\002\019\002\019\002\019\002\019\002\019\002\019\002\019\
\\002\019\002\019\002\019\002\019\002\019\002\019\002\019\002\019\
\\002\019\002\019\002\019\002\019\002\019\002\019\002\019\002\019\
\\002\019\002\019\002\019\000\000\002\019\002\019\002\019\002\019\
\\002\019\002\019\002\019\002\019\002\019\002\019\002\019\002\019\
\\002\019\002\019\002\019\002\019\002\019\002\019\002\019\002\019\
\\002\019\002\019\002\019\002\019\002\019\002\019\002\019\002\019\
\\002\019\002\019\002\019\002\019\002\019\002\019\002\019\002\019\
\\002\019\002\019\002\019\002\019\002\019\002\019\002\019\002\019\
\\002\019\002\019\002\019\002\019\002\019\002\019\002\019\002\019\
\\002\019\002\019\002\019\002\019\002\019\002\019\002\019\002\019\
\\002\019\002\019\002\019\002\019\002\019\002\019\002\019\002\019\
\\002\019\002\019\002\019\002\019\002\019\002\019\002\019\002\019\
\\002\019\002\019\002\019\002\019\002\019\002\019\002\019\002\019\
\\002\019\002\019\002\019\002\019\002\019\002\019\002\019\002\019\
\\002\019\002\019\002\019\002\019\002\019\002\019\002\019\002\019\
\\002\019\002\019\002\019\002\019\002\019\002\019\002\019\002\019\
\\002\019\002\019\002\019\002\019\002\019\002\019\002\019\002\019\
\\002\019\002\019\002\019\002\019\002\019\002\019\002\019\002\019\
\\002\019\002\019\002\019\002\019\002\019\002\019\002\019\002\019"
),
 (534,256, 
"\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\
\\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\
\\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\
\\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\
\\000\000\002\027\000\000\000\000\000\000\000\000\000\000\000\000\
\\000\000\000\000\000\000\000\000\000\000\000\000\000\000\002\024\
\\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\
\\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\
\\000\000\002\023\002\023\002\023\002\023\002\023\002\023\002\023\
\\002\023\002\023\002\023\002\023\002\023\002\023\002\023\002\023\
\\002\023\002\023\002\023\002\023\002\023\002\023\002\023\002\023\
\\002\023\002\023\002\023\000\000\000\000\000\000\000\000\000\000\
\\000\000\002\023\002\023\002\023\002\023\002\023\002\023\002\023\
\\002\023\002\023\002\023\002\023\002\023\002\023\002\023\002\023\
\\002\023\002\023\002\023\002\023\002\023\002\023\002\023\002\023\
\\002\023\002\023\002\023\000\000\000\000\000\000\000\000\000\000\
\\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\
\\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\
\\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\
\\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\
\\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\
\\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\
\\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\
\\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\
\\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\
\\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\
\\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\
\\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\
\\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\
\\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\
\\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\
\\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000"
),
 (535,256, 
"\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\
\\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\
\\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\
\\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\
\\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\
\\000\000\000\000\000\000\000\000\000\000\002\023\000\000\000\000\
\\002\023\002\023\002\023\002\023\002\023\002\023\002\023\002\023\
\\002\023\002\023\000\000\000\000\000\000\000\000\000\000\000\000\
\\000\000\002\023\002\023\002\023\002\023\002\023\002\023\002\023\
\\002\023\002\023\002\023\002\023\002\023\002\023\002\023\002\023\
\\002\023\002\023\002\023\002\023\002\023\002\023\002\023\002\023\
\\002\023\002\023\002\023\000\000\000\000\000\000\000\000\002\023\
\\000\000\002\023\002\023\002\023\002\023\002\023\002\023\002\023\
\\002\023\002\023\002\023\002\023\002\023\002\023\002\023\002\023\
\\002\023\002\023\002\023\002\023\002\023\002\023\002\023\002\023\
\\002\023\002\023\002\023\000\000\000\000\000\000\000\000\000\000\
\\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\
\\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\
\\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\
\\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\
\\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\
\\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\
\\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\
\\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\
\\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\
\\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\
\\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\
\\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\
\\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\
\\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\
\\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\
\\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000"
),
 (536,256, 
"\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\
\\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\
\\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\
\\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\
\\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\
\\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\
\\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\
\\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\
\\000\000\002\025\002\025\002\025\002\025\002\025\002\025\002\025\
\\002\025\002\025\002\025\002\025\002\025\002\025\002\025\002\025\
\\002\025\002\025\002\025\002\025\002\025\002\025\002\025\002\025\
\\002\025\002\025\002\025\000\000\000\000\000\000\000\000\000\000\
\\000\000\002\025\002\025\002\025\002\025\002\025\002\025\002\025\
\\002\025\002\025\002\025\002\025\002\025\002\025\002\025\002\025\
\\002\025\002\025\002\025\002\025\002\025\002\025\002\025\002\025\
\\002\025\002\025\002\025\000\000\000\000\000\000\000\000\000\000\
\\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\
\\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\
\\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\
\\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\
\\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\
\\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\
\\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\
\\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\
\\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\
\\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\
\\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\
\\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\
\\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\
\\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\
\\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\
\\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000"
),
 (537,256, 
"\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\
\\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\
\\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\
\\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\
\\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\
\\000\000\000\000\000\000\000\000\000\000\002\025\000\000\000\000\
\\002\025\002\025\002\025\002\025\002\025\002\025\002\025\002\025\
\\002\025\002\025\000\000\000\000\000\000\000\000\002\026\000\000\
\\000\000\002\025\002\025\002\025\002\025\002\025\002\025\002\025\
\\002\025\002\025\002\025\002\025\002\025\002\025\002\025\002\025\
\\002\025\002\025\002\025\002\025\002\025\002\025\002\025\002\025\
\\002\025\002\025\002\025\000\000\000\000\000\000\000\000\002\025\
\\000\000\002\025\002\025\002\025\002\025\002\025\002\025\002\025\
\\002\025\002\025\002\025\002\025\002\025\002\025\002\025\002\025\
\\002\025\002\025\002\025\002\025\002\025\002\025\002\025\002\025\
\\002\025\002\025\002\025\000\000\000\000\000\000\000\000\000\000\
\\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\
\\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\
\\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\
\\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\
\\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\
\\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\
\\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\
\\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\
\\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\
\\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\
\\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\
\\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\
\\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\
\\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\
\\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\
\\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000"
),
 (539,256, 
"\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\
\\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\
\\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\
\\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\
\\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\
\\000\000\000\000\000\000\000\000\000\000\002\028\000\000\000\000\
\\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\
\\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\
\\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\
\\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\
\\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\
\\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\
\\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\
\\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\
\\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\
\\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\
\\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\
\\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\
\\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\
\\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\
\\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\
\\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\
\\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\
\\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\
\\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\
\\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\
\\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\
\\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\
\\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\
\\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\
\\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\
\\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000"
),
 (540,256, 
"\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\
\\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\
\\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\
\\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\
\\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\
\\000\000\000\000\000\000\000\000\000\000\002\029\000\000\000\000\
\\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\
\\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\
\\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\
\\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\
\\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\
\\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\
\\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\
\\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\
\\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\
\\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\
\\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\
\\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\
\\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\
\\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\
\\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\
\\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\
\\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\
\\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\
\\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\
\\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\
\\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\
\\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\
\\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\
\\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\
\\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\
\\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000"
),
 (541,256, 
"\002\030\002\030\002\030\002\030\002\030\002\030\002\030\002\030\
\\002\030\002\030\002\030\002\030\002\030\002\030\002\030\002\030\
\\002\030\002\030\002\030\002\030\002\030\002\030\002\030\002\030\
\\002\030\002\030\002\030\002\030\002\030\002\030\002\030\002\030\
\\002\030\002\030\002\030\002\030\002\030\002\030\002\030\002\030\
\\002\030\002\030\002\030\002\030\002\030\002\034\002\030\002\030\
\\002\030\002\030\002\030\002\030\002\030\002\030\002\030\002\030\
\\002\030\002\030\002\030\002\030\002\030\002\030\002\030\002\030\
\\002\030\002\030\002\030\002\030\002\030\002\030\002\030\002\030\
\\002\030\002\030\002\030\002\030\002\030\002\030\002\030\002\030\
\\002\030\002\030\002\030\002\030\002\030\002\030\002\030\002\030\
\\002\030\002\030\002\030\002\030\002\030\002\030\002\030\002\030\
\\002\030\002\030\002\030\002\030\002\030\002\030\002\030\002\030\
\\002\030\002\030\002\030\002\030\002\030\002\030\002\030\002\030\
\\002\030\002\030\002\030\002\030\002\030\002\030\002\030\002\030\
\\002\030\002\030\002\030\002\030\002\030\002\030\002\030\002\030\
\\002\030\002\030\002\030\002\030\002\030\002\030\002\030\002\030\
\\002\030\002\030\002\030\002\030\002\030\002\030\002\030\002\030\
\\002\030\002\030\002\030\002\030\002\030\002\030\002\030\002\030\
\\002\030\002\030\002\030\002\030\002\030\002\030\002\030\002\030\
\\002\030\002\030\002\030\002\030\002\030\002\030\002\030\002\030\
\\002\030\002\030\002\030\002\030\002\030\002\030\002\030\002\030\
\\002\030\002\030\002\030\002\030\002\030\002\030\002\030\002\030\
\\002\030\002\030\002\030\002\030\002\030\002\030\002\030\002\030\
\\002\030\002\030\002\030\002\030\002\030\002\030\002\030\002\030\
\\002\030\002\030\002\030\002\030\002\030\002\030\002\030\002\030\
\\002\030\002\030\002\030\002\030\002\030\002\030\002\030\002\030\
\\002\030\002\030\002\030\002\030\002\030\002\030\002\030\002\030\
\\002\030\002\030\002\030\002\030\002\030\002\030\002\030\002\030\
\\002\030\002\030\002\030\002\030\002\030\002\030\002\030\002\030\
\\002\030\002\030\002\030\002\030\002\030\002\030\002\030\002\030\
\\002\030\002\030\002\030\002\030\002\030\002\030\002\030\002\030"
),
 (542,256, 
"\002\030\002\030\002\030\002\030\002\030\002\030\002\030\002\030\
\\002\030\002\030\002\030\002\030\002\030\002\030\002\030\002\030\
\\002\030\002\030\002\030\002\030\002\030\002\030\002\030\002\030\
\\002\030\002\030\002\030\002\030\002\030\002\030\002\030\002\030\
\\002\030\002\030\002\030\002\030\002\030\002\030\002\030\002\030\
\\002\030\002\030\002\030\002\030\002\030\002\031\002\030\002\030\
\\002\030\002\030\002\030\002\030\002\030\002\030\002\030\002\030\
\\002\030\002\030\002\030\002\030\002\030\002\030\002\030\002\030\
\\002\030\002\030\002\030\002\030\002\030\002\030\002\030\002\030\
\\002\030\002\030\002\030\002\030\002\030\002\030\002\030\002\030\
\\002\030\002\030\002\030\002\030\002\030\002\030\002\030\002\030\
\\002\030\002\030\002\030\002\030\002\030\002\030\002\030\002\030\
\\002\030\002\030\002\030\002\030\002\030\002\030\002\030\002\030\
\\002\030\002\030\002\030\002\030\002\030\002\030\002\030\002\030\
\\002\030\002\030\002\030\002\030\002\030\002\030\002\030\002\030\
\\002\030\002\030\002\030\002\030\002\030\002\030\002\030\002\030\
\\002\030\002\030\002\030\002\030\002\030\002\030\002\030\002\030\
\\002\030\002\030\002\030\002\030\002\030\002\030\002\030\002\030\
\\002\030\002\030\002\030\002\030\002\030\002\030\002\030\002\030\
\\002\030\002\030\002\030\002\030\002\030\002\030\002\030\002\030\
\\002\030\002\030\002\030\002\030\002\030\002\030\002\030\002\030\
\\002\030\002\030\002\030\002\030\002\030\002\030\002\030\002\030\
\\002\030\002\030\002\030\002\030\002\030\002\030\002\030\002\030\
\\002\030\002\030\002\030\002\030\002\030\002\030\002\030\002\030\
\\002\030\002\030\002\030\002\030\002\030\002\030\002\030\002\030\
\\002\030\002\030\002\030\002\030\002\030\002\030\002\030\002\030\
\\002\030\002\030\002\030\002\030\002\030\002\030\002\030\002\030\
\\002\030\002\030\002\030\002\030\002\030\002\030\002\030\002\030\
\\002\030\002\030\002\030\002\030\002\030\002\030\002\030\002\030\
\\002\030\002\030\002\030\002\030\002\030\002\030\002\030\002\030\
\\002\030\002\030\002\030\002\030\002\030\002\030\002\030\002\030\
\\002\030\002\030\002\030\002\030\002\030\002\030\002\030\002\030"
),
 (543,256, 
"\002\030\002\030\002\030\002\030\002\030\002\030\002\030\002\030\
\\002\030\002\030\002\030\002\030\002\030\002\030\002\030\002\030\
\\002\030\002\030\002\030\002\030\002\030\002\030\002\030\002\030\
\\002\030\002\030\002\030\002\030\002\030\002\030\002\030\002\030\
\\002\030\002\030\002\030\002\030\002\030\002\030\002\030\002\030\
\\002\030\002\030\002\030\002\030\002\030\002\032\002\030\002\030\
\\002\030\002\030\002\030\002\030\002\030\002\030\002\030\002\030\
\\002\030\002\030\002\030\002\030\002\030\002\030\002\030\002\030\
\\002\030\002\030\002\030\002\030\002\030\002\030\002\030\002\030\
\\002\030\002\030\002\030\002\030\002\030\002\030\002\030\002\030\
\\002\030\002\030\002\030\002\030\002\030\002\030\002\030\002\030\
\\002\030\002\030\002\030\002\030\002\030\002\030\002\030\002\030\
\\002\030\002\030\002\030\002\030\002\030\002\030\002\030\002\030\
\\002\030\002\030\002\030\002\030\002\030\002\030\002\030\002\030\
\\002\030\002\030\002\030\002\030\002\030\002\030\002\030\002\030\
\\002\030\002\030\002\030\002\030\002\030\002\030\002\030\002\030\
\\002\030\002\030\002\030\002\030\002\030\002\030\002\030\002\030\
\\002\030\002\030\002\030\002\030\002\030\002\030\002\030\002\030\
\\002\030\002\030\002\030\002\030\002\030\002\030\002\030\002\030\
\\002\030\002\030\002\030\002\030\002\030\002\030\002\030\002\030\
\\002\030\002\030\002\030\002\030\002\030\002\030\002\030\002\030\
\\002\030\002\030\002\030\002\030\002\030\002\030\002\030\002\030\
\\002\030\002\030\002\030\002\030\002\030\002\030\002\030\002\030\
\\002\030\002\030\002\030\002\030\002\030\002\030\002\030\002\030\
\\002\030\002\030\002\030\002\030\002\030\002\030\002\030\002\030\
\\002\030\002\030\002\030\002\030\002\030\002\030\002\030\002\030\
\\002\030\002\030\002\030\002\030\002\030\002\030\002\030\002\030\
\\002\030\002\030\002\030\002\030\002\030\002\030\002\030\002\030\
\\002\030\002\030\002\030\002\030\002\030\002\030\002\030\002\030\
\\002\030\002\030\002\030\002\030\002\030\002\030\002\030\002\030\
\\002\030\002\030\002\030\002\030\002\030\002\030\002\030\002\030\
\\002\030\002\030\002\030\002\030\002\030\002\030\002\030\002\030"
),
 (544,256, 
"\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\
\\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\
\\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\
\\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\
\\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\
\\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\
\\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\
\\000\000\000\000\000\000\000\000\000\000\000\000\002\033\000\000\
\\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\
\\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\
\\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\
\\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\
\\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\
\\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\
\\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\
\\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\
\\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\
\\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\
\\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\
\\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\
\\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\
\\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\
\\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\
\\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\
\\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\
\\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\
\\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\
\\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\
\\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\
\\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\
\\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\
\\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000"
),
 (546,256, 
"\002\030\002\030\002\030\002\030\002\030\002\030\002\030\002\030\
\\002\030\002\030\002\030\002\030\002\030\002\030\002\030\002\030\
\\002\030\002\030\002\030\002\030\002\030\002\030\002\030\002\030\
\\002\030\002\030\002\030\002\030\002\030\002\030\002\030\002\030\
\\002\030\002\030\002\030\002\030\002\030\002\030\002\030\002\030\
\\002\030\002\030\002\030\002\030\002\030\000\000\002\030\002\030\
\\002\030\002\030\002\030\002\030\002\030\002\030\002\030\002\030\
\\002\030\002\030\002\030\002\030\002\030\002\030\002\030\002\030\
\\002\030\002\030\002\030\002\030\002\030\002\030\002\030\002\030\
\\002\030\002\030\002\030\002\030\002\030\002\030\002\030\002\030\
\\002\030\002\030\002\030\002\030\002\030\002\030\002\030\002\030\
\\002\030\002\030\002\030\002\030\002\030\002\030\002\030\002\030\
\\002\030\002\030\002\030\002\030\002\030\002\030\002\030\002\030\
\\002\030\002\030\002\030\002\030\002\030\002\030\002\030\002\030\
\\002\030\002\030\002\030\002\030\002\030\002\030\002\030\002\030\
\\002\030\002\030\002\030\002\030\002\030\002\030\002\030\002\030\
\\002\030\002\030\002\030\002\030\002\030\002\030\002\030\002\030\
\\002\030\002\030\002\030\002\030\002\030\002\030\002\030\002\030\
\\002\030\002\030\002\030\002\030\002\030\002\030\002\030\002\030\
\\002\030\002\030\002\030\002\030\002\030\002\030\002\030\002\030\
\\002\030\002\030\002\030\002\030\002\030\002\030\002\030\002\030\
\\002\030\002\030\002\030\002\030\002\030\002\030\002\030\002\030\
\\002\030\002\030\002\030\002\030\002\030\002\030\002\030\002\030\
\\002\030\002\030\002\030\002\030\002\030\002\030\002\030\002\030\
\\002\030\002\030\002\030\002\030\002\030\002\030\002\030\002\030\
\\002\030\002\030\002\030\002\030\002\030\002\030\002\030\002\030\
\\002\030\002\030\002\030\002\030\002\030\002\030\002\030\002\030\
\\002\030\002\030\002\030\002\030\002\030\002\030\002\030\002\030\
\\002\030\002\030\002\030\002\030\002\030\002\030\002\030\002\030\
\\002\030\002\030\002\030\002\030\002\030\002\030\002\030\002\030\
\\002\030\002\030\002\030\002\030\002\030\002\030\002\030\002\030\
\\002\030\002\030\002\030\002\030\002\030\002\030\002\030\002\030"
),
 (547,256, 
"\002\019\002\019\002\019\002\019\002\019\002\019\002\019\002\019\
\\002\019\002\019\000\000\002\019\002\019\002\019\002\019\002\019\
\\002\019\002\019\002\019\002\019\002\019\002\019\002\019\002\019\
\\002\019\002\019\002\019\002\019\002\019\002\019\002\019\002\019\
\\002\019\002\019\002\019\002\019\002\019\002\019\002\019\002\019\
\\002\020\002\036\002\019\002\019\002\019\002\019\002\019\002\019\
\\002\019\002\019\002\019\002\019\002\019\002\019\002\019\002\019\
\\002\019\002\019\002\019\002\019\000\000\002\019\002\019\002\019\
\\002\019\002\019\002\019\002\019\002\019\002\019\002\019\002\019\
\\002\019\002\019\002\019\002\019\002\019\002\019\002\019\002\019\
\\002\019\002\019\002\019\002\019\002\019\002\019\002\019\002\019\
\\002\019\002\019\002\019\002\019\002\019\002\019\002\019\002\019\
\\002\019\002\019\002\019\002\019\002\019\002\019\002\019\002\019\
\\002\019\002\019\002\019\002\019\002\019\002\019\002\019\002\019\
\\002\019\002\019\002\019\002\019\002\019\002\019\002\019\002\019\
\\002\019\002\019\002\019\000\000\002\019\002\019\002\019\002\019\
\\002\019\002\019\002\019\002\019\002\019\002\019\002\019\002\019\
\\002\019\002\019\002\019\002\019\002\019\002\019\002\019\002\019\
\\002\019\002\019\002\019\002\019\002\019\002\019\002\019\002\019\
\\002\019\002\019\002\019\002\019\002\019\002\019\002\019\002\019\
\\002\019\002\019\002\019\002\019\002\019\002\019\002\019\002\019\
\\002\019\002\019\002\019\002\019\002\019\002\019\002\019\002\019\
\\002\019\002\019\002\019\002\019\002\019\002\019\002\019\002\019\
\\002\019\002\019\002\019\002\019\002\019\002\019\002\019\002\019\
\\002\019\002\019\002\019\002\019\002\019\002\019\002\019\002\019\
\\002\019\002\019\002\019\002\019\002\019\002\019\002\019\002\019\
\\002\019\002\019\002\019\002\019\002\019\002\019\002\019\002\019\
\\002\019\002\019\002\019\002\019\002\019\002\019\002\019\002\019\
\\002\019\002\019\002\019\002\019\002\019\002\019\002\019\002\019\
\\002\019\002\019\002\019\002\019\002\019\002\019\002\019\002\019\
\\002\019\002\019\002\019\002\019\002\019\002\019\002\019\002\019\
\\002\019\002\019\002\019\002\019\002\019\002\019\002\019\002\019"
),
 (549,256, 
"\002\019\002\019\002\019\002\019\002\019\002\019\002\019\002\019\
\\002\019\002\019\000\000\002\019\002\019\002\019\002\019\002\019\
\\002\019\002\019\002\019\002\019\002\019\002\019\002\019\002\019\
\\002\019\002\019\002\019\002\019\002\019\002\019\002\019\002\019\
\\002\019\002\019\002\019\002\019\002\019\002\019\002\019\002\019\
\\002\019\002\019\002\038\002\019\002\019\002\019\002\019\002\019\
\\002\019\002\019\002\019\002\019\002\019\002\019\002\019\002\019\
\\002\019\002\019\002\019\002\019\000\000\002\019\002\019\002\019\
\\002\019\002\019\002\019\002\019\002\019\002\019\002\019\002\019\
\\002\019\002\019\002\019\002\019\002\019\002\019\002\019\002\019\
\\002\019\002\019\002\019\002\019\002\019\002\019\002\019\002\019\
\\002\019\002\019\002\019\002\019\002\019\002\019\002\019\002\019\
\\002\019\002\019\002\019\002\019\002\019\002\019\002\019\002\019\
\\002\019\002\019\002\019\002\019\002\019\002\019\002\019\002\019\
\\002\019\002\019\002\019\002\019\002\019\002\019\002\019\002\019\
\\002\019\002\019\002\019\000\000\002\019\002\019\002\019\002\019\
\\002\019\002\019\002\019\002\019\002\019\002\019\002\019\002\019\
\\002\019\002\019\002\019\002\019\002\019\002\019\002\019\002\019\
\\002\019\002\019\002\019\002\019\002\019\002\019\002\019\002\019\
\\002\019\002\019\002\019\002\019\002\019\002\019\002\019\002\019\
\\002\019\002\019\002\019\002\019\002\019\002\019\002\019\002\019\
\\002\019\002\019\002\019\002\019\002\019\002\019\002\019\002\019\
\\002\019\002\019\002\019\002\019\002\019\002\019\002\019\002\019\
\\002\019\002\019\002\019\002\019\002\019\002\019\002\019\002\019\
\\002\019\002\019\002\019\002\019\002\019\002\019\002\019\002\019\
\\002\019\002\019\002\019\002\019\002\019\002\019\002\019\002\019\
\\002\019\002\019\002\019\002\019\002\019\002\019\002\019\002\019\
\\002\019\002\019\002\019\002\019\002\019\002\019\002\019\002\019\
\\002\019\002\019\002\019\002\019\002\019\002\019\002\019\002\019\
\\002\019\002\019\002\019\002\019\002\019\002\019\002\019\002\019\
\\002\019\002\019\002\019\002\019\002\019\002\019\002\019\002\019\
\\002\019\002\019\002\019\002\019\002\019\002\019\002\019\002\019"
),
 (554,256, 
"\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\
\\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\
\\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\
\\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\
\\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\
\\000\000\000\000\000\000\000\000\000\000\002\043\000\000\000\000\
\\002\043\002\043\002\043\002\043\002\043\002\043\002\043\002\043\
\\002\043\002\043\000\000\000\000\000\000\000\000\000\000\000\000\
\\000\000\002\043\002\043\002\043\002\043\002\043\002\043\002\043\
\\002\043\002\043\002\043\002\043\002\043\002\043\002\043\002\043\
\\002\043\002\043\002\043\002\043\002\043\002\043\002\043\002\043\
\\002\043\002\043\002\043\000\000\000\000\000\000\000\000\002\043\
\\000\000\002\043\002\043\002\043\002\043\002\043\002\043\002\043\
\\002\043\002\043\002\043\002\043\002\043\002\043\002\043\002\043\
\\002\043\002\043\002\043\002\043\002\043\002\043\002\043\002\043\
\\002\043\002\043\002\043\000\000\000\000\000\000\000\000\000\000\
\\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\
\\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\
\\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\
\\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\
\\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\
\\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\
\\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\
\\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\
\\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\
\\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\
\\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\
\\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\
\\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\
\\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\
\\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\
\\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000"
),
 (558,256, 
"\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\
\\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\
\\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\
\\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\
\\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\
\\000\000\000\000\000\000\000\000\000\000\000\000\002\048\000\000\
\\002\047\002\047\002\047\002\047\002\047\002\047\002\047\002\047\
\\002\047\002\047\000\000\000\000\000\000\000\000\000\000\000\000\
\\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\
\\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\
\\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\
\\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\
\\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\
\\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\
\\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\
\\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\
\\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\
\\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\
\\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\
\\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\
\\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\
\\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\
\\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\
\\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\
\\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\
\\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\
\\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\
\\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\
\\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\
\\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\
\\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\
\\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000"
),
 (560,256, 
"\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\
\\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\
\\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\
\\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\
\\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\
\\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\
\\002\048\002\048\002\048\002\048\002\048\002\048\002\048\002\048\
\\002\048\002\048\000\000\000\000\000\000\000\000\000\000\000\000\
\\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\
\\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\
\\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\
\\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\
\\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\
\\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\
\\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\
\\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\
\\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\
\\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\
\\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\
\\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\
\\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\
\\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\
\\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\
\\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\
\\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\
\\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\
\\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\
\\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\
\\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\
\\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\
\\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\
\\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000"
),
 (563,256, 
"\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\
\\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\
\\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\
\\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\
\\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\
\\000\000\000\000\002\052\000\000\000\000\000\000\000\000\000\000\
\\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\
\\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\
\\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\
\\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\
\\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\
\\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\
\\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\
\\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\
\\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\
\\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\
\\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\
\\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\
\\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\
\\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\
\\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\
\\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\
\\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\
\\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\
\\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\
\\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\
\\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\
\\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\
\\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\
\\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\
\\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\
\\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000"
),
 (566,256, 
"\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\
\\000\000\002\055\000\000\000\000\002\055\002\055\000\000\000\000\
\\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\
\\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\
\\002\055\000\000\000\000\000\000\000\000\000\000\000\000\000\000\
\\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\
\\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\
\\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\
\\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\
\\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\
\\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\
\\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\
\\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\
\\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\
\\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\
\\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\
\\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\
\\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\
\\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\
\\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\
\\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\
\\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\
\\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\
\\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\
\\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\
\\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\
\\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\
\\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\
\\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\
\\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\
\\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\
\\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000"
),
(0, 0, "")]
fun f(n, i, x) = (n, Vector.tabulate(i, decode x)) 
val s = map f (rev (tl (rev s))) 
exception LexHackingError 
fun look ((j,x)::r, i: int) = if i = j then x else look(r, i) 
  | look ([], i) = raise LexHackingError
fun g {fin=x, trans=i} = {fin=x, trans=look(s,i)} 
in Vector.fromList(map g 
[{fin = [], trans = 0},
{fin = [], trans = 1},
{fin = [], trans = 1},
{fin = [], trans = 3},
{fin = [], trans = 3},
{fin = [], trans = 5},
{fin = [], trans = 5},
{fin = [], trans = 7},
{fin = [], trans = 7},
{fin = [], trans = 9},
{fin = [], trans = 9},
{fin = [], trans = 11},
{fin = [], trans = 11},
{fin = [(N 941)], trans = 0},
{fin = [(N 262),(N 941)], trans = 0},
{fin = [(N 156),(N 941)], trans = 0},
{fin = [(N 264),(N 941)], trans = 16},
{fin = [(N 188)], trans = 0},
{fin = [(N 202)], trans = 0},
{fin = [(N 154),(N 941)], trans = 0},
{fin = [(N 921),(N 941)], trans = 20},
{fin = [(N 921)], trans = 20},
{fin = [(N 921),(N 941)], trans = 22},
{fin = [(N 921)], trans = 23},
{fin = [(N 921)], trans = 24},
{fin = [(N 921)], trans = 25},
{fin = [(N 401),(N 921)], trans = 20},
{fin = [(N 921),(N 941)], trans = 27},
{fin = [(N 921)], trans = 28},
{fin = [(N 921)], trans = 29},
{fin = [(N 464),(N 921)], trans = 20},
{fin = [(N 921)], trans = 31},
{fin = [(N 308),(N 921)], trans = 20},
{fin = [(N 921),(N 941)], trans = 33},
{fin = [(N 921)], trans = 34},
{fin = [(N 921)], trans = 35},
{fin = [(N 292),(N 921)], trans = 20},
{fin = [(N 921)], trans = 37},
{fin = [(N 921)], trans = 38},
{fin = [(N 340),(N 921)], trans = 20},
{fin = [(N 921)], trans = 40},
{fin = [(N 921)], trans = 41},
{fin = [(N 488),(N 921)], trans = 20},
{fin = [(N 921)], trans = 43},
{fin = [(N 921)], trans = 44},
{fin = [(N 450),(N 921)], trans = 20},
{fin = [(N 921),(N 941)], trans = 46},
{fin = [(N 921)], trans = 47},
{fin = [(N 921)], trans = 48},
{fin = [(N 921)], trans = 49},
{fin = [(N 483),(N 921)], trans = 20},
{fin = [(N 921)], trans = 51},
{fin = [(N 921)], trans = 52},
{fin = [(N 921)], trans = 53},
{fin = [(N 372),(N 921)], trans = 54},
{fin = [(N 921)], trans = 55},
{fin = [(N 921)], trans = 56},
{fin = [(N 355),(N 921)], trans = 20},
{fin = [(N 921)], trans = 58},
{fin = [(N 376),(N 921)], trans = 59},
{fin = [(N 921)], trans = 60},
{fin = [(N 921)], trans = 61},
{fin = [(N 921)], trans = 62},
{fin = [(N 921)], trans = 63},
{fin = [(N 921)], trans = 64},
{fin = [(N 365),(N 921)], trans = 20},
{fin = [(N 921)], trans = 66},
{fin = [(N 921)], trans = 67},
{fin = [(N 921)], trans = 68},
{fin = [(N 921)], trans = 69},
{fin = [(N 921)], trans = 70},
{fin = [(N 921)], trans = 71},
{fin = [(N 459),(N 921)], trans = 20},
{fin = [(N 921),(N 941)], trans = 73},
{fin = [(N 921)], trans = 74},
{fin = [(N 312),(N 921)], trans = 20},
{fin = [(N 921),(N 941)], trans = 76},
{fin = [(N 921)], trans = 77},
{fin = [(N 921)], trans = 78},
{fin = [(N 921)], trans = 79},
{fin = [(N 921)], trans = 80},
{fin = [(N 495),(N 921)], trans = 20},
{fin = [(N 921),(N 941)], trans = 82},
{fin = [(N 921)], trans = 83},
{fin = [(N 921)], trans = 84},
{fin = [(N 414),(N 921)], trans = 20},
{fin = [(N 304),(N 921)], trans = 20},
{fin = [(N 921),(N 941)], trans = 87},
{fin = [(N 921)], trans = 88},
{fin = [(N 327),(N 921)], trans = 20},
{fin = [(N 921),(N 941)], trans = 90},
{fin = [(N 921)], trans = 91},
{fin = [(N 380),(N 921)], trans = 20},
{fin = [(N 921),(N 941)], trans = 93},
{fin = [(N 383),(N 921)], trans = 94},
{fin = [(N 921)], trans = 95},
{fin = [(N 921)], trans = 96},
{fin = [(N 921)], trans = 97},
{fin = [(N 921)], trans = 98},
{fin = [(N 409),(N 921)], trans = 20},
{fin = [(N 335),(N 921)], trans = 20},
{fin = [(N 921),(N 941)], trans = 101},
{fin = [(N 921)], trans = 102},
{fin = [(N 320),(N 921)], trans = 103},
{fin = [(N 921)], trans = 104},
{fin = [(N 921)], trans = 105},
{fin = [(N 921)], trans = 106},
{fin = [(N 395),(N 921)], trans = 20},
{fin = [(N 323),(N 921)], trans = 20},
{fin = [(N 921)], trans = 109},
{fin = [(N 499),(N 921)], trans = 20},
{fin = [(N 921),(N 941)], trans = 111},
{fin = [(N 921)], trans = 112},
{fin = [(N 921)], trans = 113},
{fin = [(N 921)], trans = 114},
{fin = [(N 921)], trans = 115},
{fin = [(N 444),(N 921)], trans = 20},
{fin = [(N 921)], trans = 117},
{fin = [(N 387),(N 921)], trans = 20},
{fin = [(N 921)], trans = 119},
{fin = [(N 921)], trans = 120},
{fin = [(N 345),(N 921)], trans = 20},
{fin = [(N 921),(N 941)], trans = 122},
{fin = [(N 921)], trans = 123},
{fin = [(N 921)], trans = 124},
{fin = [(N 921)], trans = 125},
{fin = [(N 921)], trans = 126},
{fin = [(N 921)], trans = 127},
{fin = [(N 921)], trans = 128},
{fin = [(N 301),(N 921)], trans = 20},
{fin = [(N 921),(N 941)], trans = 130},
{fin = [(N 921)], trans = 131},
{fin = [(N 921)], trans = 132},
{fin = [(N 921)], trans = 133},
{fin = [(N 921)], trans = 134},
{fin = [(N 477),(N 921)], trans = 20},
{fin = [(N 287),(N 921)], trans = 136},
{fin = [(N 921)], trans = 137},
{fin = [(N 921)], trans = 138},
{fin = [(N 921)], trans = 139},
{fin = [(N 921)], trans = 140},
{fin = [(N 921)], trans = 141},
{fin = [(N 921)], trans = 142},
{fin = [(N 425),(N 921)], trans = 143},
{fin = [(N 437),(N 921)], trans = 20},
{fin = [(N 921)], trans = 145},
{fin = [(N 921)], trans = 146},
{fin = [(N 921)], trans = 147},
{fin = [(N 470),(N 921)], trans = 20},
{fin = [(N 921)], trans = 149},
{fin = [(N 921)], trans = 150},
{fin = [(N 332),(N 921)], trans = 20},
{fin = [(N 921),(N 941)], trans = 152},
{fin = [(N 921)], trans = 153},
{fin = [(N 316),(N 921)], trans = 20},
{fin = [(N 941)], trans = 155},
{fin = [], trans = 156},
{fin = [(N 210)], trans = 0},
{fin = [], trans = 158},
{fin = [], trans = 155},
{fin = [(N 260),(N 921),(N 941)], trans = 160},
{fin = [(N 258),(N 921)], trans = 20},
{fin = [(N 921)], trans = 162},
{fin = [(N 921)], trans = 163},
{fin = [(N 921)], trans = 164},
{fin = [(N 918),(N 921)], trans = 20},
{fin = [(N 182),(N 941)], trans = 0},
{fin = [(N 152),(N 941)], trans = 0},
{fin = [(N 150),(N 941)], trans = 0},
{fin = [(N 924),(N 941)], trans = 169},
{fin = [(N 924)], trans = 169},
{fin = [(N 924),(N 941)], trans = 171},
{fin = [(N 924)], trans = 172},
{fin = [(N 924)], trans = 173},
{fin = [(N 924)], trans = 174},
{fin = [(N 544),(N 924)], trans = 169},
{fin = [(N 924),(N 941)], trans = 176},
{fin = [(N 924)], trans = 177},
{fin = [(N 924)], trans = 178},
{fin = [(N 924)], trans = 179},
{fin = [(N 924)], trans = 180},
{fin = [(N 769),(N 924)], trans = 169},
{fin = [(N 924),(N 941)], trans = 182},
{fin = [(N 924)], trans = 183},
{fin = [(N 924)], trans = 184},
{fin = [(N 514),(N 924)], trans = 169},
{fin = [(N 924)], trans = 186},
{fin = [(N 924)], trans = 187},
{fin = [(N 924)], trans = 188},
{fin = [(N 924)], trans = 189},
{fin = [(N 776),(N 924)], trans = 169},
{fin = [(N 924)], trans = 191},
{fin = [(N 924)], trans = 192},
{fin = [(N 924)], trans = 193},
{fin = [(N 924)], trans = 194},
{fin = [(N 827),(N 924)], trans = 169},
{fin = [(N 924)], trans = 196},
{fin = [(N 640),(N 924)], trans = 169},
{fin = [(N 924),(N 941)], trans = 198},
{fin = [(N 924)], trans = 199},
{fin = [(N 924)], trans = 200},
{fin = [(N 504),(N 924)], trans = 169},
{fin = [(N 924)], trans = 202},
{fin = [(N 924)], trans = 203},
{fin = [(N 662),(N 924)], trans = 169},
{fin = [(N 924)], trans = 205},
{fin = [(N 924)], trans = 206},
{fin = [(N 729),(N 924)], trans = 169},
{fin = [(N 924),(N 941)], trans = 208},
{fin = [(N 924)], trans = 209},
{fin = [(N 693),(N 924)], trans = 169},
{fin = [(N 924)], trans = 211},
{fin = [(N 548),(N 924)], trans = 169},
{fin = [(N 924)], trans = 213},
{fin = [(N 780),(N 924)], trans = 169},
{fin = [(N 924)], trans = 215},
{fin = [(N 924)], trans = 216},
{fin = [(N 924)], trans = 217},
{fin = [(N 521),(N 924)], trans = 218},
{fin = [(N 595),(N 924)], trans = 169},
{fin = [(N 924),(N 941)], trans = 220},
{fin = [(N 924)], trans = 221},
{fin = [(N 924)], trans = 222},
{fin = [(N 924)], trans = 223},
{fin = [(N 629),(N 924)], trans = 169},
{fin = [(N 924)], trans = 225},
{fin = [(N 924)], trans = 226},
{fin = [(N 924)], trans = 227},
{fin = [(N 924)], trans = 228},
{fin = [(N 924)], trans = 229},
{fin = [(N 924)], trans = 230},
{fin = [(N 875),(N 924)], trans = 169},
{fin = [(N 924)], trans = 232},
{fin = [(N 924)], trans = 233},
{fin = [(N 924)], trans = 234},
{fin = [(N 924)], trans = 235},
{fin = [(N 924)], trans = 236},
{fin = [(N 924)], trans = 237},
{fin = [(N 924)], trans = 238},
{fin = [(N 894),(N 924)], trans = 169},
{fin = [(N 924)], trans = 240},
{fin = [(N 924)], trans = 241},
{fin = [(N 706),(N 924)], trans = 169},
{fin = [(N 924)], trans = 243},
{fin = [(N 924)], trans = 244},
{fin = [(N 750),(N 924)], trans = 169},
{fin = [(N 924),(N 941)], trans = 246},
{fin = [(N 924)], trans = 247},
{fin = [(N 924)], trans = 248},
{fin = [(N 924)], trans = 249},
{fin = [(N 924)], trans = 250},
{fin = [(N 924)], trans = 251},
{fin = [(N 841),(N 924)], trans = 169},
{fin = [(N 924)], trans = 253},
{fin = [(N 924)], trans = 254},
{fin = [(N 924)], trans = 255},
{fin = [(N 924)], trans = 256},
{fin = [(N 924)], trans = 257},
{fin = [(N 924)], trans = 258},
{fin = [(N 924)], trans = 259},
{fin = [(N 716),(N 924)], trans = 169},
{fin = [(N 924),(N 941)], trans = 261},
{fin = [(N 924)], trans = 262},
{fin = [(N 924)], trans = 263},
{fin = [(N 721),(N 924)], trans = 169},
{fin = [(N 924)], trans = 265},
{fin = [(N 924)], trans = 266},
{fin = [(N 924)], trans = 267},
{fin = [(N 618),(N 924)], trans = 169},
{fin = [(N 675),(N 924)], trans = 269},
{fin = [(N 924)], trans = 270},
{fin = [(N 924)], trans = 271},
{fin = [(N 560),(N 924)], trans = 169},
{fin = [(N 856),(N 924)], trans = 169},
{fin = [(N 924)], trans = 274},
{fin = [(N 924)], trans = 275},
{fin = [(N 924)], trans = 276},
{fin = [(N 924)], trans = 277},
{fin = [(N 583),(N 924)], trans = 169},
{fin = [(N 924),(N 941)], trans = 279},
{fin = [(N 924)], trans = 280},
{fin = [(N 924)], trans = 281},
{fin = [(N 509),(N 924)], trans = 169},
{fin = [(N 924)], trans = 283},
{fin = [(N 924)], trans = 284},
{fin = [(N 792),(N 924)], trans = 169},
{fin = [(N 859),(N 924)], trans = 286},
{fin = [(N 679),(N 924)], trans = 169},
{fin = [(N 924),(N 941)], trans = 288},
{fin = [(N 924)], trans = 289},
{fin = [(N 697),(N 924)], trans = 169},
{fin = [(N 924)], trans = 291},
{fin = [(N 701),(N 924)], trans = 169},
{fin = [(N 924),(N 941)], trans = 293},
{fin = [(N 924)], trans = 294},
{fin = [(N 924)], trans = 295},
{fin = [(N 924)], trans = 296},
{fin = [(N 576),(N 924)], trans = 169},
{fin = [(N 924)], trans = 298},
{fin = [(N 809),(N 924)], trans = 169},
{fin = [(N 924)], trans = 300},
{fin = [(N 924)], trans = 301},
{fin = [(N 623),(N 924)], trans = 169},
{fin = [(N 924),(N 941)], trans = 303},
{fin = [(N 924)], trans = 304},
{fin = [(N 853),(N 924)], trans = 169},
{fin = [(N 924),(N 941)], trans = 306},
{fin = [(N 924)], trans = 307},
{fin = [(N 924)], trans = 308},
{fin = [(N 600),(N 924)], trans = 169},
{fin = [(N 924),(N 941)], trans = 310},
{fin = [(N 795),(N 924)], trans = 169},
{fin = [(N 924)], trans = 312},
{fin = [(N 924)], trans = 313},
{fin = [(N 762),(N 924)], trans = 169},
{fin = [(N 924)], trans = 315},
{fin = [(N 924)], trans = 316},
{fin = [(N 924)], trans = 317},
{fin = [(N 924)], trans = 318},
{fin = [(N 924)], trans = 319},
{fin = [(N 650),(N 924)], trans = 169},
{fin = [(N 924)], trans = 321},
{fin = [(N 924)], trans = 322},
{fin = [(N 924)], trans = 323},
{fin = [(N 757),(N 924)], trans = 169},
{fin = [(N 924)], trans = 325},
{fin = [(N 924)], trans = 326},
{fin = [(N 606),(N 924)], trans = 169},
{fin = [(N 724),(N 924)], trans = 169},
{fin = [(N 924),(N 941)], trans = 329},
{fin = [(N 924)], trans = 330},
{fin = [(N 924)], trans = 331},
{fin = [(N 924)], trans = 332},
{fin = [(N 924)], trans = 333},
{fin = [(N 570),(N 924)], trans = 169},
{fin = [(N 924),(N 941)], trans = 335},
{fin = [(N 924)], trans = 336},
{fin = [(N 924)], trans = 337},
{fin = [(N 924)], trans = 338},
{fin = [(N 554),(N 924)], trans = 169},
{fin = [(N 924),(N 941)], trans = 340},
{fin = [(N 924)], trans = 341},
{fin = [(N 924)], trans = 342},
{fin = [(N 634),(N 924)], trans = 169},
{fin = [(N 924)], trans = 344},
{fin = [(N 924)], trans = 345},
{fin = [(N 535),(N 924)], trans = 169},
{fin = [(N 924)], trans = 347},
{fin = [(N 924)], trans = 348},
{fin = [(N 924)], trans = 349},
{fin = [(N 924)], trans = 350},
{fin = [(N 924)], trans = 351},
{fin = [(N 849),(N 924)], trans = 169},
{fin = [(N 924)], trans = 353},
{fin = [(N 924)], trans = 354},
{fin = [(N 924)], trans = 355},
{fin = [(N 668),(N 924)], trans = 169},
{fin = [(N 924),(N 941)], trans = 357},
{fin = [(N 924)], trans = 358},
{fin = [(N 924)], trans = 359},
{fin = [(N 924)], trans = 360},
{fin = [(N 924)], trans = 361},
{fin = [(N 657),(N 924)], trans = 169},
{fin = [(N 924)], trans = 363},
{fin = [(N 924)], trans = 364},
{fin = [(N 734),(N 924)], trans = 169},
{fin = [(N 924),(N 941)], trans = 366},
{fin = [(N 924)], trans = 367},
{fin = [(N 924)], trans = 368},
{fin = [(N 924)], trans = 369},
{fin = [(N 924)], trans = 370},
{fin = [(N 924)], trans = 371},
{fin = [(N 924)], trans = 372},
{fin = [(N 530),(N 924)], trans = 169},
{fin = [(N 924)], trans = 374},
{fin = [(N 924)], trans = 375},
{fin = [(N 743),(N 924)], trans = 169},
{fin = [(N 924)], trans = 377},
{fin = [(N 924)], trans = 378},
{fin = [(N 924)], trans = 379},
{fin = [(N 787),(N 924)], trans = 169},
{fin = [(N 924),(N 941)], trans = 381},
{fin = [(N 924)], trans = 382},
{fin = [(N 924)], trans = 383},
{fin = [(N 924)], trans = 384},
{fin = [(N 924)], trans = 385},
{fin = [(N 924)], trans = 386},
{fin = [(N 924)], trans = 387},
{fin = [(N 924)], trans = 388},
{fin = [(N 924)], trans = 389},
{fin = [(N 924)], trans = 390},
{fin = [(N 924)], trans = 391},
{fin = [(N 924)], trans = 392},
{fin = [(N 924)], trans = 393},
{fin = [(N 924)], trans = 394},
{fin = [(N 924)], trans = 395},
{fin = [(N 924)], trans = 396},
{fin = [(N 912),(N 924)], trans = 169},
{fin = [(N 924)], trans = 398},
{fin = [(N 924)], trans = 399},
{fin = [(N 924)], trans = 400},
{fin = [(N 612),(N 924)], trans = 169},
{fin = [(N 924)], trans = 402},
{fin = [(N 924)], trans = 403},
{fin = [(N 924)], trans = 404},
{fin = [(N 685),(N 924)], trans = 169},
{fin = [(N 924)], trans = 406},
{fin = [(N 924)], trans = 407},
{fin = [(N 924)], trans = 408},
{fin = [(N 924)], trans = 409},
{fin = [(N 924)], trans = 410},
{fin = [(N 924)], trans = 411},
{fin = [(N 924)], trans = 412},
{fin = [(N 820),(N 924)], trans = 169},
{fin = [(N 924)], trans = 414},
{fin = [(N 924)], trans = 415},
{fin = [(N 924)], trans = 416},
{fin = [(N 924)], trans = 417},
{fin = [(N 924)], trans = 418},
{fin = [(N 804),(N 924)], trans = 169},
{fin = [(N 924)], trans = 420},
{fin = [(N 924)], trans = 421},
{fin = [(N 924)], trans = 422},
{fin = [(N 833),(N 924)], trans = 169},
{fin = [(N 924)], trans = 424},
{fin = [(N 924)], trans = 425},
{fin = [(N 924)], trans = 426},
{fin = [(N 924)], trans = 427},
{fin = [(N 924)], trans = 428},
{fin = [(N 883),(N 924)], trans = 169},
{fin = [(N 924),(N 941)], trans = 430},
{fin = [(N 563),(N 924)], trans = 169},
{fin = [(N 924),(N 941)], trans = 432},
{fin = [(N 924)], trans = 433},
{fin = [(N 689),(N 924)], trans = 169},
{fin = [(N 538),(N 924)], trans = 435},
{fin = [(N 738),(N 924)], trans = 169},
{fin = [(N 924)], trans = 437},
{fin = [(N 672),(N 924)], trans = 169},
{fin = [(N 924)], trans = 439},
{fin = [(N 587),(N 924)], trans = 169},
{fin = [(N 924)], trans = 441},
{fin = [(N 924)], trans = 442},
{fin = [(N 924)], trans = 443},
{fin = [(N 924)], trans = 444},
{fin = [(N 866),(N 924)], trans = 169},
{fin = [(N 283),(N 941)], trans = 0},
{fin = [(N 219),(N 941)], trans = 447},
{fin = [], trans = 448},
{fin = [(N 196)], trans = 0},
{fin = [(N 225)], trans = 0},
{fin = [(N 212),(N 941)], trans = 451},
{fin = [(N 170)], trans = 0},
{fin = [], trans = 453},
{fin = [(N 167)], trans = 0},
{fin = [(N 217),(N 941)], trans = 455},
{fin = [(N 199)], trans = 0},
{fin = [], trans = 457},
{fin = [(N 90)], trans = 0},
{fin = [], trans = 459},
{fin = [(N 85)], trans = 0},
{fin = [(N 215)], trans = 0},
{fin = [(N 222)], trans = 0},
{fin = [], trans = 463},
{fin = [(N 192)], trans = 0},
{fin = [(N 269)], trans = 0},
{fin = [(N 271),(N 941)], trans = 0},
{fin = [(N 245),(N 941)], trans = 467},
{fin = [(N 243)], trans = 468},
{fin = [(N 240)], trans = 0},
{fin = [(N 236)], trans = 470},
{fin = [(N 232)], trans = 0},
{fin = [(N 932),(N 941)], trans = 472},
{fin = [(N 932)], trans = 472},
{fin = [(N 937)], trans = 474},
{fin = [(N 932),(N 941)], trans = 475},
{fin = [], trans = 476},
{fin = [(N 929)], trans = 476},
{fin = [(N 279),(N 941)], trans = 0},
{fin = [(N 251),(N 941)], trans = 479},
{fin = [], trans = 480},
{fin = [(N 249)], trans = 0},
{fin = [(N 277),(N 941)], trans = 482},
{fin = [(N 163)], trans = 0},
{fin = [(N 176)], trans = 484},
{fin = [(N 160)], trans = 0},
{fin = [(N 180)], trans = 0},
{fin = [(N 227),(N 941)], trans = 0},
{fin = [(N 275),(N 941)], trans = 488},
{fin = [(N 173)], trans = 0},
{fin = [(N 266),(N 941)], trans = 490},
{fin = [(N 18)], trans = 0},
{fin = [(N 148),(N 941)], trans = 0},
{fin = [(N 146),(N 941)], trans = 493},
{fin = [(N 9)], trans = 0},
{fin = [(N 144)], trans = 0},
{fin = [(N 77),(N 941)], trans = 0},
{fin = [(N 941)], trans = 497},
{fin = [(N 185)], trans = 0},
{fin = [(N 281),(N 941)], trans = 0},
{fin = [(N 253),(N 941)], trans = 0},
{fin = [(N 255),(N 941)], trans = 501},
{fin = [(N 71)], trans = 0},
{fin = [(N 75),(N 941)], trans = 0},
{fin = [(N 273),(N 941)], trans = 0},
{fin = [(N 6),(N 941)], trans = 505},
{fin = [(N 6)], trans = 505},
{fin = [(N 1)], trans = 0},
{fin = [(N 939)], trans = 0},
{fin = [(N 939)], trans = 509},
{fin = [(N 24)], trans = 0},
{fin = [(N 939)], trans = 511},
{fin = [(N 21)], trans = 0},
{fin = [(N 79)], trans = 0},
{fin = [(N 79)], trans = 514},
{fin = [], trans = 515},
{fin = [], trans = 516},
{fin = [(N 68)], trans = 0},
{fin = [(N 56)], trans = 0},
{fin = [(N 50)], trans = 0},
{fin = [(N 47)], trans = 0},
{fin = [(N 53)], trans = 0},
{fin = [], trans = 522},
{fin = [], trans = 523},
{fin = [(N 63)], trans = 0},
{fin = [(N 44)], trans = 0},
{fin = [(N 41)], trans = 0},
{fin = [(N 58)], trans = 0},
{fin = [(N 73)], trans = 0},
{fin = [(N 73)], trans = 514},
{fin = [(N 137),(N 141)], trans = 530},
{fin = [(N 137)], trans = 530},
{fin = [], trans = 532},
{fin = [(N 130),(N 141)], trans = 0},
{fin = [(N 141)], trans = 534},
{fin = [(N 100)], trans = 535},
{fin = [], trans = 536},
{fin = [], trans = 537},
{fin = [(N 96)], trans = 0},
{fin = [], trans = 539},
{fin = [], trans = 540},
{fin = [], trans = 541},
{fin = [], trans = 542},
{fin = [], trans = 543},
{fin = [], trans = 544},
{fin = [(N 38)], trans = 0},
{fin = [], trans = 546},
{fin = [(N 137),(N 141)], trans = 547},
{fin = [(N 18),(N 137)], trans = 530},
{fin = [(N 139),(N 141)], trans = 549},
{fin = [(N 12)], trans = 0},
{fin = [(N 3)], trans = 0},
{fin = [(N 128)], trans = 0},
{fin = [(N 124),(N 128)], trans = 0},
{fin = [(N 110),(N 128)], trans = 554},
{fin = [(N 110)], trans = 554},
{fin = [(N 104),(N 128)], trans = 0},
{fin = [(N 112),(N 128)], trans = 0},
{fin = [(N 115),(N 128)], trans = 558},
{fin = [(N 115)], trans = 558},
{fin = [(N 120)], trans = 560},
{fin = [(N 102),(N 128)], trans = 0},
{fin = [(N 128)], trans = 490},
{fin = [(N 126),(N 128)], trans = 563},
{fin = [(N 15)], trans = 0},
{fin = [(N 122),(N 128)], trans = 0},
{fin = [(N 107),(N 128)], trans = 566},
{fin = [(N 107)], trans = 566}])
end
structure StartStates =
	struct
	datatype yystartstate = STARTSTATE of int

(* start state definitions *)

val CHAR = STARTSTATE 7;
val COMMENT = STARTSTATE 3;
val INITIAL = STARTSTATE 1;
val STRING = STARTSTATE 5;
val XML = STARTSTATE 9;
val XMLTAG = STARTSTATE 11;

end
type result = UserDeclarations.lexresult
	exception LexerError (* raised if illegal leaf action tried *)
end

structure YYPosInt : INTEGER = Int
fun makeLexer yyinput =
let	val yygone0= YYPosInt.fromInt ~1
	val yyb = ref "\n" 		(* buffer *)
	val yybl = ref 1		(*buffer length *)
	val yybufpos = ref 1		(* location of next character to use *)
	val yygone = ref yygone0	(* position in file of beginning of buffer *)
	val yydone = ref false		(* eof found yet? *)
	val yybegin = ref 1		(*Current 'start state' for lexer *)

	val YYBEGIN = fn (Internal.StartStates.STARTSTATE x) =>
		 yybegin := x

fun lex () : Internal.result =
let fun continue() = lex() in
  let fun scan (s,AcceptingLeaves : Internal.yyfinstate list list,l,i0) =
	let fun action (i,nil) = raise LexError
	| action (i,nil::l) = action (i-1,l)
	| action (i,(node::acts)::l) =
		case node of
		    Internal.N yyk => 
			(let fun yymktext() = substring(!yyb,i0,i-i0)
			     val yypos = YYPosInt.+(YYPosInt.fromInt i0, !yygone)
			open UserDeclarations Internal.StartStates
 in (yybufpos := i; case yyk of 

			(* Application actions *)

  1 => ((*#line 194.27 "urweb.mlton.lex"*)newline yypos;
                          continue ()(*#line 13773.1 "urweb.mlton.lex.sml"*)
)
| 100 => let val yytext=yymktext() in (*#line 309.27 "urweb.mlton.lex"*)YYBEGIN XMLTAG;
			  Tokens.BEGIN_TAG (String.extract (yytext, 1, NONE),
					    yypos, yypos + size yytext)(*#line 13777.1 "urweb.mlton.lex.sml"*)
 end
| 102 => let val yytext=yymktext() in (*#line 313.27 "urweb.mlton.lex"*)Tokens.DIVIDE (yypos, yypos + size yytext)(*#line 13779.1 "urweb.mlton.lex.sml"*)
 end
| 104 => let val yytext=yymktext() in (*#line 314.27 "urweb.mlton.lex"*)YYBEGIN XML;
			  Tokens.GT (yypos, yypos + size yytext)(*#line 13782.1 "urweb.mlton.lex.sml"*)
 end
| 107 => ((*#line 317.27 "urweb.mlton.lex"*)lex ()(*#line 13784.1 "urweb.mlton.lex.sml"*)
)
| 110 => let val yytext=yymktext() in (*#line 319.27 "urweb.mlton.lex"*)Tokens.SYMBOL (yytext, yypos, yypos + size yytext)(*#line 13786.1 "urweb.mlton.lex.sml"*)
 end
| 112 => let val yytext=yymktext() in (*#line 320.27 "urweb.mlton.lex"*)Tokens.EQ (yypos, yypos + size yytext)(*#line 13788.1 "urweb.mlton.lex.sml"*)
 end
| 115 => let val yytext=yymktext() in (*#line 322.27 "urweb.mlton.lex"*)case Int64.fromString yytext of
                            SOME x => Tokens.INT (x, yypos, yypos + size yytext)
                          | NONE   => (ErrorMsg.errorAt' (yypos, yypos)
                                       ("Expected int, received: " ^ yytext);
                                       continue ())(*#line 13794.1 "urweb.mlton.lex.sml"*)
 end
| 12 => ((*#line 205.27 "urweb.mlton.lex"*)YYBEGIN COMMENT;
                          commentOut := (fn () => YYBEGIN XML);
                          enterComment (pos yypos);
                          continue ()(*#line 13799.1 "urweb.mlton.lex.sml"*)
)
| 120 => let val yytext=yymktext() in (*#line 327.27 "urweb.mlton.lex"*)case Real.fromString yytext of
                            SOME x => Tokens.FLOAT (x, yypos, yypos + size yytext)
                          | NONE   => (ErrorMsg.errorAt' (yypos, yypos)
                                       ("Expected float, received: " ^ yytext);
                                       continue ())(*#line 13805.1 "urweb.mlton.lex.sml"*)
 end
| 122 => ((*#line 332.27 "urweb.mlton.lex"*)YYBEGIN STRING;
			  xmlString := true; strEnder := #"\"";
			  strStart := yypos; str := []; continue ()(*#line 13809.1 "urweb.mlton.lex.sml"*)
)
| 124 => ((*#line 336.27 "urweb.mlton.lex"*)YYBEGIN INITIAL;
			  pushLevel (fn () => YYBEGIN XMLTAG);
			  Tokens.LBRACE (yypos, yypos + 1)(*#line 13813.1 "urweb.mlton.lex.sml"*)
)
| 126 => ((*#line 339.27 "urweb.mlton.lex"*)YYBEGIN INITIAL;
			  pushLevel (fn () => YYBEGIN XMLTAG);
			  Tokens.LPAREN (yypos, yypos + 1)(*#line 13817.1 "urweb.mlton.lex.sml"*)
)
| 128 => let val yytext=yymktext() in (*#line 343.27 "urweb.mlton.lex"*)ErrorMsg.errorAt' (yypos, yypos)
                          ("illegal XML tag character: \"" ^ yytext ^ "\"");
                          continue ()(*#line 13821.1 "urweb.mlton.lex.sml"*)
 end
| 130 => ((*#line 347.27 "urweb.mlton.lex"*)YYBEGIN INITIAL;
			  pushLevel (fn () => YYBEGIN XML);
			  Tokens.LBRACE (yypos, yypos + 1)(*#line 13825.1 "urweb.mlton.lex.sml"*)
)
| 137 => let val yytext=yymktext() in (*#line 351.27 "urweb.mlton.lex"*)Tokens.NOTAGS (unescape (yypos, yypos + size yytext) yytext, yypos, yypos + size yytext)(*#line 13827.1 "urweb.mlton.lex.sml"*)
 end
| 139 => let val yytext=yymktext() in (*#line 353.27 "urweb.mlton.lex"*)Tokens.NOTAGS ("(", yypos, yypos + size yytext)(*#line 13829.1 "urweb.mlton.lex.sml"*)
 end
| 141 => let val yytext=yymktext() in (*#line 355.27 "urweb.mlton.lex"*)ErrorMsg.errorAt' (yypos, yypos)
                          ("illegal XML character: \"" ^ yytext ^ "\"");
                          continue ()(*#line 13833.1 "urweb.mlton.lex.sml"*)
 end
| 144 => let val yytext=yymktext() in (*#line 359.27 "urweb.mlton.lex"*)Tokens.UNIT (pos yypos, pos yypos + size yytext)(*#line 13835.1 "urweb.mlton.lex.sml"*)
 end
| 146 => let val yytext=yymktext() in (*#line 360.27 "urweb.mlton.lex"*)Tokens.LPAREN (pos yypos, pos yypos + size yytext)(*#line 13837.1 "urweb.mlton.lex.sml"*)
 end
| 148 => let val yytext=yymktext() in (*#line 361.27 "urweb.mlton.lex"*)Tokens.RPAREN (pos yypos, pos yypos + size yytext)(*#line 13839.1 "urweb.mlton.lex.sml"*)
 end
| 15 => ((*#line 209.27 "urweb.mlton.lex"*)YYBEGIN COMMENT;
                          commentOut := (fn () => YYBEGIN XMLTAG);
                          enterComment (pos yypos);
                          continue ()(*#line 13844.1 "urweb.mlton.lex.sml"*)
)
| 150 => let val yytext=yymktext() in (*#line 362.27 "urweb.mlton.lex"*)Tokens.LBRACK (pos yypos, pos yypos + size yytext)(*#line 13846.1 "urweb.mlton.lex.sml"*)
 end
| 152 => let val yytext=yymktext() in (*#line 363.27 "urweb.mlton.lex"*)Tokens.RBRACK (pos yypos, pos yypos + size yytext)(*#line 13848.1 "urweb.mlton.lex.sml"*)
 end
| 154 => let val yytext=yymktext() in (*#line 364.27 "urweb.mlton.lex"*)enterBrace ();
                          Tokens.LBRACE (pos yypos, pos yypos + size yytext)(*#line 13851.1 "urweb.mlton.lex.sml"*)
 end
| 156 => let val yytext=yymktext() in (*#line 366.27 "urweb.mlton.lex"*)exitBrace ();
                          Tokens.RBRACE (pos yypos, pos yypos + size yytext)(*#line 13854.1 "urweb.mlton.lex.sml"*)
 end
| 160 => let val yytext=yymktext() in (*#line 369.27 "urweb.mlton.lex"*)Tokens.KARROW (pos yypos, pos yypos + size yytext)(*#line 13856.1 "urweb.mlton.lex.sml"*)
 end
| 163 => let val yytext=yymktext() in (*#line 370.27 "urweb.mlton.lex"*)Tokens.ARROW (pos yypos, pos yypos + size yytext)(*#line 13858.1 "urweb.mlton.lex.sml"*)
 end
| 167 => let val yytext=yymktext() in (*#line 371.27 "urweb.mlton.lex"*)Tokens.DKARROW (pos yypos, pos yypos + size yytext)(*#line 13860.1 "urweb.mlton.lex.sml"*)
 end
| 170 => let val yytext=yymktext() in (*#line 372.27 "urweb.mlton.lex"*)Tokens.DARROW (pos yypos, pos yypos + size yytext)(*#line 13862.1 "urweb.mlton.lex.sml"*)
 end
| 173 => let val yytext=yymktext() in (*#line 373.27 "urweb.mlton.lex"*)Tokens.PLUSPLUS (pos yypos, pos yypos + size yytext)(*#line 13864.1 "urweb.mlton.lex.sml"*)
 end
| 176 => let val yytext=yymktext() in (*#line 374.27 "urweb.mlton.lex"*)Tokens.MINUSMINUS (pos yypos, pos yypos + size yytext)(*#line 13866.1 "urweb.mlton.lex.sml"*)
 end
| 18 => ((*#line 214.27 "urweb.mlton.lex"*)ErrorMsg.errorAt' (pos yypos, pos yypos) "Unbalanced comments";
			  continue ()(*#line 13869.1 "urweb.mlton.lex.sml"*)
)
| 180 => let val yytext=yymktext() in (*#line 375.27 "urweb.mlton.lex"*)Tokens.MINUSMINUSMINUS (pos yypos, pos yypos + size yytext)(*#line 13871.1 "urweb.mlton.lex.sml"*)
 end
| 182 => let val yytext=yymktext() in (*#line 376.27 "urweb.mlton.lex"*)Tokens.CARET (pos yypos, pos yypos + size yytext)(*#line 13873.1 "urweb.mlton.lex.sml"*)
 end
| 185 => let val yytext=yymktext() in (*#line 378.27 "urweb.mlton.lex"*)Tokens.ANDALSO (pos yypos, pos yypos + size yytext)(*#line 13875.1 "urweb.mlton.lex.sml"*)
 end
| 188 => let val yytext=yymktext() in (*#line 379.27 "urweb.mlton.lex"*)Tokens.ORELSE (pos yypos, pos yypos + size yytext)(*#line 13877.1 "urweb.mlton.lex.sml"*)
 end
| 192 => let val yytext=yymktext() in (*#line 381.27 "urweb.mlton.lex"*)Tokens.COMPOSE (pos yypos, pos yypos + size yytext)(*#line 13879.1 "urweb.mlton.lex.sml"*)
 end
| 196 => let val yytext=yymktext() in (*#line 382.27 "urweb.mlton.lex"*)Tokens.ANDTHEN (pos yypos, pos yypos + size yytext)(*#line 13881.1 "urweb.mlton.lex.sml"*)
 end
| 199 => let val yytext=yymktext() in (*#line 383.27 "urweb.mlton.lex"*)Tokens.FWDAPP (pos yypos, pos yypos + size yytext)(*#line 13883.1 "urweb.mlton.lex.sml"*)
 end
| 202 => let val yytext=yymktext() in (*#line 384.27 "urweb.mlton.lex"*)Tokens.REVAPP (pos yypos, pos yypos + size yytext)(*#line 13885.1 "urweb.mlton.lex.sml"*)
 end
| 21 => ((*#line 217.27 "urweb.mlton.lex"*)enterComment (pos yypos);
                          continue ()(*#line 13888.1 "urweb.mlton.lex.sml"*)
)
| 210 => let val yytext=yymktext() in (*#line 386.42 "urweb.mlton.lex"*)Tokens.BACKTICK_PATH ( (* strip backticks *)
                                                              substring (yytext,1,size yytext -2),
                                                              pos yypos, pos yypos + size yytext)(*#line 13892.1 "urweb.mlton.lex.sml"*)
 end
| 212 => let val yytext=yymktext() in (*#line 390.27 "urweb.mlton.lex"*)Tokens.EQ (pos yypos, pos yypos + size yytext)(*#line 13894.1 "urweb.mlton.lex.sml"*)
 end
| 215 => let val yytext=yymktext() in (*#line 391.27 "urweb.mlton.lex"*)Tokens.NE (pos yypos, pos yypos + size yytext)(*#line 13896.1 "urweb.mlton.lex.sml"*)
 end
| 217 => let val yytext=yymktext() in (*#line 392.27 "urweb.mlton.lex"*)Tokens.LT (pos yypos, pos yypos + size yytext)(*#line 13898.1 "urweb.mlton.lex.sml"*)
 end
| 219 => let val yytext=yymktext() in (*#line 393.27 "urweb.mlton.lex"*)Tokens.GT (pos yypos, pos yypos + size yytext)(*#line 13900.1 "urweb.mlton.lex.sml"*)
 end
| 222 => let val yytext=yymktext() in (*#line 394.27 "urweb.mlton.lex"*)Tokens.LE (pos yypos, pos yypos + size yytext)(*#line 13902.1 "urweb.mlton.lex.sml"*)
 end
| 225 => let val yytext=yymktext() in (*#line 395.27 "urweb.mlton.lex"*)Tokens.GE (pos yypos, pos yypos + size yytext)(*#line 13904.1 "urweb.mlton.lex.sml"*)
 end
| 227 => let val yytext=yymktext() in (*#line 396.27 "urweb.mlton.lex"*)Tokens.COMMA (pos yypos, pos yypos + size yytext)(*#line 13906.1 "urweb.mlton.lex.sml"*)
 end
| 232 => let val yytext=yymktext() in (*#line 397.27 "urweb.mlton.lex"*)Tokens.TCOLONWILD (pos yypos, pos yypos + size yytext)(*#line 13908.1 "urweb.mlton.lex.sml"*)
 end
| 236 => let val yytext=yymktext() in (*#line 398.27 "urweb.mlton.lex"*)Tokens.TCOLON (pos yypos, pos yypos + size yytext)(*#line 13910.1 "urweb.mlton.lex.sml"*)
 end
| 24 => ((*#line 219.27 "urweb.mlton.lex"*)exitComment ();
			  continue ()(*#line 13913.1 "urweb.mlton.lex.sml"*)
)
| 240 => let val yytext=yymktext() in (*#line 399.27 "urweb.mlton.lex"*)Tokens.DCOLONWILD (pos yypos, pos yypos + size yytext)(*#line 13915.1 "urweb.mlton.lex.sml"*)
 end
| 243 => let val yytext=yymktext() in (*#line 400.27 "urweb.mlton.lex"*)Tokens.DCOLON (pos yypos, pos yypos + size yytext)(*#line 13917.1 "urweb.mlton.lex.sml"*)
 end
| 245 => let val yytext=yymktext() in (*#line 401.27 "urweb.mlton.lex"*)Tokens.COLON (pos yypos, pos yypos + size yytext)(*#line 13919.1 "urweb.mlton.lex.sml"*)
 end
| 249 => let val yytext=yymktext() in (*#line 402.27 "urweb.mlton.lex"*)Tokens.DOTDOTDOT (pos yypos, pos yypos + size yytext)(*#line 13921.1 "urweb.mlton.lex.sml"*)
 end
| 251 => let val yytext=yymktext() in (*#line 403.27 "urweb.mlton.lex"*)Tokens.DOT (pos yypos, pos yypos + size yytext)(*#line 13923.1 "urweb.mlton.lex.sml"*)
 end
| 253 => let val yytext=yymktext() in (*#line 404.27 "urweb.mlton.lex"*)Tokens.DOLLAR (pos yypos, pos yypos + size yytext)(*#line 13925.1 "urweb.mlton.lex.sml"*)
 end
| 255 => let val yytext=yymktext() in (*#line 405.27 "urweb.mlton.lex"*)Tokens.HASH (pos yypos, pos yypos + size yytext)(*#line 13927.1 "urweb.mlton.lex.sml"*)
 end
| 258 => let val yytext=yymktext() in (*#line 406.27 "urweb.mlton.lex"*)Tokens.UNDERUNDER (pos yypos, pos yypos + size yytext)(*#line 13929.1 "urweb.mlton.lex.sml"*)
 end
| 260 => let val yytext=yymktext() in (*#line 407.27 "urweb.mlton.lex"*)Tokens.UNDER (pos yypos, pos yypos + size yytext)(*#line 13931.1 "urweb.mlton.lex.sml"*)
 end
| 262 => let val yytext=yymktext() in (*#line 408.27 "urweb.mlton.lex"*)Tokens.TWIDDLE (pos yypos, pos yypos + size yytext)(*#line 13933.1 "urweb.mlton.lex.sml"*)
 end
| 264 => let val yytext=yymktext() in (*#line 409.27 "urweb.mlton.lex"*)Tokens.BAR (pos yypos, pos yypos + size yytext)(*#line 13935.1 "urweb.mlton.lex.sml"*)
 end
| 266 => let val yytext=yymktext() in (*#line 410.27 "urweb.mlton.lex"*)Tokens.STAR (pos yypos, pos yypos + size yytext)(*#line 13937.1 "urweb.mlton.lex.sml"*)
 end
| 269 => let val yytext=yymktext() in (*#line 411.27 "urweb.mlton.lex"*)Tokens.LARROW (pos yypos, pos yypos + size yytext)(*#line 13939.1 "urweb.mlton.lex.sml"*)
 end
| 271 => let val yytext=yymktext() in (*#line 412.27 "urweb.mlton.lex"*)Tokens.SEMI (pos yypos, pos yypos + size yytext)(*#line 13941.1 "urweb.mlton.lex.sml"*)
 end
| 273 => let val yytext=yymktext() in (*#line 413.27 "urweb.mlton.lex"*)Tokens.BANG (pos yypos, pos yypos + size yytext)(*#line 13943.1 "urweb.mlton.lex.sml"*)
 end
| 275 => let val yytext=yymktext() in (*#line 415.27 "urweb.mlton.lex"*)Tokens.PLUS (pos yypos, pos yypos + size yytext)(*#line 13945.1 "urweb.mlton.lex.sml"*)
 end
| 277 => let val yytext=yymktext() in (*#line 416.27 "urweb.mlton.lex"*)Tokens.MINUS (pos yypos, pos yypos + size yytext)(*#line 13947.1 "urweb.mlton.lex.sml"*)
 end
| 279 => let val yytext=yymktext() in (*#line 417.27 "urweb.mlton.lex"*)Tokens.DIVIDE (yypos, yypos + size yytext)(*#line 13949.1 "urweb.mlton.lex.sml"*)
 end
| 281 => let val yytext=yymktext() in (*#line 418.27 "urweb.mlton.lex"*)Tokens.MOD (pos yypos, pos yypos + size yytext)(*#line 13951.1 "urweb.mlton.lex.sml"*)
 end
| 283 => let val yytext=yymktext() in (*#line 419.27 "urweb.mlton.lex"*)Tokens.AT (pos yypos, pos yypos + size yytext)(*#line 13953.1 "urweb.mlton.lex.sml"*)
 end
| 287 => let val yytext=yymktext() in (*#line 421.27 "urweb.mlton.lex"*)Tokens.CON (pos yypos, pos yypos + size yytext)(*#line 13955.1 "urweb.mlton.lex.sml"*)
 end
| 292 => let val yytext=yymktext() in (*#line 422.27 "urweb.mlton.lex"*)Tokens.LTYPE (pos yypos, pos yypos + size yytext)(*#line 13957.1 "urweb.mlton.lex.sml"*)
 end
| 3 => let val yytext=yymktext() in (*#line 196.27 "urweb.mlton.lex"*)newline yypos;
                          Tokens.NOTAGS (yytext, yypos, yypos + size yytext)(*#line 13960.1 "urweb.mlton.lex.sml"*)
 end
| 301 => let val yytext=yymktext() in (*#line 423.27 "urweb.mlton.lex"*)Tokens.DATATYPE (pos yypos, pos yypos + size yytext)(*#line 13962.1 "urweb.mlton.lex.sml"*)
 end
| 304 => let val yytext=yymktext() in (*#line 424.27 "urweb.mlton.lex"*)Tokens.OF (pos yypos, pos yypos + size yytext)(*#line 13964.1 "urweb.mlton.lex.sml"*)
 end
| 308 => let val yytext=yymktext() in (*#line 425.27 "urweb.mlton.lex"*)Tokens.VAL (pos yypos, pos yypos + size yytext)(*#line 13966.1 "urweb.mlton.lex.sml"*)
 end
| 312 => let val yytext=yymktext() in (*#line 426.27 "urweb.mlton.lex"*)Tokens.REC (pos yypos, pos yypos + size yytext)(*#line 13968.1 "urweb.mlton.lex.sml"*)
 end
| 316 => let val yytext=yymktext() in (*#line 427.27 "urweb.mlton.lex"*)Tokens.AND (pos yypos, pos yypos + size yytext)(*#line 13970.1 "urweb.mlton.lex.sml"*)
 end
| 320 => let val yytext=yymktext() in (*#line 428.27 "urweb.mlton.lex"*)Tokens.FUN (pos yypos, pos yypos + size yytext)(*#line 13972.1 "urweb.mlton.lex.sml"*)
 end
| 323 => let val yytext=yymktext() in (*#line 429.27 "urweb.mlton.lex"*)Tokens.FN (pos yypos, pos yypos + size yytext)(*#line 13974.1 "urweb.mlton.lex.sml"*)
 end
| 327 => let val yytext=yymktext() in (*#line 430.27 "urweb.mlton.lex"*)Tokens.MAP (pos yypos, pos yypos + size yytext)(*#line 13976.1 "urweb.mlton.lex.sml"*)
 end
| 332 => let val yytext=yymktext() in (*#line 431.27 "urweb.mlton.lex"*)Tokens.CASE (pos yypos, pos yypos + size yytext)(*#line 13978.1 "urweb.mlton.lex.sml"*)
 end
| 335 => let val yytext=yymktext() in (*#line 432.27 "urweb.mlton.lex"*)Tokens.IF (pos yypos, pos yypos + size yytext)(*#line 13980.1 "urweb.mlton.lex.sml"*)
 end
| 340 => let val yytext=yymktext() in (*#line 433.27 "urweb.mlton.lex"*)Tokens.THEN (pos yypos, pos yypos + size yytext)(*#line 13982.1 "urweb.mlton.lex.sml"*)
 end
| 345 => let val yytext=yymktext() in (*#line 434.27 "urweb.mlton.lex"*)Tokens.ELSE (pos yypos, pos yypos + size yytext)(*#line 13984.1 "urweb.mlton.lex.sml"*)
 end
| 355 => let val yytext=yymktext() in (*#line 437.27 "urweb.mlton.lex"*)Tokens.STRUCTURE (pos yypos, pos yypos + size yytext)(*#line 13986.1 "urweb.mlton.lex.sml"*)
 end
| 365 => let val yytext=yymktext() in (*#line 438.27 "urweb.mlton.lex"*)Tokens.SIGNATURE (pos yypos, pos yypos + size yytext)(*#line 13988.1 "urweb.mlton.lex.sml"*)
 end
| 372 => let val yytext=yymktext() in (*#line 439.27 "urweb.mlton.lex"*)Tokens.STRUCT (pos yypos, pos yypos + size yytext)(*#line 13990.1 "urweb.mlton.lex.sml"*)
 end
| 376 => let val yytext=yymktext() in (*#line 440.27 "urweb.mlton.lex"*)if yypos <= 2 then initialSig () else (); Tokens.SIG (pos yypos, pos yypos + size yytext)(*#line 13992.1 "urweb.mlton.lex.sml"*)
 end
| 38 => ((*#line 222.31 "urweb.mlton.lex"*)continue ()(*#line 13994.1 "urweb.mlton.lex.sml"*)
)
| 380 => let val yytext=yymktext() in (*#line 441.27 "urweb.mlton.lex"*)Tokens.LET (pos yypos, pos yypos + size yytext)(*#line 13996.1 "urweb.mlton.lex.sml"*)
 end
| 383 => let val yytext=yymktext() in (*#line 442.27 "urweb.mlton.lex"*)Tokens.IN (pos yypos, pos yypos + size yytext)(*#line 13998.1 "urweb.mlton.lex.sml"*)
 end
| 387 => let val yytext=yymktext() in (*#line 443.27 "urweb.mlton.lex"*)Tokens.END (pos yypos, pos yypos + size yytext)(*#line 14000.1 "urweb.mlton.lex.sml"*)
 end
| 395 => let val yytext=yymktext() in (*#line 444.27 "urweb.mlton.lex"*)Tokens.FUNCTOR (pos yypos, pos yypos + size yytext)(*#line 14002.1 "urweb.mlton.lex.sml"*)
 end
| 401 => let val yytext=yymktext() in (*#line 445.27 "urweb.mlton.lex"*)Tokens.WHERE (pos yypos, pos yypos + size yytext)(*#line 14004.1 "urweb.mlton.lex.sml"*)
 end
| 409 => let val yytext=yymktext() in (*#line 446.27 "urweb.mlton.lex"*)Tokens.INCLUDE (pos yypos, pos yypos + size yytext)(*#line 14006.1 "urweb.mlton.lex.sml"*)
 end
| 41 => ((*#line 224.27 "urweb.mlton.lex"*)str := #"\"" :: !str; continue()(*#line 14008.1 "urweb.mlton.lex.sml"*)
)
| 414 => let val yytext=yymktext() in (*#line 447.27 "urweb.mlton.lex"*)Tokens.OPEN (pos yypos, pos yypos + size yytext)(*#line 14010.1 "urweb.mlton.lex.sml"*)
 end
| 425 => let val yytext=yymktext() in (*#line 448.27 "urweb.mlton.lex"*)Tokens.CONSTRAINT (pos yypos, pos yypos + size yytext)(*#line 14012.1 "urweb.mlton.lex.sml"*)
 end
| 437 => let val yytext=yymktext() in (*#line 449.28 "urweb.mlton.lex"*)Tokens.CONSTRAINTS (pos yypos, pos yypos + size yytext)(*#line 14014.1 "urweb.mlton.lex.sml"*)
 end
| 44 => ((*#line 225.27 "urweb.mlton.lex"*)str := #"'" :: !str; continue()(*#line 14016.1 "urweb.mlton.lex.sml"*)
)
| 444 => let val yytext=yymktext() in (*#line 450.27 "urweb.mlton.lex"*)Tokens.EXPORT (pos yypos, pos yypos + size yytext)(*#line 14018.1 "urweb.mlton.lex.sml"*)
 end
| 450 => let val yytext=yymktext() in (*#line 451.27 "urweb.mlton.lex"*)Tokens.TABLE (pos yypos, pos yypos + size yytext)(*#line 14020.1 "urweb.mlton.lex.sml"*)
 end
| 459 => let val yytext=yymktext() in (*#line 452.27 "urweb.mlton.lex"*)Tokens.SEQUENCE (pos yypos, pos yypos + size yytext)(*#line 14022.1 "urweb.mlton.lex.sml"*)
 end
| 464 => let val yytext=yymktext() in (*#line 453.27 "urweb.mlton.lex"*)Tokens.VIEW (pos yypos, pos yypos + size yytext)(*#line 14024.1 "urweb.mlton.lex.sml"*)
 end
| 47 => ((*#line 226.27 "urweb.mlton.lex"*)str := #"\n" :: !str; continue()(*#line 14026.1 "urweb.mlton.lex.sml"*)
)
| 470 => let val yytext=yymktext() in (*#line 454.27 "urweb.mlton.lex"*)Tokens.CLASS (pos yypos, pos yypos + size yytext)(*#line 14028.1 "urweb.mlton.lex.sml"*)
 end
| 477 => let val yytext=yymktext() in (*#line 455.27 "urweb.mlton.lex"*)Tokens.COOKIE (pos yypos, pos yypos + size yytext)(*#line 14030.1 "urweb.mlton.lex.sml"*)
 end
| 483 => let val yytext=yymktext() in (*#line 456.27 "urweb.mlton.lex"*)Tokens.STYLE (pos yypos, pos yypos + size yytext)(*#line 14032.1 "urweb.mlton.lex.sml"*)
 end
| 488 => let val yytext=yymktext() in (*#line 457.27 "urweb.mlton.lex"*)Tokens.TASK (pos yypos, pos yypos + size yytext)(*#line 14034.1 "urweb.mlton.lex.sml"*)
 end
| 495 => let val yytext=yymktext() in (*#line 458.27 "urweb.mlton.lex"*)Tokens.POLICY (pos yypos, pos yypos + size yytext)(*#line 14036.1 "urweb.mlton.lex.sml"*)
 end
| 499 => let val yytext=yymktext() in (*#line 459.27 "urweb.mlton.lex"*)Tokens.FFI (pos yypos, pos yypos + size yytext)(*#line 14038.1 "urweb.mlton.lex.sml"*)
 end
| 50 => ((*#line 227.27 "urweb.mlton.lex"*)str := #"\r" :: !str; continue()(*#line 14040.1 "urweb.mlton.lex.sml"*)
)
| 504 => let val yytext=yymktext() in (*#line 461.27 "urweb.mlton.lex"*)Tokens.TYPE (pos yypos, pos yypos + size yytext)(*#line 14042.1 "urweb.mlton.lex.sml"*)
 end
| 509 => let val yytext=yymktext() in (*#line 462.27 "urweb.mlton.lex"*)Tokens.NAME (pos yypos, pos yypos + size yytext)(*#line 14044.1 "urweb.mlton.lex.sml"*)
 end
| 514 => let val yytext=yymktext() in (*#line 463.27 "urweb.mlton.lex"*)Tokens.KUNIT (pos yypos, pos yypos + size yytext)(*#line 14046.1 "urweb.mlton.lex.sml"*)
 end
| 521 => let val yytext=yymktext() in (*#line 465.27 "urweb.mlton.lex"*)Tokens.SELECT (pos yypos, pos yypos + size yytext)(*#line 14048.1 "urweb.mlton.lex.sml"*)
 end
| 53 => ((*#line 228.27 "urweb.mlton.lex"*)str := #"\\" :: !str; continue()(*#line 14050.1 "urweb.mlton.lex.sml"*)
)
| 530 => let val yytext=yymktext() in (*#line 466.27 "urweb.mlton.lex"*)Tokens.DISTINCT (pos yypos, pos yypos + size yytext)(*#line 14052.1 "urweb.mlton.lex.sml"*)
 end
| 535 => let val yytext=yymktext() in (*#line 467.27 "urweb.mlton.lex"*)Tokens.FROM (pos yypos, pos yypos + size yytext)(*#line 14054.1 "urweb.mlton.lex.sml"*)
 end
| 538 => let val yytext=yymktext() in (*#line 468.27 "urweb.mlton.lex"*)Tokens.AS (pos yypos, pos yypos + size yytext)(*#line 14056.1 "urweb.mlton.lex.sml"*)
 end
| 544 => let val yytext=yymktext() in (*#line 469.27 "urweb.mlton.lex"*)Tokens.CWHERE (pos yypos, pos yypos + size yytext)(*#line 14058.1 "urweb.mlton.lex.sml"*)
 end
| 548 => let val yytext=yymktext() in (*#line 470.27 "urweb.mlton.lex"*)Tokens.SQL (pos yypos, pos yypos + size yytext)(*#line 14060.1 "urweb.mlton.lex.sml"*)
 end
| 554 => let val yytext=yymktext() in (*#line 471.27 "urweb.mlton.lex"*)Tokens.GROUP (pos yypos, pos yypos + size yytext)(*#line 14062.1 "urweb.mlton.lex.sml"*)
 end
| 56 => ((*#line 229.27 "urweb.mlton.lex"*)str := #"\t" :: !str; continue()(*#line 14064.1 "urweb.mlton.lex.sml"*)
)
| 560 => let val yytext=yymktext() in (*#line 472.27 "urweb.mlton.lex"*)Tokens.ORDER (pos yypos, pos yypos + size yytext)(*#line 14066.1 "urweb.mlton.lex.sml"*)
 end
| 563 => let val yytext=yymktext() in (*#line 473.27 "urweb.mlton.lex"*)Tokens.BY (pos yypos, pos yypos + size yytext)(*#line 14068.1 "urweb.mlton.lex.sml"*)
 end
| 570 => let val yytext=yymktext() in (*#line 474.27 "urweb.mlton.lex"*)Tokens.HAVING (pos yypos, pos yypos + size yytext)(*#line 14070.1 "urweb.mlton.lex.sml"*)
 end
| 576 => let val yytext=yymktext() in (*#line 475.27 "urweb.mlton.lex"*)Tokens.LIMIT (pos yypos, pos yypos + size yytext)(*#line 14072.1 "urweb.mlton.lex.sml"*)
 end
| 58 => ((*#line 230.27 "urweb.mlton.lex"*)newline yypos;
			  str := #"\n" :: !str; continue()(*#line 14075.1 "urweb.mlton.lex.sml"*)
)
| 583 => let val yytext=yymktext() in (*#line 476.27 "urweb.mlton.lex"*)Tokens.OFFSET (pos yypos, pos yypos + size yytext)(*#line 14077.1 "urweb.mlton.lex.sml"*)
 end
| 587 => let val yytext=yymktext() in (*#line 477.27 "urweb.mlton.lex"*)Tokens.ALL (pos yypos, pos yypos + size yytext)(*#line 14079.1 "urweb.mlton.lex.sml"*)
 end
| 595 => let val yytext=yymktext() in (*#line 478.27 "urweb.mlton.lex"*)Tokens.SELECT1 (pos yypos, pos yypos + size yytext)(*#line 14081.1 "urweb.mlton.lex.sml"*)
 end
| 6 => ((*#line 199.27 "urweb.mlton.lex"*)lex ()(*#line 14083.1 "urweb.mlton.lex.sml"*)
)
| 600 => let val yytext=yymktext() in (*#line 480.27 "urweb.mlton.lex"*)Tokens.JOIN (pos yypos, pos yypos + size yytext)(*#line 14085.1 "urweb.mlton.lex.sml"*)
 end
| 606 => let val yytext=yymktext() in (*#line 481.27 "urweb.mlton.lex"*)Tokens.INNER (pos yypos, pos yypos + size yytext)(*#line 14087.1 "urweb.mlton.lex.sml"*)
 end
| 612 => let val yytext=yymktext() in (*#line 482.27 "urweb.mlton.lex"*)Tokens.CROSS (pos yypos, pos yypos + size yytext)(*#line 14089.1 "urweb.mlton.lex.sml"*)
 end
| 618 => let val yytext=yymktext() in (*#line 483.27 "urweb.mlton.lex"*)Tokens.OUTER (pos yypos, pos yypos + size yytext)(*#line 14091.1 "urweb.mlton.lex.sml"*)
 end
| 623 => let val yytext=yymktext() in (*#line 484.27 "urweb.mlton.lex"*)Tokens.LEFT (pos yypos, pos yypos + size yytext)(*#line 14093.1 "urweb.mlton.lex.sml"*)
 end
| 629 => let val yytext=yymktext() in (*#line 485.27 "urweb.mlton.lex"*)Tokens.RIGHT (pos yypos, pos yypos + size yytext)(*#line 14095.1 "urweb.mlton.lex.sml"*)
 end
| 63 => let val yytext=yymktext() in (*#line 232.31 "urweb.mlton.lex"*)case StringCvt.scanString (Int.scan StringCvt.OCT)
                                                        (String.extract (yytext, 1, NONE)) of
                                  NONE => ErrorMsg.errorAt' (pos yypos, pos yypos) "Illegal string escape"
                                | SOME n => str := chr n :: !str;
                              continue()(*#line 14101.1 "urweb.mlton.lex.sml"*)
 end
| 634 => let val yytext=yymktext() in (*#line 486.27 "urweb.mlton.lex"*)Tokens.FULL (pos yypos, pos yypos + size yytext)(*#line 14103.1 "urweb.mlton.lex.sml"*)
 end
| 640 => let val yytext=yymktext() in (*#line 488.27 "urweb.mlton.lex"*)Tokens.UNION (pos yypos, pos yypos + size yytext)(*#line 14105.1 "urweb.mlton.lex.sml"*)
 end
| 650 => let val yytext=yymktext() in (*#line 489.27 "urweb.mlton.lex"*)Tokens.INTERSECT (pos yypos, pos yypos + size yytext)(*#line 14107.1 "urweb.mlton.lex.sml"*)
 end
| 657 => let val yytext=yymktext() in (*#line 490.27 "urweb.mlton.lex"*)Tokens.EXCEPT (pos yypos, pos yypos + size yytext)(*#line 14109.1 "urweb.mlton.lex.sml"*)
 end
| 662 => let val yytext=yymktext() in (*#line 492.27 "urweb.mlton.lex"*)Tokens.TRUE (pos yypos, pos yypos + size yytext)(*#line 14111.1 "urweb.mlton.lex.sml"*)
 end
| 668 => let val yytext=yymktext() in (*#line 493.27 "urweb.mlton.lex"*)Tokens.FALSE (pos yypos, pos yypos + size yytext)(*#line 14113.1 "urweb.mlton.lex.sml"*)
 end
| 672 => let val yytext=yymktext() in (*#line 494.27 "urweb.mlton.lex"*)Tokens.CAND (pos yypos, pos yypos + size yytext)(*#line 14115.1 "urweb.mlton.lex.sml"*)
 end
| 675 => let val yytext=yymktext() in (*#line 495.27 "urweb.mlton.lex"*)Tokens.OR (pos yypos, pos yypos + size yytext)(*#line 14117.1 "urweb.mlton.lex.sml"*)
 end
| 679 => let val yytext=yymktext() in (*#line 496.27 "urweb.mlton.lex"*)Tokens.NOT (pos yypos, pos yypos + size yytext)(*#line 14119.1 "urweb.mlton.lex.sml"*)
 end
| 68 => let val yytext=yymktext() in (*#line 237.31 "urweb.mlton.lex"*)case StringCvt.scanString (Int.scan StringCvt.HEX)
                                                        (String.extract (yytext, 2, NONE)) of
                                  NONE => ErrorMsg.errorAt' (pos yypos, pos yypos) "Illegal string escape"
                                | SOME n => str := chr n :: !str;
                              continue()(*#line 14125.1 "urweb.mlton.lex.sml"*)
 end
| 685 => let val yytext=yymktext() in (*#line 498.27 "urweb.mlton.lex"*)Tokens.COUNT (pos yypos, pos yypos + size yytext)(*#line 14127.1 "urweb.mlton.lex.sml"*)
 end
| 689 => let val yytext=yymktext() in (*#line 499.27 "urweb.mlton.lex"*)Tokens.AVG (pos yypos, pos yypos + size yytext)(*#line 14129.1 "urweb.mlton.lex.sml"*)
 end
| 693 => let val yytext=yymktext() in (*#line 500.27 "urweb.mlton.lex"*)Tokens.SUM (pos yypos, pos yypos + size yytext)(*#line 14131.1 "urweb.mlton.lex.sml"*)
 end
| 697 => let val yytext=yymktext() in (*#line 501.27 "urweb.mlton.lex"*)Tokens.MIN (pos yypos, pos yypos + size yytext)(*#line 14133.1 "urweb.mlton.lex.sml"*)
 end
| 701 => let val yytext=yymktext() in (*#line 502.27 "urweb.mlton.lex"*)Tokens.MAX (pos yypos, pos yypos + size yytext)(*#line 14135.1 "urweb.mlton.lex.sml"*)
 end
| 706 => let val yytext=yymktext() in (*#line 503.27 "urweb.mlton.lex"*)Tokens.RANK (pos yypos, pos yypos + size yytext)(*#line 14137.1 "urweb.mlton.lex.sml"*)
 end
| 71 => ((*#line 243.27 "urweb.mlton.lex"*)YYBEGIN CHAR; strEnder := #"\""; strStart := pos yypos; str := []; continue()(*#line 14139.1 "urweb.mlton.lex.sml"*)
)
| 716 => let val yytext=yymktext() in (*#line 504.27 "urweb.mlton.lex"*)Tokens.PARTITION (pos yypos, pos yypos + size yytext)(*#line 14141.1 "urweb.mlton.lex.sml"*)
 end
| 721 => let val yytext=yymktext() in (*#line 505.27 "urweb.mlton.lex"*)Tokens.OVER (pos yypos, pos yypos + size yytext)(*#line 14143.1 "urweb.mlton.lex.sml"*)
 end
| 724 => let val yytext=yymktext() in (*#line 507.27 "urweb.mlton.lex"*)Tokens.CIF (pos yypos, pos yypos + size yytext)(*#line 14145.1 "urweb.mlton.lex.sml"*)
 end
| 729 => let val yytext=yymktext() in (*#line 508.27 "urweb.mlton.lex"*)Tokens.CTHEN (pos yypos, pos yypos + size yytext)(*#line 14147.1 "urweb.mlton.lex.sml"*)
 end
| 73 => let val yytext=yymktext() in (*#line 245.27 "urweb.mlton.lex"*)let
                              val ch = String.sub (yytext, 0)
                          in
                              if ch = !strEnder then
                                  let
                                      val s = String.implode (List.rev (!str))
                                  in
			              YYBEGIN INITIAL;
                                      if size s = 1 then
			                  Tokens.CHAR (String.sub (s, 0), !strStart, pos yypos + 1)
                                      else
                                          (ErrorMsg.errorAt' (yypos, yypos)
                                                             "Character constant is zero or multiple characters";
                                           continue ())
                                  end
                              else
                                  (str := ch :: !str;
                                   continue ())
                          end(*#line 14167.1 "urweb.mlton.lex.sml"*)
 end
| 734 => let val yytext=yymktext() in (*#line 509.27 "urweb.mlton.lex"*)Tokens.CELSE (pos yypos, pos yypos + size yytext)(*#line 14169.1 "urweb.mlton.lex.sml"*)
 end
| 738 => let val yytext=yymktext() in (*#line 511.27 "urweb.mlton.lex"*)Tokens.ASC (pos yypos, pos yypos + size yytext)(*#line 14171.1 "urweb.mlton.lex.sml"*)
 end
| 743 => let val yytext=yymktext() in (*#line 512.27 "urweb.mlton.lex"*)Tokens.DESC (pos yypos, pos yypos + size yytext)(*#line 14173.1 "urweb.mlton.lex.sml"*)
 end
| 75 => ((*#line 265.27 "urweb.mlton.lex"*)YYBEGIN STRING; strEnder := #"\""; strStart := pos yypos; str := []; continue()(*#line 14175.1 "urweb.mlton.lex.sml"*)
)
| 750 => let val yytext=yymktext() in (*#line 513.27 "urweb.mlton.lex"*)Tokens.RANDOM (pos yypos, pos yypos + size yytext)(*#line 14177.1 "urweb.mlton.lex.sml"*)
 end
| 757 => let val yytext=yymktext() in (*#line 515.27 "urweb.mlton.lex"*)Tokens.INSERT (pos yypos, pos yypos + size yytext)(*#line 14179.1 "urweb.mlton.lex.sml"*)
 end
| 762 => let val yytext=yymktext() in (*#line 516.27 "urweb.mlton.lex"*)Tokens.INTO (pos yypos, pos yypos + size yytext)(*#line 14181.1 "urweb.mlton.lex.sml"*)
 end
| 769 => let val yytext=yymktext() in (*#line 517.27 "urweb.mlton.lex"*)Tokens.VALUES (pos yypos, pos yypos + size yytext)(*#line 14183.1 "urweb.mlton.lex.sml"*)
 end
| 77 => ((*#line 266.27 "urweb.mlton.lex"*)YYBEGIN STRING; strEnder := #"'"; strStart := pos yypos; str := []; continue()(*#line 14185.1 "urweb.mlton.lex.sml"*)
)
| 776 => let val yytext=yymktext() in (*#line 518.27 "urweb.mlton.lex"*)Tokens.UPDATE (pos yypos, pos yypos + size yytext)(*#line 14187.1 "urweb.mlton.lex.sml"*)
 end
| 780 => let val yytext=yymktext() in (*#line 519.27 "urweb.mlton.lex"*)Tokens.SET (pos yypos, pos yypos + size yytext)(*#line 14189.1 "urweb.mlton.lex.sml"*)
 end
| 787 => let val yytext=yymktext() in (*#line 520.27 "urweb.mlton.lex"*)Tokens.DELETE (pos yypos, pos yypos + size yytext)(*#line 14191.1 "urweb.mlton.lex.sml"*)
 end
| 79 => let val yytext=yymktext() in (*#line 268.27 "urweb.mlton.lex"*)let
                              val ch = String.sub (yytext, 0)
                          in
                              if ch = !strEnder then
                                  (if !xmlString then
			               (xmlString := false; YYBEGIN XMLTAG)
			           else
			               YYBEGIN INITIAL;
			           Tokens.STRING (String.implode (List.rev (!str)), !strStart, pos yypos + 1))
                              else
                                  (str := ch :: !str;
                                   continue ())
                          end(*#line 14205.1 "urweb.mlton.lex.sml"*)
 end
| 792 => let val yytext=yymktext() in (*#line 521.27 "urweb.mlton.lex"*)Tokens.NULL (pos yypos, pos yypos + size yytext)(*#line 14207.1 "urweb.mlton.lex.sml"*)
 end
| 795 => let val yytext=yymktext() in (*#line 522.27 "urweb.mlton.lex"*)Tokens.IS (pos yypos, pos yypos + size yytext)(*#line 14209.1 "urweb.mlton.lex.sml"*)
 end
| 804 => let val yytext=yymktext() in (*#line 523.27 "urweb.mlton.lex"*)Tokens.COALESCE (pos yypos, pos yypos + size yytext)(*#line 14211.1 "urweb.mlton.lex.sml"*)
 end
| 809 => let val yytext=yymktext() in (*#line 524.27 "urweb.mlton.lex"*)Tokens.LIKE (pos yypos, pos yypos + size yytext)(*#line 14213.1 "urweb.mlton.lex.sml"*)
 end
| 820 => let val yytext=yymktext() in (*#line 526.27 "urweb.mlton.lex"*)Tokens.CCONSTRAINT (pos yypos, pos yypos + size yytext)(*#line 14215.1 "urweb.mlton.lex.sml"*)
 end
| 827 => let val yytext=yymktext() in (*#line 527.27 "urweb.mlton.lex"*)Tokens.UNIQUE (pos yypos, pos yypos + size yytext)(*#line 14217.1 "urweb.mlton.lex.sml"*)
 end
| 833 => let val yytext=yymktext() in (*#line 528.27 "urweb.mlton.lex"*)Tokens.CHECK (pos yypos, pos yypos + size yytext)(*#line 14219.1 "urweb.mlton.lex.sml"*)
 end
| 841 => let val yytext=yymktext() in (*#line 529.27 "urweb.mlton.lex"*)Tokens.PRIMARY (pos yypos, pos yypos + size yytext)(*#line 14221.1 "urweb.mlton.lex.sml"*)
 end
| 849 => let val yytext=yymktext() in (*#line 530.27 "urweb.mlton.lex"*)Tokens.FOREIGN (pos yypos, pos yypos + size yytext)(*#line 14223.1 "urweb.mlton.lex.sml"*)
 end
| 85 => let val yytext=yymktext() in (*#line 282.30 "urweb.mlton.lex"*)let
			      val tag = String.substring (yytext, 1, size yytext - 3)
			  in
			      Tokens.XML_BEGIN_END (tag, yypos, yypos + size yytext)
			  end(*#line 14229.1 "urweb.mlton.lex.sml"*)
 end
| 853 => let val yytext=yymktext() in (*#line 531.27 "urweb.mlton.lex"*)Tokens.KEY (pos yypos, pos yypos + size yytext)(*#line 14231.1 "urweb.mlton.lex.sml"*)
 end
| 856 => let val yytext=yymktext() in (*#line 532.27 "urweb.mlton.lex"*)Tokens.ON (pos yypos, pos yypos + size yytext)(*#line 14233.1 "urweb.mlton.lex.sml"*)
 end
| 859 => let val yytext=yymktext() in (*#line 533.27 "urweb.mlton.lex"*)Tokens.NO (pos yypos, pos yypos + size yytext)(*#line 14235.1 "urweb.mlton.lex.sml"*)
 end
| 866 => let val yytext=yymktext() in (*#line 534.27 "urweb.mlton.lex"*)Tokens.ACTION (pos yypos, pos yypos + size yytext)(*#line 14237.1 "urweb.mlton.lex.sml"*)
 end
| 875 => let val yytext=yymktext() in (*#line 535.27 "urweb.mlton.lex"*)Tokens.RESTRICT (pos yypos, pos yypos + size yytext)(*#line 14239.1 "urweb.mlton.lex.sml"*)
 end
| 883 => let val yytext=yymktext() in (*#line 536.27 "urweb.mlton.lex"*)Tokens.CASCADE (pos yypos, pos yypos + size yytext)(*#line 14241.1 "urweb.mlton.lex.sml"*)
 end
| 894 => let val yytext=yymktext() in (*#line 537.27 "urweb.mlton.lex"*)Tokens.REFERENCES (pos yypos, pos yypos + size yytext)(*#line 14243.1 "urweb.mlton.lex.sml"*)
 end
| 9 => ((*#line 201.27 "urweb.mlton.lex"*)YYBEGIN COMMENT;
                          commentOut := (fn () => YYBEGIN INITIAL);
                          enterComment (pos yypos);
                          continue ()(*#line 14248.1 "urweb.mlton.lex.sml"*)
)
| 90 => let val yytext=yymktext() in (*#line 287.30 "urweb.mlton.lex"*)let
			      val tag = String.substring (yytext, 1, size yytext - 2)
			  in
			      YYBEGIN XML;
			      xmlTag := tag :: (!xmlTag);
			      Tokens.XML_BEGIN (tag, yypos, yypos + size yytext)
			  end(*#line 14256.1 "urweb.mlton.lex.sml"*)
 end
| 912 => let val yytext=yymktext() in (*#line 539.35 "urweb.mlton.lex"*)Tokens.CURRENT_TIMESTAMP (pos yypos, pos yypos + size yytext)(*#line 14258.1 "urweb.mlton.lex.sml"*)
 end
| 918 => let val yytext=yymktext() in (*#line 541.23 "urweb.mlton.lex"*)let val strLoc = ErrorMsg.spanToString (ErrorMsg.spanOf
                                            (pos yypos, pos yypos + size yytext))
                      in
                          Tokens.STRING (strLoc, pos yypos, pos yypos + size yytext)
                      end(*#line 14264.1 "urweb.mlton.lex.sml"*)
 end
| 921 => let val yytext=yymktext() in (*#line 547.27 "urweb.mlton.lex"*)Tokens.SYMBOL (yytext, pos yypos, pos yypos + size yytext)(*#line 14266.1 "urweb.mlton.lex.sml"*)
 end
| 924 => let val yytext=yymktext() in (*#line 548.27 "urweb.mlton.lex"*)Tokens.CSYMBOL (yytext, pos yypos, pos yypos + size yytext)(*#line 14268.1 "urweb.mlton.lex.sml"*)
 end
| 929 => let val yytext=yymktext() in (*#line 550.27 "urweb.mlton.lex"*)let val digits = String.extract (yytext, 2, NONE)
                              val v = (StringCvt.scanString (Int64.scan StringCvt.HEX) digits)
                                      handle Overflow => NONE
                          in
                          case v of
                              SOME x => Tokens.INT (x, pos yypos, pos yypos + size yytext)
                            | NONE   => (ErrorMsg.errorAt' (pos yypos, pos yypos)
                                                           ("Expected hexInt, received: " ^ yytext);
                                         continue ())
                         end(*#line 14279.1 "urweb.mlton.lex.sml"*)
 end
| 932 => let val yytext=yymktext() in (*#line 561.27 "urweb.mlton.lex"*)let val v = (Int64.fromString yytext) handle Overflow => NONE
                          in 
                          case v of
                              SOME x => Tokens.INT (x, pos yypos, pos yypos + size yytext)
                            | NONE   => (ErrorMsg.errorAt' (pos yypos, pos yypos)
                                                           ("Expected int, received: " ^ yytext);
                                         continue ())
                         end(*#line 14288.1 "urweb.mlton.lex.sml"*)
 end
| 937 => let val yytext=yymktext() in (*#line 569.27 "urweb.mlton.lex"*)case Real64.fromString yytext of
                            SOME x => Tokens.FLOAT (x, pos yypos, pos yypos + size yytext)
                          | NONE   => (ErrorMsg.errorAt' (pos yypos, pos yypos)
                                       ("Expected float, received: " ^ yytext);
                                       continue ())(*#line 14294.1 "urweb.mlton.lex.sml"*)
 end
| 939 => ((*#line 575.27 "urweb.mlton.lex"*)continue()(*#line 14296.1 "urweb.mlton.lex.sml"*)
)
| 941 => let val yytext=yymktext() in (*#line 577.27 "urweb.mlton.lex"*)ErrorMsg.errorAt' (pos yypos, pos yypos)
                                            ("illegal character: \"" ^ yytext ^ "\"");
                          continue ()(*#line 14300.1 "urweb.mlton.lex.sml"*)
 end
| 96 => let val yytext=yymktext() in (*#line 294.28 "urweb.mlton.lex"*)let
			      val id = String.substring (yytext, 2, size yytext - 3)
			  in
			      case !xmlTag of
			          id' :: rest =>
			          if id = id' then
				      (YYBEGIN INITIAL;
				       xmlTag := rest;
				       Tokens.XML_END (yypos, yypos + size yytext))
			          else
				      Tokens.END_TAG (id, yypos, yypos + size yytext)
			        | _ =>
			          Tokens.END_TAG (id, yypos, yypos + size yytext)
			  end(*#line 14315.1 "urweb.mlton.lex.sml"*)
 end
| _ => raise Internal.LexerError

		) end )

	val {fin,trans} = Vector.sub(Internal.tab, s)
	val NewAcceptingLeaves = fin::AcceptingLeaves
	in if l = !yybl then
	     if trans = #trans(Vector.sub(Internal.tab,0))
	       then action(l,NewAcceptingLeaves
) else	    let val newchars= if !yydone then "" else yyinput 1024
	    in if (size newchars)=0
		  then (yydone := true;
		        if (l=i0) then UserDeclarations.eof ()
		                  else action(l,NewAcceptingLeaves))
		  else (if i0=l then yyb := newchars
		     else yyb := substring(!yyb,i0,l-i0)^newchars;
		     yygone := YYPosInt.+(!yygone, YYPosInt.fromInt i0);
		     yybl := size (!yyb);
		     scan (s,AcceptingLeaves,l-i0,0))
	    end
	  else let val NewChar = Char.ord(CharVector.sub(!yyb,l))
		val NewState = Vector.sub(trans, NewChar)
		in if NewState=0 then action(l,NewAcceptingLeaves)
		else scan(NewState,NewAcceptingLeaves,l+1,i0)
	end
	end
(*
	val start= if substring(!yyb,!yybufpos-1,1)="\n"
then !yybegin+1 else !yybegin
*)
	in scan(!yybegin (* start *),nil,!yybufpos,!yybufpos)
    end
end
  in lex
  end
end
